#include <QPushButton>
#include <QGroupBox>
#include <QLabel>
#include <QLineEdit>
#include <QTextEdit>
#include <QMessageBox>
#include <QIntValidator>
#include <QDoubleValidator>

#include "ARsql.h"
#include "ARFinestra.h"

#include "ARServizio.h"

ARServizio::ARServizio(QWidget *parent) : QWidget(parent)
 {
 	mainWin=(ARFinestra *)parent;
 	sql = new ARsql(this);
 	infobox = new QMessageBox(tr("Informazioni"),"",QMessageBox::Question,0,0,0,this);
 	warnbox = new QMessageBox(tr("Avviso"),"",QMessageBox::Warning,0,0,0,this);
 	cornice = new QGroupBox(tr("Inserisci nuovo servizio "),this);
 	cornice->setGeometry(2,0,650,420);

  _articolo    = new QLabel(tr("Codice servizio"),this); _articolo->setGeometry   (10,  20,   80,  24);
   articolo    = new QLineEdit("",this);                 articolo->setGeometry    (100, 20,  530,  24);
  _descrizione = new QLabel(tr("Descrizione"),this);     _descrizione->setGeometry(10,  50,   80,  24);
   descrizione = new QLineEdit("",this);                 descrizione->setGeometry (100, 50,  530,  24);
  _prezzo      = new QLabel(tr("Prezzo unitario"),this); _prezzo->setGeometry     (10,  80,   80,  24);
   prezzo      = new QLineEdit("",this);                prezzo->setGeometry       (100, 80,  120,  24);
  _iva         = new QLabel(tr("IVA (%)"),this);        _iva->setGeometry         ( 10, 110,  80,  24);
   iva         = new QLineEdit(tr("20"),this);          iva->setGeometry          (100, 110, 120,  24);
  _note        = new QLabel(tr("<b>Note:</b>"),this);   _note->setGeometry        (  6, 140,  80,  24);
   note        = new QTextEdit("",this);                note->setGeometry         ( 10, 165, 620, 220);

  articolo->setMaxLength(255);
  descrizione->setMaxLength(255);
  prezzo->setValidator(new QDoubleValidator(-50000000.0,50000000.0,2,prezzo));
  iva->setValidator(new QIntValidator(0,100,iva));

 	esegui = new QPushButton(QIcon("pic/servizi_add.png"),tr("Inserisci"),this);
 	esegui->setGeometry(543,393,106,24);

  connect(esegui,SIGNAL(clicked()),this,SLOT(addServizio()));

 	infobox->setWindowModality(Qt::WindowModal);
 	warnbox->setWindowModality(Qt::WindowModal);
  setGeometry(0,61,680,440);
  azione=ARSERVIZIO_ADD;  
  hide();
 }

void ARServizio::addServizio()
 {
  QString articolo=quote(this->articolo->text());
  QString descrizione=quote(this->descrizione->text());
  QString prezzo=quote(this->prezzo->text());
  QString iva=quote(this->iva->text());
  QString note=quote(this->note->toPlainText());
  QString ts=sql->timeStamp();
  QString data=sql->data(ts);
  QString ora=sql->ora(ts);

 	if(isAzione(ARSERVIZIO_ADD))
 	 {
 	  if(!checkForm())
 	   {
 	   	if(sql->doQuery("INSERT INTO servizi VALUES('0','"+articolo+"','"+descrizione+"','"+prezzo+"','"+iva+"','"+note+"','"+data+"','"+ora+"','"+ts+"')"))
       {
        infobox->setText(tr("Nuovo servizio inserito"));
        infobox->exec();
        clearForm();
 	     }
 	   }
 	 }
 	if(isAzione(ARSERVIZIO_EDIT))
 	 {
 	  if(!checkForm())
 	   {
 	 	  if(sql->doQuery("UPDATE servizi SET articolo='"+articolo+"', descrizione='"+descrizione+"', prezzo='"+prezzo+"', iva='"+iva+"', note='"+note+"' WHERE servizioID='"+servizioID+"'"))
 	 	   {
        warnbox->setText(tr("Servizio modificato e salvato!"));
        warnbox->exec(); 
        mainWin->visServizi();
       }
     }
 	 }
 }

bool ARServizio::setForm(QString servizioID)
 {
 	MYSQL_RES *rs;
 	MYSQL_ROW row;

  rs=sql->doQueryRS("SELECT * FROM servizi WHERE servizioID='"+servizioID+"'");
  if(rs)
   {
    if(mysql_num_rows(rs)!=1) { mysql_free_result(rs); return false; }
    row=mysql_fetch_row(rs);
    articolo->setFocus();
 	  articolo->setText(row[1]);
 	  descrizione->setText(row[2]);
 	  prezzo->setText(row[3]);
 	  iva->setText(row[4]);
 	  note->setPlainText(row[5]);
 	  mysql_free_result(rs);
 	  return true;
 	 }
  return false;
 }

void ARServizio::clearForm()
 {
 	articolo->setFocus();
 	articolo->clear();
 	descrizione->clear();
 	prezzo->clear();
 	iva->setText(tr("20"));
 	note->clear();
 }

bool ARServizio::checkForm()
 {
 	if(quote(this->descrizione->text())=="")
 	 {
 	  warnbox->setText(tr("Devi inserire la descrizione del servizio"));
 	  warnbox->exec();
 	  return true;
 	 }
 	if(quote(this->prezzo->text()).toDouble(NULL) > 50000000.0 || quote(this->prezzo->text()).toDouble(NULL) < -50000000.0)
 	 {
 	  warnbox->setText(tr("Prezzo errato, devi inserire un valore\ncompreso tra 50000000.00 e -50000000.00"));
 	  warnbox->exec();
 	  return true;
 	 }
 	if(quote(this->note->toPlainText()).length()>1024)
 	 {
 	  warnbox->setText(tr("Campo note troppo lungo,\nmassimo 1000 caratteri."));
 	  warnbox->exec();
 	  return true;
 	 }
 	return false;
 }

QString ARServizio::quote(QString str, bool like)
 {
 	if(like)
 	 {
 	  str.replace('\\',"\\\\\\\\");
 	  str.replace('\'',"\\'");
 	 }
 	else
   {
 	  str.replace('\\',"\\\\");
 	  str.replace('\'',"\\'");
   }
 	return str;
 }

void ARServizio::setServizioID(QString serID) { servizioID=serID; }

void ARServizio::setAzione(int azio) { azione=azio; }

bool ARServizio::isAzione(int azio) { if(azione==azio) return true; else return false; }
