#include <QString>
#include <QDateTime>
#include <QFile>
#include <QTextStream>
#include <QMessageBox>

#include "costanti.h"

#include "ARsql.h"

ARsql::ARsql(QWidget *parent)
 {
  lastError=ARSQL_NOERR;
  lastAffected=0;
  lastID="0";
  infobox  = new QMessageBox(tr("Informazioni"),"",QMessageBox::Question,0,0,0,parent);
  warnbox  = new QMessageBox(tr("Avviso"),"",QMessageBox::Warning,0,0,0,parent);
  errorbox = new QMessageBox(tr("Errore"),"",QMessageBox::Critical,0,0,0,parent);
  infobox->setWindowModality(Qt::WindowModal);
  warnbox->setWindowModality(Qt::WindowModal);
  errorbox->setWindowModality(Qt::WindowModal);
  readConfig();
  connesso=false;
 }

bool ARsql::connetti()
 {
  lastError=ARSQL_NOERR;
  mysql_init(&mysql);
  if(!mysql_real_connect(&mysql,SERVER_ADDR,USER_LOG,USER_PWD,DB_NAME,0,NULL,0)) lastError=ARSQL_CONERR;
  if(isError(ARSQL_CONERR))
   {
    errorbox->setText(tr("Errore di connessione al database!"));
    errorbox->exec();
    connesso=false;
    return false;
   }
  connesso=true;
  return true;
 }

void ARsql::disconnetti() { connesso=false; mysql_close(&mysql); }

void ARsql::faiQuery(string qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {
 	MYSQL_RES *rs;
  MYSQL_ROW row;
  
 	lastError=ARSQL_NOERR;
  mysql_init(&mysql);
  if(!mysql_real_connect(&mysql,SERVER_ADDR,USER_LOG,USER_PWD,DB_NAME,0,NULL,0)) lastError=ARSQL_CONERR;
  else
   {
    if(mysql_query(&mysql,qry.c_str())) lastError=ARSQL_QUERYERR;
   }
  if(settaLID && lastError==ARSQL_NOERR)
   {
   	lastID="0";
    mysql_query(&mysql,"SELECT LAST_INSERT_ID()");
    rs=mysql_store_result(&mysql);
    if(rs) { row=mysql_fetch_row(rs); lastID=row[0]; mysql_free_result(rs); }
   }
  lastAffected=mysql_affected_rows(&mysql);
  mysql_close(&mysql);
 }

void ARsql::faiQuery(const char *qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {
 	MYSQL_RES *rs;
  MYSQL_ROW row;

 	lastError=ARSQL_NOERR;
  mysql_init(&mysql);
  if(!mysql_real_connect(&mysql,SERVER_ADDR,USER_LOG,USER_PWD,DB_NAME,0,NULL,0)) lastError=ARSQL_CONERR;
  else
   {
    if(mysql_query(&mysql,qry)) lastError=ARSQL_QUERYERR;
   }
  if(settaLID && lastError==ARSQL_NOERR)
   {
   	lastID="0";
    mysql_query(&mysql,"SELECT LAST_INSERT_ID()");
    rs=mysql_store_result(&mysql);
    if(rs) { row=mysql_fetch_row(rs); lastID=row[0]; mysql_free_result(rs); }
   }
  lastAffected=mysql_affected_rows(&mysql);
  mysql_close(&mysql);
 }

MYSQL_RES *ARsql::faiQueryRS(string qry)
 {
  MYSQL_RES *result;

  lastError=ARSQL_NOERR;
  mysql_init(&mysql);
  if(mysql_real_connect(&mysql,SERVER_ADDR,USER_LOG,USER_PWD,DB_NAME,0,NULL,0))
   {
    mysql_query(&mysql,qry.c_str());
    result=mysql_store_result(&mysql);
    mysql_close(&mysql);
    if(!result) lastError=ARSQL_QUERYERR;
    return result;
   }
  else { lastError=ARSQL_CONERR; mysql_close(&mysql); return NULL; }
 }

MYSQL_RES *ARsql::faiQueryRS(const char *qry)
 {
  MYSQL_RES *result;

  lastError=ARSQL_NOERR;
  mysql_init(&mysql);
  if(mysql_real_connect(&mysql,SERVER_ADDR,USER_LOG,USER_PWD,DB_NAME,0,NULL,0))
   {
    mysql_query(&mysql,qry);
    result=mysql_store_result(&mysql);
    mysql_close(&mysql);
    if(!result) lastError=ARSQL_QUERYERR;
    return result;
   }
  else { lastError=ARSQL_CONERR; mysql_close(&mysql); return NULL; }
 }

void ARsql::faiQueryPer(string qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {																								 // Si usa una connessione persistente
  MYSQL_RES *rs;
  MYSQL_ROW row;
  
  lastError=ARSQL_NOERR;
  if(!connesso) lastError=ARSQL_CONERR;
  else
   {
    if(mysql_query(&mysql,qry.c_str())) lastError=ARSQL_QUERYERR;
   }
  if(settaLID && lastError==ARSQL_NOERR)
   {
    lastID="0";
    mysql_query(&mysql,"SELECT LAST_INSERT_ID()");
    rs=mysql_store_result(&mysql);
    if(rs) { row=mysql_fetch_row(rs); lastID=row[0]; mysql_free_result(rs); }
   }
  lastAffected=mysql_affected_rows(&mysql); 
 }

void ARsql::faiQueryPer(const char *qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {																								// Si usa una connessione persistente
  MYSQL_RES *rs;
  MYSQL_ROW row;

  lastError=ARSQL_NOERR;
  if(!connesso) lastError=ARSQL_CONERR;
  else
   {
    if(mysql_query(&mysql,qry)) lastError=ARSQL_QUERYERR;
   }
  if(settaLID && lastError==ARSQL_NOERR)
   {
    lastID="0";
    mysql_query(&mysql,"SELECT LAST_INSERT_ID()");
    rs=mysql_store_result(&mysql);
    if(rs) { row=mysql_fetch_row(rs); lastID=row[0]; mysql_free_result(rs); }
   }
  lastAffected=mysql_affected_rows(&mysql);
 }

MYSQL_RES *ARsql::faiQueryRSPer(string qry) // Si usa una connessione persistente
 {
  MYSQL_RES *result;

  lastError=ARSQL_NOERR;
  if(connesso)
   {
    mysql_query(&mysql,qry.c_str());
    result=mysql_store_result(&mysql);
    if(!result) lastError=ARSQL_QUERYERR;
    return result;
   }
  else { lastError=ARSQL_CONERR; return NULL; }
 }

MYSQL_RES *ARsql::faiQueryRSPer(const char *qry)// Si usa una connessione persistente
 {
  MYSQL_RES *result;

  lastError=ARSQL_NOERR;
  if(connesso)
   {
    mysql_query(&mysql,qry);
    result=mysql_store_result(&mysql);
    if(!result) lastError=ARSQL_QUERYERR;
    return result;
   }
  else { lastError=ARSQL_CONERR; return NULL; }
 }

bool ARsql::doQuery(const char *qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {
	faiQuery(qry,settaLID);
	if(isError(ARSQL_CONERR))
 	 {
 	  errorbox->setText(tr("Errore di connessione al database!"));
 	  errorbox->exec();
 	  return false;
 	 }
 	if(isError(ARSQL_QUERYERR))
 	 {
 	 	string str,aux;
 	 	 	
 	 	str="Query errata!\n";
 	 	aux=qry;
 	 	str+=aux;
	  errorbox->setText(tr(str.c_str()));
 	  errorbox->exec();
 	  return false;
 	 }
 	return true;
 }

bool ARsql::doQuery(string qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {
	faiQuery(qry,settaLID);
	if(isError(ARSQL_CONERR))
 	 {
 	  errorbox->setText(tr("Errore di connessione al database!"));
 	  errorbox->exec();
 	  return false;
 	 }
 	if(isError(ARSQL_QUERYERR))
 	 {
	 	string str;
 	 	 	
 	 	str="Query errata!\n"+qry;
 	  errorbox->setText(tr(str.c_str()));
 	  errorbox->exec();
 	  return false;
 	 }
 	return true;
 }

bool ARsql::doQuery(QString qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {
	faiQuery(qry.toStdString(),settaLID);
	if(isError(ARSQL_CONERR))
 	 {
 	  errorbox->setText(tr("Errore di connessione al database!"));
 	  errorbox->exec();
 	  return false;
 	 }
 	if(isError(ARSQL_QUERYERR))
 	 {
 	 	QString str,aux;
 	 	 	
 	 	str="Query errata!\n";
 	 	aux=qry;
 	 	str+=aux;
	  errorbox->setText(tr(str.toStdString().c_str()));
 	  errorbox->exec();
 	  return false;
 	 }
 	return true;
 }

MYSQL_RES *ARsql::doQueryRS(const char *qry)
 {
 	MYSQL_RES *rs;

	rs=faiQueryRS(qry);
 	if(!rs)
 	 {
 	 	if(isError(ARSQL_CONERR))
 	 	 {
 	 	  errorbox->setText(tr("Errore di connessione al database!"));
 	 	  errorbox->exec();
 	 	 }
 	 	if(isError(ARSQL_QUERYERR))
 	 	 {
 	 	 	string str,aux;
 	 	 	
 	 	 	str="Query errata!\n";
 	 	 	aux=qry;
 	 	 	str+=aux;
 	 	  errorbox->setText(tr(str.c_str()));
 	 	  errorbox->exec();
 	 	 }
 	 }
 	return rs;
 }

MYSQL_RES *ARsql::doQueryRS(string qry)
 {
 	MYSQL_RES *rs;

	rs=faiQueryRS(qry);
 	if(!rs)
 	 {
 	 	if(isError(ARSQL_CONERR))
 	 	 {
 	 	  errorbox->setText(tr("Errore di connessione al database!"));
 	 	  errorbox->exec();
 	 	 }
 	 	if(isError(ARSQL_QUERYERR))
 	 	 {
	 	 	string str;
 	 	 	
 	 	 	str="Query errata!\n"+qry;
 	 	  errorbox->setText(tr(str.c_str()));
 	 	  errorbox->exec();
 	 	 }
 	 }
 	return rs;
 }

MYSQL_RES *ARsql::doQueryRS(QString qry)
 {
 	MYSQL_RES *rs;

	rs=faiQueryRS(qry.toStdString());
 	if(!rs)
 	 {
 	 	if(isError(ARSQL_CONERR))
 	 	 {
 	 	  errorbox->setText(tr("Errore di connessione al database!"));
 	 	  errorbox->exec();
 	 	 }
 	 	if(isError(ARSQL_QUERYERR))
 	 	 {
 	 	 	QString str,aux;
 	 	 	
 	 	 	str="Query errata!\n";
 	 	 	aux=qry;
 	 	 	str+=aux;
 	 	  errorbox->setText(tr(str.toStdString().c_str()));
 	 	  errorbox->exec();
 	 	 }
 	 }
 	return rs;
 }

bool ARsql::doQueryPer(const char *qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {
	faiQueryPer(qry,settaLID);
	if(isError(ARSQL_CONERR))
 	 {
 	  errorbox->setText(tr("Errore di connessione al database!"));
 	  errorbox->exec();
 	  return false;
 	 }
 	if(isError(ARSQL_QUERYERR))
 	 {
 	 	string str,aux;
 	 	 	
 	 	str="Query errata!\n";
 	 	aux=qry;
 	 	str+=aux;
	  errorbox->setText(tr(str.c_str()));
 	  errorbox->exec();
 	  return false;
 	 }
 	return true;
 }

bool ARsql::doQueryPer(string qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {
	faiQueryPer(qry,settaLID);
	if(isError(ARSQL_CONERR))
 	 {
 	  errorbox->setText(tr("Errore di connessione al database!"));
 	  errorbox->exec();
 	  return false;
 	 }
 	if(isError(ARSQL_QUERYERR))
 	 {
	 	string str;
 	 	 	
 	 	str="Query errata!\n"+qry;
 	  errorbox->setText(tr(str.c_str()));
 	  errorbox->exec();
 	  return false;
 	 }
 	return true;
 }

bool ARsql::doQueryPer(QString qry, bool settaLID) // settaLID  usato per ricavare il LAST_INSERT_ID();
 {
	faiQueryPer(qry.toStdString(),settaLID);
	if(isError(ARSQL_CONERR))
 	 {
 	  errorbox->setText(tr("Errore di connessione al database!"));
 	  errorbox->exec();
 	  return false;
 	 }
 	if(isError(ARSQL_QUERYERR))
 	 {
 	 	QString str,aux;
 	 	 	
 	 	str="Query errata!\n";
 	 	aux=qry;
 	 	str+=aux;
	  errorbox->setText(tr(str.toStdString().c_str()));
 	  errorbox->exec();
 	  return false;
 	 }
 	return true;
 }

MYSQL_RES *ARsql::doQueryRSPer(const char *qry)
 {
 	MYSQL_RES *rs;

	rs=faiQueryRSPer(qry);
 	if(!rs)
 	 {
 	 	if(isError(ARSQL_CONERR))
 	 	 {
 	 	  errorbox->setText(tr("Errore di connessione al database!"));
 	 	  errorbox->exec();
 	 	 }
 	 	if(isError(ARSQL_QUERYERR))
 	 	 {
 	 	 	string str,aux;
 	 	 	
 	 	 	str="Query errata!\n";
 	 	 	aux=qry;
 	 	 	str+=aux;
 	 	  errorbox->setText(tr(str.c_str()));
 	 	  errorbox->exec();
 	 	 }
 	 }
 	return rs;
 }

MYSQL_RES *ARsql::doQueryRSPer(string qry)
 {
 	MYSQL_RES *rs;

	rs=faiQueryRSPer(qry);
 	if(!rs)
 	 {
 	 	if(isError(ARSQL_CONERR))
 	 	 {
 	 	  errorbox->setText(tr("Errore di connessione al database!"));
 	 	  errorbox->exec();
 	 	 }
 	 	if(isError(ARSQL_QUERYERR))
 	 	 {
	 	 	string str;
 	 	 	
 	 	 	str="Query errata!\n"+qry;
 	 	  errorbox->setText(tr(str.c_str()));
 	 	  errorbox->exec();
 	 	 }
 	 }
 	return rs;
 }

MYSQL_RES *ARsql::doQueryRSPer(QString qry)
 {
 	MYSQL_RES *rs;

	rs=faiQueryRSPer(qry.toStdString());
 	if(!rs)
 	 {
 	 	if(isError(ARSQL_CONERR))
 	 	 {
 	 	  errorbox->setText(tr("Errore di connessione al database!"));
 	 	  errorbox->exec();
 	 	 }
 	 	if(isError(ARSQL_QUERYERR))
 	 	 {
 	 	 	QString str,aux;
 	 	 	
 	 	 	str="Query errata!\n";
 	 	 	aux=qry;
 	 	 	str+=aux;
 	 	  errorbox->setText(tr(str.toStdString().c_str()));
 	 	  errorbox->exec();
 	 	 }
 	 }
 	return rs;
 }

bool ARsql::bloccaPer(QString v, QString t)
 {
 	QString aux;
 	MYSQL_ROW row;
 	MYSQL_RES *rs;
 	 	
 	rs=doQueryRSPer("SELECT GET_LOCK('"+v+"',"+t+")");
 	if(rs)
 	 {
 	  row=mysql_fetch_row(rs);
 	  aux=row[0];
 	  mysql_free_result(rs);
 	 }
 	if(aux=="1") return true;
 	return false;
 }

bool ARsql::isBloccatoPer(QString v)
 {
 	QString aux;
 	MYSQL_ROW row;
 	MYSQL_RES *rs;

 	rs=doQueryRSPer("SELECT IS_FREE_LOCK('"+v+"')");
 	if(rs)
 	 {
 	  row=mysql_fetch_row(rs);
 	  aux=row[0];
 	  mysql_free_result(rs);
 	 }
 	if(aux=="1") return true;
 	return false;
 }

QString ARsql::prendiLastID() { return lastID; }

QString ARsql::prendiPwd()
 {
 	QString aux;
 	MYSQL_ROW row;
 	MYSQL_RES *rs;
 	
 	rs=doQueryRS("SELECT password FROM pref_varie");
 	if(rs)
 	 {
 	  row=mysql_fetch_row(rs);
 	  aux=row[0];
 	  mysql_free_result(rs);
 	 }
 	else aux="";
 	return aux;
 }

bool ARsql::isError(int err) { if(lastError==err) return true; else return false; }

QString ARsql::data(QString ts, bool eng)
 {
 	QString date;
 	uint sec;

  sec=ts.toUInt();
 	QDateTime *dt = new QDateTime();
 	dt->setTime_t(sec);
 	if(eng) date=dt->toString("yyyy-MM-dd");
  else    date=dt->toString("dd-MM-yyyy");
 	return date;
 }

QString ARsql::ora(QString ts)
 {
 	uint sec;

  sec=ts.toUInt();
 	QDateTime *dt = new QDateTime();
 	dt->setTime_t(sec);
 	QString time=dt->toString("hh:mm:ss");
 	return time;
 }

QString ARsql::dataTempo(QString ts)
 {
 	uint sec;

  sec=ts.toUInt();
 	QDateTime *dt = new QDateTime();
 	dt->setTime_t(sec);
 	QString date=dt->toString(Qt::ISODate);
 	return date;
 }

QString ARsql::timeStamp()
 {
 	QDateTime *dt = new QDateTime(QDateTime::currentDateTime());
 	QString ts;
 	ts.sprintf("%u",dt->toTime_t());
 	return ts;
 }

bool ARsql::isConnesso() { return connesso; }

double ARsql::getDbVersion()
 {
  QString aux;
  MYSQL_ROW row;
  MYSQL_RES *rs;

  rs=doQueryRS("SELECT ver FROM db");
  if(rs)
   {
    row=mysql_fetch_row(rs);
    aux=row[0];
    mysql_free_result(rs);
   }
  else aux="0.0";
  return aux.toDouble();
 }

QString ARsql::getPref(int p,QString tb)
 {
 	QString aux;
 	MYSQL_ROW row;
 	MYSQL_RES *rs;
 	
 	rs=doQueryRS("SELECT * FROM "+tb);
 	if(rs)
 	 {
 	  row=mysql_fetch_row(rs);
 	  aux=row[p];
 	  mysql_free_result(rs);
 	 }
 	else aux="";
 	return aux;
 }

void ARsql::readConfig()
 {
 	QString par,val;
 	QFile *fd = new QFile(CFG_FILE);

 	if(!fd->exists(CFG_FILE)) // default configuration
 	 {
 	 	fd->open(QIODevice::WriteOnly | QIODevice::Text);
 	 	QTextStream out(fd);
 	 	out << "[SERVER_ADDR]\nlocalhost\n" <<
 	 	       "[SERVER_PORT]\n3306\n" <<
 	 	       "[USER_LOG]\nroot\n" <<
 	 	       "[USER_PWD]\n\n" <<
 	 	       "[DB_NAME]\nedepol\n";
 	 	fd->close();
 	 }
 	fd->open(QIODevice::ReadOnly | QIODevice::Text);
 	QTextStream in(fd);
 	while(!in.atEnd())
 	 {
    par=in.readLine();
    val=in.readLine();
    if(par=="[SERVER_ADDR]" || par=="SERVER_ADDR") strcpy(SERVER_ADDR,val.toStdString().c_str());
    if(par=="[SERVER_PORT]" || par=="SERVER_PORT") strcpy(SERVER_PORT,val.toStdString().c_str());
    if(par=="[USER_LOG]"    || par=="USER_LOG"   ) strcpy(USER_LOG   ,val.toStdString().c_str());
    if(par=="[USER_PWD]"    || par=="USER_PWD"   ) strcpy(USER_PWD   ,val.toStdString().c_str());
    if(par=="[DB_NAME]"     || par=="DB_NAME"    ) strcpy(DB_NAME    ,val.toStdString().c_str());
   }
  fd->close();
 }

bool ARsql::testConnection()
 {
  bool test;
 	
  mysql_init(&mysql);
  if(!mysql_real_connect(&mysql,SERVER_ADDR,USER_LOG,USER_PWD,"",0,NULL,0)) test=false;
  else test=true;
  mysql_close(&mysql);
  return test;
 }

bool ARsql::testDbExist()
 {
  bool test;
 	
  mysql_init(&mysql);
  if(!mysql_real_connect(&mysql,SERVER_ADDR,USER_LOG,USER_PWD,DB_NAME,0,NULL,0)) test=false;
  else test=true;
  mysql_close(&mysql);
  return test;
 }

bool ARsql::testDbEmpty()
 {
  bool test;
  MYSQL aux_mysql;
  MYSQL_ROW row;
  MYSQL_RES *rs;
  QString aux;

  mysql_init(&aux_mysql);
  if(!mysql_real_connect(&aux_mysql,SERVER_ADDR,USER_LOG,USER_PWD,DB_NAME,0,NULL,0)) test=true;
  else
   {
   	rs=faiQueryRS("SELECT edepol from db");
   	if(!rs) { test=true; }
   	else
   	 {
  	  row=mysql_fetch_row(rs);
      aux=row[0];
      if(aux=="Edepol!") test=false; else test=true;
      mysql_free_result(rs);
   	 }
   }
  mysql_close(&aux_mysql);
  return test;
 }

bool ARsql::testDbNeedUpdate()
 {
  double v;
  QString aux;
  
  aux = EDEPOL_DB_VER; // Database version needed
  v = this->getDbVersion();
  if(v < aux.toDouble()) return true;
  else                   return false;
 }

bool ARsql::testDbBadVersion()
 {
  double v;
  QString aux;
  
  aux = EDEPOL_DB_VER;
  v = this->getDbVersion();
  if(v>aux.toDouble()) return true; // Versione db errata, la versione attuale
                                    //  maggiore di quella richiesta, per evitare errori
                                    // al database il programma deve fermarsi
  else                 return false;
 }

int ARsql::getAffected() { return lastAffected; }

QString ARsql::getServerAddr()
 {
 	QString addr;
 	
 	addr=SERVER_ADDR; return addr;
 }

QString ARsql::getServerPort()
 {
 	QString port;
 	
 	port=SERVER_PORT; return port;
 }

QString ARsql::getUserLog()
 {
 	QString log;
 	
 	log=USER_LOG; return log;
 }

QString ARsql::getUserPwd()
 {
 	QString pwd;
 	
 	pwd=USER_PWD; return pwd;
 }

QString ARsql::getDbName()
 {
 	QString name;
 	
 	name=DB_NAME; return name;
 }

void ARsql::writeConfig(QString addr, QString port, QString log, QString pwd, QString name)
 {
 	QFile *fd = new QFile(CFG_FILE);

 	fd->open(QIODevice::WriteOnly | QIODevice::Text);
 	QTextStream out(fd);
 	out << "[SERVER_ADDR]\n" << addr << "\n" <<
 	       "[SERVER_PORT]\n" << port << "\n" <<
 	       "[USER_LOG]\n"    << log  << "\n" <<
 	       "[USER_PWD]\n"    << pwd  << "\n" <<
 	       "[DB_NAME]\n"     << name << "\n";
 	fd->close();
  readConfig();
 }

void ARsql::createDb()
 {
 	lastError=ARSQL_NOERR;
  mysql_init(&mysql);
  if(!mysql_real_connect(&mysql,SERVER_ADDR,USER_LOG,USER_PWD,"",0,NULL,0)) lastError=ARSQL_CONERR;
  else
   {
   	char query[300];
   	
   	sprintf(query,"CREATE DATABASE %s",DB_NAME);
    if(mysql_query(&mysql,query)) lastError=ARSQL_QUERYERR;
   }
  mysql_close(&mysql);
 }

void ARsql::resetDb()
 {
	QFile *fd = new QFile(RESETDB_FILE);
	QString query;

 	fd->open(QIODevice::ReadOnly | QIODevice::Text);
 	QTextStream in(fd);
 	while(!in.atEnd())
 	 {
    query+=in.readLine();
    if(query.at(query.length()-1)==';') { doQuery(query); query=""; }
   }
 	fd->close();
 }

void ARsql::updateDb()
 {//TODO(da farsi a partire dalla prima versione che necessita di un aggiornamento del database)
  //double v;
  //QString aux;
  //String update_file;
  //aux = EDEPOL_DB_VER; // Database version needed
  //v = this->getDbVersion();
  //if(v < aux.toDouble()) return true;
  //if(v == 1.0)  update_file = "query/update_database_10_11.sql";//todo...
  /*QFile *fd = new QFile(update_file);
  QString query;

  fd->open(QIODevice::ReadOnly | QIODevice::Text);
  QTextStream in(fd);
  while(!in.atEnd())
   {
    query+=in.readLine();
    if(query.at(query.length()-1)==';') { doQuery(query); query=""; }
   }
  fd->close();*/
 }
