CREATE TABLE aziende
 (
  aziendaID bigint(20) unsigned primary key auto_increment,
  nome      char(255),
  indirizzo char(255),
  cap       char(5),
  citta     char(255),
  provincia char(2),
  nazione   char(255),
  tel       char(255),
  fax       char(255),
  cell      char(255),
  piva      char(255),
  cf        char(255),
  email     char(255),
  sitoweb   char(255),
  data      date,
  ora       time,
  ts        int(16) unsigned
 );

CREATE TABLE fornitori
 (
  fornitoreID bigint(20) unsigned primary key auto_increment,
  nome        char(255),
  etichetta   char(255),
  indirizzo   char(255),
  cap         char(5),
  citta       char(255),
  provincia   char(2),
  nazione     char(255),
  tel         char(255),
  fax         char(255),
  cell        char(255),
  piva        char(255),
  cf          char(255),
  banca       char(255),
  abi         char(255),
  cab         char(255),
  cin         char(255),
  cc          char(255),
  email       char(255),
  sitoweb     char(255),
  data        date,
  ora         time,
  ts          int(16) unsigned
 );

CREATE TABLE indirizzi_reso
 (
  indir_resoID bigint(20) unsigned primary key auto_increment,
  fornitoreID  bigint(20) unsigned,
  nome         char(255),
  indirizzo    char(255),
  cap          char(5),
  citta        char(255),
  provincia    char(2),
  nazione      char(255),
  tel          char(255),
  fax          char(255),
  cell         char(255),
  email        char(255),
  data         date,
  ora          time,
  ts           int(16) unsigned
 );

CREATE TABLE clienti
 (
  clienteID  bigint(20) unsigned primary key auto_increment,
  nome       char(255),
  indirizzo  char(255),
  cap        char(5),
  citta      char(255),
  provincia  char(2),
  nazione    char(255),
  tel        char(255),
  fax        char(255),
  cell       char(255),
  piva       char(255),
  cf         char(255),
  email      char(255),
  sitoweb    char(255),
  note       text,
  data       date,
  ora        time,
  ts         int(16) unsigned
 );

CREATE TABLE fatture
 (
  fatturaID    bigint(20) unsigned primary key auto_increment,
  clienteID    bigint(20) unsigned,
  tipologia    char(255),
  scontrino    char(255),
  note         text,
  data_fattura date,
  ora_fattura  time,
  ts_fattura   int(16) unsigned,
  numero       bigint(20) unsigned,
  anno         char(255),
  data         date,
  ora          time,
  ts           int(16) unsigned
 );

CREATE TABLE fatture_elementi_extra
 (
  elementoID    bigint(20) unsigned primary key auto_increment,
  fatturaID     bigint(20) unsigned,
  clienteID     bigint(20) unsigned,
  articolo      char(255),
  descrizione   char(255),
  quantita      int(16),
  prezzo        double(10,2),
  iva           int(5),
  da_cancellare int(1),
  data          date,
  ora           time,
  ts            int(16) unsigned
 );

CREATE TABLE servizi
 (
  servizioID    bigint(20) unsigned primary key auto_increment,
  articolo      char(255),
  descrizione   char(255),
  prezzo        double(10,2),
  iva           int(5),
  note          text,
  data          date,
  ora           time,
  ts            int(16) unsigned
 );

CREATE TABLE bolle
 (
  bollaID      bigint(20) unsigned primary key auto_increment,
  fornitoreID  bigint(20) unsigned,
  indir_resoID bigint(20) unsigned,
  causale      char(255),
  mezzo        char(255),
  aspetto      char(255),
  colli        char(255),
  peso_kg      char(255),
  porto        char(255),
  inizio       char(255),
  vettore1     text,
  vettore2     text,
  vettore3     text,
  note         text,
  data_bolla   date,
  ora_bolla    time,
  ts_bolla     int(16) unsigned,
  numero       bigint(20) unsigned,
  anno         char(255),
  data         date,
  ora          time,
  ts           int(16) unsigned
 );

CREATE TABLE scadenze
 (
  scadenzaID    bigint(20) unsigned primary key auto_increment,
  fornitoreID   bigint(20) unsigned,
  descrizione   char(255),
  note          text,
  stato         int(1),
  somma         double(10,2),
  data_scadenza date,
  ora_scadenza  time,
  ts_scadenza   int(16) unsigned,
  data          date,
  ora           time,
  ts            int(16) unsigned
 );

CREATE TABLE articoli
 (
  articoloID      bigint(20) unsigned primary key auto_increment,
  fornitoreID     bigint(20) unsigned,
  clienteID       bigint(20) unsigned,
  tipo_articoloID bigint(20) unsigned,
  fatturaID       bigint(20) unsigned,
  bollaID         bigint(20) unsigned,
  codice          char(255),
  codice_extra    char(255),
  descrizione     char(255),

  coloreID        bigint(20) unsigned,
  colore          char(255),
  fondoID         bigint(20) unsigned,
  fondo           char(255),
  taccoID         bigint(20) unsigned,
  tacco           char(255),
  stagioneID      bigint(20) unsigned,
  stagione        char(255),

  prezzo          double(10,2),
  prezzo_pub      double(10,2),
  prezzo_lis      double(10,2),
  iva             int(5),
  sconto          double(5,2),
  misura          char(20),
  stato           int(5),
  fatturato       int(1),
  bolla           int(1),
  data_sr         date,
  ora_sr          time,
  ts_sr           int(16),
  data_fat        date,
  ora_fat         time,
  ts_fat          int(16),
  data            date,
  ora             time,
  ts              int(16) unsigned
 );

CREATE TABLE colori
 (
  coloreID    bigint(20) unsigned primary key auto_increment,
  codice      char(255),
  descrizione char(255),
  etichetta   char(255),
  deflt       int(1),
  data        date,
  ora         time,
  ts          int(16) unsigned
 );

CREATE TABLE fondi
 (
  fondoID     bigint(20) unsigned primary key auto_increment,
  codice      char(255),
  descrizione char(255),
  etichetta   char(255),
  deflt       int(1),
  data        date,
  ora         time,
  ts          int(16) unsigned
 );

CREATE TABLE tacchi
 (
  taccoID     bigint(20) unsigned primary key auto_increment,
  codice      char(255),
  descrizione char(255),
  etichetta   char(255),
  deflt       int(1),
  data        date,
  ora         time,
  ts          int(16) unsigned
 );

CREATE TABLE stagioni
 (
  stagioneID  bigint(20) unsigned primary key auto_increment,
  codice      char(255),
  descrizione char(255),
  etichetta   char(255),
  deflt       int(1),
  data        date,
  ora         time,
  ts          int(16) unsigned
 );

CREATE TABLE tipi_articolo
 (
  tipo_articoloID bigint(20) unsigned primary key auto_increment,
  descrizione     char(255),
  _1              int(1),
  _1m             int(1),
  _2              int(1),
  _2m             int(1),
  _3              int(1),
  _3m             int(1),
  _4              int(1),
  _4m             int(1),
  _5              int(1),
  _5m             int(1),
  _6              int(1),
  _6m             int(1),
  _7              int(1),
  _7m             int(1),
  _8              int(1),
  _8m             int(1),
  _9              int(1),
  _9m             int(1),
  _10             int(1),
  _10m            int(1),
  _11             int(1),
  _11m            int(1),
  _12             int(1),
  _12m            int(1),
  _13             int(1),
  _13m            int(1),
  _14             int(1),
  _14m            int(1),
  _15             int(1),
  _15m            int(1),
  _16             int(1),
  _16m            int(1),
  _17             int(1),
  _17m            int(1),
  _18             int(1),
  _18m            int(1),
  _19             int(1),
  _19m            int(1),
  _20             int(1),
  _20m            int(1),
  _21             int(1),
  _21m            int(1),
  _22             int(1),
  _22m            int(1),
  _23             int(1),
  _23m            int(1),
  _24             int(1),
  _24m            int(1),
  _25             int(1),
  _25m            int(1),
  _26             int(1),
  _26m            int(1),
  _27             int(1),
  _27m            int(1),
  _28             int(1),
  _28m            int(1),
  _29             int(1),
  _29m            int(1),
  _30             int(1),
  _30m            int(1),
  _31             int(1),
  _31m            int(1),
  _32             int(1),
  _33             int(1),
  _34             int(1),
  _34m            int(1),
  _35             int(1),
  _35m            int(1),
  _36             int(1),
  _36m            int(1),
  _37             int(1),
  _37m            int(1),
  _38             int(1),
  _38m            int(1),
  _39             int(1),
  _39m            int(1),
  _40             int(1),
  _40m            int(1),
  _41             int(1),
  _41m            int(1),
  _42             int(1),
  _42m            int(1),
  _43             int(1),
  _43m            int(1),
  _44             int(1),
  _44m            int(1),
  _45             int(1),
  _45m            int(1),
  _46             int(1),
  _46m            int(1),
  _47             int(1),
  _47m            int(1),
  _48             int(1),
  _49             int(1),
  _50             int(1),
  _XXXS           int(1),
  _XXS            int(1),
  _XS             int(1),
  _S              int(1),
  _M              int(1),
  _L              int(1),
  _XL             int(1),
  _XXL            int(1),
  _XXXL           int(1),
  _QTA            int(1),

  colore          int(1),
  fondo           int(1),
  tacco           int(1),
  stagione        int(1),
  iva             int(5),
  sconto          double(5,2),

  data            date,
  ora             time,
  ts              int(16) unsigned
 );

CREATE TABLE cap
 (
  capID     bigint(20) unsigned primary key auto_increment,
  citta     char(255),
  cap       char(5),
  provincia char(2)
 );

INSERT INTO cap VALUES('0','A','14023','AT'),
											('0','Abano Terme Bagni','35031','PD'),
											('0','Abatemarco','84040','SA'),
											('0','Abazia di Sulmona','67030','AQ'),
											('0','Abbadia Alpina','10060','TO'),
											('0','Abbadia Cerreto','26834','LO'),
											('0','Abbadia di Montepulciano','53040','SI'),
											('0','Abbadia di Naro','61041','PU'),
											('0','Abbadia Lariana','23821','LC'),
											('0','Abbadia San Salvatore','53021','SI'),
											('0','Abbasanta','09071','OR'),
											('0','Abbateggio','65020','PE'),
											('0','Abbatesse','48012','RA'),
											('0','Abbazia','15024','AL'),
											('0','Abbazia di Fossanova','04010','LT'),
											('0','Abbiate Guazzone','21049','VA'),
											('0','Abbiategrasso','20081','MI'),
											('0','Abetina  Vallesana','23035','SO'),
											('0','Abeto','06040','PG'),
											('0','Abetone','51021','PT'),
											('0','Abriola','85010','PZ'),
											('0','Abtei','39036','BZ'),
											('0','Acate','97011','RG'),
											('0','Acaya','73020','LE'),
											('0','Accadia','71021','FG'),
											('0','Accaria','88040','CZ'),
											('0','Acceglio','12021','CN'),
											('0','Accettura','75011','MT'),
											('0','Acciano','67020','AQ'),
											('0','Acciarello','89010','RC'),
											('0','Acciaroli','84041','SA'),
											('0','Acconia','88022','CZ'),
											('0','Accorneri','14030','AT'),
											('0','Accumoli','02011','RI'),
											('0','Acerenza','85011','PZ'),
											('0','Acereto','39030','BZ'),
											('0','Acerno','84042','SA'),
											('0','Acerra','80011','NA'),
											('0','Aci Bonaccorsi','95020','CT'),
											('0','Aci Castello','95021','CT'),
											('0','Aci Catena','95022','CT'),
											('0','Aci Platani','95023','CT'),
											('0','Aci San Filippo','95020','CT'),
											('0','Aci Sant\'Antonio','95025','CT'),
											('0','Aci Trezza','95026','CT'),
											('0','Acilia','00125','RM'),
											('0','Acireale','95024','CT'),
											('0','Acireale Citt del Fanciullo','95024','CT'),
											('0','Acqua dei Corsari','90121','PA'),
											('0','Acquabona','32043','BL'),
											('0','Acquacalda','98050','ME'),
											('0','Acquacanina','62035','MC'),
											('0','Acquafondata','03040','FR'),
											('0','Acquaformosa','87010','CS'),
											('0','Acquafredda','85046','PZ'),
											('0','Acquafredda','25010','BS'),
											('0','Acqualagna','61041','PU'),
											('0','Acqualoreto','05020','TR'),
											('0','Acquamela','84080','SA'),
											('0','Acquanegra Cremonese','26020','CR'),
											('0','Acquanegra Sul Chiese','46011','MN'),
											('0','Acquapendente','01021','VT'),
											('0','Acquappesa','87020','CS'),
											('0','Acquappesa Marina','87020','CS'),
											('0','Acquaria','41025','MO'),
											('0','Acquarica del Capo','73040','LE'),
											('0','Acquarica di Lecce','73020','LE'),
											('0','Acquaro','89832','VV'),
											('0','Acquarola','84080','SA'),
											('0','Acquasanta','16010','GE'),
											('0','Acquasanta Terme','63041','AP'),
											('0','Acquaseria','22010','CO'),
											('0','Acquasparta','05021','TR'),
											('0','Acquatraversa di Formia','04023','LT'),
											('0','Acquavella','84040','SA'),
											('0','Acquavena','84040','SA'),
											('0','Acquaviva','53040','SI'),
											('0','Acquaviva','84040','SA'),
											('0','Acquaviva Collecroce','86030','CB'),
											('0','Acquaviva Delle Fonti','70021','BA'),
											('0','Acquaviva d\'Isernia','86080','IS'),
											('0','Acquaviva Marche','61043','PU'),
											('0','Acquaviva Picena','63030','AP'),
											('0','Acquaviva Platani','93010','CL'),
											('0','Acquedolci','98070','ME'),
											('0','Acqui Terme','15011','AL'),
											('0','Acquicella','95122','CT'),
											('0','Acri','87041','CS'),
											('0','Acuto','03010','FR'),
											('0','Adami','88041','CZ'),
											('0','Adegliacco','33010','UD'),
											('0','Adelfia Canneto','70010','BA'),
											('0','Adelfia Montrone','70010','BA'),
											('0','Adrano','95031','CT'),
											('0','Adrara San Martino','24060','BG'),
											('0','Adrara San Rocco','24060','BG'),
											('0','Adria','45011','RO'),
											('0','Adro','25030','BS'),
											('0','Afers','39040','BZ'),
											('0','Affi','37010','VR'),
											('0','Affile','00021','RM'),
											('0','Affori','20161','MI'),
											('0','Afing','39050','BZ'),
											('0','Afragola','80021','NA'),
											('0','Africo','89030','RC'),
											('0','Agaggio Inferiore','18010','IM'),
											('0','Agazzano','29010','PC'),
											('0','Agelli','63049','AP'),
											('0','Agello','06060','PG'),
											('0','Agenzia','61010','PU'),
											('0','Agerola','80051','NA'),
											('0','Aggius','07020','SS'),
											('0','Agira','94011','EN'),
											('0','Agliana','51031','PT'),
											('0','Agliano Terme','14041','AT'),
											('0','Agliate','20040','MI'),
											('0','Agli','10011','TO'),
											('0','Aglientu','07020','SS'),
											('0','Aglietti','13836','BI'),
											('0','Agna','35021','PD'),
											('0','Agnadello','26020','CR'),
											('0','Agnana','89040','RC'),
											('0','Agnano','56017','PI'),
											('0','Agnano','80125','NA'),
											('0','Agnedo','38059','TN'),
											('0','Agnino','54010','MS'),
											('0','Agnone','86081','IS'),
											('0','Agnone Cilento','84040','SA'),
											('0','Agnosine','25071','BS'),
											('0','Agognate','28100','NO'),
											('0','Agordo','32021','BL'),
											('0','Agosta','00020','RM'),
											('0','Agra','21010','VA'),
											('0','Agrano','28887','VB'),
											('0','Agrate Brianza','20041','MI'),
											('0','Agrate Conturbia','28010','NO'),
											('0','Agriano','06040','PG'),
											('0','Agrigento','92100','AG'),
											('0','Agromonte','85043','PZ'),
											('0','Agropoli','84043','SA'),
											('0','Agropoli Stazione','84043','SA'),
											('0','Agrustos','08020','NU'),
											('0','Agugliano','60020','AN'),
											('0','Agugliaro','36020','VI'),
											('0','Ahornach','39030','BZ'),
											('0','Ahrntal','39030','BZ'),
											('0','Aica di Fi','39050','BZ'),
											('0','Aicurzio','20040','MI'),
											('0','Aidomaggiore','09070','OR'),
											('0','Aidone','94010','EN'),
											('0','Aielli','67041','AQ'),
											('0','Aielli Stazione','67040','AQ'),
											('0','Aiello Calabro','87031','CS'),
											('0','Aiello del Friuli','33041','UD'),
											('0','Aiello del Sabato','83020','AV'),
											('0','Aieta','87020','CS'),
											('0','Ailano','81010','CE'),
											('0','Ailoche','13861','BI'),
											('0','Airasca','10060','TO'),
											('0','Airetta','28825','VB'),
											('0','Airola','82011','BN'),
											('0','Airole','18030','IM'),
											('0','Airuno','23881','LC'),
											('0','Aisone','12010','CN'),
											('0','Ala','38061','TN'),
											('0','Al dei Sardi','07020','SS'),
											('0','Ala di Stura','10070','TO'),
											('0','Alagna Lomellina','27020','PV'),
											('0','Alagna Valsesia','13021','VC'),
											('0','Alanno','65020','PE'),
											('0','Alanno Stazione','65020','PE'),
											('0','Alano di Piave','32031','BL'),
											('0','Alassio','17021','SV'),
											('0','Alatri','03011','FR'),
											('0','Alba','12051','CN'),
											('0','Alba Adriatica','64011','TE'),
											('0','Alba di Canazei','38030','TN'),
											('0','Albacina','60040','AN'),
											('0','Albagiara','09090','OR'),
											('0','Albairate','20080','MI'),
											('0','Albanella','84044','SA'),
											('0','Albanese','67039','AQ'),
											('0','Albaneto','02016','RI'),
											('0','Albano di Lucania','85010','PZ'),
											('0','Albano Laziale','00041','RM'),
											('0','Albano Sant\'Alessandro','24061','BG'),
											('0','Albano Vercellese','13030','VC'),
											('0','Albar','37010','VR'),
											('0','Albaredo','31030','TV'),
											('0','Albaredo Arnaboldi','27040','PV'),
											('0','Albaredo d\'Adige','37041','VR'),
											('0','Albaredo Per San Marco','23010','SO'),
											('0','Albareto','43051','PR'),
											('0','Albareto','41030','MO'),
											('0','Albaretto della Torre','12050','CN'),
											('0','Albaro','37050','VR'),
											('0','Albate','22100','CO'),
											('0','Albavilla','22031','CO'),
											('0','Albe','67050','AQ'),
											('0','Albenga','17031','SV'),
											('0','Albera Ligure','15060','AL'),
											('0','Alberese','58010','GR'),
											('0','Alberobello','70011','BA'),
											('0','Alberona','71031','FG'),
											('0','Alberone di Cento','44040','FE'),
											('0','Alberone di Guarda','44030','FE'),
											('0','Alberoni','30126','VE'),
											('0','Albese','22032','CO'),
											('0','Albettone','36020','VI'),
											('0','Albi','88055','CZ'),
											('0','Albiano di Trento','38041','TN'),
											('0','Albiano d\'Ivrea','10010','TO'),
											('0','Albiano Magra','54010','MS'),
											('0','Albiate','20042','MI'),
											('0','Albidona','87070','CS'),
											('0','Albignano d\'Adda','20060','MI'),
											('0','Albignasego','35020','PD'),
											('0','Albina','31018','TV'),
											('0','Albinea','42020','RE'),
											('0','Albinia','58010','GR'),
											('0','Albino','24021','BG'),
											('0','Albiolo','22070','CO'),
											('0','Albisola Capo','17011','SV'),
											('0','Albisola Superiore','17011','SV'),
											('0','Albissola Marina','17012','SV'),
											('0','Albizzate','21041','VA'),
											('0','Albo','28802','VB'),
											('0','Albonese','27020','PV'),
											('0','Albosaggia','23100','SO'),
											('0','Albugnano','14022','AT'),
											('0','Albuzzano','27010','PV'),
											('0','Alcamo','91011','TP'),
											('0','Alcara Li Fusi','98070','ME'),
											('0','Aldein','39040','BZ'),
											('0','Aldeno','38060','TN'),
											('0','Aldino','39040','BZ'),
											('0','Ales','09091','OR'),
											('0','Alessandria','15100','AL'),
											('0','Alessandria del Carretto','87070','CS'),
											('0','Alessandria della Rocca','92010','AG'),
											('0','Alessano','73031','LE'),
											('0','Alessia','84013','SA'),
											('0','Alesso','33010','UD'),
											('0','Alezio','73011','LE'),
											('0','Alfano','84040','SA'),
											('0','Alfedena','67030','AQ'),
											('0','Alfero','47020','FC'),
											('0','Alfianello','25020','BS'),
											('0','Alfiano Natta','15021','AL'),
											('0','Alfonsine','48011','RA'),
											('0','Alghero','07041','SS'),
											('0','Algua','24010','BG'),
											('0','Algund','39022','BZ'),
											('0','Al','98020','ME'),
											('0','Al Terme','98021','ME'),
											('0','Alia','90021','PA'),
											('0','Aliano','75010','MT'),
											('0','Alica','56036','PI'),
											('0','Alice Bel Colle','15010','AL'),
											('0','Alice Castello','13040','VC'),
											('0','Alice Superiore','10010','TO'),
											('0','Alicudi','98050','ME'),
											('0','Alife','81011','CE'),
											('0','Alimena','90020','PA'),
											('0','Aliminusa','90020','PA'),
											('0','Allai','09080','OR'),
											('0','Alleghe','32022','BL'),
											('0','Allegrezze','16040','GE'),
											('0','Allein','11010','AO'),
											('0','Allerona','05011','TR'),
											('0','Allerona Stazione','05010','TR'),
											('0','Alliste','73040','LE'),
											('0','Allumiere','00051','RM'),
											('0','Alluvioni Cambi','15040','AL'),
											('0','Alm','24011','BG'),
											('0','Almenno San Bartolomeo','24030','BG'),
											('0','Almenno San Salvatore','24031','BG'),
											('0','Almese','10040','TO'),
											('0','Almisano','36045','VI'),
											('0','Alonte','36045','VI'),
											('0','Alpe di Siusi','39040','BZ'),
											('0','Alpepiana','16040','GE'),
											('0','Alpette','10080','TO'),
											('0','Alpicella','17010','SV'),
											('0','Alpignano','10091','TO'),
											('0','Alpo','37060','VR'),
											('0','Alseno','29010','PC'),
											('0','Alserio','22040','CO'),
											('0','Altagnana','54030','MS'),
											('0','Altamura','70022','BA'),
											('0','Altare','17041','SV'),
											('0','Altarello','95014','CT'),
											('0','Altavilla Irpina','83011','AV'),
											('0','Altavilla Milicia','90010','PA'),
											('0','Altavilla Monferrato','15041','AL'),
											('0','Altavilla Silentina','84045','SA'),
											('0','Altavilla Vicentina','36077','VI'),
											('0','Alte di Montecchio Maggiore','36041','VI'),
											('0','Altedo','40051','BO'),
											('0','Altessano','10078','TO'),
											('0','Alteta','63025','AP'),
											('0','Altidona','63016','AP'),
											('0','Altilia','88832','KR'),
											('0','Altilia','87040','CS'),
											('0','Altino','66040','CH'),
											('0','Altipiani di Arcinazzo','00020','RM'),
											('0','Altissimo','36070','VI'),
											('0','Altivole','31030','TV'),
											('0','Alto','12070','CN'),
											('0','Altofonte','90030','PA'),
											('0','Altolia','98143','ME'),
											('0','Altomonte','87042','CS'),
											('0','Altopascio','55011','LU'),
											('0','Altrei','39040','BZ'),
											('0','Alvano','83040','AV'),
											('0','Alviano','05020','TR'),
											('0','Alvignanello','81010','CE'),
											('0','Alvignano','81012','CE'),
											('0','Alvito','03041','FR'),
											('0','Alzano Lombardo','24022','BG'),
											('0','Alzano Scrivia','15050','AL'),
											('0','Alzate Brianza','22040','CO'),
											('0','Alzo','28010','NO'),
											('0','Ama','53010','SI'),
											('0','Amalfi','84011','SA'),
											('0','Amandola','63021','AP'),
											('0','Amantea','87032','CS'),
											('0','Amantea Marina','87032','CS'),
											('0','Amaro','33020','UD'),
											('0','Amaroni','88050','CZ'),
											('0','Amaseno','03021','FR'),
											('0','Amato','88040','CZ'),
											('0','Amato di Taurianova','89020','RC'),
											('0','Amatrice','02012','RI'),
											('0','Ambivere','24030','BG'),
											('0','Amblar','38011','TN'),
											('0','Amborzasco','16040','GE'),
											('0','Ambra','52020','AR'),
											('0','Ambrogiana','50056','FI'),
											('0','Ambrogio','44031','FE'),
											('0','Ameglia','19031','SP'),
											('0','Ameglio','81035','CE'),
											('0','Amelia','05022','TR'),
											('0','Amendolara','87071','CS'),
											('0','Amendolara Marina','87070','CS'),
											('0','Ameno','28010','NO'),
											('0','Amola di Piano','40017','BO'),
											('0','Amorosi','82031','BN'),
											('0','Ampezzo','33021','UD'),
											('0','Anacapri','80071','NA'),
											('0','Anagni','03012','FR'),
											('0','Ancarano','64010','TE'),
											('0','Ancarano','06040','PG'),
											('0','Anchiano','55020','LU'),
											('0','Ancona','60100','AN'),
											('0','Anconetta','36100','VI'),
											('0','Andali','88050','CZ'),
											('0','Andalo','38010','TN'),
											('0','Andalo Valtellino','23014','SO'),
											('0','Andezeno','10020','TO'),
											('0','Andonno','12010','CN'),
											('0','Andora','17051','SV'),
											('0','Andorno Micca','13811','BI'),
											('0','Andrano','73032','LE'),
											('0','Andrate','10010','TO'),
											('0','Andreis','33080','PN'),
											('0','Andreotta di Castrolibero','87040','CS'),
											('0','Andretta','83040','AV'),
											('0','Andria','70031','BA'),
											('0','Andrian','39010','BZ'),
											('0','Andriano','39010','BZ'),
											('0','Anduins','33090','PN'),
											('0','Anela','07010','SS'),
											('0','Anfo','25070','BS'),
											('0','Angeli di Rosora','60030','AN'),
											('0','Angellara','84040','SA'),
											('0','Angera','21021','VA'),
											('0','Anghebeni di Vallarsa','38060','TN'),
											('0','Anghiari','52031','AR'),
											('0','Angiari','37050','VR'),
											('0','Angoli','88040','CZ'),
											('0','Angolo Terme','25040','BS'),
											('0','Angri','84012','SA'),
											('0','Angrogna','10060','TO'),
											('0','Anguillara Sabazia','00061','RM'),
											('0','Anguillara Veneta','35022','PD'),
											('0','Anita','44010','FE'),
											('0','Anitrella','03030','FR'),
											('0','Anna','89063','RC'),
											('0','Annicco','26021','CR'),
											('0','Annifo','06030','PG'),
											('0','Annone di Brianza','23841','LC'),
											('0','Annone Veneto','30020','VE'),
											('0','Anoia','89020','RC'),
											('0','Anoia Superiore','89020','RC'),
											('0','Anqua','53030','SI'),
											('0','Antagnod','11020','AO'),
											('0','Antegnate','24051','BG'),
											('0','Antella','50011','FI'),
											('0','Anterivo','39040','BZ'),
											('0','Anterselva','39030','BZ'),
											('0','Antey Saint Andr','11020','AO'),
											('0','Antholz','39030','BZ'),
											('0','Anticoli Corrado','00022','RM'),
											('0','Antignano','57128','LI'),
											('0','Antignano d\'Asti','14010','AT'),
											('0','Antillo','98030','ME'),
											('0','Antole','32100','BL'),
											('0','Antoliva','','VB'),
											('0','Antonelli','70041','BA'),
											('0','Antonimina','89040','RC'),
											('0','Antrodoco','02013','RI'),
											('0','Antrona Schieranco','28841','VB'),
											('0','Antronapiana','28841','VB'),
											('0','Antrosano','67050','AQ'),
											('0','Anversa degli Abruzzi','67030','AQ'),
											('0','Anzano','31012','TV'),
											('0','Anzano del Parco','22040','CO'),
											('0','Anzano di Puglia','71020','FG'),
											('0','Anzi','85010','PZ'),
											('0','Anzio','00042','RM'),
											('0','Anzola Dell\'Emilia','40011','BO'),
											('0','Anzola d\'Ossola','28877','VB'),
											('0','Anz','32032','BL'),
											('0','Aosta','11100','AO'),
											('0','Apecchio','61042','PU'),
											('0','Apice','82021','BN'),
											('0','Apiro','62021','MC'),
											('0','Apollosa','82030','BN'),
											('0','Appalto','41019','MO'),
											('0','Apparizione','16133','GE'),
											('0','Appennino','62036','MC'),
											('0','Appiano Gentile','22070','CO'),
											('0','Appiano Strada Vino','39057','BZ'),
											('0','Appignano','64030','TE'),
											('0','Appignano del Tronto','63031','AP'),
											('0','Appignano di Macerata','62010','MC'),
											('0','Aprica','23031','SO'),
											('0','Apricale','18035','IM'),
											('0','Apricena','71011','FG'),
											('0','Aprigliano','87051','CS'),
											('0','Aprilia','04011','LT'),
											('0','Aquara','84020','SA'),
											('0','Aquila di Arroscia','18020','IM'),
											('0','Aquileia','33051','UD'),
											('0','Aquilinia','34147','TS'),
											('0','Aquilonia','83041','AV'),
											('0','Aquino','03031','FR'),
											('0','Arabba','32020','BL'),
											('0','Arabona','67039','AQ'),
											('0','Aradeo','73040','LE'),
											('0','Aradolo La Bruna','12010','CN'),
											('0','Aragno','67010','AQ'),
											('0','Aragona','92021','AG'),
											('0','Aramengo','14020','AT'),
											('0','Aranova','00050','RM'),
											('0','Aras','89060','RC'),
											('0','Arba','33090','PN'),
											('0','Arbatax','08041','NU'),
											('0','Arbizzano di Valpolicella','37020','VR'),
											('0','Arborea','09092','OR'),
											('0','Arborio','13031','VC'),
											('0','Arbus','09031','CA'),
											('0','Arcade','31030','TV'),
											('0','Arcara','84013','SA'),
											('0','Arce','03032','FR'),
											('0','Arcella','83030','AV'),
											('0','Arcellasco','22036','CO'),
											('0','Arcene','24040','BG'),
											('0','Arcesaz','11022','AO'),
											('0','Arceto','42010','RE'),
											('0','Arcetri','50125','FI'),
											('0','Arcevia','60011','AN'),
											('0','Archi','66040','CH'),
											('0','Archi','89051','RC'),
											('0','Arcidosso','58031','GR'),
											('0','Arcille di Campagnatico','58050','GR'),
											('0','Arcinazzo Romano','00020','RM'),
											('0','Arcisate','21051','VA'),
											('0','Arco','38062','TN'),
											('0','Arco Felice','80078','NA'),
											('0','Arcola','19021','SP'),
											('0','Arcole','37040','VR'),
											('0','Arconate','20020','MI'),
											('0','Arcore','20043','MI'),
											('0','Arcugnano','36057','VI'),
											('0','Ardali','08040','NU'),
											('0','Ardara','07010','SS'),
											('0','Ardauli','09081','OR'),
											('0','Ardea','00040','RM'),
											('0','Ardenno','23011','SO'),
											('0','Ardenza','57128','LI'),
											('0','Ardesio','24020','BG'),
											('0','Ardore','89031','RC'),
											('0','Aremogna','67030','AQ'),
											('0','Arena','89832','VV'),
											('0','Arena Metato','56010','PI'),
											('0','Arena Po','27040','PV'),
											('0','Arenabianca','84030','SA'),
											('0','Arenzano','16011','GE'),
											('0','Arese','20020','MI'),
											('0','Arezzo','52100','AR'),
											('0','Argegno','22010','CO'),
											('0','Argelato','40050','BO'),
											('0','Argenta','44011','FE'),
											('0','Argentera','10080','TO'),
											('0','Argentera','12010','CN'),
											('0','Argentiera Nurra','07040','SS'),
											('0','Argignano','60040','AN'),
											('0','Arguello','12050','CN'),
											('0','Argusto','88060','CZ'),
											('0','Ari','66010','CH'),
											('0','Aria di Lupi','87035','CS'),
											('0','Ariano','44020','FE'),
											('0','Ariano Irpino','83031','AV'),
											('0','Ariano Irpino Stazione','83030','AV'),
											('0','Ariano nel Polesine','45012','RO'),
											('0','Ariccia','00040','RM'),
											('0','Arielli','66030','CH'),
											('0','Arienzo','81021','CE'),
											('0','Arigliano','73034','LE'),
											('0','Arigna','23030','SO'),
											('0','Arignano','10020','TO'),
											('0','Arina','32030','BL'),
											('0','Aringo','67010','AQ'),
											('0','Arischia','67011','AQ'),
											('0','Aritzo','08031','NU'),
											('0','Arizzano','28811','VB'),
											('0','Arlena di Castro','01010','VT'),
											('0','Arlesega','35035','PD'),
											('0','Arluno','20010','MI'),
											('0','Arma di Taggia','18011','IM'),
											('0','Armeno','28011','NO'),
											('0','Armento','85010','PZ'),
											('0','Armo','89061','RC'),
											('0','Armo','18026','IM'),
											('0','Armungia','09040','CA'),
											('0','Arnad','11020','AO'),
											('0','Arnara','03020','FR'),
											('0','Arnasco','17032','SV'),
											('0','Arnesano','73010','LE'),
											('0','Arola','28891','VB'),
											('0','Arona','28041','NO'),
											('0','Arosio','22060','CO'),
											('0','Arpaia','82011','BN'),
											('0','Arpaise','82010','BN'),
											('0','Arpino','03033','FR'),
											('0','Arpino','80026','NA'),
											('0','Arpinova','71010','FG'),
											('0','Arpuilles','11100','AO'),
											('0','Arqu Petrarca','35032','PD'),
											('0','Arqu Polesine','45031','RO'),
											('0','Arquata del Tronto','63043','AP'),
											('0','Arquata Scrivia','15061','AL'),
											('0','Arre di Padova','35020','PD'),
											('0','Arrone','05031','TR'),
											('0','Arsago Seprio','21010','VA'),
											('0','Arsego','35010','PD'),
											('0','Arsi','32030','BL'),
											('0','Arsiero','36011','VI'),
											('0','Arsita','64031','TE'),
											('0','Arsoli','00023','RM'),
											('0','Arta Terme','33022','UD'),
											('0','Artegna','33011','UD'),
											('0','Arten','32030','BL'),
											('0','Artena','00031','RM'),
											('0','Artimino','59015','PO'),
											('0','Artogne','25040','BS'),
											('0','Arvier','11011','AO'),
											('0','Arzachena','07021','SS'),
											('0','Arzago d\'Adda','24040','BG'),
											('0','Arzana','08040','NU'),
											('0','Arzano','80022','NA'),
											('0','Arzene','33098','PN'),
											('0','Arzeno d\'Oneglia','18022','IM'),
											('0','Arzergrande','35020','PD'),
											('0','Arzignano','36071','VI'),
											('0','Arzona','89841','VV'),
											('0','Ascea','84046','SA'),
											('0','Ascensione','48022','RA'),
											('0','Asciano','53041','SI'),
											('0','Asciano','56017','PI'),
											('0','Ascoli Piceno','63100','AP'),
											('0','Ascoli Satriano','71022','FG'),
											('0','Ascrea','02020','RI'),
											('0','Asiago','36012','VI'),
											('0','Asigliano Veneto','36020','VI'),
											('0','Asigliano Vercellese','13032','VC'),
											('0','Asinara Cala d\'Oliva','07042','SS'),
											('0','Asinara Lazzaretto','','SS'),
											('0','Asnago di Cant','22063','CO'),
											('0','Asola','46041','MN'),
											('0','Asolo','31011','TV'),
											('0','Asparetto','37050','VR'),
											('0','Aspio Terme','60021','AN'),
											('0','Aspra','90010','PA'),
											('0','Assago','20090','MI'),
											('0','Assemini','09032','CA'),
											('0','Assergi','67010','AQ'),
											('0','Assisi','06081','PG'),
											('0','Assisi Santuario','06082','PG'),
											('0','Asso','22033','CO'),
											('0','Assolo','09080','OR'),
											('0','Assoro','94010','EN'),
											('0','Asta Nell\'Emilia','42030','RE'),
											('0','Asti','14100','AT'),
											('0','Asuni','09080','OR'),
											('0','Ateleta','67030','AQ'),
											('0','Atella','85020','PZ'),
											('0','Atena Lucana','84030','SA'),
											('0','Atena Lucana Scalo','84030','SA'),
											('0','Aterrana','83026','AV'),
											('0','Atessa','66041','CH'),
											('0','Atina','03042','FR'),
											('0','Atina Inferiore','03042','FR'),
											('0','Atrani','84010','SA'),
											('0','Atri','64032','TE'),
											('0','Atripalda','83042','AV'),
											('0','Attiggio','60040','AN'),
											('0','Attigliano','05012','TR'),
											('0','Attimis','33040','UD'),
											('0','Atzara','08030','NU'),
											('0','Atzwang','39040','BZ'),
											('0','Auditore','61020','PU'),
											('0','Auer','39040','BZ'),
											('0','Augusta','96011','SR'),
											('0','Auletta','84031','SA'),
											('0','Aulla','54011','MS'),
											('0','Auna di Sopra','39050','BZ'),
											('0','Auna Inferiore','39050','BZ'),
											('0','Aurano','28812','VB'),
											('0','Aurelia di Civitavecchia','00050','RM'),
											('0','Aurigo','18021','IM'),
											('0','Aurisina','34011','TS'),
											('0','Auronzo di Cadore','32041','BL'),
											('0','Ausonia','03040','FR'),
											('0','Austis','08030','NU'),
											('0','Autostrada A1 Area di Servizio"Feronia"','00065','RM'),
											('0','Avacelli','60040','AN'),
											('0','Avaglio','51010','PT'),
											('0','Avane','56019','PI'),
											('0','Ave Gratia Plena','82030','BN'),
											('0','Avegno','16030','GE'),
											('0','Avelengo','39010','BZ'),
											('0','Avella','83021','AV'),
											('0','Avellino','83100','AV'),
											('0','Avena','52014','AR'),
											('0','Avenale','62011','MC'),
											('0','Avenza','54031','MS'),
											('0','Averara','24010','BG'),
											('0','Aversa','81031','CE'),
											('0','Avesa','37127','VR'),
											('0','Avetrana','74020','TA'),
											('0','Avezzano','67051','AQ'),
											('0','Avezzano e Sorbello','81030','CE'),
											('0','Aviano','33081','PN'),
											('0','Aviatico','24020','BG'),
											('0','Avigliana','10051','TO'),
											('0','Avigliano','85021','PZ'),
											('0','Avigliano Scalo','85020','PZ'),
											('0','Avigliano Umbro','05020','TR'),
											('0','Avigna','39050','BZ'),
											('0','Avilla','33030','UD'),
											('0','Avio','38063','TN'),
											('0','Avise','11010','AO'),
											('0','Avola','96012','SR'),
											('0','Avolasca','15050','AL'),
											('0','Avoscan','32020','BL'),
											('0','Ayas','11020','AO'),
											('0','Aymavilles','11010','AO'),
											('0','Azeglio','10010','TO'),
											('0','Azzanello','26010','CR'),
											('0','Azzano','55040','LU'),
											('0','Azzano d\'Asti','14030','AT'),
											('0','Azzano Decimo','33082','PN'),
											('0','Azzano Mella','25020','BS'),
											('0','Azzano San Paolo','24052','BG'),
											('0','Azzate','21022','VA'),
											('0','Azzinano','64040','TE'),
											('0','Azzio','21030','VA'),
											('0','Azzone','24020','BG'),
											('0','Bacchereto','59015','PO'),
											('0','Baccinello','58050','GR'),
											('0','Bacciolino','47022','FC'),
											('0','Bacedasco Sotto','29010','PC'),
											('0','Baceno','28861','VB'),
											('0','Bacoli','80070','NA'),
											('0','Bacu Abis','09010','CA'),
											('0','Badalucco','18010','IM'),
											('0','Badesi','07030','SS'),
											('0','Badesse','53035','SI'),
											('0','Badi','40030','BO'),
											('0','Badia','39036','BZ'),
											('0','Badia','89844','VV'),
											('0','Badia a Ripoli','50126','FI'),
											('0','Badia a Settimo','50010','FI'),
											('0','Badia Agnano','52020','AR'),
											('0','Badia Al Pino','52041','AR'),
											('0','Badia Calavena','37030','VR'),
											('0','Badia Cantignano','55060','LU'),
											('0','Badia di Cava De\' Tirreni','84010','SA'),
											('0','Badia Pavese','27010','PV'),
											('0','Badia Polesine','45021','RO'),
											('0','Badia Pozzeveri','55010','LU'),
											('0','Badia Prataglia','52010','AR'),
											('0','Badia Tedalda','52032','AR'),
											('0','Badile','20082','MI'),
											('0','Badino','04019','LT'),
											('0','Badiola','06070','PG'),
											('0','Badolato','88060','CZ'),
											('0','Badolato Marina','88060','CZ'),
											('0','Badualga','08020','NU'),
											('0','Bafia','98050','ME'),
											('0','Bagaladi','89060','RC'),
											('0','Baganzola','43031','PR'),
											('0','Bagazzano','41015','MO'),
											('0','Baggio','20152','MI'),
											('0','Baggiovara','41100','MO'),
											('0','Bagheria','90011','PA'),
											('0','Bagnacavallo','48012','RA'),
											('0','Bagnaia','01031','VT'),
											('0','Bagnaia','06071','PG'),
											('0','Bagnara','82010','BN'),
											('0','Bagnara Calabra','89011','RC'),
											('0','Bagnara di Romagna','48010','RA'),
											('0','Bagnaria','27050','PV'),
											('0','Bagnaria Arsa','33050','UD'),
											('0','Bagnarola','33079','PN'),
											('0','Bagnarola','40054','BO'),
											('0','Bagnarola','47040','FC'),
											('0','Bagnasco','12071','CN'),
											('0','Bagnatica','24060','BG'),
											('0','Bagnaturo','67030','AQ'),
											('0','Bagnella','28887','VB'),
											('0','Bagni di Comano','38077','TN'),
											('0','Bagni di Contursi','84020','SA'),
											('0','Bagni di Lucca Ponte','55021','LU'),
											('0','Bagni di Lucca Villa','55022','LU'),
											('0','Bagni di San Filippo','53020','SI'),
											('0','Bagni di Tivoli','00011','RM'),
											('0','Bagni di Vinadio','12010','CN'),
											('0','Bagni Nuovi di Bormio','23032','SO'),
											('0','Bagno','67042','AQ'),
											('0','Bagno','42048','RE'),
											('0','Bagno a Ripoli','50012','FI'),
											('0','Bagno di Gavorrano','58021','GR'),
											('0','Bagno di Romagna','47021','FC'),
											('0','Bagno Vignoni','53027','SI'),
											('0','Bagnoli','82019','BN'),
											('0','Bagnoli','80124','NA'),
											('0','Bagnoli','58031','GR'),
											('0','Bagnoli del Trigno','86091','IS'),
											('0','Bagnoli della Rosandra','34018','TS'),
											('0','Bagnoli di Sopra','35023','PD'),
											('0','Bagnoli Irpino','83043','AV'),
											('0','Bagnolo','58030','GR'),
											('0','Bagnolo Cremasco','26010','CR'),
											('0','Bagnolo del Salento','73020','LE'),
											('0','Bagnolo di Lonigo','36045','VI'),
											('0','Bagnolo di Po','45022','RO'),
											('0','Bagnolo in Piano','42011','RE'),
											('0','Bagnolo Mella','25021','BS'),
											('0','Bagnolo Piemonte','12031','CN'),
											('0','Bagnolo San Vito','46031','MN'),
											('0','Bagnone','54021','MS'),
											('0','Bagnore','58032','GR'),
											('0','Bagnoregio','01022','VT'),
											('0','Bagolino','25072','BS'),
											('0','Baia','80070','NA'),
											('0','Baia d\'Argento','04016','LT'),
											('0','Baia del Re','29100','PC'),
											('0','Baia Domizia','81030','CE'),
											('0','Baia e Latina','81010','CE'),
											('0','Baia Sardinia','07020','SS'),
											('0','Baiano','83022','AV'),
											('0','Baiano di Spoleto','06040','PG'),
											('0','Baiardo','18031','IM'),
											('0','Baio Dora','10010','TO'),
											('0','Bairo','10010','TO'),
											('0','Baiso','42031','RE'),
											('0','Balangero','10070','TO'),
											('0','Balata di Baida','91010','TP'),
											('0','Baldaria','37044','VR'),
											('0','Baldasseria','33100','UD'),
											('0','Baldichieri','14011','AT'),
											('0','Baldissero Canavese','10080','TO'),
											('0','Baldissero d\'Alba','12040','CN'),
											('0','Baldissero Torinese','10020','TO'),
											('0','Balestrate','90041','PA'),
											('0','Balestrino','17020','SV'),
											('0','Ballabio','23811','LC'),
											('0','Ballao','09040','CA'),
											('0','Ballata','91010','TP'),
											('0','Ballino','38075','TN'),
											('0','Balma Biellese','13812','BI'),
											('0','Balme','10070','TO'),
											('0','Balmuccia','13020','VC'),
											('0','Balocco','13040','VC'),
											('0','Balossa Bigli','27039','PV'),
											('0','Balsorano','67052','AQ'),
											('0','Balvano','85050','PZ'),
											('0','Balze','47020','FC'),
											('0','Balzola','15031','AL'),
											('0','Banari','07040','SS'),
											('0','Bancali','07040','SS'),
											('0','Banchette','10010','TO'),
											('0','Banco','38010','TN'),
											('0','Bandino','50126','FI'),
											('0','Bandita','15070','AL'),
											('0','Bandito','12040','CN'),
											('0','Bando','44010','FE'),
											('0','Bannia','33080','PN'),
											('0','Bannio Anzino','28871','VB'),
											('0','Banzano di Montoro Superiore','83020','AV'),
											('0','Banzena','52010','AR'),
											('0','Banzi','85010','PZ'),
											('0','Baone','35030','PD'),
											('0','Baradili','09090','OR'),
											('0','Baragazza','40035','BO'),
											('0','Baraggia','21059','VA'),
											('0','Baraggia','28019','NO'),
											('0','Baragiano','85050','PZ'),
											('0','Baragiano Scalo','85050','PZ'),
											('0','Baranello','86011','CB'),
											('0','Barano d\'Ischia','80070','NA'),
											('0','Baranzate','20021','MI'),
											('0','Barasso','21020','VA'),
											('0','Baratili San Pietro','09070','OR'),
											('0','Barazzetto','13900','BI'),
											('0','Barbaiana','20020','MI'),
											('0','Barbalaconi','89866','VV'),
											('0','Barbania','10070','TO'),
											('0','Barbara','60010','AN'),
											('0','Barbarano','25087','BS'),
											('0','Barbarano del Capo','73040','LE'),
											('0','Barbarano Romano','01010','VT'),
											('0','Barbarano Vicentino','36021','VI'),
											('0','Barbarasco','54012','MS'),
											('0','Barbaresco','12050','CN'),
											('0','Barbariga','25030','BS'),
											('0','Barbasso','46030','MN'),
											('0','Barbata','24040','BG'),
											('0','Barberino di Mugello','50031','FI'),
											('0','Barberino Val d\'Elsa','50021','FI'),
											('0','Barbian','39040','BZ'),
											('0','Barbianello','27041','PV'),
											('0','Barbiano','39040','BZ'),
											('0','Barbiano','48010','RA'),
											('0','Barbisano','31053','TV'),
											('0','Barbona','35040','PD'),
											('0','Barbuglio','45026','RO'),
											('0','Barcarola','36040','VI'),
											('0','Barcellona Pozzo di Gotto','98051','ME'),
											('0','Barchi','61040','PU'),
											('0','Barchi di Asola','46041','MN'),
											('0','Barcis','33080','PN'),
											('0','Barco','42020','RE'),
											('0','Bard','11020','AO'),
											('0','Bardalone','51022','PT'),
											('0','Bardello','21020','VA'),
											('0','Bardi','43032','PR'),
											('0','Bardineto','17057','SV'),
											('0','Bardino Nuovo','17020','SV'),
											('0','Bardino Vecchio','17020','SV'),
											('0','Bardolino','37011','VR'),
											('0','Bardonecchia','','TO'),
											('0','Bareggio','20010','MI'),
											('0','Barengo','28010','NO'),
											('0','Baressa','09090','OR'),
											('0','Barete','67010','AQ'),
											('0','Barga','55051','LU'),
											('0','Bargagli','16021','GE'),
											('0','Barge','12032','CN'),
											('0','Barghe','25070','BS'),
											('0','Bargi','40032','BO'),
											('0','Bargone','16030','GE'),
											('0','Bargone','43030','PR'),
											('0','Bari','70100','BA'),
											('0','Bari','70121','BA'),
											('0','Bari','70122','BA'),
											('0','Bari Sardo','08042','NU'),
											('0','Bariano','24050','BG'),
											('0','Baricella','40052','BO'),
											('0','Baricetta','45010','RO'),
											('0','Barigazzo','41024','MO'),
											('0','Barile','85022','PZ'),
											('0','Barisano','47010','FC'),
											('0','Barisciano','67021','AQ'),
											('0','Barlassina','20030','MI'),
											('0','Barletta','70051','BA'),
											('0','Barme','11020','AO'),
											('0','Barni','22030','CO'),
											('0','Barolo','12060','CN'),
											('0','Barona','20143','MI'),
											('0','Barone Canavese','10010','TO'),
											('0','Baronissi','84081','SA'),
											('0','Barra','80147','NA'),
											('0','Barracca','98020','ME'),
											('0','Barrafranca','94012','EN'),
											('0','Barrali','09040','CA'),
											('0','Barrea','67030','AQ'),
											('0','Barriera del Bosco','95125','CT'),
											('0','Barritteri','89010','RC'),
											('0','Baruccana','20030','MI'),
											('0','Barumini','09021','CA'),
											('0','Barzago','23890','LC'),
											('0','Barzana','24030','BG'),
											('0','Barzaniga','26010','CR'),
											('0','Barzan','23891','LC'),
											('0','Barzio','23816','LC'),
											('0','Basaldella','33030','UD'),
											('0','Basaluzzo','15060','AL'),
											('0','Basati','55040','LU'),
											('0','Bascap','27010','PV'),
											('0','Baschi','05023','TR'),
											('0','Basciano','64030','TE'),
											('0','Baselga di Pin','38042','TN'),
											('0','Baselga di Vezzano','38070','TN'),
											('0','Baselicaduce','29017','PC'),
											('0','Baselice','82020','BN'),
											('0','Basella','24050','BG'),
											('0','Basiano','20060','MI'),
											('0','Basic','98060','ME'),
											('0','Basiglio','20080','MI'),
											('0','Basiliano','33031','UD'),
											('0','Basilicagoiano','43020','PR'),
											('0','Basilicanova','43030','PR'),
											('0','Basovizza','34012','TS'),
											('0','Bassa','50050','FI'),
											('0','Bassacutena','07020','SS'),
											('0','Bassano Bresciano','25020','BS'),
											('0','Bassano del Grappa','36061','VI'),
											('0','Bassano in Teverina','01030','VT'),
											('0','Bassano Romano','01030','VT'),
											('0','Bassiano','04010','LT'),
											('0','Bassignana','15042','AL'),
											('0','Bastardo','06030','PG'),
											('0','Bastia','17030','SV'),
											('0','Bastia di Rovolon','35030','PD'),
											('0','Bastia Mondov','12060','CN'),
											('0','Bastia Umbra','06083','PG'),
											('0','Bastida De\' Dossi','27050','PV'),
											('0','Bastida Pancarana','27050','PV'),
											('0','Bastiglia','41030','MO'),
											('0','Bastremoli','19020','SP'),
											('0','Batignano','58041','GR'),
											('0','Battaglia','84030','SA'),
											('0','Battaglia','91012','TP'),
											('0','Battaglia Terme','35041','PD'),
											('0','Battiferro','05100','TR'),
											('0','Battifollo','12070','CN'),
											('0','Battipaglia','84091','SA'),
											('0','Battuda','27020','PV'),
											('0','Baucina','90020','PA'),
											('0','Baudenasca','10060','TO'),
											('0','Bauladu','09070','OR'),
											('0','Baunei','08040','NU'),
											('0','Baura','44032','FE'),
											('0','Bavari','16133','GE'),
											('0','Bavaria','31040','TV'),
											('0','Baveno','28831','VB'),
											('0','Bazzana','14046','AT'),
											('0','Bazzano','40053','BO'),
											('0','Bazzano','67010','AQ'),
											('0','Bazzano Inferiore','06049','PG'),
											('0','Bazzano Parmense','43020','PR'),
											('0','Beano','33030','UD'),
											('0','Beaulard','10050','TO'),
											('0','Becchi','14022','AT'),
											('0','Bedero Valcuvia','21039','VA'),
											('0','Bedizzano','54032','MS'),
											('0','Bedizzole','25081','BS'),
											('0','Bedollo','38043','TN'),
											('0','Bedonia','43041','PR'),
											('0','Bedulita','24030','BG'),
											('0','Beduzzo','43020','PR'),
											('0','Bee','28813','VB'),
											('0','Beffi','67020','AQ'),
											('0','Begliano','34075','GO'),
											('0','Begosso','37040','VR'),
											('0','Beinasco','10092','TO'),
											('0','Beinette','12081','CN'),
											('0','Belcastro','88050','CZ'),
											('0','Belfiore','06030','PG'),
											('0','Belfiore d\'Adige','37050','VR'),
											('0','Belforte','46010','MN'),
											('0','Belforte','06047','PG'),
											('0','Belforte','53030','SI'),
											('0','Belforte All\'Isauro','61026','PU'),
											('0','Belforte del Chienti','62020','MC'),
											('0','Belforte Monferrato','15070','AL'),
											('0','Belgioioso','27011','PV'),
											('0','Belgirate','28832','VB'),
											('0','Bella','85051','PZ'),
											('0','Bella di Lamezia Terme','88046','CZ'),
											('0','Bellagio','22021','CO'),
											('0','Bellaguarda','46030','MN'),
											('0','Bellamonte','38037','TN'),
											('0','Bellano','23822','LC'),
											('0','Bellante','64020','TE'),
											('0','Bellantone','89020','RC'),
											('0','Bellaria','47814','RN'),
											('0','Bellariva','47900','RN'),
											('0','Bellavista','80052','NA'),
											('0','Bellegra','00030','RM'),
											('0','Bellino','12020','CN'),
											('0','Bellinzago Lombardo','20060','MI'),
											('0','Bellinzago Novarese','28043','NO'),
											('0','Bellisio Solfare','61045','PU'),
											('0','Bellizzi','84092','SA'),
											('0','Bellizzi Irpino','83020','AV'),
											('0','Bellocchi','61030','PU'),
											('0','Bellocozzo','97010','RG'),
											('0','Bellombra','45010','RO'),
											('0','Bellona','81041','CE'),
											('0','Bellosguardo','84020','SA'),
											('0','Belluno','32100','BL'),
											('0','Belluno Veronese','37020','VR'),
											('0','Bellusco','20040','MI'),
											('0','Belmonte Calabro','87033','CS'),
											('0','Belmonte Calabro Marina','87030','CS'),
											('0','Belmonte Castello','03040','FR'),
											('0','Belmonte del Sannio','86080','IS'),
											('0','Belmonte in Sabina','02020','RI'),
											('0','Belmonte Mezzagno','90031','PA'),
											('0','Belmonte Piceno','63029','AP'),
											('0','Belpasso','95032','CT'),
											('0','Belricetto','48010','RA'),
											('0','Belsito','87030','CS'),
											('0','Beltiglio di Ceppaloni','82010','BN'),
											('0','Belvedere','36056','VI'),
											('0','Belvedere Delle Langhe','12060','CN'),
											('0','Belvedere di Aquileia','33050','UD'),
											('0','Belvedere di Battipaglia','84090','SA'),
											('0','Belvedere di Siracusa','96010','SR'),
											('0','Belvedere Fogliense','61010','PU'),
											('0','Belvedere Marittimo','87021','CS'),
											('0','Belvedere Ostrense','60030','AN'),
											('0','Belvedere Spinello','88824','KR'),
											('0','Belveglio','14047','AT'),
											('0','Belv','08030','NU'),
											('0','Bema','23010','SO'),
											('0','Benabbio','55022','LU'),
											('0','Bene Lario','22010','CO'),
											('0','Bene Vagienna','12041','CN'),
											('0','Benedello','41026','MO'),
											('0','Benestare','89030','RC'),
											('0','Benetutti','07010','SS'),
											('0','Benevello','12050','CN'),
											('0','Benevento','82100','BN'),
											('0','Benna','13871','BI'),
											('0','Bentivoglio','40010','BO'),
											('0','Berardinone','71032','FG'),
											('0','Berbenno','24030','BG'),
											('0','Berbenno di Valtellina','23010','SO'),
											('0','Berceto','43042','PR'),
											('0','Berchida','08020','NU'),
											('0','Berchidda','07022','SS'),
											('0','Berchiddeddu','07020','SS'),
											('0','Beregazzo Con Figliaro','22070','CO'),
											('0','Bereguardo','27021','PV'),
											('0','Bergamasco','15022','AL'),
											('0','Bergamo','24100','BG'),
											('0','Bergantino','45032','RO'),
											('0','Bergeggi','17028','SV'),
											('0','Bergolo','12074','CN'),
											('0','Bergotto','43042','PR'),
											('0','Berlingo','25030','BS'),
											('0','Bernalda','75012','MT'),
											('0','Bernareggio','20044','MI'),
											('0','Bernate','21020','VA'),
											('0','Bernate Ticino','20010','MI'),
											('0','Bernezzo','12010','CN'),
											('0','Beroide','06040','PG'),
											('0','Berra','44033','FE'),
											('0','Berruiles','08020','NU'),
											('0','Bersezio','12010','CN'),
											('0','Bersone','38085','TN'),
											('0','Bertalia','40131','BO'),
											('0','Bertigaro','16040','GE'),
											('0','Bertinoro','47032','FC'),
											('0','Bertiolo','33032','UD'),
											('0','Bertocchi','41055','MO'),
											('0','Bertolla Barca','10156','TO'),
											('0','Bertonico','26821','LO'),
											('0','Bertorella','43050','PR'),
											('0','Berzano di Tortona','15050','AL'),
											('0','Berzano San Pietro','14020','AT'),
											('0','Berzo Demo','25040','BS'),
											('0','Berzo Inferiore','25040','BS'),
											('0','Berzo San Fermo','24060','BG'),
											('0','Bes','32100','BL'),
											('0','Besagno','38065','TN'),
											('0','Besana in Brianza','20045','MI'),
											('0','Besano','21050','VA'),
											('0','Besate','20080','MI'),
											('0','Besenello','38060','TN'),
											('0','Besenzone','29010','PC'),
											('0','Besnate','21010','VA'),
											('0','Besozzo','21023','VA'),
											('0','Bessica','31030','TV'),
											('0','Bessude','07040','SS'),
											('0','Bette','23022','SO'),
											('0','Bettola','29021','PC'),
											('0','Bettole di Buffalora','25129','BS'),
											('0','Bettole Sesia','13011','VC'),
											('0','Bettolle','53040','SI'),
											('0','Bettona','06084','PG'),
											('0','Beura','28851','VB'),
											('0','Beura Cardezza','28851','VB'),
											('0','Bevagna','06031','PG'),
											('0','Bevera','18039','IM'),
											('0','Beverate','23883','LC'),
											('0','Beverino','19020','SP'),
											('0','Bevilacqua','37040','VR'),
											('0','Bezzecca','38060','TN'),
											('0','Biacesa di Ledro','38060','TN'),
											('0','Biadene','31044','TV'),
											('0','Biana','29020','PC'),
											('0','Biancade','31056','TV'),
											('0','Biancareddu','07040','SS'),
											('0','Biancavilla','95033','CT'),
											('0','Bianchi','87050','CS'),
											('0','Bianchini','80059','NA'),
											('0','Bianco','89032','RC'),
											('0','Bianconese','43010','PR'),
											('0','Biandrate','28061','NO'),
											('0','Biandronno','21024','VA'),
											('0','Bianzano','24060','BG'),
											('0','Bianz','13041','VC'),
											('0','Bianzone','23030','SO'),
											('0','Biassa','19133','SP'),
											('0','Biassono','20046','MI'),
											('0','Bibano','31010','TV'),
											('0','Bibbiano','42021','RE'),
											('0','Bibbiena','52011','AR'),
											('0','Bibbiena Stazione','52012','AR'),
											('0','Bibbona','57020','LI'),
											('0','Bibiana','10060','TO'),
											('0','Bibione','30020','VE'),
											('0','Bibione Pineda','30020','VE'),
											('0','Bibola','54011','MS'),
											('0','Biccari','71032','FG'),
											('0','Bicinicco','33050','UD'),
											('0','Bicocca di Novara','28100','NO'),
											('0','Bidon','09080','OR'),
											('0','Biella','13900','BI'),
											('0','Bienate','20020','MI'),
											('0','Bienno','25040','BS'),
											('0','Bieno','','VB'),
											('0','Bieno','38050','TN'),
											('0','Bientina','56031','PI'),
											('0','Biforco','52010','AR'),
											('0','Bigarello','46030','MN'),
											('0','Bigliolo','54010','MS'),
											('0','Bigolino','31030','TV'),
											('0','Binago','22070','CO'),
											('0','Binasco','20082','MI'),
											('0','Binda','28838','VB'),
											('0','Bindo','23813','LC'),
											('0','Binetto','70020','BA'),
											('0','Binzago','20031','MI'),
											('0','Bioglio','13841','BI'),
											('0','Bionaz','11010','AO'),
											('0','Bione','25070','BS'),
											('0','Birchabruck','39050','BZ'),
											('0','Bircolov','08020','NU'),
											('0','Birgi Aerostazione','91020','TP'),
											('0','Birori','08010','NU'),
											('0','Bisaccia','83044','AV'),
											('0','Bisacquino','90032','PA'),
											('0','Bisano','40050','BO'),
											('0','Bisceglie','70052','BA'),
											('0','Bisegna','67050','AQ'),
											('0','Bisenti','64033','TE'),
											('0','Biserno','47018','FC'),
											('0','Bisignano','63040','AP'),
											('0','Bisignano','87043','CS'),
											('0','Bistagno','15012','AL'),
											('0','Bistrigna','34079','GO'),
											('0','Bisuschio','21050','VA'),
											('0','Bitetto','70020','BA'),
											('0','Bitonto','70032','BA'),
											('0','Bitritto','70020','BA'),
											('0','Bitti','08021','NU'),
											('0','Bivigliano','50030','FI'),
											('0','Bivio Cumiana','10040','TO'),
											('0','Bivio di Ravi','58020','GR'),
											('0','Bivio Mortola','81040','CE'),
											('0','Bivio Palomonte','84020','SA'),
											('0','Bivona','92010','AG'),
											('0','Bivongi','89040','RC'),
											('0','Bizzarone','22020','CO'),
											('0','Bizzozero','21100','VA'),
											('0','Blavy Nus','11020','AO'),
											('0','Bleggio','38071','TN'),
											('0','Blello','24012','BG'),
											('0','Blera','01010','VT'),
											('0','Blessagno','22028','CO'),
											('0','Blevio','22020','CO'),
											('0','Blufi','90020','PA'),
											('0','Blumau','39050','BZ'),
											('0','Boara','44030','FE'),
											('0','Boara Pisani','35040','PD'),
											('0','Boara Polesine','45030','RO'),
											('0','Boario','24020','BG'),
											('0','Boario Terme','25041','BS'),
											('0','Bobbio','29022','PC'),
											('0','Bobbio Pellice','10060','TO'),
											('0','Boca','28010','NO'),
											('0','Bocale Secondo','89060','RC'),
											('0','Bocca di Magra','19030','SP'),
											('0','Boccadifalco','90121','PA'),
											('0','Boccadiganda','46030','MN'),
											('0','Boccaleone','24125','BG'),
											('0','Boccaleone','44013','FE'),
											('0','Boccasette','45010','RO'),
											('0','Boccassuolo','41046','MO'),
											('0','Boccheggiano','58020','GR'),
											('0','Bocchigliero','87060','CS'),
											('0','Bocchignano','02030','RI'),
											('0','Boccia Al Mauro','80040','NA'),
											('0','Boccioleto','13022','VC'),
											('0','Bocconi','47010','FC'),
											('0','Bocenago','38080','TN'),
											('0','Bodio Lomnago','21020','VA'),
											('0','Boffalora d\'Adda','26811','LO'),
											('0','Boffalora Sopra Ticino','20010','MI'),
											('0','Bogliaco','25084','BS'),
											('0','Bogliasco','16031','GE'),
											('0','Boglietto','14055','AT'),
											('0','Bognanco','28842','VB'),
											('0','Bognanco Fonti','28842','VB'),
											('0','Bogogno','28010','NO'),
											('0','Boissano','17054','SV'),
											('0','Bojano','86021','CB'),
											('0','Bojon','30010','VE'),
											('0','Bolano','19020','SP'),
											('0','Bolbeno','38079','TN'),
											('0','Bolgare','24060','BG'),
											('0','Bolgheri','57020','LI'),
											('0','Bolladello','21050','VA'),
											('0','Bollate','20021','MI'),
											('0','Bollengo','10012','TO'),
											('0','Bologna','40100','BO'),
											('0','Bologna','40125','BO'),
											('0','Bologna','40134','BO'),
											('0','Bologna','40133','BO'),
											('0','Bologna','40139','BO'),
											('0','Bologna','40137','BO'),
											('0','Bologna','40126','BO'),
											('0','Bologna','40124','BO'),
											('0','Bologna','40123','BO'),
											('0','Bologna','40122','BO'),
											('0','Bologna','40121','BO'),
											('0','Bologna','40129','BO'),
											('0','Bolognano','65020','PE'),
											('0','Bolognetta','90030','PA'),
											('0','Bolognola','62035','MC'),
											('0','Bolotana','08011','NU'),
											('0','Bolsena','01023','VT'),
											('0','Boltiere','24040','BG'),
											('0','Bolzaneto','16162','GE'),
											('0','Bolzano','39100','BZ'),
											('0','Bolzano di Belluno','32020','BL'),
											('0','Bolzano Novarese','28010','NO'),
											('0','Bolzano Vicentino','36050','VI'),
											('0','Bomarzo','01020','VT'),
											('0','Bomba','66042','CH'),
											('0','Bombiana','40041','BO'),
											('0','Bombile','89030','RC'),
											('0','Bomerano','80051','NA'),
											('0','Bompensiere','93010','CL'),
											('0','Bompietro','90020','PA'),
											('0','Bomporto','41030','MO'),
											('0','Bonagia','91010','TP'),
											('0','Bonarcado','09070','OR'),
											('0','Bonassola','19011','SP'),
											('0','Bonate Sopra','24040','BG'),
											('0','Bonate Sotto','24040','BG'),
											('0','Bonavicina','37050','VR'),
											('0','Bonavigo','37040','VR'),
											('0','Boncellino','48012','RA'),
											('0','Boncore','73050','LE'),
											('0','Bondanello','46020','MN'),
											('0','Bondeno','44012','FE'),
											('0','Bondeno di Gonzaga','46020','MN'),
											('0','Bondo','38081','TN'),
											('0','Bondo Petello','24021','BG'),
											('0','Bondone','38080','TN'),
											('0','Bonea','80069','NA'),
											('0','Bonea','82013','BN'),
											('0','Bonefro','86041','CB'),
											('0','Bonemerse','26040','CR'),
											('0','Bonferraro','37060','VR'),
											('0','Bonifati','87020','CS'),
											('0','Bonifica Villa Literno','81039','CE'),
											('0','Bonito','83032','AV'),
											('0','Bonnanaro','07043','SS'),
											('0','Bono','07011','SS'),
											('0','Bonorva','07012','SS'),
											('0','Bonvicino','12060','CN'),
											('0','Bonzo','10070','TO'),
											('0','Borbiago','30030','VE'),
											('0','Borbona','02010','RI'),
											('0','Borboruso','87050','CS'),
											('0','Borca di Cadore','32040','BL'),
											('0','Borca di Macugnaga','28872','VB'),
											('0','Bordano','33010','UD'),
											('0','Bordighera','18012','IM'),
											('0','Bordighera Alta','18012','IM'),
											('0','Bordogna','24010','BG'),
											('0','Bordolano','26020','CR'),
											('0','Bordonaro','98145','ME'),
											('0','Bore','43030','PR'),
											('0','Borello','18038','IM'),
											('0','Borello','47022','FC'),
											('0','Boretto','42022','RE'),
											('0','Borgagne','73020','LE'),
											('0','Borgarello','27010','PV'),
											('0','Borgaretto','10092','TO'),
											('0','Borgaria di Narni','05035','TR'),
											('0','Borgaro Torinese','10071','TO'),
											('0','Borgata Borghesiana','00132','RM'),
											('0','Borgata Casalotti','00166','RM'),
											('0','Borgata Corviale','00148','RM'),
											('0','Borgata Fidene','00138','RM'),
											('0','Borgata Finocchio','00132','RM'),
											('0','Borgata Mezzanone','71040','FG'),
											('0','Borgata Ottavia','00135','RM'),
											('0','Borgata Paradiso di Collegno','10097','TO'),
											('0','Borgetto','90042','PA'),
											('0','Borghetto All\'Adige','38060','TN'),
											('0','Borghetto Borbera','15060','AL'),
											('0','Borghetto d\'Arroscia','18020','IM'),
											('0','Borghetto di Civita Castellana Stazione','01030','VT'),
											('0','Borghetto di Tuoro','06060','PG'),
											('0','Borghetto di Vara','19020','SP'),
											('0','Borghetto Lodigiano','26812','LO'),
											('0','Borghetto San Nicol','18012','IM'),
											('0','Borghetto Santo Spirito','17052','SV'),
											('0','Borghi','47030','FC'),
											('0','Borgia','88021','CZ'),
											('0','Borgiallo','10080','TO'),
											('0','Borgio Verezzi','17022','SV'),
											('0','Borgnano','34071','GO'),
											('0','Borgo a Buggiano','51011','PT'),
											('0','Borgo a Mozzano','55023','LU'),
											('0','Borgo Alla Collina','52010','AR'),
											('0','Borgo Annunziata','91100','TP'),
											('0','Borgo Baccarato','94010','EN'),
											('0','Borgo Bainsizza','04010','LT'),
											('0','Borgo Bonsignore','92016','AG'),
											('0','Borgo Callea','92020','AG'),
											('0','Borgo Capanne','40045','BO'),
											('0','Borgo Carige','58010','GR'),
											('0','Borgo Carso','04010','LT'),
											('0','Borgo Cascino','94010','EN'),
											('0','Borgo Cerreto','06041','PG'),
											('0','Borgo Cervaro','71020','FG'),
											('0','Borgo d\'Ale','13040','VC'),
											('0','Borgo di Montoro Inferiore','83020','AV'),
											('0','Borgo di Terzo','24060','BG'),
											('0','Borgo di Trevi','06032','PG'),
											('0','Borgo Faiti','04010','LT'),
											('0','Borgo Fazio','91027','TP'),
											('0','Borgo Flora','04012','LT'),
											('0','Borgo Fornari','16010','GE'),
											('0','Borgo Gesso','12100','CN'),
											('0','Borgo Giardinetto','71020','FG'),
											('0','Borgo Grappa','04010','LT'),
											('0','Borgo Hermada','04010','LT'),
											('0','Borgo Incoronata','71040','FG'),
											('0','Borgo Isonzo','04100','LT'),
											('0','Borgo La Loggia','92100','AG'),
											('0','Borgo Libert','71040','FG'),
											('0','Borgo Lombardo','20098','MI'),
											('0','Borgo Lupo','95040','CT'),
											('0','Borgo Macchia','75013','MT'),
											('0','Borgo Meduna','33170','PN'),
											('0','Borgo Montello','04010','LT'),
											('0','Borgo Montenero','04010','LT'),
											('0','Borgo Pace','61040','PU'),
											('0','Borgo Panigale','40132','BO'),
											('0','Borgo Partenope','87040','CS'),
											('0','Borgo Pasubio','04014','LT'),
											('0','Borgo Perrone','74010','TA'),
											('0','Borgo Petilia','93010','CL'),
											('0','Borgo Piave','04010','LT'),
											('0','Borgo Podgora','04010','LT'),
											('0','Borgo Primo','18100','IM'),
											('0','Borgo Priolo','27040','PV'),
											('0','Borgo Quinzio','02030','RI'),
											('0','Borgo Revel','10030','TO'),
											('0','Borgo Rivola','48010','RA'),
											('0','Borgo Rizza','96013','SR'),
											('0','Borgo Rurale Appio','81046','CE'),
											('0','Borgo Sabotino','04010','LT'),
											('0','Borgo Sacco','38068','TN'),
											('0','Borgo Salario','','RI'),
											('0','Borgo Salsasio','10022','TO'),
											('0','Borgo San Dalmazzo','12011','CN'),
											('0','Borgo San Donato','04010','LT'),
											('0','Borgo San Giacomo','25022','BS'),
											('0','Borgo San Giovanni','26851','LO'),
											('0','Borgo San Giuseppe','12100','CN'),
											('0','Borgo San Lazzaro','84020','SA'),
											('0','Borgo San Lorenzo','50032','FI'),
											('0','Borgo San Martino','15032','AL'),
											('0','Borgo San Martino di Cerveteri','00050','RM'),
											('0','Borgo San Michele','04010','LT'),
											('0','Borgo San Pietro','02020','RI'),
											('0','Borgo San Pietro di Moncalieri','10021','TO'),
											('0','Borgo San Siro','27020','PV'),
											('0','Borgo Santa Maria','61020','PU'),
											('0','Borgo Sant\'Antonio Abate','81040','CE'),
											('0','Borgo Sassoferrato','60041','AN'),
											('0','Borgo Stazione','','AT'),
											('0','Borgo Ticino','28040','NO'),
											('0','Borgo Tossignano','40021','BO'),
											('0','Borgo Trebbia','29100','PC'),
											('0','Borgo Tressanti','71040','FG'),
											('0','Borgo Val di Taro','43043','PR'),
											('0','Borgo Valsugana','38051','TN'),
											('0','Borgo Velino','02010','RI'),
											('0','Borgo Vercelli','13012','VC'),
											('0','Borgo Vittoria','39010','BZ'),
											('0','Borgo Vodice','04010','LT'),
											('0','Borgoforte','35022','PD'),
											('0','Borgoforte','46030','MN'),
											('0','Borgofranco d\'Ivrea','10013','TO'),
											('0','Borgofranco Sul Po','46020','MN'),
											('0','Borgolavezzaro','28071','NO'),
											('0','Borgomale','12050','CN'),
											('0','Borgomanero','28021','NO'),
											('0','Borgomaro','18021','IM'),
											('0','Borgomasino','10031','TO'),
											('0','Borgonato','25040','BS'),
											('0','Borgone Susa','10050','TO'),
											('0','Borgonovo Bardonecchia','10052','TO'),
											('0','Borgonovo Ligure','16046','GE'),
											('0','Borgonovo Val Tidone','29011','PC'),
											('0','Borgonuovo','23030','SO'),
											('0','Borgonuovo di Neive','12052','CN'),
											('0','Borgonuovo di Piuro','23020','SO'),
											('0','Borgoratto Alessandrino','15013','AL'),
											('0','Borgoratto Mormorolo','27040','PV'),
											('0','Borgoricco','35010','PD'),
											('0','Borgorose','02021','RI'),
											('0','Borgosatollo','25010','BS'),
											('0','Borgosesia','13011','VC'),
											('0','Bormida','17045','SV'),
											('0','Bormio','23032','SO'),
											('0','Bornago','20060','MI'),
											('0','Bornasco','27010','PV'),
											('0','Bornate Sesia','13037','VC'),
											('0','Bornato','25046','BS'),
											('0','Borno','25042','BS'),
											('0','Boroneddu','09080','OR'),
											('0','Borore','08016','NU'),
											('0','Borrello','66040','CH'),
											('0','Borrello di Catania','95030','CT'),
											('0','Borrello di San Mauro Castelverde','90010','PA'),
											('0','Borriana','13872','BI'),
											('0','Borsano','21052','VA'),
											('0','Borsea','45100','RO'),
											('0','Borselli','50060','FI'),
											('0','Borso del Grappa','31030','TV'),
											('0','Bortigali','08012','NU'),
											('0','Bortigiadas','07030','SS'),
											('0','Borutta','07040','SS'),
											('0','Borzano','42010','RE'),
											('0','Borzoli','16153','GE'),
											('0','Borzonasca','16041','GE'),
											('0','Bosa','08013','NU'),
											('0','Bosa Marina','08013','NU'),
											('0','Bosaro','45033','RO'),
											('0','Boschi di Bardone','43040','PR'),
											('0','Boschi Sant\'Anna','37040','VR'),
											('0','Bosco','06080','PG'),
											('0','Bosco','44020','FE'),
											('0','Bosco','84040','SA'),
											('0','Bosco','89025','RC'),
											('0','Bosco Chiesanuova','37021','VR'),
											('0','Bosco di Corniglio','43020','PR'),
											('0','Bosco di Galliera','40015','BO'),
											('0','Bosco Marengo','15062','AL'),
											('0','Bosco Sant\'Ippolito','89034','RC'),
											('0','Boscochiaro','30010','VE'),
											('0','Boscomare','18010','IM'),
											('0','Bosconero','10080','TO'),
											('0','Boscoreale','80041','NA'),
											('0','Boscotrecase','80042','NA'),
											('0','Bosentino','38049','TN'),
											('0','Bosia','12050','CN'),
											('0','Bosio','15060','AL'),
											('0','Bosisio Parini','23842','LC'),
											('0','Bosnasco','27040','PV'),
											('0','Bossea','12080','CN'),
											('0','Bosses','11010','AO'),
											('0','Bossico','24060','BG'),
											('0','Bossolasco','12060','CN'),
											('0','Bostone','25089','BS'),
											('0','Botricello','88070','CZ'),
											('0','Botrugno','73020','LE'),
											('0','Botta di Sedrina','24010','BG'),
											('0','Bottagna','19020','SP'),
											('0','Bottanuco','24040','BG'),
											('0','Bottegone','51032','PT'),
											('0','Botticino','25082','BS'),
											('0','Botticino','55010','LU'),
											('0','Botticino Mattina','25082','BS'),
											('0','Botticino Sera','25082','BS'),
											('0','Bottidda','07010','SS'),
											('0','Bottrighe','45013','RO'),
											('0','Bousson','10054','TO'),
											('0','Bova','89033','RC'),
											('0','Bova Marina','89035','RC'),
											('0','Bovalino Marina','89034','RC'),
											('0','Bovalino Superiore','89030','RC'),
											('0','Bovegno','25061','BS'),
											('0','Boves','12012','CN'),
											('0','Bovezzo','25073','BS'),
											('0','Boville Ernica','03022','FR'),
											('0','Bovino','71023','FG'),
											('0','Bovisio Masciago','20030','MI'),
											('0','Bovolenta','35024','PD'),
											('0','Bovolone','37051','VR'),
											('0','Bozen','39100','BZ'),
											('0','Bozzana','38020','TN'),
											('0','Bozzano','55050','LU'),
											('0','Bozzole','15040','AL'),
											('0','Bozzolo','46012','MN'),
											('0','Bra','12042','CN'),
											('0','Bracca','24010','BG'),
											('0','Bracciano','00062','RM'),
											('0','Bracigliano','84082','SA'),
											('0','Bragioli','12070','CN'),
											('0','Bragno','17014','SV'),
											('0','Braidi','98060','ME'),
											('0','Braies','39030','BZ'),
											('0','Brallo di Pregola','27050','PV'),
											('0','Branca','06020','PG'),
											('0','Brancaleone','89036','RC'),
											('0','Brandico','25030','BS'),
											('0','Brandizzo','10032','TO'),
											('0','Branzi','24010','BG'),
											('0','Branzoll','39051','BZ'),
											('0','Braone','25040','BS'),
											('0','Brarola','13100','VC'),
											('0','Brattir','89862','VV'),
											('0','Bratto','24020','BG'),
											('0','Brazzano','34071','GO'),
											('0','Brazzolo','44035','FE'),
											('0','Brebbia','21020','VA'),
											('0','Breccia','22100','CO'),
											('0','Brecciarola','66010','CH'),
											('0','Breda Cisoni','46010','MN'),
											('0','Breda di Piave','31030','TV'),
											('0','Bregano','21020','VA'),
											('0','Breganze','36042','VI'),
											('0','Bregnano','22070','CO'),
											('0','Breguzzo','38081','TN'),
											('0','Breia','13020','VC'),
											('0','Brembate','24041','BG'),
											('0','Brembate di Sopra','24030','BG'),
											('0','Brembilla','24012','BG'),
											('0','Brembio','26822','LO'),
											('0','Breme','27020','PV'),
											('0','Brendola','36040','VI'),
											('0','Brenna','22040','CO'),
											('0','Brenner','39041','BZ'),
											('0','Brennero','39041','BZ'),
											('0','Brenno Useria','21051','VA'),
											('0','Breno','25043','BS'),
											('0','Brenta','21030','VA'),
											('0','Brentino Belluno','37020','VR'),
											('0','Brentonico','38060','TN'),
											('0','Brenzone','37010','VR'),
											('0','Breolungi','12080','CN'),
											('0','Breonio','37020','VR'),
											('0','Brescello','42041','RE'),
											('0','Brescia','25100','BS'),
											('0','Bresimo','38020','TN'),
											('0','Bressana Bottarone','27042','PV'),
											('0','Bressanone','39042','BZ'),
											('0','Bressanvido','36050','VI'),
											('0','Bresseo','35033','PD'),
											('0','Bresso','20091','MI'),
											('0','Breuil Cervinia','11021','AO'),
											('0','Brez','38021','TN'),
											('0','Brezza','81046','CE'),
											('0','Brezzo di Bedero','21010','VA'),
											('0','Briaglia','12080','CN'),
											('0','Brianco','13885','BI'),
											('0','Briano','81100','CE'),
											('0','Briatico','89817','VV'),
											('0','Bribano','32030','BL'),
											('0','Bricherasio','10060','TO'),
											('0','Brienno','22010','CO'),
											('0','Brienza','85050','PZ'),
											('0','Briga Alta (Prov.Cuneo)','18025','IM'),
											('0','Briga Novarese','28010','NO'),
											('0','Brignano Frascata','15050','AL'),
											('0','Brignano Gera d\'Adda','24053','BG'),
											('0','Brignola Sottana','12018','CN'),
											('0','Brindisi','72100','BR'),
											('0','Brindisi Casale','72011','BR'),
											('0','Brindisi di Montagna','85010','PZ'),
											('0','Brinzio','21030','VA'),
											('0','Briona','28072','NO'),
											('0','Brione','10040','TO'),
											('0','Brione','25060','BS'),
											('0','Brione','38083','TN'),
											('0','Briosco','20040','MI'),
											('0','Brisighella','48013','RA'),
											('0','Brissago Valtravaglia','21030','VA'),
											('0','Brissogne','11020','AO'),
											('0','Brittoli','65010','PE'),
											('0','Brivio','23883','LC'),
											('0','Brixen','39042','BZ'),
											('0','Brizzolara','16040','GE'),
											('0','Broccostella','03030','FR'),
											('0','Brogliano','36070','VI'),
											('0','Brognaturo','89822','VV'),
											('0','Brognoligo','37030','VR'),
											('0','Brolo','98061','ME'),
											('0','Brondello','12030','CN'),
											('0','Broni','27043','PV'),
											('0','Bronte','95034','CT'),
											('0','Bronzolo','39051','BZ'),
											('0','Brossasco','12020','CN'),
											('0','Brosso','10080','TO'),
											('0','Brovello Carpugnino','28833','VB'),
											('0','Brozolo','10020','TO'),
											('0','Brozzi','50145','FI'),
											('0','Brozzo','25060','BS'),
											('0','Bruca','91010','TP'),
											('0','Brucianesi','50055','FI'),
											('0','Brucoli','96010','SR'),
											('0','Brufa','06089','PG'),
											('0','Brugherio','20047','MI'),
											('0','Brugine','35020','PD'),
											('0','Brugnato','19020','SP'),
											('0','Brugnera','33070','PN'),
											('0','Brugneto','29020','PC'),
											('0','Brugnetto','60010','AN'),
											('0','Bruino','10090','TO'),
											('0','Brumano','24037','BG'),
											('0','Bruna','06080','PG'),
											('0','Brunate','22034','CO'),
											('0','Bruneck','39031','BZ'),
											('0','Brunella','08020','NU'),
											('0','Brunello','21020','VA'),
											('0','Brunico','39031','BZ'),
											('0','Bruno','14046','AT'),
											('0','Brusago','38043','TN'),
											('0','Brusaporto','24060','BG'),
											('0','Brusaschetto','15020','AL'),
											('0','Brusasco','10020','TO'),
											('0','Brusatasso','46020','MN'),
											('0','Brusciano','80031','NA'),
											('0','Bruscoli','50033','FI'),
											('0','Brusegana','35143','PD'),
											('0','Brusimpiano','21050','VA'),
											('0','Brusnengo','13862','BI'),
											('0','Brusson','11022','AO'),
											('0','Brusuglio','20032','MI'),
											('0','Bruzolo','10050','TO'),
											('0','Bruzzano','20161','MI'),
											('0','Bruzzano Zeffirio','89030','RC'),
											('0','Bubano','40027','BO'),
											('0','Bubbiano','20080','MI'),
											('0','Bubbio','14051','AT'),
											('0','Buccheri','96010','SR'),
											('0','Bucchianico','66011','CH'),
											('0','Bucciano','82010','BN'),
											('0','Buccinasco','20090','MI'),
											('0','Buccino','84021','SA'),
											('0','Buccino Stazione','84020','SA'),
											('0','Bucine','52021','AR'),
											('0','Bucita','87030','CS'),
											('0','Budditogliu','08020','NU'),
											('0','Buddus','07020','SS'),
											('0','Budoia','33070','PN'),
											('0','Budoni','08020','NU'),
											('0','Budrie','40017','BO'),
											('0','Budrio','40054','BO'),
											('0','Budrione','41012','MO'),
											('0','Bufalata','91020','TP'),
											('0','Buggerru','09010','CA'),
											('0','Buggiano','06040','PG'),
											('0','Buggiano','51011','PT'),
											('0','Buglio in Monte','23010','SO'),
											('0','Bugnara','67030','AQ'),
											('0','Buguggiate','21020','VA'),
											('0','Buia','33030','UD'),
											('0','Buisson','11020','AO'),
											('0','Bulciago','23892','LC'),
											('0','Bulfons','33010','UD'),
											('0','Bulgaria','47023','FC'),
											('0','Bulgarograsso','22070','CO'),
											('0','Bulgorello','22071','CO'),
											('0','Bultei','07010','SS'),
											('0','Bulzi','07030','SS'),
											('0','Buonabitacolo','84032','SA'),
											('0','Buonacompra','44040','FE'),
											('0','Buonacquisto','05030','TR'),
											('0','Buonalbergo','82020','BN'),
											('0','Buonanotte','','CH'),
											('0','Buonconvento','53022','SI'),
											('0','Buonopane','80070','NA'),
											('0','Buonvicino','87020','CS'),
											('0','Burago di Molgora','20040','MI'),
											('0','Burana','44010','FE'),
											('0','Burano','30012','VE'),
											('0','Burcei','09040','CA'),
											('0','Burgio','92010','AG'),
											('0','Burgos','07010','SS'),
											('0','Burgstall','39014','BZ'),
											('0','Buriano','58040','GR'),
											('0','Buriasco','10060','TO'),
											('0','Burolo','10010','TO'),
											('0','Buronzo','13040','VC'),
											('0','Busachi','09082','OR'),
											('0','Busalla','16012','GE'),
											('0','Busana','42032','RE'),
											('0','Busano','10080','TO'),
											('0','Busca','12022','CN'),
											('0','Buscate','20010','MI'),
											('0','Buscemi','96010','SR'),
											('0','Busche','32020','BL'),
											('0','Buscoldo','46010','MN'),
											('0','Buseto Palizzolo','91012','TP'),
											('0','Busnago','20040','MI'),
											('0','Buso Sarzano','45100','RO'),
											('0','Bussana','18038','IM'),
											('0','Bussero','20060','MI'),
											('0','Busseto','43011','PR'),
											('0','Bussi Officine','65021','PE'),
											('0','Bussi Sul Tirino','65022','PE'),
											('0','Busso','86010','CB'),
											('0','Bussolengo','37012','VR'),
											('0','Bussoleno','10053','TO'),
											('0','Bussolino','10090','TO'),
											('0','Busto Arsizio','21052','VA'),
											('0','Busto Garolfo','20020','MI'),
											('0','Butera','93011','CL'),
											('0','Buti','56032','PI'),
											('0','Buttapietra','37060','VR'),
											('0','Buttigliera Alta','10090','TO'),
											('0','Buttigliera d\'Asti','14021','AT'),
											('0','Buttrio','33042','UD'),
											('0','Buturo','88073','CZ'),
											('0','Buzzoletto','46030','MN'),
											('0','C Bianca','30015','VE'),
											('0','C Bramante','61028','PU'),
											('0','C Corniani','30021','VE'),
											('0','C d\'Andrea','26030','CR'),
											('0','C De Caroli','42019','RE'),
											('0','C De\' Fabbri','40061','BO'),
											('0','C De\' Mari','26030','CR'),
											('0','C De\' Stefani','26039','CR'),
											('0','C degli Oppi','37050','VR'),
											('0','C di David','37061','VR'),
											('0','C di Ianzo','13020','VC'),
											('0','C Dolfin','45010','RO'),
											('0','C Emiliani','30175','VE'),
											('0','C Emo','45010','RO'),
											('0','C Gallo','61020','PU'),
											('0','C Raffaello','52030','AR'),
											('0','C Rainati','31020','TV'),
											('0','C Savio','30010','VE'),
											('0','C Tiepolo','45018','RO'),
											('0','C Vendramin','45010','RO'),
											('0','C Venier','45010','RO'),
											('0','C Zuliani','45010','RO'),
											('0','Cabanne','16040','GE'),
											('0','Cabella Ligure','15060','AL'),
											('0','Cabernardi','60042','AN'),
											('0','Cabiate','22060','CO'),
											('0','Cabras','09072','OR'),
											('0','Caccamo','90012','PA'),
											('0','Cacchiamo','94010','EN'),
											('0','Cacciano','82030','BN'),
											('0','Caccuri','88833','KR'),
											('0','Cad','42040','RE'),
											('0','Cadegliano','21031','VA'),
											('0','Cadelbosco di Sopra','42023','RE'),
											('0','Cadelbosco di Sotto','42020','RE'),
											('0','Cadenabbia','22011','CO'),
											('0','Cadeo','29010','PC'),
											('0','Caderzone','38080','TN'),
											('0','Cadibona','17041','SV'),
											('0','Cadignano','41023','MO'),
											('0','Cadimare','19131','SP'),
											('0','Cadine','38070','TN'),
											('0','Cadipietra','39030','BZ'),
											('0','Cadola','32011','BL'),
											('0','Cadoneghe','35010','PD'),
											('0','Cadorago','22071','CO'),
											('0','Cadrezzate','21020','VA'),
											('0','Caerano San Marco','31031','TV'),
											('0','Cafaggio','59100','PO'),
											('0','Cafaggiolo','50037','FI'),
											('0','Cafasse','10070','TO'),
											('0','Caggiano','84030','SA'),
											('0','Cagli','61043','PU'),
											('0','Cagliari','09100','CA'),
											('0','Cagliari','09128','CA'),
											('0','Cagliari','09125','CA'),
											('0','Cagliari','09129','CA'),
											('0','Cagliari','09127','CA'),
											('0','Cagliari','09123','CA'),
											('0','Cagliari','09122','CA'),
											('0','Cagliari','09121','CA'),
											('0','Cagliari','09131','CA'),
											('0','Cagliari','09124','CA'),
											('0','Caglio','22030','CO'),
											('0','Cagnano Amiterno','67012','AQ'),
											('0','Cagnano Varano','71010','FG'),
											('0','Cagno','22070','CO'),
											('0','Cagn','38028','TN'),
											('0','Caianello','81059','CE'),
											('0','Caiazzo','81013','CE'),
											('0','Caicambiucci','06020','PG'),
											('0','Caines','39010','BZ'),
											('0','Caino','25070','BS'),
											('0','Caiolo','23010','SO'),
											('0','Caionvico','25135','BS'),
											('0','Caira','03040','FR'),
											('0','Cairano','83040','AV'),
											('0','Cairate','21050','VA'),
											('0','Cairo Montenotte','17014','SV'),
											('0','Caivano','80023','NA'),
											('0','Cala di Volpe','07020','SS'),
											('0','Cala Ginepro','08028','NU'),
											('0','Cala Gonone','08020','NU'),
											('0','Cala Liberotto','08028','NU'),
											('0','Cala Mosca','09126','CA'),
											('0','Cala Reale','07040','SS'),
											('0','Calabricata','88050','CZ'),
											('0','Calabritto','83040','AV'),
											('0','Calalzo di Cadore','32042','BL'),
											('0','Calamandrana','14042','AT'),
											('0','Calamecca','51010','PT'),
											('0','Calamonaci','92010','AG'),
											('0','Calamoresca','08041','NU'),
											('0','Calangianus','07023','SS'),
											('0','Calanna','89050','RC'),
											('0','Calasca Castiglione','28873','VB'),
											('0','Calascibetta','94010','EN'),
											('0','Calascio','67020','AQ'),
											('0','Calasetta','09011','CA'),
											('0','Calatabiano','95011','CT'),
											('0','Calatafimi','91013','TP'),
											('0','Calavino','38072','TN'),
											('0','Calavorno','55024','LU'),
											('0','Calbola','47017','FC'),
											('0','Calcara','40056','BO'),
											('0','Calcarelli','90020','PA'),
											('0','Calcata','01030','VT'),
											('0','Calceranica Al Lago','38050','TN'),
											('0','Calci','56011','PI'),
											('0','Calciano','75010','MT'),
											('0','Calcinaia','56012','PI'),
											('0','Calcinate','24050','BG'),
											('0','Calcinate del Pesce','21100','VA'),
											('0','Calcinatello','25011','BS'),
											('0','Calcinato','25011','BS'),
											('0','Calcinelli','61030','PU'),
											('0','Calcio','24054','BG'),
											('0','Calco','23885','LC'),
											('0','Caldana','58020','GR'),
											('0','Caldare','92020','AG'),
											('0','Caldaro sulla Strada del Vino','39052','BZ'),
											('0','Caldarola','62020','MC'),
											('0','Cald','21010','VA'),
											('0','Calder','98050','ME'),
											('0','Calderara','18026','IM'),
											('0','Calderara','95030','CT'),
											('0','Calderara di Reno','40012','BO'),
											('0','Calderino','40050','BO'),
											('0','Caldes','38022','TN'),
											('0','Caldierino','37042','VR'),
											('0','Caldiero','37042','VR'),
											('0','Caldine','50010','FI'),
											('0','Caldirola','15050','AL'),
											('0','Caldogno','36030','VI'),
											('0','Caldonazzo','38052','TN'),
											('0','Caldopiano','87040','CS'),
											('0','Calendasco','29010','PC'),
											('0','Calenzano','50041','FI'),
											('0','Calerno','42040','RE'),
											('0','Calestano','43030','PR'),
											('0','Caletta di Castiglioncello','57012','LI'),
											('0','Caliano','83020','AV'),
											('0','Calice Al Cornoviglio','19020','SP'),
											('0','Calice Ligure','17020','SV'),
											('0','Calimera Calabra','89842','VV'),
											('0','Calimera di Lecce','73021','LE'),
											('0','Calino','25046','BS'),
											('0','Calisese','47020','FC'),
											('0','Calitri','83045','AV'),
											('0','Calizzano','17057','SV'),
											('0','Callabiana','13821','BI'),
											('0','Calle','75019','MT'),
											('0','Callianetto','14033','AT'),
											('0','Calliano','14031','AT'),
											('0','Calliano','38060','TN'),
											('0','Calmasino','37011','VR'),
											('0','Calmazzo','61034','PU'),
											('0','Calolziocorte','23801','LC'),
											('0','Calopezzati','87060','CS'),
											('0','Calore','83033','AV'),
											('0','Calosso','14052','AT'),
											('0','Caloveto','87060','CS'),
											('0','Caltabellotta','92010','AG'),
											('0','Caltagirone','95041','CT'),
											('0','Caltana','30030','VE'),
											('0','Caltanissetta','93100','CL'),
											('0','Caltavuturo','90022','PA'),
											('0','Caltignaga','28010','NO'),
											('0','Calto','45030','RO'),
											('0','Caltrano','36030','VI'),
											('0','Caltron','38023','TN'),
											('0','Calusco d\'Adda','24033','BG'),
											('0','Caluso','10014','TO'),
											('0','Calvagese della Riviera','25080','BS'),
											('0','Calvanico','84080','SA'),
											('0','Calvari','16040','GE'),
											('0','Calvaruso','98040','ME'),
											('0','Calvatone','26030','CR'),
											('0','Calvello','85010','PZ'),
											('0','Calvene','36030','VI'),
											('0','Calvenzano','24040','BG'),
											('0','Calvera','85030','PZ'),
											('0','Calvi','82018','BN'),
											('0','Calvi Dell\'Umbria','05032','TR'),
											('0','Calvi Risorta','81042','CE'),
											('0','Calvignano','27045','PV'),
											('0','Calvignasco','20080','MI'),
											('0','Calvisano','25012','BS'),
											('0','Calvisi','81010','CE'),
											('0','Calvizzano','80012','NA'),
											('0','Calvo','18039','IM'),
											('0','Calzolaro','06018','PG'),
											('0','Camagna Monferrato','15030','AL'),
											('0','Camaiore','55041','LU'),
											('0','Camairago','26823','LO'),
											('0','Camaldoli','52010','AR'),
											('0','Camandona','13821','BI'),
											('0','Camarda','67010','AQ'),
											('0','Camarda di Aprigliano','87050','CS'),
											('0','Camaro','98151','ME'),
											('0','Camaro Inferiore','98149','ME'),
											('0','Camarza','16012','GE'),
											('0','Camastra','92020','AG'),
											('0','Camatta','41026','MO'),
											('0','Cambiago','20040','MI'),
											('0','Cambiano','10020','TO'),
											('0','Cambiano','50051','FI'),
											('0','Cambiasca','28814','VB'),
											('0','Camburzano','13891','BI'),
											('0','Camerana','12072','CN'),
											('0','Camerano','60021','AN'),
											('0','Camerano Casasco','14020','AT'),
											('0','Camerata','06059','PG'),
											('0','Camerata Cornello','24010','BG'),
											('0','Camerata Nuova','00020','RM'),
											('0','Camerata Picena','60020','AN'),
											('0','Cameri','28062','NO'),
											('0','Cameri Aeronautica','28060','NO'),
											('0','Cameriano','28060','NO'),
											('0','Camerino','62032','MC'),
											('0','Camerlata','22100','CO'),
											('0','Camerlona','48010','RA'),
											('0','Camerota','84040','SA'),
											('0','Camigliano','81050','CE'),
											('0','Camigliano Santa Gemma','55010','LU'),
											('0','Camigliatello','87052','CS'),
											('0','Camignone','25040','BS'),
											('0','Camin','35127','PD'),
											('0','Caminata','29010','PC'),
											('0','Camini','89040','RC'),
											('0','Camino','15020','AL'),
											('0','Camino','81040','CE'),
											('0','Camino Al Tagliamento','33030','UD'),
											('0','Camisano','26010','CR'),
											('0','Camisano Vicentino','36043','VI'),
											('0','Cammarata','92022','AG'),
											('0','Camnago','20030','MI'),
											('0','Camnago Faloppio','22020','CO'),
											('0','Camnago Volta','22030','CO'),
											('0','Camo','12050','CN'),
											('0','Camogli','16032','GE'),
											('0','Campagna','33085','PN'),
											('0','Campagna','84022','SA'),
											('0','Campagna Lupia','30010','VE'),
											('0','Campagnano di Roma','00063','RM'),
											('0','Campagnatico','58042','GR'),
											('0','Campagnola','35020','PD'),
											('0','Campagnola','81035','CE'),
											('0','Campagnola','24126','BG'),
											('0','Campagnola Cremasca','26010','CR'),
											('0','Campagnola Emilia','42012','RE'),
											('0','Campalto','30030','VE'),
											('0','Campana','87061','CS'),
											('0','Campanedda','07040','SS'),
											('0','Camparada','20050','MI'),
											('0','Campasso','16151','GE'),
											('0','Campazzo','41015','MO'),
											('0','Campedello','36100','VI'),
											('0','Campegine','42040','RE'),
											('0','Campeglio','33040','UD'),
											('0','Campello Sul Clitunno','06042','PG'),
											('0','Campertogno','13023','VC'),
											('0','Campese','36061','VI'),
											('0','Campese','58010','GR'),
											('0','Campestrin','38030','TN'),
											('0','Campi Bisenzio','50013','FI'),
											('0','Campi Salentina','73012','LE'),
											('0','Campiano','48010','RA'),
											('0','Campiglia','19132','SP'),
											('0','Campiglia Cervo','13812','BI'),
											('0','Campiglia dei Berici','36020','VI'),
											('0','Campiglia d\'Orcia','53020','SI'),
											('0','Campiglia Marittima','57021','LI'),
											('0','Campiglia Marittima Stazione','57020','LI'),
											('0','Campiglione','54020','MS'),
											('0','Campiglione Fenile','10060','TO'),
											('0','Campill','39030','BZ'),
											('0','Campione del Garda','25010','BS'),
											('0','Campione d\'Italia','22060','CO'),
											('0','Campitello','46010','MN'),
											('0','Campitello di Fassa','38031','TN'),
											('0','Campli','64012','TE'),
											('0','Campo','56010','PI'),
											('0','Campo Calabro','89052','RC'),
											('0','Campo Canavese','10080','TO'),
											('0','Campo di Carne','04011','LT'),
											('0','Campo di Fano','67030','AQ'),
											('0','Campo di Giove','67030','AQ'),
											('0','Campo di Pietra di Salgareda','31040','TV'),
											('0','Campo di Trens','39040','BZ'),
											('0','Campo Imperatore','67010','AQ'),
											('0','Campo Ligure','16013','GE'),
											('0','Campo Nell\'Elba','57034','LI'),
											('0','Campo San Martino','35010','PD'),
											('0','Campo Tartano','23010','SO'),
											('0','Campo Tizzoro','51023','PT'),
											('0','Campo Tures','39032','BZ'),
											('0','Campobasso','86100','CB'),
											('0','Campobello di Licata','92023','AG'),
											('0','Campobello di Mazara','91021','TP'),
											('0','Campobello Ravanusa Stazione','92020','AG'),
											('0','Campocatino','03016','FR'),
											('0','Campochiaro','86020','CB'),
											('0','Campochiesa','17031','SV'),
											('0','Campodarsego','35011','PD'),
											('0','Campodazzo','39040','BZ'),
											('0','Campodenno','38010','TN'),
											('0','Campodimele','04020','LT'),
											('0','Campodipietra','86010','CB'),
											('0','Campodolcino','23021','SO'),
											('0','Campodonico','60040','AN'),
											('0','Campodoro','35010','PD'),
											('0','Campofelice di Fitalia','90030','PA'),
											('0','Campofelice di Roccella','90010','PA'),
											('0','Campofilone','63016','AP'),
											('0','Campofiorito','90030','PA'),
											('0','Campoformido','33030','UD'),
											('0','Campofranco','93010','CL'),
											('0','Campogalliano','41011','MO'),
											('0','Campogialli','52020','AR'),
											('0','Campogrande','98060','ME'),
											('0','Campolano','02020','RI'),
											('0','Campolattaro','82020','BN'),
											('0','Campoleone','04010','LT'),
											('0','Campoli Appennino','03030','FR'),
											('0','Campoli del Monte Taburno','82030','BN'),
											('0','Campoli di Caulonia','89041','RC'),
											('0','Campolieto','86040','CB'),
											('0','Campolongo Al Torre','33040','UD'),
											('0','Campolongo di Cadore','32040','BL'),
											('0','Campolongo Maggiore','30010','VE'),
											('0','Campolongo Sul Brenta','36020','VI'),
											('0','Campomaggiore','85010','PZ'),
											('0','Campomarino','86042','CB'),
											('0','Campomarino Lido','86042','CB'),
											('0','Campomorone','16014','GE'),
											('0','Campone','33090','PN'),
											('0','Camponogara','30010','VE'),
											('0','Campora','84040','SA'),
											('0','Campora San Giovanni','87030','CS'),
											('0','Campore','13825','BI'),
											('0','Campore','43039','PR'),
											('0','Camporeale','90043','PA'),
											('0','Camporeggiano','06020','PG'),
											('0','Camporgiano','55031','LU'),
											('0','Camporosso','18033','IM'),
											('0','Camporosso in Valcanale','33018','UD'),
											('0','Camporosso Mare','18033','IM'),
											('0','Camporotondo di Fiastrone','62020','MC'),
											('0','Camporotondo Etneo','95040','CT'),
											('0','Camporovere','36030','VI'),
											('0','Camposampiero','35012','PD'),
											('0','Camposano','80030','NA'),
											('0','Camposanto Sul Panaro','41031','MO'),
											('0','Campospinoso','27040','PV'),
											('0','Campotosto','67013','AQ'),
											('0','Campotto','44010','FE'),
											('0','Campovalano','64010','TE'),
											('0','Campoverde','25087','BS'),
											('0','Campoverde','04010','LT'),
											('0','Campovico','23010','SO'),
											('0','Campremoldo Sopra e Sotto','29010','PC'),
											('0','Camucia','52042','AR'),
											('0','Camugnano','40032','BO'),
											('0','Camurana','41036','MO'),
											('0','Cana','58050','GR'),
											('0','Canaglia','07040','SS'),
											('0','Canal Bianco','44029','FE'),
											('0','Canal San Bovo','38050','TN'),
											('0','Canale','12043','CN'),
											('0','Canale','83020','AV'),
											('0','Canale','05010','TR'),
											('0','Canale d\'Agordo','32020','BL'),
											('0','Canale Fontanigorda','16020','GE'),
											('0','Canale Monterano','00060','RM'),
											('0','Canali','42100','RE'),
											('0','Canalicchio','95125','CT'),
											('0','Canaro','45034','RO'),
											('0','Canavaccio','61029','PU'),
											('0','Canazei di Fassa','38032','TN'),
											('0','Cancellara','85010','PZ'),
											('0','Cancelli','50066','FI'),
											('0','Cancelli','60040','AN'),
											('0','Cancello','88040','CZ'),
											('0','Cancello di Ferrovia','81020','CE'),
											('0','Cancello Ed Arnone','81030','CE'),
											('0','Canda','45020','RO'),
											('0','Candeglia','51030','PT'),
											('0','Candela','71024','FG'),
											('0','Candelara','61100','PU'),
											('0','Candelassu','08040','NU'),
											('0','Candeli','50012','FI'),
											('0','Candelo','13878','BI'),
											('0','Candel','31030','TV'),
											('0','Candia Canavese','10010','TO'),
											('0','Candia di Ancona','60020','AN'),
											('0','Candia Lomellina','27031','PV'),
											('0','Candiana','35020','PD'),
											('0','Candida','83040','AV'),
											('0','Candide','32040','BL'),
											('0','Candidoni','89020','RC'),
											('0','Candiolo','10060','TO'),
											('0','Canedole','46040','MN'),
											('0','Canegrate','20010','MI'),
											('0','Canelli','14053','AT'),
											('0','Canelli Recapito Gancia','14053','AT'),
											('0','Canepa','16030','GE'),
											('0','Canepina','01030','VT'),
											('0','Canetra di Castel Sant\'Angelo','','RI'),
											('0','Caneva','33028','UD'),
											('0','Caneva','33070','PN'),
											('0','Canevara','54030','MS'),
											('0','Canevare','41021','MO'),
											('0','Canevino','27040','PV'),
											('0','Canezza','38057','TN'),
											('0','Canicatt e Borgalino','92024','AG'),
											('0','Canicattini Bagni','96010','SR'),
											('0','Canicossa','46010','MN'),
											('0','Canino','01011','VT'),
											('0','Caniparola','54030','MS'),
											('0','Canischio','10080','TO'),
											('0','Canistro','67050','AQ'),
											('0','Canistro Superiore','67050','AQ'),
											('0','Canizzano','31100','TV'),
											('0','Canna','87070','CS'),
											('0','Cannalonga','84040','SA'),
											('0','Cannara','06033','PG'),
											('0','Cannav','89060','RC'),
											('0','Cannero Riviera','28821','VB'),
											('0','Canneto di Caronia','98070','ME'),
											('0','Canneto di Monteverdi','56040','PI'),
											('0','Canneto Lipari','98052','ME'),
											('0','Canneto Pavese','27044','PV'),
											('0','Canneto Sabino','02030','RI'),
											('0','Canneto Sull\'Oglio','46013','MN'),
											('0','Cannicchio','84040','SA'),
											('0','Cannigione','07020','SS'),
											('0','Cannitello','89010','RC'),
											('0','Cannizzaro','95020','CT'),
											('0','Cannobio','28822','VB'),
											('0','Cannole','73020','LE'),
											('0','Cannuzzo','48010','RA'),
											('0','Canolo','89040','RC'),
											('0','Canonica','06059','PG'),
											('0','Canonica d\'Adda','24040','BG'),
											('0','Canosa di Puglia','70053','BA'),
											('0','Canosa Sannita','66010','CH'),
											('0','Canosio','12020','CN'),
											('0','Canove','12050','CN'),
											('0','Canove di Roana','36010','VI'),
											('0','Cansano','67030','AQ'),
											('0','Cantagallo','40033','BO'),
											('0','Cantagallo','59025','PO'),
											('0','Cantalice','02014','RI'),
											('0','Cantalupa','10060','TO'),
											('0','Cantalupo','06030','PG'),
											('0','Cantalupo','15014','AL'),
											('0','Cantalupo','20020','MI'),
											('0','Cantalupo del Sannio','86092','IS'),
											('0','Cantalupo in Sabina','02040','RI'),
											('0','Cantalupo Ligure','15060','AL'),
											('0','Cantarana','14010','AT'),
											('0','Cantavenna','15020','AL'),
											('0','Cantello','21050','VA'),
											('0','Canterano','00020','RM'),
											('0','Cantiano','61044','PU'),
											('0','Cantinella','87060','CS'),
											('0','Cantoira','10070','TO'),
											('0','Cantonazzo','45100','RO'),
											('0','Cantone','81025','CE'),
											('0','Cantoniera della Presolana','24020','BG'),
											('0','Cant','22063','CO'),
											('0','Canzano','64020','TE'),
											('0','Canzo','22035','CO'),
											('0','Caoria','38050','TN'),
											('0','Caorle','30021','VE'),
											('0','Caorso','29012','PC'),
											('0','Capaccio','84047','SA'),
											('0','Capaccio Scalo','84040','SA'),
											('0','Capaci','90040','PA'),
											('0','Capalbio','58011','GR'),
											('0','Capalbio Stazione','58010','GR'),
											('0','Capalle','50010','FI'),
											('0','Capanne','56020','PI'),
											('0','Capanne Vecchie','58024','GR'),
											('0','Capannelle','00178','RM'),
											('0','Capannole','52020','AR'),
											('0','Capannoli Val d\'Era','56033','PI'),
											('0','Capannori','55012','LU'),
											('0','Capece Bax','72020','BR'),
											('0','Capena','00060','RM'),
											('0','Capergnanica','26010','CR'),
											('0','Capestrano','67022','AQ'),
											('0','Capezzano','84080','SA'),
											('0','Capezzano Monte','55045','LU'),
											('0','Capezzano Pianore','55040','LU'),
											('0','Capezzine','','AR'),
											('0','Capiago Intimiano','22070','CO'),
											('0','Capistrano','89818','VV'),
											('0','Capistrello','67053','AQ'),
											('0','Capitello','84040','SA'),
											('0','Capitignano','67014','AQ'),
											('0','Capitone','05020','TR'),
											('0','Capizzi','98031','ME'),
											('0','Capizzo','84040','SA'),
											('0','Capizzone','24030','BG'),
											('0','Capo Coda Cavallo','08020','NU'),
											('0','Capo Comino','08020','NU'),
											('0','Capo di Ponte','25044','BS'),
											('0','Capo di Sorrento','80060','NA'),
											('0','Capo d\'Orlando','98071','ME'),
											('0','Capo Miseno','80070','NA'),
											('0','Capo Spartivento','89030','RC'),
											('0','Capocolle','47032','FC'),
											('0','Capodacqua','06030','PG'),
											('0','Capodacqua','63040','AP'),
											('0','Capodarco','63010','AP'),
											('0','Capodigiano','85054','PZ'),
											('0','Capodimonte','01010','VT'),
											('0','Capodrise','81020','CE'),
											('0','Capoferro','07021','SS'),
											('0','Capolago','21100','VA'),
											('0','Capoliveri','57031','LI'),
											('0','Capolona','52010','AR'),
											('0','Caponago','20040','MI'),
											('0','Capoponte','43020','PR'),
											('0','Caporciano','67020','AQ'),
											('0','Caposele','83040','AV'),
											('0','Capostrada','51033','PT'),
											('0','Capoterra','09012','CA'),
											('0','Capovalle','25070','BS'),
											('0','Cappadocia','67060','AQ'),
											('0','Cappella','80070','NA'),
											('0','Cappella Cangiani','80131','NA'),
											('0','Cappella Cantone','26020','CR'),
											('0','Cappella De\' Picenardi','26038','CR'),
											('0','Cappella Maggiore','31012','TV'),
											('0','Cappelle dei Marsi','67060','AQ'),
											('0','Cappelle Sul Tavo','65010','PE'),
											('0','Cappelletta','46030','MN'),
											('0','Cappuccini','13100','VC'),
											('0','Cappuccini','80078','NA'),
											('0','Capracotta','86082','IS'),
											('0','Capradosso','02020','RI'),
											('0','Capraia','50056','FI'),
											('0','Capraia Isola','57032','LI'),
											('0','Capralba','26010','CR'),
											('0','Capranica','01012','VT'),
											('0','Capranica Prenestina','00030','RM'),
											('0','Caprara d\'Abruzzo','65010','PE'),
											('0','Caprarica del Capo','73039','LE'),
											('0','Caprarica di Lecce','73010','LE'),
											('0','Caprarico','75020','MT'),
											('0','Caprarola','01032','VT'),
											('0','Caprauna','12070','CN'),
											('0','Caprazzino','61028','PU'),
											('0','Caprese Michelangelo','52033','AR'),
											('0','Caprezzo','28815','VB'),
											('0','Capri','80073','NA'),
											('0','Capri Leone','98070','ME'),
											('0','Capriana','38030','TN'),
											('0','Capriano','20040','MI'),
											('0','Capriano del Colle','25020','BS'),
											('0','Capriata d\'Orba','15060','AL'),
											('0','Capriate San Gervasio','24042','BG'),
											('0','Capriati Al Volturno','81014','CE'),
											('0','Caprie','10040','TO'),
											('0','Capriglia','84080','SA'),
											('0','Capriglia','55045','LU'),
											('0','Capriglia Irpina','83010','AV'),
											('0','Capriglio','14022','AT'),
											('0','Capriglio','43020','PR'),
											('0','Caprigliola','54010','MS'),
											('0','Caprile','03038','FR'),
											('0','Caprile','80054','NA'),
											('0','Caprile','13864','BI'),
											('0','Caprile','32023','BL'),
											('0','Caprino Bergamasco','24030','BG'),
											('0','Caprino Veronese','37013','VR'),
											('0','Caprioli','84040','SA'),
											('0','Capriolo','25031','BS'),
											('0','Capriva del Friuli','34070','GO'),
											('0','Caprona','56011','PI'),
											('0','Capua','81043','CE'),
											('0','Capugnano','40046','BO'),
											('0','Capurso','70010','BA'),
											('0','Caraffa del Bianco','89030','RC'),
											('0','Caraffa di Catanzaro','88050','CZ'),
											('0','Caraglio','12023','CN'),
											('0','Caragna','17057','SV'),
											('0','Caramagna Ligure','18100','IM'),
											('0','Caramagna Piemonte','12030','CN'),
											('0','Caramanico Terme','65023','PE'),
											('0','Carano','04011','LT'),
											('0','Carano','38033','TN'),
											('0','Carano di Sessa Aurunca','81030','CE'),
											('0','Caranzano','15016','AL'),
											('0','Carapelle','71041','FG'),
											('0','Carapelle Calvisio','67020','AQ'),
											('0','Carasco','16042','GE'),
											('0','Carassai','63030','AP'),
											('0','Carate Brianza','20048','MI'),
											('0','Carate Urio','22010','CO'),
											('0','Carattano','81010','CE'),
											('0','Caravaggio','24043','BG'),
											('0','Caravate','21032','VA'),
											('0','Caravino','10010','TO'),
											('0','Caravita','80040','NA'),
											('0','Caravonica','18022','IM'),
											('0','Carbognano','01030','VT'),
											('0','Carbonara','70012','BA'),
											('0','Carbonara Al Ticino','27020','PV'),
											('0','Carbonara di Nola','80030','NA'),
											('0','Carbonara di Po','46020','MN'),
											('0','Carbonara Scrivia','15050','AL'),
											('0','Carbonare di Folgaria','38044','TN'),
											('0','Carbonate','22070','CO'),
											('0','Carbone','85030','PZ'),
											('0','Carbonera','31030','TV'),
											('0','Carbonia','09013','CA'),
											('0','Carcare','17043','SV'),
											('0','Carceri','35040','PD'),
											('0','Carchitti','00030','RM'),
											('0','Carciano','28834','VB'),
											('0','Carcina','25069','BS'),
											('0','Carcoforo','13026','VC'),
											('0','Cardano','39053','BZ'),
											('0','Cardano Al Campo','21010','VA'),
											('0','Card','12030','CN'),
											('0','Cardedu','08040','NU'),
											('0','Cardeto','89060','RC'),
											('0','Cardile','84040','SA'),
											('0','Cardinale','88062','CZ'),
											('0','Cardito','80024','NA'),
											('0','Cardito di Vallerotonda','03040','FR'),
											('0','Cardona','15021','AL'),
											('0','Careggi','50134','FI'),
											('0','Careggine','55030','LU'),
											('0','Carema','10010','TO'),
											('0','Carenno','23802','LC'),
											('0','Carentino','15022','AL'),
											('0','Careri','89030','RC'),
											('0','Caresana','13010','VC'),
											('0','Caresanablot','13030','VC'),
											('0','Carezza Al Lago','39056','BZ'),
											('0','Carezzano','15051','AL'),
											('0','Carfizzi','88817','KR'),
											('0','Cargedolo','41044','MO'),
											('0','Cargeghe','07030','SS'),
											('0','Caria','89862','VV'),
											('0','Cariati','87062','CS'),
											('0','Cariati Marina','87063','CS'),
											('0','Carife','83040','AV'),
											('0','Carifi','84080','SA'),
											('0','Cariglio','87020','CS'),
											('0','Carignano','10041','TO'),
											('0','Carillia','84023','SA'),
											('0','Carimate','22060','CO'),
											('0','Carinaro','81032','CE'),
											('0','Carini','90044','PA'),
											('0','Carinola','81030','CE'),
											('0','Carisio','13040','VC'),
											('0','Carisolo','38080','TN'),
											('0','Carlantino','71030','FG'),
											('0','Carlazzo','22010','CO'),
											('0','Carlentini','96013','SR'),
											('0','Carlino','33050','UD'),
											('0','Carloforte','09014','CA'),
											('0','Carlopoli','88040','CZ'),
											('0','Carmagnola','10022','TO'),
											('0','Carmiano','29020','PC'),
											('0','Carmiano','73041','LE'),
											('0','Carmignanello','59022','PO'),
											('0','Carmignano','59015','PO'),
											('0','Carmignano di Brenta','35010','PD'),
											('0','Carnago','21040','VA'),
											('0','Carnaiola','05010','TR'),
											('0','Carnate','20040','MI'),
											('0','Carnello','03030','FR'),
											('0','Carobbio degli Angeli','24060','BG'),
											('0','Carolei','87030','CS'),
											('0','Carona','24010','BG'),
											('0','Caronia','98072','ME'),
											('0','Caroniti','89863','VV'),
											('0','Caronno Pertusella','21042','VA'),
											('0','Caronno Varesino','21040','VA'),
											('0','Carosino','74021','TA'),
											('0','Carovigno','72012','BR'),
											('0','Carovilli','86083','IS'),
											('0','Carpacco','33030','UD'),
											('0','Carpadasco','43049','PR'),
											('0','Carpan','36020','VI'),
											('0','Carpaneto','43028','PR'),
											('0','Carpaneto Piacentino','29013','PC'),
											('0','Carpani','57037','LI'),
											('0','Carpanzano','87050','CS'),
											('0','Carpari','74010','TA'),
											('0','Carpasio','18010','IM'),
											('0','Carpegna','61021','PU'),
											('0','Carpenedo','30175','VE'),
											('0','Carpenedolo','25013','BS'),
											('0','Carpeneto','15071','AL'),
											('0','Carpesica','31010','TV'),
											('0','Carpi','41012','MO'),
											('0','Carpi di Villa Bartolomea','37040','VR'),
											('0','Carpiano','20080','MI'),
											('0','Carpignano','83035','AV'),
											('0','Carpignano Salentino','73020','LE'),
											('0','Carpignano Sesia','28064','NO'),
											('0','Carpinelli','55030','LU'),
											('0','Carpinello','47010','FC'),
											('0','Carpineti','42033','RE'),
											('0','Carpineto della Nora','65010','PE'),
											('0','Carpineto Romano','00032','RM'),
											('0','Carpineto Sinello','66030','CH'),
											('0','Carpino','71010','FG'),
											('0','Carpinone','86093','IS'),
											('0','Carrabba','95010','CT'),
											('0','Carraia','55061','LU'),
											('0','Carrara','54033','MS'),
											('0','Carrara San Giorgio','35020','PD'),
											('0','Carrara Santo Stefano','35020','PD'),
											('0','Carrassi','70125','BA'),
											('0','Carr','36010','VI'),
											('0','Carrega Ligure','15060','AL'),
											('0','Carrito','67050','AQ'),
											('0','Carro','19012','SP'),
											('0','Carrodano','19020','SP'),
											('0','Carrone','10010','TO'),
											('0','Carrosio','15060','AL'),
											('0','Carr','12061','CN'),
											('0','Carruba','95010','CT'),
											('0','Carrufo','67020','AQ'),
											('0','Carseggio','40025','BO'),
											('0','Carsi','16010','GE'),
											('0','Carsoli','67061','AQ'),
											('0','Cartabbia','21100','VA'),
											('0','Cartari','18022','IM'),
											('0','Cartecchio','64020','TE'),
											('0','Cartigliano','36050','VI'),
											('0','Cartignano','12020','CN'),
											('0','Cartoceto','61030','PU'),
											('0','Cartosio','15015','AL'),
											('0','Cartura','35025','PD'),
											('0','Carugate','20061','MI'),
											('0','Carugo','22060','CO'),
											('0','Carunchio','66050','CH'),
											('0','Carvico','24030','BG'),
											('0','Carzago della Riviera','25080','BS'),
											('0','Carzano','38050','TN'),
											('0','Casa Calistri','40045','BO'),
											('0','Casa Castalda','06020','PG'),
											('0','Casa del Conte','85030','PZ'),
											('0','Casa Selvatica','43030','PR'),
											('0','Casabasciana','55050','LU'),
											('0','Casabianca','14100','AT'),
											('0','Casabianca','00043','RM'),
											('0','Casabona','88822','KR'),
											('0','Casacalenda','86043','CB'),
											('0','Casacanditella','66010','CH'),
											('0','Casaccia Centro Studi Nucleari','00060','RM'),
											('0','Casadio','40050','BO'),
											('0','Casaferro','80034','NA'),
											('0','Casafredda','81057','CE'),
											('0','Casagiove','81022','CE'),
											('0','Casaglia','50034','FI'),
											('0','Casaglia','40135','BO'),
											('0','Casal Borsetti','48010','RA'),
											('0','Casal Cermelli','15072','AL'),
											('0','Casal di Basso','87040','CS'),
											('0','Casal di Principe','81033','CE'),
											('0','Casal Palocco','00124','RM'),
											('0','Casal Velino Marina','84050','SA'),
											('0','Casal Velino Scalo','84040','SA'),
											('0','Casalalta','06050','PG'),
											('0','Casalanguida','66031','CH'),
											('0','Casalattico','03030','FR'),
											('0','Casalbagliano','15020','AL'),
											('0','Casalbellotto','26040','CR'),
											('0','Casalbeltrame','28060','NO'),
											('0','Casalbordino','66021','CH'),
											('0','Casalbordino Stazione','66020','CH'),
											('0','Casalbore','83034','AV'),
											('0','Casalborgone','10020','TO'),
											('0','Casalbuono','84030','SA'),
											('0','Casalbuttano','26011','CR'),
											('0','Casalcassinese','03040','FR'),
											('0','Casalciprano','86010','CB'),
											('0','Casalduni','82027','BN'),
											('0','Casale','43055','PR'),
											('0','Casale','46034','MN'),
											('0','Casale','81030','CE'),
											('0','Casale','81057','CE'),
											('0','Casale Corte Cerro','28881','VB'),
											('0','Casale Cremasco Vidolasco','26010','CR'),
											('0','Casale di Pari','58040','GR'),
											('0','Casale di Scodosia','35040','PD'),
											('0','Casale di Tornolo','43050','PR'),
											('0','Casale Litta','21020','VA'),
											('0','Casale Marittimo','56040','PI'),
											('0','Casale Monferrato','15033','AL'),
											('0','Casale Sul Sile','31032','TV'),
											('0','Casalecchio di Reno','40033','BO'),
											('0','Casaleggio Boiro','15070','AL'),
											('0','Casaleggio Novara','28060','NO'),
											('0','Casaleone','37052','VR'),
											('0','Casaletto Ceredano','26010','CR'),
											('0','Casaletto di Sopra','26014','CR'),
											('0','Casaletto Lodigiano','26852','LO'),
											('0','Casaletto Spartano','84030','SA'),
											('0','Casaletto Vaprio','26010','CR'),
											('0','Casalfiumanese','40020','BO'),
											('0','Casalgiate','28100','NO'),
											('0','Casalgrande','42013','RE'),
											('0','Casalgrasso','12030','CN'),
											('0','Casalguidi','51034','PT'),
											('0','Casali','87100','CS'),
											('0','Casali d\'Aschi','67050','AQ'),
											('0','Casali di Roccapiemonte','84080','SA'),
											('0','Casalina','06051','PG'),
											('0','Casalincontrada','66012','CH'),
											('0','Casalini','72010','BR'),
											('0','Casalino','28060','NO'),
											('0','Casalino di Mombello','15020','AL'),
											('0','Casalmaggiore','26041','CR'),
											('0','Casalmaiocco','26831','LO'),
											('0','Casalmorano','26020','CR'),
											('0','Casalmoro','46040','MN'),
											('0','Casalnoceto','15052','AL'),
											('0','Casalnuovo d\'Africo','89030','RC'),
											('0','Casalnuovo di Napoli','80013','NA'),
											('0','Casalnuovo Monterotaro','71033','FG'),
											('0','Casaloldo','46040','MN'),
											('0','Casalpusterlengo','26841','LO'),
											('0','Casalromano','46040','MN'),
											('0','Casalserugo','35020','PD'),
											('0','Casalsigone','26010','CR'),
											('0','Casalsottano','84040','SA'),
											('0','Casaluce','81030','CE'),
											('0','Casalvecchio di Puglia','71030','FG'),
											('0','Casalvecchio Siculo','98032','ME'),
											('0','Casalvelino','84040','SA'),
											('0','Casalvieri','03034','FR'),
											('0','Casalvolone','28060','NO'),
											('0','Casalzuigno','21030','VA'),
											('0','Casamaina di Lucoli','67040','AQ'),
											('0','Casamarciano','80032','NA'),
											('0','Casamari','03020','FR'),
											('0','Casamassella','73020','LE'),
											('0','Casamassima','70010','BA'),
											('0','Casamazzagno','32040','BL'),
											('0','Casamicciola Terme','80074','NA'),
											('0','Casamostra','81057','CE'),
											('0','Casandrino','80025','NA'),
											('0','Casano','19034','SP'),
											('0','Casanova','16023','GE'),
											('0','Casanova','17019','SV'),
											('0','Casanova','81030','CE'),
											('0','Casanova di Destra','27050','PV'),
											('0','Casanova Elvo','13030','VC'),
											('0','Casanova Lanza','','CO'),
											('0','Casanova Lerrone','17033','SV'),
											('0','Casanova Lonati','27041','PV'),
											('0','Casape','00010','RM'),
											('0','Casapesenna','81030','CE'),
											('0','Casapinta','13823','BI'),
											('0','Casaprota','02030','RI'),
											('0','Casapulla','81020','CE'),
											('0','Casarano','73042','LE'),
											('0','Casargo','23831','LC'),
											('0','Casarile','20080','MI'),
											('0','Casarsa della Delizia','33072','PN'),
											('0','Casarza Ligure','16030','GE'),
											('0','Casasco','15050','AL'),
											('0','Casasco d\'Intelvi','22022','CO'),
											('0','Casatenovo','23880','LC'),
											('0','Casatico','46010','MN'),
											('0','Casatisma','27040','PV'),
											('0','Casavatore','80020','NA'),
											('0','Casavecchia','62036','MC'),
											('0','Casazza','24060','BG'),
											('0','Casbeno','21100','VA'),
											('0','Cascano','81037','CE'),
											('0','Cascia','06043','PG'),
											('0','Cascia','50066','FI'),
											('0','Casciago','21020','VA'),
											('0','Casciana Alta','56035','PI'),
											('0','Casciana Terme','56034','PI'),
											('0','Casciano','53010','SI'),
											('0','Cascina','56021','PI'),
											('0','Cascina Amata','22060','CO'),
											('0','Cascina Buon Ges','21057','VA'),
											('0','Cascina Nuova di Misinto','20020','MI'),
											('0','Cascinagrossa','15040','AL'),
											('0','Cascinare','63011','AP'),
											('0','Cascine','56032','PI'),
											('0','Cascine Gandini','26020','CR'),
											('0','Cascine Vica','10090','TO'),
											('0','Cascinette d\'Ivrea','10010','TO'),
											('0','Case del Conte','84040','SA'),
											('0','Case di Nava','18024','IM'),
											('0','Case Forlai','40045','BO'),
											('0','Case Mezzano','48018','RA'),
											('0','Case San Martino','48018','RA'),
											('0','Casei Gerola','27050','PV'),
											('0','Caselette','10040','TO'),
											('0','Casella','16015','GE'),
											('0','Casella d\'Asolo','31011','TV'),
											('0','Caselle','37040','VR'),
											('0','Caselle','40014','BO'),
											('0','Caselle di Altivole','31030','TV'),
											('0','Caselle di Selvazzano Dentro','35030','PD'),
											('0','Caselle di Sommacampagna','37060','VR'),
											('0','Caselle in Pittari','84030','SA'),
											('0','Caselle Landi','26842','LO'),
											('0','Caselle Lurani','26853','LO'),
											('0','Caselle Torinese','10072','TO'),
											('0','Casellina','50018','FI'),
											('0','Casenove','06030','PG'),
											('0','Casenove','27040','PV'),
											('0','Casenuove','01020','VT'),
											('0','Caserta','81100','CE'),
											('0','Caserta Vecchia','81020','CE'),
											('0','Casette','54030','MS'),
											('0','Casette','02030','RI'),
											('0','Casette','37045','VR'),
											('0','Casette d\'Ete','63011','AP'),
											('0','Casez','38010','TN'),
											('0','Casi','81057','CE'),
											('0','Casiacco','33090','PN'),
											('0','Casier','31030','TV'),
											('0','Casigliano','05021','TR'),
											('0','Casignana','89030','RC'),
											('0','Casilli','80047','NA'),
											('0','Casina','42034','RE'),
											('0','Casinalbo','41041','MO'),
											('0','Casine','41029','MO'),
											('0','Casinina','61020','PU'),
											('0','Casino di Terra','56040','PI'),
											('0','Casino Pica','03042','FR'),
											('0','Casirate d\'Adda','24040','BG'),
											('0','Casletto','23849','LC'),
											('0','Caslino Al Piano','22070','CO'),
											('0','Caslino d\'Erba','22030','CO'),
											('0','Casnate','22070','CO'),
											('0','Casnigo','24020','BG'),
											('0','Casola','41045','MO'),
											('0','Casola','43030','PR'),
											('0','Casola','80050','NA'),
											('0','Casola','83020','AV'),
											('0','Casola di Caserta','81020','CE'),
											('0','Casola in Lunigiana','54014','MS'),
											('0','Casola Valsenio','48010','RA'),
											('0','Casole Bruzio','87050','CS'),
											('0','Casole d\'Elsa','53031','SI'),
											('0','Casoli','55060','LU'),
											('0','Casoli','66043','CH'),
											('0','Casoli di Atri','64030','TE'),
											('0','Casolla','81100','CE'),
											('0','Casone','58010','GR'),
											('0','Casoni','36060','VI'),
											('0','Casoni','40051','BO'),
											('0','Casoni','16023','GE'),
											('0','Casoni','42010','RE'),
											('0','Casorate Primo','27022','PV'),
											('0','Casorate Sempione','21011','VA'),
											('0','Casore del Monte','51030','PT'),
											('0','Casorezzo','20010','MI'),
											('0','Casoria','80026','NA'),
											('0','Casorzo','14032','AT'),
											('0','Casotto','36040','VI'),
											('0','Casperia','02041','RI'),
											('0','Caspoggio','23020','SO'),
											('0','Caspoli','81049','CE'),
											('0','Cassacco','33010','UD'),
											('0','Cassago Brianza','23893','LC'),
											('0','Cassana','44044','FE'),
											('0','Cassano','41040','MO'),
											('0','Cassano Caudino','83010','AV'),
											('0','Cassano d\'Adda','20062','MI'),
											('0','Cassano Delle Murge','70020','BA'),
											('0','Cassano Irpino','83040','AV'),
											('0','Cassano Jonio','87011','CS'),
											('0','Cassano Magnago','21012','VA'),
											('0','Cassano Spinola','15063','AL'),
											('0','Cassano Valcuvia','21030','VA'),
											('0','Cassaro','96010','SR'),
											('0','Cassegliano','34070','GO'),
											('0','Cassibile','96010','SR'),
											('0','Cassiglio','24010','BG'),
											('0','Cassina De\' Pecchi','20060','MI'),
											('0','Cassina Nuova','20021','MI'),
											('0','Cassina Rizzardi','22070','CO'),
											('0','Cassina Savina','20030','MI'),
											('0','Cassina Valsassina','23814','LC'),
											('0','Cassinasco','14050','AT'),
											('0','Cassine','15016','AL'),
											('0','Cassinelle','15070','AL'),
											('0','Cassinetta di Lugagnano','20081','MI'),
											('0','Cassingheno','16020','GE'),
											('0','Cassino','03043','FR'),
											('0','Cassio','43040','PR'),
											('0','Cassola','36022','VI'),
											('0','Cassolnovo','27023','PV'),
											('0','Cassolo','29020','PC'),
											('0','Cassone','37018','VR'),
											('0','Castagna','88040','CZ'),
											('0','Castagnaro','37043','VR'),
											('0','Castagneto','41026','MO'),
											('0','Castagneto','42030','RE'),
											('0','Castagneto','64040','TE'),
											('0','Castagneto Carducci','57022','LI'),
											('0','Castagneto Po','10090','TO'),
											('0','Castagnito','12050','CN'),
											('0','Castagnola di Fraconalto','15060','AL'),
											('0','Castagnole','31038','TV'),
											('0','Castagnole Lanze','14054','AT'),
											('0','Castagnole Monferrato','14030','AT'),
											('0','Castagnole Piemonte','10060','TO'),
											('0','Castagnoli','53010','SI'),
											('0','Castana','27040','PV'),
											('0','Castana','36010','VI'),
											('0','Castanea','98155','ME'),
											('0','Castano Primo','20022','MI'),
											('0','Casteggio','27045','PV'),
											('0','Castegnato','25045','BS'),
											('0','Castegnero','36020','VI'),
											('0','Castel Baronia','83040','AV'),
											('0','Castel Boglione','14040','AT'),
											('0','Castel Bolognese','48014','RA'),
											('0','Castel Campagnano','81010','CE'),
											('0','Castel Castagna','64030','TE'),
											('0','Castel Cellesi','01020','VT'),
											('0','Castel Colonna','60010','AN'),
											('0','Castel Condino','38082','TN'),
											('0','Castel d\'Aiano','40034','BO'),
											('0','Castel d\'Ario','46033','MN'),
											('0','Castel d\'Azzano','37060','VR'),
											('0','Castel De\' Conti','24060','BG'),
											('0','Castel dei Britti','40068','BO'),
											('0','Castel del Bosco','10060','TO'),
											('0','Castel del Bosco','56020','PI'),
											('0','Castel del Giudice','86080','IS'),
											('0','Castel del Monte','67023','AQ'),
											('0','Castel del Piano','58033','GR'),
											('0','Castel del Piano Umbro','06071','PG'),
											('0','Castel del Rio','40022','BO'),
											('0','Castel Dell\'Alpi','40048','BO'),
											('0','Castel Dell\'Aquila','05020','TR'),
											('0','Castel d\'Emilio','60020','AN'),
											('0','Castel di Casio','40030','BO'),
											('0','Castel di Croce','63030','AP'),
											('0','Castel di Decima','00128','RM'),
											('0','Castel di Guido','00057','RM'),
											('0','Castel di Ieri','67020','AQ'),
											('0','Castel di Judica','95040','CT'),
											('0','Castel di Lama Piattoni','63031','AP'),
											('0','Castel di Lama Stazione','63031','AP'),
											('0','Castel di Leva','00134','RM'),
											('0','Castel di Lucio','98070','ME'),
											('0','Castel di Pietra','58027','GR'),
											('0','Castel di Sangro','67031','AQ'),
											('0','Castel di Sasso','81040','CE'),
											('0','Castel di Tora','02020','RI'),
											('0','Castel di Tusa','98070','ME'),
											('0','Castel Focognano','52016','AR'),
											('0','Castel Frentano','66032','CH'),
											('0','Castel Fusano','00122','RM'),
											('0','Castel Gabbiano','26010','CR'),
											('0','Castel Gandolfo','00040','RM'),
											('0','Castel Giorgio','05013','TR'),
											('0','Castel Giubileo','00138','RM'),
											('0','Castel Giuliano','00062','RM'),
											('0','Castel Goffredo','46042','MN'),
											('0','Castel Guelfo di Bologna','40023','BO'),
											('0','Castel Madama','00024','RM'),
											('0','Castel Madruzzo','38076','TN'),
											('0','Castel Maggiore','40013','BO'),
											('0','Castel Morrone','81020','CE'),
											('0','Castel Porziano','00122','RM'),
											('0','Castel Rigone','06060','PG'),
											('0','Castel Ritaldi','06044','PG'),
											('0','Castel Rocchero','14044','AT'),
											('0','Castel Romano','00128','RM'),
											('0','Castel Rozzone','24040','BG'),
											('0','Castel Ruggero','84040','SA'),
											('0','Castel San Giminiano','53030','SI'),
											('0','Castel San Giorgio','84083','SA'),
											('0','Castel San Giovanni','29015','PC'),
											('0','Castel San Lorenzo','84049','SA'),
											('0','Castel San Niccol','52018','AR'),
											('0','Castel San Pietro','02030','RI'),
											('0','Castel San Pietro','62027','MC'),
											('0','Castel San Pietro Monferrato','15020','AL'),
											('0','Castel San Pietro Romano','00030','RM'),
											('0','Castel San Pietro Terme','40024','BO'),
											('0','Castel San Vincenzo','86071','IS'),
											('0','Castel Sant\'Angelo','02010','RI'),
											('0','Castel Sant\'Elia','01030','VT'),
											('0','Castel Trosino','63100','AP'),
											('0','Castel Viscardo','05014','TR'),
											('0','Castel Vittorio','18037','IM'),
											('0','Castel Volturno','81030','CE'),
											('0','Castelbaldo','35040','PD'),
											('0','Castelbasso','64020','TE'),
											('0','Castelbelforte','46032','MN'),
											('0','Castelbellino','60030','AN'),
											('0','Castelbello Ciardes','39020','BZ'),
											('0','Castelbianco','17030','SV'),
											('0','Castelbottaccio','86030','CB'),
											('0','Castelbuono','90013','PA'),
											('0','Castelcavallino','61029','PU'),
											('0','Castelceriolo','15040','AL'),
											('0','Castelchiodato','00010','RM'),
											('0','Castelcivita','84020','SA'),
											('0','Castelcovati','25030','BS'),
											('0','Castelcucco','31030','TV'),
											('0','Casteldaccia','90014','PA'),
											('0','Casteldelci','61010','PU'),
											('0','Casteldelfino','12020','CN'),
											('0','Casteldidone','26030','CR'),
											('0','Casteldilago','05031','TR'),
											('0','Castelferretti','60020','AN'),
											('0','Castelferro','15070','AL'),
											('0','Castelfidardo','60022','AN'),
											('0','Castelfiorentino','50051','FI'),
											('0','Castelfirmiano','39010','BZ'),
											('0','Castelfondo','38020','TN'),
											('0','Castelforte','04021','LT'),
											('0','Castelfranci','83040','AV'),
											('0','Castelfranco di Sopra','52020','AR'),
											('0','Castelfranco di Sotto','56022','PI'),
											('0','Castelfranco Emilia','41013','MO'),
											('0','Castelfranco in Miscano','82022','BN'),
											('0','Castelfranco Veneto','31033','TV'),
											('0','Castelgomberto','36070','VI'),
											('0','Castelgrande','85050','PZ'),
											('0','Castelguelfo','43010','PR'),
											('0','Castelguglielmo','45020','RO'),
											('0','Castelguidone','66040','CH'),
											('0','Castellabate','84048','SA'),
											('0','Castellaccio (Prov.Di Frosinone)','00030','RM'),
											('0','Castellace','89010','RC'),
											('0','Castellafiume','67050','AQ'),
											('0','Castell\'Alfero','14033','AT'),
											('0','Castellalto','64020','TE'),
											('0','Castellammare del Golfo','91014','TP'),
											('0','Castellammare di Stabia','80053','NA'),
											('0','Castellamonte','10081','TO'),
											('0','Castellana Grotte','70013','BA'),
											('0','Castellana Sicula','90020','PA'),
											('0','Castellaneta','74011','TA'),
											('0','Castellaneta Marina','','TA'),
											('0','Castellania','15051','AL'),
											('0','Castell\'Anselmo','57010','LI'),
											('0','Castellanza','21053','VA'),
											('0','Castellar','12030','CN'),
											('0','Castellar Guidobono','15050','AL'),
											('0','Castellar Ponzano','15050','AL'),
											('0','Castellarano','42014','RE'),
											('0','Castellare di Pescia','51012','PT'),
											('0','Castellaro','18011','IM'),
											('0','Castellaro','60040','AN'),
											('0','Castellaro De\' Giorgi','27030','PV'),
											('0','Castellaro nel Frignano','41029','MO'),
											('0','Castell\'Arquato','29014','PC'),
											('0','Castell\'Azzara','58034','GR'),
											('0','Castellazzo','42048','RE'),
											('0','Castellazzo Bormida','15073','AL'),
											('0','Castellazzo Novarese','28060','NO'),
											('0','Castellengo','13836','BI'),
											('0','Castelleone','26012','CR'),
											('0','Castelleone di Suasa','60010','AN'),
											('0','Castellero','14013','AT'),
											('0','Castelletta','60040','AN'),
											('0','Castelletto Busca','12022','CN'),
											('0','Castelletto Cervo','13851','BI'),
											('0','Castelletto d\'Erro','15010','AL'),
											('0','Castelletto di Branduzzo','27040','PV'),
											('0','Castelletto di Brenzone','37010','VR'),
											('0','Castelletto di Leno','25024','BS'),
											('0','Castelletto d\'Orba','15060','AL'),
											('0','Castelletto Merli','15020','AL'),
											('0','Castelletto Molina','14040','AT'),
											('0','Castelletto Monferrato','15040','AL'),
											('0','Castelletto Stura','12040','CN'),
											('0','Castelletto Ticino','28053','NO'),
											('0','Castelletto Uzzone','12070','CN'),
											('0','Castelli','64041','TE'),
											('0','Castelli Calepio','24060','BG'),
											('0','Castellina in Chianti','53011','SI'),
											('0','Castellina in Chianti Stazione','53032','SI'),
											('0','Castellina Marittima','56040','PI'),
											('0','Castellinaldo','12050','CN'),
											('0','Castellino Brocco','41020','MO'),
											('0','Castellino del Biferno','86020','CB'),
											('0','Castellino Delle Formiche','41050','MO'),
											('0','Castellino Tanaro','12060','CN'),
											('0','Castelliri','03030','FR'),
											('0','Castello','80036','NA'),
											('0','Castello','51020','PT'),
											('0','Castello','50141','FI'),
											('0','Castello','19012','SP'),
											('0','Castello','41020','MO'),
											('0','Castello Cabiaglio','21030','VA'),
											('0','Castello d\'Agogna','27030','PV'),
											('0','Castello d\'Alvito','03041','FR'),
											('0','Castello d\'Argile','40050','BO'),
											('0','Castello del Lago','83030','AV'),
											('0','Castello Dell\'Acqua','23030','SO'),
											('0','Castello di Annone','14034','AT'),
											('0','Castello di Brianza','23884','LC'),
											('0','Castello di Cisterna','80030','NA'),
											('0','Castello di Fiemme','38030','TN'),
											('0','Castello di Godego','31030','TV'),
											('0','Castello di Querceto','56040','PI'),
											('0','Castello di Serravalle','40050','BO'),
											('0','Castello Inici','91014','TP'),
											('0','Castello Lavazzo','32010','BL'),
											('0','Castello Matese','81016','CE'),
											('0','Castello Roganzuolo','31010','TV'),
											('0','Castello Tesino','38053','TN'),
											('0','Castellonchio','43030','PR'),
											('0','Castellone di Boiano','86020','CB'),
											('0','Castellonorato','04020','LT'),
											('0','Castell\'Ottieri','58010','GR'),
											('0','Castellucchio','46014','MN'),
											('0','Castelluccio','84080','SA'),
											('0','Castelluccio','96017','SR'),
											('0','Castelluccio','40046','BO'),
											('0','Castelluccio','06046','PG'),
											('0','Castelluccio Cosentino','84030','SA'),
											('0','Castelluccio dei Sauri','71025','FG'),
											('0','Castelluccio di Moscheda','41055','MO'),
											('0','Castelluccio Inferiore','85040','PZ'),
											('0','Castelluccio Superiore','85040','PZ'),
											('0','Castelluccio Valmaggiore','71020','FG'),
											('0','Castell\'Umberto','98070','ME'),
											('0','Castelluzzo','91010','TP'),
											('0','Castelmaggiore','56011','PI'),
											('0','Castelmagno','12020','CN'),
											('0','Castelmareri','02023','RI'),
											('0','Castelmarte','22030','CO'),
											('0','Castelmartini','51030','PT'),
											('0','Castelmassa','45035','RO'),
											('0','Castelmassimo','03020','FR'),
											('0','Castelmauro','86031','CB'),
											('0','Castelmella','25030','BS'),
											('0','Castelmezzano','85010','PZ'),
											('0','Castelminio','31023','TV'),
											('0','Castelmola','98030','ME'),
											('0','Castelmonte','33040','UD'),
											('0','Castelmuzio','53020','SI'),
											('0','Castelnovetto','27030','PV'),
											('0','Castelnovo','36033','VI'),
											('0','Castelnovo Bariano','45030','RO'),
											('0','Castelnovo del Friuli','33090','PN'),
											('0','Castelnovo di Sotto','42024','RE'),
											('0','Castelnovo Ne\' Monti','42035','RE'),
											('0','Castelnovo Val Tidone','29010','PC'),
											('0','Castelnuovo Al Volturno','86070','IS'),
											('0','Castelnuovo Asolano','46040','MN'),
											('0','Castelnuovo Belbo','14043','AT'),
											('0','Castelnuovo Berardenga','53019','SI'),
											('0','Castelnuovo Bocca d\'Adda','26843','LO'),
											('0','Castelnuovo Bormida','15017','AL'),
											('0','Castelnuovo Bozzente','22070','CO'),
											('0','Castelnuovo Calcea','14040','AT'),
											('0','Castelnuovo Cilento','84040','SA'),
											('0','Castelnuovo d\'Assisi','06088','PG'),
											('0','Castelnuovo dei Sabbioni','52020','AR'),
											('0','Castelnuovo del Garda','37014','VR'),
											('0','Castelnuovo della  Misericordia','57011','LI'),
											('0','Castelnuovo della Daunia','71034','FG'),
											('0','Castelnuovo Dell\'Abate','53020','SI'),
											('0','Castelnuovo d\'Elsa','50051','FI'),
											('0','Castelnuovo di Ceva','12070','CN'),
											('0','Castelnuovo di Conza','84020','SA'),
											('0','Castelnuovo di Farfa','02031','RI'),
											('0','Castelnuovo di Garfagnana','55032','LU'),
											('0','Castelnuovo di Porto','00060','RM'),
											('0','Castelnuovo di San Pio Delle Camere','67020','AQ'),
											('0','Castelnuovo Don Bosco','14022','AT'),
											('0','Castelnuovo Fogliani','29010','PC'),
											('0','Castelnuovo Magra','19030','SP'),
											('0','Castelnuovo Nigra','10080','TO'),
											('0','Castelnuovo Parano','03040','FR'),
											('0','Castelnuovo Rangone','41051','MO'),
											('0','Castelnuovo Scrivia','15053','AL'),
											('0','Castelnuovo Val di Cecina','56041','PI'),
											('0','Castelnuovo Vallo Stazione','84040','SA'),
											('0','Castelnuovo Valsugana','38050','TN'),
											('0','Castelnuovo Vomano','64020','TE'),
											('0','Castelpagano','82024','BN'),
											('0','Castelpetroso','86090','IS'),
											('0','Castelpizzuto','86090','IS'),
											('0','Castelplanio','60031','AN'),
											('0','Castelplanio Stazione','60032','AN'),
											('0','Castelponzone','26040','CR'),
											('0','Castelpoto','82030','BN'),
											('0','Castelraimondo','62022','MC'),
											('0','Castelromano','86170','IS'),
											('0','Castelrosso','10033','TO'),
											('0','Castelrotto','12050','CN'),
											('0','Castelrotto','39040','BZ'),
											('0','Castelsantangelo Sul Nera','62039','MC'),
											('0','Castelsaraceno','85031','PZ'),
											('0','Castelsardo','07031','SS'),
											('0','Castelseprio','21050','VA'),
											('0','Castelsilano','88834','KR'),
											('0','Castelspina','15070','AL'),
											('0','Casteltermini','92025','AG'),
											('0','Casteltermini Zolfare','92020','AG'),
											('0','Casteltodino','05020','TR'),
											('0','Castelveccana','21010','VA'),
											('0','Castelvecchio','36078','VI'),
											('0','Castelvecchio','61040','PU'),
											('0','Castelvecchio Calvisio','67020','AQ'),
											('0','Castelvecchio di Rocca Barbena','17034','SV'),
											('0','Castelvecchio di Santa Maria Maggiore','18100','IM'),
											('0','Castelvecchio di Vellano','51010','PT'),
											('0','Castelvecchio Pascoli','55020','LU'),
											('0','Castelvecchio Subequo','67024','AQ'),
											('0','Castelvecchio sulla Secchia','41048','MO'),
											('0','Castelvenere','82037','BN'),
											('0','Castelverde','26022','CR'),
											('0','Castelverde di Lunghezza','00010','RM'),
											('0','Castelverrino','86081','IS'),
											('0','Castelvetere in Val Fortore','82023','BN'),
											('0','Castelvetere Sul Calore','83040','AV'),
											('0','Castelvetrano','91022','TP'),
											('0','Castelvetro di Modena','41014','MO'),
											('0','Castelvetro Piacentino','29010','PC'),
											('0','Castelvisconti','26010','CR'),
											('0','Castenaso','40055','BO'),
											('0','Castenedolo','25014','BS'),
											('0','Castiadas','09040','CA'),
											('0','Castiglion Fibocchi','52029','AR'),
											('0','Castiglion Fiorentino','52043','AR'),
											('0','Castiglion Fosco','06060','PG'),
											('0','Castiglioncello','57012','LI'),
											('0','Castiglioncello Bandini','58040','GR'),
											('0','Castiglione','73030','LE'),
											('0','Castiglione','86083','IS'),
											('0','Castiglione a Casauria','65020','PE'),
											('0','Castiglione Chiavarese','16030','GE'),
											('0','Castiglione Cosentino','87040','CS'),
											('0','Castiglione Cosentino Stazione','87030','CS'),
											('0','Castiglione d\'Adda','26823','LO'),
											('0','Castiglione d\'Asti','14037','AT'),
											('0','Castiglione dei Pepoli','40035','BO'),
											('0','Castiglione del Genovesi','84090','SA'),
											('0','Castiglione del Lago','06061','PG'),
											('0','Castiglione della Pescaia','58043','GR'),
											('0','Castiglione della Valle','06072','PG'),
											('0','Castiglione Delle Stiviere','46043','MN'),
											('0','Castiglione di Garfagnana','55033','LU'),
											('0','Castiglione di Ravenna','48010','RA'),
											('0','Castiglione di Sicilia','95012','CT'),
											('0','Castiglione d\'Intelvi','22023','CO'),
											('0','Castiglione d\'Orcia','53023','SI'),
											('0','Castiglione d\'Ossola','28874','VB'),
											('0','Castiglione Falletto','12060','CN'),
											('0','Castiglione in Teverina','01024','VT'),
											('0','Castiglione Mantovano','46048','MN'),
											('0','Castiglione Marittimo','88042','CZ'),
											('0','Castiglione Messer Marino','66033','CH'),
											('0','Castiglione Messer Raimondo','64034','TE'),
											('0','Castiglione Olona','21043','VA'),
											('0','Castiglione Tinella','12053','CN'),
											('0','Castiglione Torinese','10090','TO'),
											('0','Castiglioni d\'Arcevia','60010','AN'),
											('0','Castignano','63032','AP'),
											('0','Castilenti','64035','TE'),
											('0','Castino','12050','CN'),
											('0','Castion','32024','BL'),
											('0','Castione Andevenno','23012','SO'),
											('0','Castione De\' Baratti','43020','PR'),
											('0','Castione dei Marchesi','43030','PR'),
											('0','Castione della Presolana','24020','BG'),
											('0','Castione Veronese','37010','VR'),
											('0','Castions','33080','PN'),
											('0','Castions di Strada','33050','UD'),
											('0','Castiraga Vidardo','26866','LO'),
											('0','Casto','25070','BS'),
											('0','Castorano','63030','AP'),
											('0','Castrezzato','25030','BS'),
											('0','Castri di Lecce','73020','LE'),
											('0','Castrignano De\' Greci','73020','LE'),
											('0','Castrignano del Capo','73040','LE'),
											('0','Castro','24063','BG'),
											('0','Castro','73030','LE'),
											('0','Castro dei Volsci','03020','FR'),
											('0','Castro Marina','73030','LE'),
											('0','Castrocaro Terme','47011','FC'),
											('0','Castrocielo','03030','FR'),
											('0','Castrofilippo','92020','AG'),
											('0','Castrolibero','87040','CS'),
											('0','Castromediano','73020','LE'),
											('0','Castronno','21040','VA'),
											('0','Castronovo','67050','AQ'),
											('0','Castronuovo di Sant\'Andrea','85030','PZ'),
											('0','Castronuovo di Sicilia','90030','PA'),
											('0','Castropignano','86010','CB'),
											('0','Castroreale','98053','ME'),
											('0','Castroreale Terme','98050','ME'),
											('0','Castroregio','87070','CS'),
											('0','Castrovalva','67030','AQ'),
											('0','Castrovillari','87012','CS'),
											('0','Casumaro','44041','FE'),
											('0','Catabbio','58050','GR'),
											('0','Cataeggio','23010','SO'),
											('0','Cataforio','89060','RC'),
											('0','Catania','95100','CT'),
											('0','Catania Fontanarossa','95030','CT'),
											('0','Catanzaro','88100','CZ'),
											('0','Catanzaro Lido','88063','CZ'),
											('0','Catanzaro Sala','88100','CZ'),
											('0','Catena','51030','PT'),
											('0','Catenanuova','94010','EN'),
											('0','Catignano','65011','PE'),
											('0','Catona','89053','RC'),
											('0','Catona di Ascea','84040','SA'),
											('0','Cattabrighe','61100','PU'),
											('0','Cattafi','98044','ME'),
											('0','Cattinara','34149','TS'),
											('0','Cattolica','47841','RN'),
											('0','Cattolica Eraclea','92011','AG'),
											('0','Caturano','81047','CE'),
											('0','Caulonia','89041','RC'),
											('0','Cauria','39040','BZ'),
											('0','Cautano','82030','BN'),
											('0','Cava','47100','FC'),
											('0','Cava d\'Aliga','97010','RG'),
											('0','Cava De\' Tirreni','84013','SA'),
											('0','Cava di Catanzaro','88100','CZ'),
											('0','Cava d\'Ispica','97015','RG'),
											('0','Cava Manara','27051','PV'),
											('0','Cava Tigozzi','26100','CR'),
											('0','Cavacurta','26844','LO'),
											('0','Cavagli','13881','BI'),
											('0','Cavaglietto','28010','NO'),
											('0','Cavaglio d\'Agogna','28010','NO'),
											('0','Cavaglio Spoccia','28825','VB'),
											('0','Cavagnolo','10020','TO'),
											('0','Cavaion Veronese','37010','VR'),
											('0','Cavalcaselle','37010','VR'),
											('0','Cavalese','38033','TN'),
											('0','Cavalicco','33010','UD'),
											('0','Cavallasca','22020','CO'),
											('0','Cavallerleone','12030','CN'),
											('0','Cavallermaggiore','12030','CN'),
											('0','Cavallina','50031','FI'),
											('0','Cavallino','30013','VE'),
											('0','Cavallino','73020','LE'),
											('0','Cavallirio','28010','NO'),
											('0','Cavallo Pastorio','98060','ME'),
											('0','Cavalo','37020','VR'),
											('0','Cavandone','','VB'),
											('0','Cavanella d\'Adige','30010','VE'),
											('0','Cavanella Po','45013','RO'),
											('0','Cavanella Vara','19020','SP'),
											('0','Cavareno','38011','TN'),
											('0','Cavargna','22010','CO'),
											('0','Cavaria Con Premezzo','21044','VA'),
											('0','Cavarzano','59024','PO'),
											('0','Cavarzere','30014','VE'),
											('0','Cavasagra di Vedelago','31030','TV'),
											('0','Cavaso del Tomba','31034','TV'),
											('0','Cavasso Nuovo','33092','PN'),
											('0','Cavate','67039','AQ'),
											('0','Cavatore','15010','AL'),
											('0','Cavazzale','36010','VI'),
											('0','Cavazzana','45020','RO'),
											('0','Cavazzo Carnico','33020','UD'),
											('0','Cavazzoli','42100','RE'),
											('0','Cavazzona','41010','MO'),
											('0','Cave','81044','CE'),
											('0','Cave','00033','RM'),
											('0','Cave','81027','CE'),
											('0','Cave del Predil','33018','UD'),
											('0','Cavedago','38010','TN'),
											('0','Cavedine','38073','TN'),
											('0','Cavedon','45011','RO'),
											('0','Cavenago Brianza','20040','MI'),
											('0','Cavenago d\'Adda','26824','LO'),
											('0','Cavernago','24050','BG'),
											('0','Cavezzo','41032','MO'),
											('0','Cavi','16030','GE'),
											('0','Caviola','32020','BL'),
											('0','Cavizzana','38022','TN'),
											('0','Cavo','57030','LI'),
											('0','Cavola','42010','RE'),
											('0','Cavoli','57030','LI'),
											('0','Cavor di Gimigliano','88040','CZ'),
											('0','Cavoretto','10133','TO'),
											('0','Cavour','10061','TO'),
											('0','Cavriago','42025','RE'),
											('0','Cavriana','46040','MN'),
											('0','Cavriglia','52022','AR'),
											('0','Cazzago Brabbia','21020','VA'),
											('0','Cazzago di Pianiga','30030','VE'),
											('0','Cazzago San Martino','25046','BS'),
											('0','Cazzano di Tramigna','37030','VR'),
											('0','Cazzano Sant\'Andrea','24024','BG'),
											('0','Cecalocco','05100','TR'),
											('0','Ceccano','03023','FR'),
											('0','Cecchignola','00143','RM'),
											('0','Cecchina Stazione','00040','RM'),
											('0','Cecchini','33087','PN'),
											('0','Ceci','29022','PC'),
											('0','Ceciliano','52010','AR'),
											('0','Cecima','27050','PV'),
											('0','Cecina','57023','LI'),
											('0','Cecina Marina','57023','LI'),
											('0','Cedas','34136','TS'),
											('0','Cedegolo','25051','BS'),
											('0','Cedrasco','23010','SO'),
											('0','Cedrate','','VA'),
											('0','Cefal Diana','90030','PA'),
											('0','Cefal','90015','PA'),
											('0','Ceggia','30022','VE'),
											('0','Ceglie del Campo','70010','BA'),
											('0','Ceglie Messapica','72013','BR'),
											('0','Celana','24030','BG'),
											('0','Celano','67043','AQ'),
											('0','Celedizzo','38024','TN'),
											('0','Celenza Sul Trigno','66050','CH'),
											('0','Celenza Valfortore','71035','FG'),
											('0','Celesia','16040','GE'),
											('0','Celico','87053','CS'),
											('0','Cella','42040','RE'),
											('0','Cella','47020','FC'),
											('0','Cella Dati','26040','CR'),
											('0','Cella di Costamezzana','43015','PR'),
											('0','Cella Monte','15034','AL'),
											('0','Cellamare','70010','BA'),
											('0','Cellara','87050','CS'),
											('0','Cellarengo','14010','AT'),
											('0','Cellatica','25060','BS'),
											('0','Celle','48018','RA'),
											('0','Celle di Bulgheria','84040','SA'),
											('0','Celle Enomondo','14010','AT'),
											('0','Celle Ligure','17015','SV'),
											('0','Celle Macra','12020','CN'),
											('0','Celle San Vito','71020','FG'),
											('0','Celle Sul Rigo','53040','SI'),
											('0','Cellena','58050','GR'),
											('0','Celleno','01020','VT'),
											('0','Cellere','01010','VT'),
											('0','Cellino Attanasio','64036','TE'),
											('0','Cellino San Marco','72020','BR'),
											('0','Cellio','13024','VC'),
											('0','Cellole','81030','CE'),
											('0','Cellore','37030','VR'),
											('0','Celso','84050','SA'),
											('0','Celzi','83020','AV'),
											('0','Cembra','38034','TN'),
											('0','Cenadi','88067','CZ'),
											('0','Cenaia','56040','PI'),
											('0','Cenate Sopra','24060','BG'),
											('0','Cenate Sotto','24069','BG'),
											('0','Cencenighe Agordino','32020','BL'),
											('0','Cene','24020','BG'),
											('0','Cenerente','06070','PG'),
											('0','Ceneselli','45030','RO'),
											('0','Cengio','17056','SV'),
											('0','Cengles','39020','BZ'),
											('0','Ceniga','38074','TN'),
											('0','Cenova','18026','IM'),
											('0','Centa San Nicol','38040','TN'),
											('0','Centallo','12044','CN'),
											('0','Centenaro','25010','BS'),
											('0','Centenaro','29020','PC'),
											('0','Centergross','','BO'),
											('0','Cento','44042','FE'),
											('0','Centobuchi','63033','AP'),
											('0','Centoia','52040','AR'),
											('0','Centola','84051','SA'),
											('0','Centrache','88067','CZ'),
											('0','Centro','37039','VR'),
											('0','Centurano','81100','CE'),
											('0','Centuripe','94010','EN'),
											('0','Cepagatti','65012','PE'),
											('0','Ceparana','19020','SP'),
											('0','Cepina Valdisotto','23030','SO'),
											('0','Ceppagna','86079','IS'),
											('0','Ceppaloni','82010','BN'),
											('0','Ceppo Morelli','28875','VB'),
											('0','Ceprano','03024','FR'),
											('0','Cerageto','55030','LU'),
											('0','Cerami','94010','EN'),
											('0','Ceranesi','16014','GE'),
											('0','Cerano','28065','NO'),
											('0','Cerano d\'Intelvi','22020','CO'),
											('0','Ceranova','27010','PV'),
											('0','Cerasa','61039','PU'),
											('0','Cerasi','89060','RC'),
											('0','Ceraso','84052','SA'),
											('0','Cerasolo','47852','RN'),
											('0','Cerasomma','55050','LU'),
											('0','Cerasuolo','86074','IS'),
											('0','Cerati','12012','CN'),
											('0','Cerbaia','50020','FI'),
											('0','Cerbara','06011','PG'),
											('0','Cercemaggiore','86012','CB'),
											('0','Cercenasco','10060','TO'),
											('0','Cercepiccola','86010','CB'),
											('0','Cerchiara di Calabria','87070','CS'),
											('0','Cerchiate','20016','MI'),
											('0','Cerchio','67044','AQ'),
											('0','Cercino','23016','SO'),
											('0','Cercivento','33020','UD'),
											('0','Cercola','80040','NA'),
											('0','Cerda','90010','PA'),
											('0','Cerdomare','02037','RI'),
											('0','Cerea','37053','VR'),
											('0','Cereda','36073','VI'),
											('0','Cereglio','40038','BO'),
											('0','Ceregnano','45010','RO'),
											('0','Cerenova','','RM'),
											('0','Cerenzia','88833','KR'),
											('0','Ceres','10070','TO'),
											('0','Ceresara','46040','MN'),
											('0','Cereseto','43050','PR'),
											('0','Cereseto Monferrato','15020','AL'),
											('0','Ceresole d\'Alba','12040','CN'),
											('0','Ceresole Reale','10080','TO'),
											('0','Cereta','46049','MN'),
											('0','Cerete','24020','BG'),
											('0','Ceretolo','40033','BO'),
											('0','Ceretta di San Maurizio Canavese','10070','TO'),
											('0','Ceretto di Carignano','10041','TO'),
											('0','Ceretto Lomellina','27030','PV'),
											('0','Cerfignano','73020','LE'),
											('0','Cergnago','27020','PV'),
											('0','Ceri','00052','RM'),
											('0','Ceriale','17023','SV'),
											('0','Ceriana','18034','IM'),
											('0','Ceriano Laghetto','20020','MI'),
											('0','Cerignale','29020','PC'),
											('0','Cerignola','71042','FG'),
											('0','Cerisano','87044','CS'),
											('0','Cerisola','12075','CN'),
											('0','Cerlongo','46040','MN'),
											('0','Cermenate','22072','CO'),
											('0','Cermes','39010','BZ'),
											('0','Cermignano','64037','TE'),
											('0','Cerna','37020','VR'),
											('0','Cernobbio','22012','CO'),
											('0','Cernobbio Grand Hotel Villa d\'Este','22010','CO'),
											('0','Cernusco Lombardone','23870','LC'),
											('0','Cernusco Sul Naviglio','20063','MI'),
											('0','Cerqueto','06052','PG'),
											('0','Cerqueto','64040','TE'),
											('0','Cerqueto del Tronto','64010','TE'),
											('0','Cerratina','65010','PE'),
											('0','Cerredolo','42010','RE'),
											('0','Cerrelli','84050','SA'),
											('0','Cerreto','86089','IS'),
											('0','Cerreto Alpi','42037','RE'),
											('0','Cerreto Castello','13852','BI'),
											('0','Cerreto d\'Asti','14020','AT'),
											('0','Cerreto d\'Esi','60043','AN'),
											('0','Cerreto di Spoleto','06040','PG'),
											('0','Cerreto di Vallerotonda','03040','FR'),
											('0','Cerreto Grue','15050','AL'),
											('0','Cerreto Guidi','50050','FI'),
											('0','Cerreto Laziale','00020','RM'),
											('0','Cerreto Sannita','82032','BN'),
											('0','Cerretto Langhe','12050','CN'),
											('0','Cerri','85043','PZ'),
											('0','Cerrina','15020','AL'),
											('0','Cerrione','13882','BI'),
											('0','Cerrisi','88041','CZ'),
											('0','Cerro Al Lambro','20070','MI'),
											('0','Cerro Al Volturno','86072','IS'),
											('0','Cerro Maggiore','20023','MI'),
											('0','Cerro Tanaro','14030','AT'),
											('0','Cerro Veronese','37020','VR'),
											('0','Cersosimo','85030','PZ'),
											('0','Certaldo','50052','FI'),
											('0','Certosa di Pavia','27012','PV'),
											('0','Certosa di Rivarolo Ligure','16159','GE'),
											('0','Certosa di Trisulti','03010','FR'),
											('0','Cerva','88050','CZ'),
											('0','Cervara','54027','MS'),
											('0','Cervara di Roma','00020','RM'),
											('0','Cervarese Santa Croce','35030','PD'),
											('0','Cervarezza','42036','RE'),
											('0','Cervaro','03044','FR'),
											('0','Cervaro','64040','TE'),
											('0','Cervasca','12010','CN'),
											('0','Cervatto','13025','VC'),
											('0','Cerveno','25040','BS'),
											('0','Cervere','12040','CN'),
											('0','Cervesina','27050','PV'),
											('0','Cerveteri','00052','RM'),
											('0','Cervia','48015','RA'),
											('0','Cervia Milano Marittima','48016','RA'),
											('0','Cervicati','87010','CS'),
											('0','Cervignano d\'Adda','26832','LO'),
											('0','Cervignano del Friuli','33052','UD'),
											('0','Cervignasco','12030','CN'),
											('0','Cervinara','83012','AV'),
											('0','Cervinia','','AO'),
											('0','Cervino','81023','CE'),
											('0','Cervo','18010','IM'),
											('0','Cerzeto','87040','CS'),
											('0','Cesa','52040','AR'),
											('0','Cesa','81030','CE'),
											('0','Cesacastina','64040','TE'),
											('0','Cesana Brianza','23861','LC'),
											('0','Cesana Torinese','10054','TO'),
											('0','Cesano','64010','TE'),
											('0','Cesano Boscone','20090','MI'),
											('0','Cesano di Roma','00060','RM'),
											('0','Cesano di Senigallia','60012','AN'),
											('0','Cesano Maderno','20031','MI'),
											('0','Cesano Stazione','00064','RM'),
											('0','Cesaproba','67010','AQ'),
											('0','Cesara','28891','VB'),
											('0','Cesar','98033','ME'),
											('0','Cesarolo','30020','VE'),
											('0','Cesate','20020','MI'),
											('0','Cese','67050','AQ'),
											('0','Ceselli','06040','PG'),
											('0','Cesena','47023','FC'),
											('0','Cesenatico','47042','FC'),
											('0','Ceserano','54010','MS'),
											('0','Cesi di Macerata','62030','MC'),
											('0','Cesi di Terni','05030','TR'),
											('0','Cesinali','83020','AV'),
											('0','Cesio','18022','IM'),
											('0','Cesiomaggiore','32030','BL'),
											('0','Cesole','46030','MN'),
											('0','Cessalto','31040','TV'),
											('0','Cessaniti','89816','VV'),
											('0','Cessapalombo','62020','MC'),
											('0','Cessole','14050','AT'),
											('0','Cesta','44030','FE'),
											('0','Cesuna','36010','VI'),
											('0','Cetara','84010','SA'),
											('0','Ceto','25040','BS'),
											('0','Cetona','53040','SI'),
											('0','Cetraro','87022','CS'),
											('0','Cetraro Marina','87020','CS'),
											('0','Ceva','12073','CN'),
											('0','Cevo','23011','SO'),
											('0','Cevo','25040','BS'),
											('0','Cevoli','56035','PI'),
											('0','Challand Saint Anselme','11020','AO'),
											('0','Challand Saint Victor','11020','AO'),
											('0','Chambave','11023','AO'),
											('0','Chamois','11020','AO'),
											('0','Champdepraz','11020','AO'),
											('0','Champoluc','11020','AO'),
											('0','Champorcher','11020','AO'),
											('0','Charvensod','11020','AO'),
											('0','Chatillon','11024','AO'),
											('0','Cherasco','12062','CN'),
											('0','Cheremule','07040','SS'),
											('0','Cherubine','37050','VR'),
											('0','Chesallet Sarre','11010','AO'),
											('0','Chia','01020','VT'),
											('0','Chiaiamari','03030','FR'),
											('0','Chiaiano Ed Uniti','80145','NA'),
											('0','Chialamberto','10070','TO'),
											('0','Chiampo','36072','VI'),
											('0','Chianche','83010','AV'),
											('0','Chianciano Terme','53042','SI'),
											('0','Chianni','56034','PI'),
											('0','Chianocco','10050','TO'),
											('0','Chiappa','19123','SP'),
											('0','Chiapuzza','32046','BL'),
											('0','Chiaramonte Gulfi','97012','RG'),
											('0','Chiaramonti','07030','SS'),
											('0','Chiarano','31040','TV'),
											('0','Chiaravalle','60033','AN'),
											('0','Chiaravalle Centrale','88064','CZ'),
											('0','Chiaravalle Milanese','20139','MI'),
											('0','Chiareggio','23023','SO'),
											('0','Chiari','25032','BS'),
											('0','Chiarino','64040','TE'),
											('0','Chiaromonte','85032','PZ'),
											('0','Chiarone','58010','GR'),
											('0','Chiaserna','61044','PU'),
											('0','Chiassa Superiore','52030','AR'),
											('0','Chiassis','33029','UD'),
											('0','Chiauci','86097','IS'),
											('0','Chiavano','06040','PG'),
											('0','Chiavari','16043','GE'),
											('0','Chiavazza','13900','BI'),
											('0','Chiavenna','23022','SO'),
											('0','Chiavenna Rocchetta','29018','PC'),
											('0','Chiaverano','10010','TO'),
											('0','Chiazzano','51030','PT'),
											('0','Chienes','39030','BZ'),
											('0','Chieri','10023','TO'),
											('0','Chies d\'Alpago','32010','BL'),
											('0','Chiesa di Rossano','54020','MS'),
											('0','Chiesa in Valmalenco','23023','SO'),
											('0','Chiesa Nuova','44028','FE'),
											('0','Chiesanuova','91010','TP'),
											('0','Chiesanuova','73010','LE'),
											('0','Chiesanuova','62010','MC'),
											('0','Chiesanuova','10080','TO'),
											('0','Chiesanuova Uzzanese','51013','PT'),
											('0','Chiesina Uzzanese','51013','PT'),
											('0','Chiesuol del Fosso','44040','FE'),
											('0','Chieti','66100','CH'),
											('0','Chieti Stazione','66013','CH'),
											('0','Chieuti','71010','FG'),
											('0','Chieuti Scalo','71010','FG'),
											('0','Chieve','26010','CR'),
											('0','Chievo','37139','VR'),
											('0','Chievolis','33090','PN'),
											('0','Chignolo d\'Isola','24040','BG'),
											('0','Chignolo Po','27013','PV'),
											('0','Chilivani','07010','SS'),
											('0','Chiocchio','50027','FI'),
											('0','Chioggia','30015','VE'),
											('0','Chiomonte','10050','TO'),
											('0','Chions','33083','PN'),
											('0','Chiopris','33048','UD'),
											('0','Chiozza','55030','LU'),
											('0','Chiozzola','43050','PR'),
											('0','Chirignago','30030','VE'),
											('0','Chitignano','52010','AR'),
											('0','Chiuduno','24060','BG'),
											('0','Chiuppano','36010','VI'),
											('0','Chiuro','23030','SO'),
											('0','Chiusa','39043','BZ'),
											('0','Chiusa Ferranda','43036','PR'),
											('0','Chiusa Pesio','12013','CN'),
											('0','Chiusa San Michele','10050','TO'),
											('0','Chiusa Sclafani','90033','PA'),
											('0','Chiusaforte','33010','UD'),
											('0','Chiusanico','18027','IM'),
											('0','Chiusano d\'Asti','14025','AT'),
											('0','Chiusano San Domenico','83040','AV'),
											('0','Chiusavecchia','18027','IM'),
											('0','Chiusdino','53012','SI'),
											('0','Chiusi Citt','53043','SI'),
											('0','Chiusi della Verna','52010','AR'),
											('0','Chiusi Stazione','53044','SI'),
											('0','Chiusure','53020','SI'),
											('0','Chivasso','10034','TO'),
											('0','Chorio','89060','RC'),
											('0','Ciampino','00043','RM'),
											('0','Ciampino Aeroporto','00040','RM'),
											('0','Ciamprisco','81050','CE'),
											('0','Cianciana','92012','AG'),
											('0','Ciano','89831','VV'),
											('0','Ciano del Montello','31030','TV'),
											('0','Ciano d\'Enza','42026','RE'),
											('0','Ciano nel Frignano','41050','MO'),
											('0','Ciardelli Inferiore','83010','AV'),
											('0','Ciavalotto','91020','TP'),
											('0','Cibali','95123','CT'),
											('0','Cibiana di Cadore','32040','BL'),
											('0','Cicagna','16044','GE'),
											('0','Cicala','88040','CZ'),
											('0','Cicciano','80033','NA'),
											('0','Cicerale','84053','SA'),
											('0','Ciciano','53010','SI'),
											('0','Ciciliano','00020','RM'),
											('0','Cicognara','46015','MN'),
											('0','Cicognolo','26030','CR'),
											('0','Ciconicco','33034','UD'),
											('0','Ciconio','10080','TO'),
											('0','Ciggiano','52040','AR'),
											('0','Cigliano','13043','VC'),
											('0','Cigli','12060','CN'),
											('0','Cigognola','27040','PV'),
											('0','Cigole','25020','BS'),
											('0','Cilavegna','27024','PV'),
											('0','Ciliverghe','25080','BS'),
											('0','Cima','22018','CO'),
											('0','Cima Paganella','38010','TN'),
											('0','Cimadolmo','31010','TV'),
											('0','Cimbergo','25050','BS'),
											('0','Cimbro','21029','VA'),
											('0','Cimego','38082','TN'),
											('0','Cimetta','31013','TV'),
											('0','Cimin','89040','RC'),
											('0','Ciminna','90023','PA'),
											('0','Cimitile','80030','NA'),
											('0','Cimolais','33080','PN'),
											('0','Cimone','38060','TN'),
											('0','Cimpello','33080','PN'),
											('0','Cinaglio','14020','AT'),
											('0','Cineto Romano','00020','RM'),
											('0','Cingia De\' Botti','26042','CR'),
											('0','Cingoli','62011','MC'),
											('0','Cinigiano','58044','GR'),
											('0','Cinisello Balsamo','20092','MI'),
											('0','Cinisi','90045','PA'),
											('0','Cino','23010','SO'),
											('0','Cinquale','54030','MS'),
											('0','Cinquecerri','42030','RE'),
											('0','Cinquefrondi','89021','RC'),
											('0','Cintano','10080','TO'),
											('0','Cinte Tesino','38050','TN'),
											('0','Cinto Caomaggiore','30020','VE'),
											('0','Cinto Euganeo','35030','PD'),
											('0','Cintolese','51030','PT'),
											('0','Cinzano','10090','TO'),
											('0','Ciola','47020','FC'),
											('0','Ciola Corniale','47822','RN'),
											('0','Ciorani','84080','SA'),
											('0','Ciorlano','81010','CE'),
											('0','Cipressa','18017','IM'),
											('0','Circello','82020','BN'),
											('0','Cireggio','28887','VB'),
											('0','Cireglio','51020','PT'),
											('0','Cirella','89040','RC'),
											('0','Cirella','87020','CS'),
											('0','Cirello','89020','RC'),
											('0','Ciri','10073','TO'),
											('0','Cirigliano','75010','MT'),
											('0','Cirignano','82016','BN'),
											('0','Cirimido','22070','CO'),
											('0','Cir','88813','KR'),
											('0','Cir Marina','88811','KR'),
											('0','Cis','38020','TN'),
											('0','Cisano','37011','VR'),
											('0','Cisano Bergamasco','24034','BG'),
											('0','Cisano Sul Neva','17035','SV'),
											('0','Ciserano','24040','BG'),
											('0','Cislago','21040','VA'),
											('0','Cisliano','20080','MI'),
											('0','Cismon del Grappa','36020','VI'),
											('0','Cison di Valmarino','31030','TV'),
											('0','Cissone','12050','CN'),
											('0','Cisterna d\'Asti','14010','AT'),
											('0','Cisterna del Friuli','33030','UD'),
											('0','Cisterna di Castel di Sasso','81040','CE'),
											('0','Cisterna di Latina','04012','LT'),
											('0','Cisternino','72014','BR'),
											('0','Cistio','50039','FI'),
											('0','Citerna','06010','PG'),
											('0','Citt del Vaticano','00120',''),
											('0','Citt della Pieve','06062','PG'),
											('0','Citt di Castello','06012','PG'),
											('0','Citt Sant\'Angelo','65013','PE'),
											('0','Cittadella','35013','PD'),
											('0','Cittadella del Capo','87020','CS'),
											('0','Cittaducale','02015','RI'),
											('0','Cittanova','89022','RC'),
											('0','Cittareale','02010','RI'),
											('0','Cittiglio','21033','VA'),
											('0','Civago','42030','RE'),
											('0','Civate','23862','LC'),
											('0','Civ','35020','PD'),
											('0','Civenna','22030','CO'),
											('0','Civezza','18017','IM'),
											('0','Civezzano','38045','TN'),
											('0','Civiasco','13010','VC'),
											('0','Cividale','41037','MO'),
											('0','Cividale del Friuli','33043','UD'),
											('0','Cividale Mantovano','46017','MN'),
											('0','Cividate Al Piano','24050','BG'),
											('0','Cividate Camuno','25040','BS'),
											('0','Cividino','24060','BG'),
											('0','Civiglio','22030','CO'),
											('0','Civita','87010','CS'),
											('0','Civita','01022','VT'),
											('0','Civita Castellana','01033','VT'),
											('0','Civita Castellana Stazione','01030','VT'),
											('0','Civita d\'Antino','67050','AQ'),
											('0','Civita di Oricola','67060','AQ'),
											('0','Civitacampomarano','86030','CB'),
											('0','Civitaluparella','66040','CH'),
											('0','Civitanova del Sannio','86094','IS'),
											('0','Civitanova Marche','62012','MC'),
											('0','Civitanova Marche Alta','62012','MC'),
											('0','Civitaquana','65010','PE'),
											('0','Civitaretenga','67020','AQ'),
											('0','Civitavecchia','00053','RM'),
											('0','Civitella','00026','RM'),
											('0','Civitella Alfedena','67030','AQ'),
											('0','Civitella Casanova','65010','PE'),
											('0','Civitella Cesi','01010','VT'),
											('0','Civitella d\'Agliano','01020','VT'),
											('0','Civitella del Lago','05020','TR'),
											('0','Civitella del Tronto','64010','TE'),
											('0','Civitella di Romagna','47012','FC'),
											('0','Civitella in Val di Chiana','52040','AR'),
											('0','Civitella Licinio','82033','BN'),
											('0','Civitella Marittima','58045','GR'),
											('0','Civitella Messer Raimondo','66010','CH'),
											('0','Civitella Paganico','58045','GR'),
											('0','Civitella Roveto','67054','AQ'),
											('0','Civitella San Paolo','00060','RM'),
											('0','Civo','23010','SO'),
											('0','Cizzago','25030','BS'),
											('0','Cizzolo','46030','MN'),
											('0','Claino Con Osteno','22010','CO'),
											('0','Clanezzo','24010','BG'),
											('0','Clauiano','33050','UD'),
											('0','Claut','33080','PN'),
											('0','Clauzetto','33090','PN'),
											('0','Clavesana','12060','CN'),
											('0','Claviere','10050','TO'),
											('0','Cles','38023','TN'),
											('0','Cleto','87030','CS'),
											('0','Clivio','21050','VA'),
											('0','Clodig','33040','UD'),
											('0','Cloz','38020','TN'),
											('0','Clusane','25049','BS'),
											('0','Clusone','24023','BG'),
											('0','Coassolo Torinese','10070','TO'),
											('0','Coazze','10050','TO'),
											('0','Coazzolo','14054','AT'),
											('0','Coccaglio','25030','BS'),
											('0','Coccanile','44030','FE'),
											('0','Coccolia','48010','RA'),
											('0','Cocconito','14023','AT'),
											('0','Coccorino','89863','VV'),
											('0','Cocomaro di Cona','44020','FE'),
											('0','Cocquio','21034','VA'),
											('0','Cocullo','67030','AQ'),
											('0','Cocumola','73020','LE'),
											('0','Cocuruzzo','81040','CE'),
											('0','Codaruina','07039','SS'),
											('0','Codemondo','42025','RE'),
											('0','Codena','54033','MS'),
											('0','Codevigo','35020','PD'),
											('0','Codevilla','27050','PV'),
											('0','Codigoro','44021','FE'),
											('0','Codiponte','54010','MS'),
											('0','Codogn','31013','TV'),
											('0','Codogno','26845','LO'),
											('0','Codroipo','33033','UD'),
											('0','Codrongianos','07040','SS'),
											('0','Coggiola','13863','BI'),
											('0','Cogliandrino','85040','PZ'),
											('0','Cogliate','20020','MI'),
											('0','Cogne','11012','AO'),
											('0','Cognento','41010','MO'),
											('0','Cogno','25052','BS'),
											('0','Cognola','38050','TN'),
											('0','Cogoleto','16016','GE'),
											('0','Cogollo del Cengio','36010','VI'),
											('0','Cogolo in Val di Pejo','38024','TN'),
											('0','Cogolonchio','43036','PR'),
											('0','Cogorno','16030','GE'),
											('0','Cogozzo','25069','BS'),
											('0','Cogozzo','46016','MN'),
											('0','Coiano','59100','PO'),
											('0','Coiromonte','28010','NO'),
											('0','Col di Cugnan','32010','BL'),
											('0','Col San Giovanni di Vi','10070','TO'),
											('0','Col San Martino','31010','TV'),
											('0','Cola','42020','RE'),
											('0','Col di Lazise','37010','VR'),
											('0','Colazza','28010','NO'),
											('0','Colbordolo','61022','PU'),
											('0','Colbuccaro','62014','MC'),
											('0','Colcavagno','14026','AT'),
											('0','Colcellalto','52032','AR'),
											('0','Coldirodi','18038','IM'),
											('0','Coldrano','39020','BZ'),
											('0','Colere','24020','BG'),
											('0','Colfelice','03030','FR'),
											('0','Colferraio','62024','MC'),
											('0','Colfiorito','06030','PG'),
											('0','Colfosco','31030','TV'),
											('0','Colfosco','39033','BZ'),
											('0','Coli','29020','PC'),
											('0','Colico','23823','LC'),
											('0','Colla','54010','MS'),
											('0','Colla','88040','CZ'),
											('0','Colla Maffone','98064','ME'),
											('0','Collagna','42037','RE'),
											('0','Collalbo','39054','BZ'),
											('0','Collalbrigo','31015','TV'),
											('0','Collalto','33017','UD'),
											('0','Collalto Sabino','02022','RI'),
											('0','Collamato','60040','AN'),
											('0','Collarmele','67040','AQ'),
											('0','Collazzone','06050','PG'),
											('0','Colle','33090','PN'),
											('0','Colle Brianza','23886','LC'),
											('0','Colle Brincioni','67100','AQ'),
											('0','Colle d\'Anchise','86020','CB'),
											('0','Colle della Maddalena','10024','TO'),
											('0','Colle di Compito','55062','LU'),
											('0','Colle di Fuori','00030','RM'),
											('0','Colle di Roio','67040','AQ'),
											('0','Colle di Tora','02020','RI'),
											('0','Colle di Val d\'Elsa','53034','SI'),
											('0','Colle Isarco','39040','BZ'),
											('0','Colle Prenestino','00010','RM'),
											('0','Colle San Magno','03030','FR'),
											('0','Colle Sannita','82024','BN'),
											('0','Colle Santa Lucia','32020','BL'),
											('0','Colle Sant\'Antonio','66010','CH'),
											('0','Colle Umberto','31014','TV'),
											('0','Colle Umberto I','06070','PG'),
											('0','Collebeato','25060','BS'),
											('0','Colleberardi','03020','FR'),
											('0','Collecalcioni','86038','CB'),
											('0','Collecchio','43044','PR'),
											('0','Collecorvino','65010','PE'),
											('0','Colledara','64042','TE'),
											('0','Colledimacine','66010','CH'),
											('0','Colledimezzo','66040','CH'),
											('0','Colledoro','64041','TE'),
											('0','Colleferro','00034','RM'),
											('0','Colleferro Stazione','00030','RM'),
											('0','Collegio','27050','PV'),
											('0','Collegiove','02020','RI'),
											('0','Collegno','10093','TO'),
											('0','Collelongo','67050','AQ'),
											('0','Collelungo','05010','TR'),
											('0','Collelungo Sabino','02030','RI'),
											('0','Collemaggiore','02028','RI'),
											('0','Collemarino','60023','AN'),
											('0','Collemeto','73010','LE'),
											('0','Colleminuccio','64020','TE'),
											('0','Collemoresco','02010','RI'),
											('0','Collepardo','03010','FR'),
											('0','Collepasso','73040','LE'),
											('0','Collepepe','06050','PG'),
											('0','Collepietra','39050','BZ'),
											('0','Collepietro','67020','AQ'),
											('0','Colleponi di Genga','60040','AN'),
											('0','Colleranesco','64020','TE'),
											('0','Colleretto Castelnuovo','10080','TO'),
											('0','Colleretto Giacosa','10010','TO'),
											('0','Collesalvetti','57014','LI'),
											('0','Collesano','90016','PA'),
											('0','Collescipoli','05033','TR'),
											('0','Collesecco','05020','TR'),
											('0','Collestatte','05030','TR'),
											('0','Collestrada','06080','PG'),
											('0','Colletorto','86044','CB'),
											('0','Collevalenza','06050','PG'),
											('0','Collevecchio','02042','RI'),
											('0','Collevecchio di Montoro','64040','TE'),
											('0','Colli','03030','FR'),
											('0','Colli a Volturno','86073','IS'),
											('0','Colli del Tronto','63030','AP'),
											('0','Colli di Montebove','67060','AQ'),
											('0','Colli di Suso','04010','LT'),
											('0','Colli Fontanelle','80065','NA'),
											('0','Colli Sul Velino','02010','RI'),
											('0','Colliano','84020','SA'),
											('0','Collina','51020','PT'),
											('0','Collina Santa Maria Nuova','60030','AN'),
											('0','Collinas','09020','CA'),
											('0','Collinello Polenta','47032','FC'),
											('0','Collio','25060','BS'),
											('0','Collobiano','13030','VC'),
											('0','Collodi','51014','PT'),
											('0','Colloredo di Montalbano','33010','UD'),
											('0','Colloredo di Prato','33030','UD'),
											('0','Colmata Fiorentina di Piombino','57020','LI'),
											('0','Colmurano','62020','MC'),
											('0','Colnago','20040','MI'),
											('0','Colobraro','75021','MT'),
											('0','Cologna','39050','BZ'),
											('0','Cologna','44030','FE'),
											('0','Cologna','64020','TE'),
											('0','Cologna Spiaggia','64020','TE'),
											('0','Cologna Veneta','37044','VR'),
											('0','Cologne Bresciano','25033','BS'),
											('0','Cologno Al Serio','24055','BG'),
											('0','Cologno Monzese','20093','MI'),
											('0','Colognola Ai Colli','37030','VR'),
											('0','Colognola Al Piano','24126','BG'),
											('0','Colognole','57010','LI'),
											('0','Colombano','45021','RO'),
											('0','Colombare di Sirmione','25019','BS'),
											('0','Colombaro','10020','TO'),
											('0','Colombaro di Formigine','41050','MO'),
											('0','Colombella','06080','PG'),
											('0','Colonia Arnaldi','16030','GE'),
											('0','Colonia di Anzio','00042','RM'),
											('0','Colonna','00030','RM'),
											('0','Colonna Stazione','00030','RM'),
											('0','Colonnata','50019','FI'),
											('0','Colonnata','54030','MS'),
											('0','Colonnella','64010','TE'),
											('0','Colonno','22010','CO'),
											('0','Colorina','23010','SO'),
											('0','Colorno','43052','PR'),
											('0','Colosimi','87050','CS'),
											('0','Colpalombo','06020','PG'),
											('0','Colpetrazzo','06050','PG'),
											('0','Coltano','','PI'),
											('0','Coltaro','43033','PR'),
											('0','Coltodino','02030','RI'),
											('0','Colturano','20060','MI'),
											('0','Colzate','24020','BG'),
											('0','Comabbio','21020','VA'),
											('0','Comacchio','44022','FE'),
											('0','Comano','54015','MS'),
											('0','Comazzo','26833','LO'),
											('0','Combai','31050','TV'),
											('0','Comeana','59015','PO'),
											('0','Comeglians','33023','UD'),
											('0','Comelico Superiore','32040','BL'),
											('0','Comenduno','24021','BG'),
											('0','Comerconi','89844','VV'),
											('0','Comerio','21025','VA'),
											('0','Comezzano','25030','BS'),
											('0','Comidapira','08040','NU'),
											('0','Comignago','28060','NO'),
											('0','Comina (La)','33170','PN'),
											('0','Comiso','97013','RG'),
											('0','Comitini','92020','AG'),
											('0','Comiziano','80030','NA'),
											('0','Commenda','87030','CS'),
											('0','Commessaggio','46010','MN'),
											('0','Commezzadura','38020','TN'),
											('0','Como','22100','CO'),
											('0','Comparni','89852','VV'),
											('0','Compiano','43053','PR'),
											('0','Compiano d\'Enza','42020','RE'),
											('0','Compignano','06050','PG'),
											('0','Compiobbi','50061','FI'),
											('0','Comun Nuovo','24040','BG'),
											('0','Comunanza','63044','AP'),
											('0','Comuneglia','19020','SP'),
											('0','Cona','30010','VE'),
											('0','Cona','44020','FE'),
											('0','Conca Casale','86079','IS'),
											('0','Conca dei Marini','84010','SA'),
											('0','Conca della Campania','81044','CE'),
											('0','Conca d\'Oro','74010','TA'),
											('0','Concadirame','45020','RO'),
											('0','Concamarise','37050','VR'),
											('0','Concas','08020','NU'),
											('0','Concei','38060','TN'),
											('0','Concerviano','02020','RI'),
											('0','Concesa','20056','MI'),
											('0','Concesio','25062','BS'),
											('0','Conche di Codevigo','35020','PD'),
											('0','Conco','36062','VI'),
											('0','Concordia Sagittaria','30023','VE'),
											('0','Concordia sulla Secchia','41033','MO'),
											('0','Concorezzo','20049','MI'),
											('0','Condino','38083','TN'),
											('0','Condofuri','89030','RC'),
											('0','Condofuri Marina','89030','RC'),
											('0','Condojanni','89040','RC'),
											('0','Condove','10055','TO'),
											('0','Condr','98040','ME'),
											('0','Conegliano','31015','TV'),
											('0','Confienza','27030','PV'),
											('0','Configni','02040','RI'),
											('0','Confine','41038','MO'),
											('0','Conflenti','88040','CZ'),
											('0','Confreria','12100','CN'),
											('0','Congelasio','43039','PR'),
											('0','Coniale','50033','FI'),
											('0','Coniolo','15030','AL'),
											('0','Coniolo','25034','BS'),
											('0','Consandolo','44013','FE'),
											('0','Conselice','48017','RA'),
											('0','Conselve','35026','PD'),
											('0','Consiglio di Rumo','22010','CO'),
											('0','Consuma','50060','FI'),
											('0','Contarina','45014','RO'),
											('0','Contea','50060','FI'),
											('0','Contemplazione','98168','ME'),
											('0','Contessa Entellina','90030','PA'),
											('0','Contesse','98125','ME'),
											('0','Contigliano','02043','RI'),
											('0','Contignano','53040','SI'),
											('0','Contrada','83020','AV'),
											('0','Contrada Val d\'Ega','39050','BZ'),
											('0','Controguerra','64010','TE'),
											('0','Controne','84020','SA'),
											('0','Contursi Terme','84024','SA'),
											('0','Conversano','70014','BA'),
											('0','Conza della Campania','83040','AV'),
											('0','Conzano','15030','AL'),
											('0','Copanello','88069','CZ'),
											('0','Coperchia','84080','SA'),
											('0','Copersito Cilento','84054','SA'),
											('0','Copertino','73043','LE'),
											('0','Copiano','27010','PV'),
											('0','Copparo','44034','FE'),
											('0','Coppito','67010','AQ'),
											('0','Corana','27050','PV'),
											('0','Corato','70033','BA'),
											('0','Corazzano','56020','PI'),
											('0','Corazzo','88821','KR'),
											('0','Corbanese','31020','TV'),
											('0','Corbara','05019','TR'),
											('0','Corbara','84010','SA'),
											('0','Corbetta','20011','MI'),
											('0','Corbezzi','51020','PT'),
											('0','Corbola','45015','RO'),
											('0','Corchiano','01030','VT'),
											('0','Corciano','06073','PG'),
											('0','Corcolle San Vittorino','00010','RM'),
											('0','Corcumello','67050','AQ'),
											('0','Cordenons','33084','PN'),
											('0','Cordignano','31016','TV'),
											('0','Cordovado','33075','PN'),
											('0','Coredo','38010','TN'),
											('0','Coreggia','70010','BA'),
											('0','Coreglia Antelminelli','55025','LU'),
											('0','Coreglia Ligure','16040','GE'),
											('0','Coreno Ausonio','03040','FR'),
											('0','Corese Terra','02030','RI'),
											('0','Corfinio','67030','AQ'),
											('0','Corfino','55030','LU'),
											('0','Corgeno','21029','VA'),
											('0','Cori','04010','LT'),
											('0','Coriano','47853','RN'),
											('0','Coriano Veronese','37050','VR'),
											('0','Corigliano','81030','CE'),
											('0','Corigliano Calabro','87064','CS'),
											('0','Corigliano Calabro Stazione','87065','CS'),
											('0','Corigliano d\'Otranto','73022','LE'),
											('0','Corinaldo','60013','AN'),
											('0','Corio','10070','TO'),
											('0','Corio','44030','FE'),
											('0','Corlaga','54021','MS'),
											('0','Corleone','90034','PA'),
											('0','Corleto Monforte','84020','SA'),
											('0','Corleto Perticara','85012','PZ'),
											('0','Corlo di Formigine','41010','MO'),
											('0','Cormano','20032','MI'),
											('0','Cormons','34071','GO'),
											('0','Corna Imagna','24030','BG'),
											('0','Cornacchiaia','50033','FI'),
											('0','Cornaiano','39050','BZ'),
											('0','Cornalba','24017','BG'),
											('0','Cornale','24020','BG'),
											('0','Cornale','27050','PV'),
											('0','Cornaredo','20010','MI'),
											('0','Cornate d\'Adda','20040','MI'),
											('0','Cornedo','39050','BZ'),
											('0','Cornedo Vicentino','36073','VI'),
											('0','Cornegliano Laudense','26854','LO'),
											('0','Corneliano d\'Alba','12040','CN'),
											('0','Corniana','43040','PR'),
											('0','Corniglia','19010','SP'),
											('0','Cornigliano Ligure','16152','GE'),
											('0','Corniglio','43021','PR'),
											('0','Cornino','33030','UD'),
											('0','Corniolo','47010','FC'),
											('0','Corno di Rosazzo','33040','UD'),
											('0','Corno Giovine','26846','LO'),
											('0','Cornovecchio','26847','LO'),
											('0','Cornuda','31041','TV'),
											('0','Corona','34070','GO'),
											('0','Coronata','16152','GE'),
											('0','Coroncina','53030','SI'),
											('0','Coronella','44028','FE'),
											('0','Corpo di Reno','44040','FE'),
											('0','Corpol','47828','RN'),
											('0','Correggio','42015','RE'),
											('0','Correggioli','46030','MN'),
											('0','Correggioverde','46030','MN'),
											('0','Correzzana','20050','MI'),
											('0','Correzzo','37060','VR'),
											('0','Correzzola','35020','PD'),
											('0','Corrido','22010','CO'),
											('0','Corridonia','62014','MC'),
											('0','Corridonia Stazione','62014','MC'),
											('0','Corropoli','64013','TE'),
											('0','Corsaglia','12080','CN'),
											('0','Corsagna','55020','LU'),
											('0','Corsanico','55040','LU'),
											('0','Corsano','53010','SI'),
											('0','Corsano','73033','LE'),
											('0','Corsico','20094','MI'),
											('0','Corsione','14020','AT'),
											('0','Cortabbio','23819','LC'),
											('0','Cortaccia sulla Strada del Vino','39040','BZ'),
											('0','Cortale','88024','CZ'),
											('0','Cortandone','14013','AT'),
											('0','Cortanze','14020','AT'),
											('0','Cortazzone','14010','AT'),
											('0','Corte','35028','PD'),
											('0','Corte','38020','TN'),
											('0','Corte Brugnatella','29020','PC'),
											('0','Corte De\' Cortesi','26020','CR'),
											('0','Corte De\' Frati','26010','CR'),
											('0','Corte Palasio','26834','LO'),
											('0','Cortefranca','25040','BS'),
											('0','Cortemaggiore','29016','PC'),
											('0','Cortemilia','12074','CN'),
											('0','Cortenedolo','25048','BS'),
											('0','Corteno Golgi','25040','BS'),
											('0','Cortenova','23813','LC'),
											('0','Cortenuova','24050','BG'),
											('0','Corteolona','27014','PV'),
											('0','Corticella','40128','BO'),
											('0','Corticelle Pieve','25020','BS'),
											('0','Cortiglione','14045','AT'),
											('0','Cortile','41012','MO'),
											('0','Cortile San Martino','43100','PR'),
											('0','Cortina d\'Ampezzo','32043','BL'),
											('0','Cortina sulla Strada del Vino','39040','BZ'),
											('0','Cortino','64040','TE'),
											('0','Cortoghiana','09010','CA'),
											('0','Cortona','52044','AR'),
											('0','Corva','33082','PN'),
											('0','Corvara','65020','PE'),
											('0','Corvara','39033','BZ'),
											('0','Corvaro','02020','RI'),
											('0','Corvino San Quirico','27050','PV'),
											('0','Corzano','25030','BS'),
											('0','Coscogno','41026','MO'),
											('0','Coseano','33030','UD'),
											('0','Cosenza','87100','CS'),
											('0','Cosina','48010','RA'),
											('0','Cosio di Arroscia','18023','IM'),
											('0','Cosio Stazione','23010','SO'),
											('0','Cosio Valtellino','23013','SO'),
											('0','Cosola di Cabella','15060','AL'),
											('0','Cosoleto','89050','RC'),
											('0','Cossano Belbo','12054','CN'),
											('0','Cossano Canavese','10010','TO'),
											('0','Cossato','13836','BI'),
											('0','Cosseria','17017','SV'),
											('0','Cossignano','63030','AP'),
											('0','Cossila','13892','BI'),
											('0','Cossirano','25030','BS'),
											('0','Cossogno','28801','VB'),
											('0','Cossoine','07010','SS'),
											('0','Cossombrato','14020','AT'),
											('0','Costa Calcinara','35043','PD'),
											('0','Costa d\'Arcevia','60010','AN'),
											('0','Costa De\' Nobili','27010','PV'),
											('0','Costa di Mezzate','24060','BG'),
											('0','Costa di Rovigo','45023','RO'),
											('0','Costa di Serina','24010','BG'),
											('0','Costa Masnaga','23845','LC'),
											('0','Costa Smeralda','07020','SS'),
											('0','Costa Valle Imagna','24030','BG'),
											('0','Costa Vescovato','15050','AL'),
											('0','Costa Volpino','24062','BG'),
											('0','Costabissara','36030','VI'),
											('0','Costacciaro','06021','PG'),
											('0','Costalissoio','32040','BL'),
											('0','Costalpino','53010','SI'),
											('0','Costalta','32040','BL'),
											('0','Costalunga Brognoligo','37030','VR'),
											('0','Costamezzana','43015','PR'),
											('0','Costano','06080','PG'),
											('0','Costanzana','13033','VC'),
											('0','Costarainera','18017','IM'),
											('0','Costasavina','38057','TN'),
											('0','Costermano','37010','VR'),
											('0','Costiera di Mazara','91026','TP'),
											('0','Costigliole d\'Asti','14055','AT'),
											('0','Costigliole d\'Asti Ferrovia','14055','AT'),
											('0','Costigliole Saluzzo','12024','CN'),
											('0','Costrignano','41040','MO'),
											('0','Cotignola','48010','RA'),
											('0','Cotone','57025','LI'),
											('0','Cotronei','88836','KR'),
											('0','Cottanello','02040','RI'),
											('0','Courmayeur','11013','AO'),
											('0','Coverciano','50135','FI'),
											('0','Covigliaio','50030','FI'),
											('0','Coviolo','42100','RE'),
											('0','Covo','24050','BG'),
											('0','Covolo','31030','TV'),
											('0','Cozzana','70040','BA'),
											('0','Cozzano','43020','PR'),
											('0','Cozze','70042','BA'),
											('0','Cozzo','27030','PV'),
											('0','Cozzuolo','31010','TV'),
											('0','Craco','75010','MT'),
											('0','Crandola Valsassina','23832','LC'),
											('0','Crastu','08030','NU'),
											('0','Crava','12047','CN'),
											('0','Cravagliana','13020','VC'),
											('0','Cravanzana','12050','CN'),
											('0','Craveggia','28852','VB'),
											('0','Creazzo','36051','VI'),
											('0','Crecchio','66014','CH'),
											('0','Creda','40030','BO'),
											('0','Credaro','24060','BG'),
											('0','Credera Rubbiano','26010','CR'),
											('0','Crema','26013','CR'),
											('0','Cremella','23894','LC'),
											('0','Cremenaga','21030','VA'),
											('0','Cremeno','23814','LC'),
											('0','Cremia','22010','CO'),
											('0','Cremnago','22044','CO'),
											('0','Cremolino','15010','AL'),
											('0','Cremona','26100','CR'),
											('0','Cremosano','26010','CR'),
											('0','Crenna','','VA'),
											('0','Crescentino','13044','VC'),
											('0','Crescenzago','20127','MI'),
											('0','Crespadoro','36070','VI'),
											('0','Crespano del Grappa','31017','TV'),
											('0','Crespellano','40056','BO'),
											('0','Crespi d\'Adda','24040','BG'),
											('0','Crespiano','54010','MS'),
											('0','Crespiatica','26835','LO'),
											('0','Crespina','56040','PI'),
											('0','Crespino','45030','RO'),
											('0','Crespino del Lamone','50034','FI'),
											('0','Crespole','51010','PT'),
											('0','Cressa','28012','NO'),
											('0','Creta','29015','PC'),
											('0','Cretone','00010','RM'),
											('0','Creva','21016','VA'),
											('0','Crevacuore','13864','BI'),
											('0','Crevalcore','40014','BO'),
											('0','Crevoladossola','28865','VB'),
											('0','Crispano','80020','NA'),
											('0','Crispiano','74012','TA'),
											('0','Crispiero','62022','MC'),
											('0','Crissolo','12030','CN'),
											('0','Cristo','15100','AL'),
											('0','Croce di Casale','63044','AP'),
											('0','Croce di Magara','87052','CS'),
											('0','Croce Ferrata','89043','RC'),
											('0','Croce Ne\' Monti','42035','RE'),
											('0','Croce Valanidi','89060','RC'),
											('0','Crocefieschi','16010','GE'),
											('0','Crocemosso','13825','BI'),
											('0','Crocetta del Montello','31035','TV'),
											('0','Crocette','24035','BG'),
											('0','Crocette','41026','MO'),
											('0','Crocevie','91010','TP'),
											('0','Crociale','55045','LU'),
											('0','Crocino San Giusto','57010','LI'),
											('0','Crodo','28862','VB'),
											('0','Crognaleto','64043','TE'),
											('0','Cropalati','87060','CS'),
											('0','Cropani','88051','CZ'),
											('0','Cropani Marina','88050','CZ'),
											('0','Crosa','13853','BI'),
											('0','Crosara','36063','VI'),
											('0','Crosia','87060','CS'),
											('0','Crosio della Valle','21020','VA'),
											('0','Crotone','88900','KR'),
											('0','Crotta d\'Adda','26020','CR'),
											('0','Crova','13040','VC'),
											('0','Croviana','38027','TN'),
											('0','Crucoli','88812','KR'),
											('0','Crucoli Torretta','88812','KR'),
											('0','Crusinallo','28882','VB'),
											('0','Cuasso Al Monte','21050','VA'),
											('0','Cuasso Al Piano','21050','VA'),
											('0','Cubante','82018','BN'),
											('0','Cuccaro Monferrato','15040','AL'),
											('0','Cuccaro Vetere','84050','SA'),
											('0','Cucciago','22060','CO'),
											('0','Cuccurano','61030','PU'),
											('0','Cuceglio','10090','TO'),
											('0','Cucigliana','56010','PI'),
											('0','Cuffiano','82020','BN'),
											('0','Cuggiono','20012','MI'),
											('0','Cugliate Fabiasco','21030','VA'),
											('0','Cuglieri','09073','OR'),
											('0','Cugnoli','65020','PE'),
											('0','Cuma','80070','NA'),
											('0','Cumia','98146','ME'),
											('0','Cumiana','10040','TO'),
											('0','Cumignano Sul Naviglio','26020','CR'),
											('0','Cunardo','21035','VA'),
											('0','Cuneo','12100','CN'),
											('0','Cunevo','38010','TN'),
											('0','Cunico','14026','AT'),
											('0','Cuorgn','10082','TO'),
											('0','Cupa e Fasani','81037','CE'),
											('0','Cupello','66051','CH'),
											('0','Cupone','86072','IS'),
											('0','Cupra Marittima','63012','AP'),
											('0','Cupramontana','60034','AN'),
											('0','Cuquello','15060','AL'),
											('0','Cura','01013','VT'),
											('0','Cura Carpignano','27010','PV'),
											('0','Curcuris','09090','OR'),
											('0','Cureggio','28060','NO'),
											('0','Curetta','63029','AP'),
											('0','Curiglia Con Monteviasco','21010','VA'),
											('0','Curinga','88022','CZ'),
											('0','Curino','13865','BI'),
											('0','Curno','24035','BG'),
											('0','Curon Venosta','39020','BZ'),
											('0','Cursi','73020','LE'),
											('0','Cursolo Orasso','28825','VB'),
											('0','Curtaniello','70022','BA'),
											('0','Curtarolo','35010','PD'),
											('0','Curtatone','46010','MN'),
											('0','Curteri','84085','SA'),
											('0','Curti','81040','CE'),
											('0','Curti','84090','SA'),
											('0','Cusago','20090','MI'),
											('0','Cusano Milanino','20095','MI'),
											('0','Cusano Mutri','82033','BN'),
											('0','Cusciano','64040','TE'),
											('0','Cusercoli','47010','FC'),
											('0','Cusiano','38020','TN'),
											('0','Cusino','22010','CO'),
											('0','Cusio','24010','BG'),
											('0','Cussignacco','33100','UD'),
											('0','Cussorgia','09011','CA'),
											('0','Custonaci','91015','TP'),
											('0','Custoza','37060','VR'),
											('0','Cutigliano','51024','PT'),
											('0','Cutro','88842','KR'),
											('0','Cutrofiano','73020','LE'),
											('0','Cuturella','88050','CZ'),
											('0','Cuveglio','21030','VA'),
											('0','Cuvio','21030','VA'),
											('0','Cuzzago','28803','VB'),
											('0','Daffin','89868','VV'),
											('0','Dagala del Re','95010','CT'),
											('0','Dagnente','28041','NO'),
											('0','Daiano','38030','TN'),
											('0','Dairago','20020','MI'),
											('0','Dalmine','24044','BG'),
											('0','Dambel','38010','TN'),
											('0','Danta di Cadore','32040','BL'),
											('0','Daone','38080','TN'),
											('0','Dardago','33070','PN'),
											('0','Dar','38080','TN'),
											('0','Darfo','25047','BS'),
											('0','Darzo','38080','TN'),
											('0','Das','89832','VV'),
											('0','Dattilo','91010','TP'),
											('0','Davagna','16022','GE'),
											('0','Daverio','21020','VA'),
											('0','Davoli','88060','CZ'),
											('0','Dazio','23010','SO'),
											('0','De Matteis','03100','FR'),
											('0','Decima','00144','RM'),
											('0','Decimomannu','09033','CA'),
											('0','Decimoputzu','09010','CA'),
											('0','Decollatura','88041','CZ'),
											('0','Decorata','82024','BN'),
											('0','Degagna','25079','BS'),
											('0','Deggiano','38020','TN'),
											('0','Dego','17058','SV'),
											('0','Deiva Marina','19013','SP'),
											('0','Delebio','23014','SO'),
											('0','Delia','93010','CL'),
											('0','Delianuova','89012','RC'),
											('0','Deliceto','71026','FG'),
											('0','Dello','25020','BS'),
											('0','Demonte','12014','CN'),
											('0','Denice','15010','AL'),
											('0','Denno','38010','TN'),
											('0','Dentecane','83030','AV'),
											('0','Deposito di Luzzi','87040','CS'),
											('0','Depressa','73030','LE'),
											('0','Derby','11015','AO'),
											('0','Dermulo','38012','TN'),
											('0','Dernice','15056','AL'),
											('0','Derovere','26040','CR'),
											('0','Deruta','06053','PG'),
											('0','Dervio','23824','LC'),
											('0','Desana','13034','VC'),
											('0','Desenzano del Garda','25015','BS'),
											('0','Desio','20033','MI'),
											('0','Destro','87060','CS'),
											('0','Desulo','08032','NU'),
											('0','Deutschnofen','39050','BZ'),
											('0','Devesi','10070','TO'),
											('0','Dezzo','24020','BG'),
											('0','Diacceto','50060','FI'),
											('0','Diamante','87023','CS'),
											('0','Diano Arentino','18013','IM'),
											('0','Diano Castello','18013','IM'),
											('0','Diano d\'Alba','12055','CN'),
											('0','Diano Marina','18013','IM'),
											('0','Diano San Pietro','18013','IM'),
											('0','Dicomano','50062','FI'),
											('0','Diecimo','55020','LU'),
											('0','Diegaro','47020','FC'),
											('0','Dietenheim','39031','BZ'),
											('0','Difensola','71010','FG'),
											('0','Dignano','33030','UD'),
											('0','Dimaro','38025','TN'),
											('0','Dinami','89833','VV'),
											('0','Dipignano','87045','CS'),
											('0','Diso','73030','LE'),
											('0','Divieto','98040','ME'),
											('0','Divignano','28010','NO'),
											('0','Divino Amore','00134','RM'),
											('0','Dizzasco','22020','CO'),
											('0','Dobbiaco','39034','BZ'),
											('0','Doberd del Lago','34070','GO'),
											('0','Dodici Morelli','44040','FE'),
											('0','Dogana','19034','SP'),
											('0','Dogana di Villa Chiavenna','23020','SO'),
											('0','Dogana Nuova','41022','MO'),
											('0','Doganella di Ninfa','04010','LT'),
											('0','Dogaro','41038','MO'),
											('0','Dogato','44020','FE'),
											('0','Dogliani','12063','CN'),
											('0','Dogliola','66050','CH'),
											('0','Dogna','33010','UD'),
											('0','Dolc','37020','VR'),
											('0','Dolceacqua','18035','IM'),
											('0','Dolcecanto','70024','BA'),
											('0','Dolcedo','18100','IM'),
											('0','Dolegna del Collio','34070','GO'),
											('0','Dolegnano','33048','UD'),
											('0','Dolianova','09041','CA'),
											('0','Dolo','30031','VE'),
											('0','Dolonne','11013','AO'),
											('0','Dolzago','23843','LC'),
											('0','Domanico','87030','CS'),
											('0','Domanins','33095','PN'),
											('0','Domaso','22013','CO'),
											('0','Domegge di Cadore','32040','BL'),
											('0','Domegliara','37015','VR'),
											('0','Domicella','83020','AV'),
											('0','Domo','21010','VA'),
											('0','Domo','60040','AN'),
											('0','Domodossola','28845','VB'),
											('0','Domus De Maria','09010','CA'),
											('0','Domusnovas','09015','CA'),
											('0','Domusnovas Canales','09071','OR'),
											('0','Don','38011','TN'),
											('0','Donada','45014','RO'),
											('0','Donato','13893','BI'),
											('0','Dongo','22014','CO'),
											('0','Donigala Fenughedu','09070','OR'),
											('0','Donisi','89048','RC'),
											('0','Donna','15062','AL'),
											('0','Donnafugata','97017','RG'),
											('0','Donnalucata','97010','RG'),
											('0','Donnas','11020','AO'),
											('0','Donnici Inferiore','87030','CS'),
											('0','Donnici Superiore','87030','CS'),
											('0','Donnini','50060','FI'),
											('0','Donoratico','57024','LI'),
											('0','Donori','09040','CA'),
											('0','Dont di Zoldo','32010','BL'),
											('0','Dorgali','08022','NU'),
											('0','Doria','87010','CS'),
											('0','Dorio','23824','LC'),
											('0','Dormelletto','28040','NO'),
											('0','Dorno','27020','PV'),
											('0','Dorsino','38070','TN'),
											('0','Dorzano','13881','BI'),
											('0','Dosimo','26043','CR'),
											('0','Dosoledo','32040','BL'),
											('0','Dosolo','46030','MN'),
											('0','Dossena','24010','BG'),
											('0','Dosso','44040','FE'),
											('0','Dosso del Liro','22010','CO'),
											('0','Dossobuono','37062','VR'),
											('0','Dosson','31030','TV'),
											('0','Doues','11010','AO'),
											('0','Dovadola','47013','FC'),
											('0','Dovera','26010','CR'),
											('0','Dozza di Zoldo','32010','BL'),
											('0','Dozza Imolese','40060','BO'),
											('0','Dragonea','84010','SA'),
											('0','Dragonetti','85020','PZ'),
											('0','Dragoni','73010','LE'),
											('0','Dragoni','81010','CE'),
											('0','Drapia','89862','VV'),
											('0','Drena','38074','TN'),
											('0','Drenchia','33040','UD'),
											('0','Dresano','20070','MI'),
											('0','Drezzo','22020','CO'),
											('0','Drizzona','26034','CR'),
											('0','Dro','38074','TN'),
											('0','Dronero','12025','CN'),
											('0','Drosi','89010','RC'),
											('0','Druento','10040','TO'),
											('0','Druogno','28853','VB'),
											('0','Drusacco','10080','TO'),
											('0','Drusco','43050','PR'),
											('0','Dualchi','08010','NU'),
											('0','Dubbione','10060','TO'),
											('0','Dubino','23015','SO'),
											('0','Ducenta','48020','RA'),
											('0','Due Cossani','21010','VA'),
											('0','Dueville','36031','VI'),
											('0','Dugenta','82030','BN'),
											('0','Duglia','87041','CS'),
											('0','Duino','34013','TS'),
											('0','Dumenza','21010','VA'),
											('0','Dunarobba','05020','TR'),
											('0','Duno','21030','VA'),
											('0','Dupino','84013','SA'),
											('0','Durazzano','48010','RA'),
											('0','Durazzano','82015','BN'),
											('0','Duronia','86020','CB'),
											('0','Dusino San Michele','14010','AT'),
											('0','Dussoi','','BL'),
											('0','Eboli','84025','SA'),
											('0','Edolo','25048','BS'),
											('0','Eggental','39050','BZ'),
											('0','Eggi','06049','PG'),
											('0','Egna','39044','BZ'),
											('0','Eianina','87010','CS'),
											('0','Elice','65010','PE'),
											('0','Elini','08040','NU'),
											('0','Ellera','17011','SV'),
											('0','Ellera Umbra','06074','PG'),
											('0','Ello','23848','LC'),
											('0','Elmas','09030','CA'),
											('0','Elmo','58010','GR'),
											('0','Elva','12020','CN'),
											('0','Elzenbaum','39040','BZ'),
											('0','Emarese','11020','AO'),
											('0','Empoli','50053','FI'),
											('0','Endine Gaiano','24060','BG'),
											('0','Enego','36052','VI'),
											('0','Enemonzo','33020','UD'),
											('0','Enna','94100','EN'),
											('0','Entracque','12010','CN'),
											('0','Entratico','24060','BG'),
											('0','Entreves','11013','AO'),
											('0','Envie','12030','CN'),
											('0','Eores','39040','BZ'),
											('0','Epinel','11012','AO'),
											('0','Episcopia','85033','PZ'),
											('0','Episcopio','84080','SA'),
											('0','Eppan Weinstrasse','39057','BZ'),
											('0','Equi','54022','MS'),
											('0','Era Samolaco','23027','SO'),
											('0','Eraclea','30020','VE'),
											('0','Eraclea Mare','30020','VE'),
											('0','Erba','22036','CO'),
											('0','Erbanno','25041','BS'),
											('0','Erb','37060','VR'),
											('0','Erbezzo','37020','VR'),
											('0','Erbusco','25030','BS'),
											('0','Erchie','72020','BR'),
											('0','Erchie','84010','SA'),
											('0','Ercolano','80056','NA'),
											('0','Ercole','81100','CE'),
											('0','Eredita','84050','SA'),
											('0','Eremo','89124','RC'),
											('0','Erice','91016','TP'),
											('0','Erli','17039','SV'),
											('0','Errano','48010','RA'),
											('0','Erto e Casso','33080','PN'),
											('0','Erula','07030','SS'),
											('0','Erve','23805','LC'),
											('0','Esanatoglia','62024','MC'),
											('0','Escalaplano','08043','NU'),
											('0','Escolca','08030','NU'),
											('0','Esine','25040','BS'),
											('0','Esino Lario','23825','LC'),
											('0','Esperia','03045','FR'),
											('0','Esperia Inferiore','03040','FR'),
											('0','Esporlatu','07010','SS'),
											('0','Este','35042','PD'),
											('0','Esterzili','08030','NU'),
											('0','Etroubles','11014','AO'),
											('0','Eupilio','22030','CO'),
											('0','Excenex','11100','AO'),
											('0','Exilles','10050','TO'),
											('0','Extrepieraz','11022','AO'),
											('0','Eyrs','39020','BZ'),
											('0','Fabbrica Curone','15050','AL'),
											('0','Fabbrica di Peccioli','56037','PI'),
											('0','Fabbriche','16158','GE'),
											('0','Fabbriche di Vallico','55020','LU'),
											('0','Fabbrico','42042','RE'),
											('0','Fabiano','19123','SP'),
											('0','Fabriano','60044','AN'),
											('0','Fabrica di Roma','01034','VT'),
											('0','Fabrizia','89823','VV'),
											('0','Fabro','05015','TR'),
											('0','Fabro Scalo','05010','TR'),
											('0','Fadalto','31010','TV'),
											('0','Faedis','33040','UD'),
											('0','Faedo','38010','TN'),
											('0','Faedo','23100','SO'),
											('0','Faella','52020','AR'),
											('0','Faenza','48018','RA'),
											('0','Faeto','41028','MO'),
											('0','Faeto','71020','FG'),
											('0','Fagagna','33034','UD'),
											('0','Fagar della Battaglia','31042','TV'),
											('0','Faggeto Lario','22020','CO'),
											('0','Faggiano','82019','BN'),
											('0','Faggiano','74020','TA'),
											('0','Fagnano','55050','LU'),
											('0','Fagnano Alto','67020','AQ'),
											('0','Fagnano Castello','87013','CS'),
											('0','Fagnano Olona','21054','VA'),
											('0','Fagnigola','33082','PN'),
											('0','Fago del Soldato','87053','CS'),
											('0','Fai della Paganella','38010','TN'),
											('0','Faiano','84093','SA'),
											('0','Faibano','80034','NA'),
											('0','Faicchio','82030','BN'),
											('0','Faida di Pin','38042','TN'),
											('0','Faidello','41022','MO'),
											('0','Faie','17010','SV'),
											('0','Falcade','32020','BL'),
											('0','Falchera','10156','TO'),
											('0','Falciano','81100','CE'),
											('0','Falciano del Massico','81030','CE'),
											('0','Falcinello','19030','SP'),
											('0','Falconara Albanese','87030','CS'),
											('0','Falconara Alta','60015','AN'),
											('0','Falconara Marittima','60015','AN'),
											('0','Falcone','98060','ME'),
											('0','Faleria','01030','VT'),
											('0','Falerna','88042','CZ'),
											('0','Falerna Scalo','88040','CZ'),
											('0','Falerone','63020','AP'),
											('0','Falesina','38057','TN'),
											('0','Falicetto','12039','CN'),
											('0','Fallascoso','66010','CH'),
											('0','Fallo','66040','CH'),
											('0','Falmenta','28825','VB'),
											('0','Faloppio','22020','CO'),
											('0','Faltona','52010','AR'),
											('0','Falvaterra','03020','FR'),
											('0','Falz di Piave','31020','TV'),
											('0','Falzes','39030','BZ'),
											('0','Fanano','41021','MO'),
											('0','Fane','37020','VR'),
											('0','Fanna','33092','PN'),
											('0','Fano','61032','PU'),
											('0','Fano a Corno','64040','TE'),
											('0','Fano Adriano','64044','TE'),
											('0','Fantina','98050','ME'),
											('0','Fanzolo','31050','TV'),
											('0','Fara Filiorum Petri','66010','CH'),
											('0','Fara Gera d\'Adda','24045','BG'),
											('0','Fara Novarese','28073','NO'),
											('0','Fara Olivana','24058','BG'),
											('0','Fara Sabina','02032','RI'),
											('0','Fara San Martino','66015','CH'),
											('0','Fara Vicentino','36030','VI'),
											('0','Faraone','64010','TE'),
											('0','Fardella','85032','PZ'),
											('0','Farfa Sabina','02030','RI'),
											('0','Farfengo','26023','CR'),
											('0','Farigliano','12060','CN'),
											('0','Farindola','65010','PE'),
											('0','Farini d\'Olmo','29023','PC'),
											('0','Farnese','01010','VT'),
											('0','Farneta','41045','MO'),
											('0','Farneta','87070','CS'),
											('0','Farneto','40042','BO'),
											('0','Farneto','40068','BO'),
											('0','Farnetta','05026','TR'),
											('0','Faro Superiore','98158','ME'),
											('0','Farra d\'Alpago','32016','BL'),
											('0','Farra di Soligo','31010','TV'),
											('0','Farra d\'Isonzo','34072','GO'),
											('0','Fasana','45010','RO'),
											('0','Fasan','90020','PA'),
											('0','Fasano del Garda','25083','BS'),
											('0','Fasano di Brindisi','72015','BR'),
											('0','Fascia','16020','GE'),
											('0','Fascia di Carlo','16020','GE'),
											('0','Fastello','01020','VT'),
											('0','Fastro','32030','BL'),
											('0','Fauglia','56043','PI'),
											('0','Faule','12033','CN'),
											('0','Favale di Malvaro','16040','GE'),
											('0','Favara','92026','AG'),
											('0','Favarella','93010','CL'),
											('0','Favaro','13813','BI'),
											('0','Favaro Veneto','30030','VE'),
											('0','Favazzina','89010','RC'),
											('0','Faver','38030','TN'),
											('0','Favignana','91023','TP'),
											('0','Favischio','02019','RI'),
											('0','Favria','10083','TO'),
											('0','Fegino','16161','GE'),
											('0','Feisoglio','12050','CN'),
											('0','Feldthurns','39040','BZ'),
											('0','Felegara','43040','PR'),
											('0','Feletto','10080','TO'),
											('0','Feletto Umberto','33010','UD'),
											('0','Felina','42038','RE'),
											('0','Felino','43035','PR'),
											('0','Felitto','84055','SA'),
											('0','Felizzano','15023','AL'),
											('0','Fellegara','42019','RE'),
											('0','Fellette di Romano d\'Ezzellino','36060','VI'),
											('0','Fellicarolo','41021','MO'),
											('0','Felline','73040','LE'),
											('0','Felonica','46022','MN'),
											('0','Feltre','32032','BL'),
											('0','Fematre','62039','MC'),
											('0','Fenegr','22070','CO'),
											('0','Fener','32030','BL'),
											('0','Fenestrelle','10060','TO'),
											('0','Fenis','11020','AO'),
											('0','Ferentillo','05034','TR'),
											('0','Ferentino','03013','FR'),
											('0','Ferentino Stazione','03013','FR'),
											('0','Feriolo Baveno','28835','VB'),
											('0','Ferla','96010','SR'),
											('0','Fermignano','61033','PU'),
											('0','Fermo','63023','AP'),
											('0','Ferno','21010','VA'),
											('0','Feroleto Antico','88043','CZ'),
											('0','Feroleto della Chiesa','89050','RC'),
											('0','Feronia','00065','RM'),
											('0','Ferrandina','75013','MT'),
											('0','Ferrania','17014','SV'),
											('0','Ferrara','44100','FE'),
											('0','Ferrara di Monte Baldo','37020','VR'),
											('0','Ferrari di Cervinara','83012','AV'),
											('0','Ferrari Stazione Serino','83020','AV'),
											('0','Ferrazza','36070','VI'),
											('0','Ferrazzano','86010','CB'),
											('0','Ferrera','13020','VC'),
											('0','Ferrera di Varese','21030','VA'),
											('0','Ferrera Erbognone','27032','PV'),
											('0','Ferrere d\'Asti','14012','AT'),
											('0','Ferriere','29024','PC'),
											('0','Ferrito','89010','RC'),
											('0','Ferro di Cavallo','06127','PG'),
											('0','Ferruccia','51030','PT'),
											('0','Ferruzzano','89030','RC'),
											('0','Fertilia','07040','SS'),
											('0','Fervento','13022','VC'),
											('0','Fesca','70123','BA'),
											('0','Fest','41054','MO'),
											('0','Festiona','12010','CN'),
											('0','Fezzano','19020','SP'),
											('0','Fiacchini','02037','RI'),
											('0','Fiamenga','06030','PG'),
											('0','Fiamignano','02023','RI'),
											('0','Fiammoi','32100','BL'),
											('0','Fianello','02040','RI'),
											('0','Fiano','10070','TO'),
											('0','Fiano','50052','FI'),
											('0','Fiano Romano','00065','RM'),
											('0','Fiascherino','19030','SP'),
											('0','Fiastra','62035','MC'),
											('0','Fiattone','55027','LU'),
											('0','Fiav','38075','TN'),
											('0','Fibbiana','50056','FI'),
											('0','Ficarazzi','95020','CT'),
											('0','Ficarazzi di Palermo','90010','PA'),
											('0','Ficarolo','45036','RO'),
											('0','Ficarra','98062','ME'),
											('0','Fico','91019','TP'),
											('0','Ficulle','05016','TR'),
											('0','Ficuzza','90030','PA'),
											('0','Fidenza','43036','PR'),
											('0','Fi Allo Sciliar','39050','BZ'),
											('0','Fiegni','62035','MC'),
											('0','Fiera','31100','TV'),
											('0','Fiera di Primiero','38054','TN'),
											('0','Fiernaz','11020','AO'),
											('0','Fierozzo','38050','TN'),
											('0','Fiesco','26010','CR'),
											('0','Fiesole','50014','FI'),
											('0','Fiesse','25020','BS'),
											('0','Fiesso','40055','BO'),
											('0','Fiesso d\'Artico','30032','VE'),
											('0','Fiesso Umbertiano','45024','RO'),
											('0','Fighille','06010','PG'),
											('0','Figino','20153','MI'),
											('0','Figino Serenza','22060','CO'),
											('0','Figline di Prato','59027','PO'),
											('0','Figline Valdarno','50063','FI'),
											('0','Figline Vegliaturo','87050','CS'),
											('0','Figlioli','83020','AV'),
											('0','Filacciano','00060','RM'),
											('0','Filadelfia','89814','VV'),
											('0','Filaga','90030','PA'),
											('0','Filago','24040','BG'),
											('0','Filandari','89851','VV'),
											('0','Filattiera','54023','MS'),
											('0','Filecchio','55050','LU'),
											('0','Filetta','84090','SA'),
											('0','Filettino','03010','FR'),
											('0','Filetto','48010','RA'),
											('0','Filetto','54020','MS'),
											('0','Filetto','66030','CH'),
											('0','Filettole','56019','PI'),
											('0','Filiano','85020','PZ'),
											('0','Filicaia','55030','LU'),
											('0','Filicudi','98050','ME'),
											('0','Filigare','50030','FI'),
											('0','Filighera','27010','PV'),
											('0','Filignano','86074','IS'),
											('0','Filippa','88838','KR'),
											('0','Filo','44010','FE'),
											('0','Filogaso','89843','VV'),
											('0','Filorsi','81035','CE'),
											('0','Filottrano','60024','AN'),
											('0','Fimiani','84080','SA'),
											('0','Final di Rero','44039','FE'),
											('0','Finalborgo','17024','SV'),
											('0','Finale','90010','PA'),
											('0','Finale Emilia','41034','MO'),
											('0','Finale Ligure','17024','SV'),
											('0','Finero','28854','VB'),
											('0','Fino del Monte','24020','BG'),
											('0','Fino Mornasco','22073','CO'),
											('0','Finocchito','84050','SA'),
											('0','Fiondi','15040','AL'),
											('0','Fiorana','44010','FE'),
											('0','Fiorano Al Serio','24020','BG'),
											('0','Fiorano Canavese','10010','TO'),
											('0','Fiorano Modenese','41042','MO'),
											('0','Fiordimonte','62035','MC'),
											('0','Fiorenzuola d\'Arda','29017','PC'),
											('0','Fiorenzuola di Focara','61010','PU'),
											('0','Firenze','50100','FI'),
											('0','Firenze','50131','FI'),
											('0','Firenze','50139','FI'),
											('0','Firenze','50137','FI'),
											('0','Firenze','50132','FI'),
											('0','Firenze','50144','FI'),
											('0','Firenze','50123','FI'),
											('0','Firenze','50122','FI'),
											('0','Firenze','50121','FI'),
											('0','Firenze','50143','FI'),
											('0','Firenze','50129','FI'),
											('0','Firenze','50133','FI'),
											('0','Firenzuola','50033','FI'),
											('0','Firmo','87010','CS'),
											('0','Fisciano','84084','SA'),
											('0','Fitili','89861','VV'),
											('0','Fiuggi','03014','FR'),
											('0','Fiuggi Fonte','03015','FR'),
											('0','Fiumalbo','41022','MO'),
											('0','Fiumana','47010','FC'),
											('0','Fiumara','89050','RC'),
											('0','Fiumara','98068','ME'),
											('0','Fiumara di Piraino','98060','ME'),
											('0','Fiumaretta','19030','SP'),
											('0','Fiumata','02020','RI'),
											('0','Fiume Veneto','33080','PN'),
											('0','Fiumedinisi','98022','ME'),
											('0','Fiumefreddo Bruzio','87030','CS'),
											('0','Fiumefreddo di Sicilia','95013','CT'),
											('0','Fiumenero','24020','BG'),
											('0','Fiumetto','55044','LU'),
											('0','Fiumicello','33050','UD'),
											('0','Fiumicello Santa Venere','85046','PZ'),
											('0','Fiumicino','00054','RM'),
											('0','Fiumicino','47039','FC'),
											('0','Fiumicino Aeroporto','00050','RM'),
											('0','Fiuminata','62025','MC'),
											('0','Fivizzano','54013','MS'),
											('0','Flaas','39010','BZ'),
											('0','Flagogna','33030','UD'),
											('0','Flaibano','33030','UD'),
											('0','Flambro','33030','UD'),
											('0','Flavon','38010','TN'),
											('0','Flecchia','13867','BI'),
											('0','Fleri','95020','CT'),
											('0','Flero','25020','BS'),
											('0','Flocco','80040','NA'),
											('0','Floresta','98030','ME'),
											('0','Floridia','96014','SR'),
											('0','Florinas','07030','SS'),
											('0','Flumeri','83040','AV'),
											('0','Flumignano','33030','UD'),
											('0','Flumini di Quartu Sant\'Elena','09046','CA'),
											('0','Fluminimaggiore','09010','CA'),
											('0','Flussio','08010','NU'),
											('0','Fobello','13025','VC'),
											('0','Foce Varano','71010','FG'),
											('0','Foce Verde','04010','LT'),
											('0','Focene','00054','RM'),
											('0','Focette','55044','LU'),
											('0','Foen','32032','BL'),
											('0','Foggia','71100','FG'),
											('0','Foggiano','85020','PZ'),
											('0','Foglia','02046','RI'),
											('0','Foglianise','82030','BN'),
											('0','Fogliano','04010','LT'),
											('0','Fogliano Redipuglia','34070','GO'),
											('0','Foglizzo','10090','TO'),
											('0','Fognano','48010','RA'),
											('0','Fognano di Montale','51037','PT'),
											('0','Foiano della Chiana','52045','AR'),
											('0','Foiano di Val Fortore','82020','BN'),
											('0','Folgaria','38064','TN'),
											('0','Folignano','63040','AP'),
											('0','Foligno','06034','PG'),
											('0','Follina','31051','TV'),
											('0','Follo','19020','SP'),
											('0','Follonica','58022','GR'),
											('0','Fombio','26861','LO'),
											('0','Fondachelli','98050','ME'),
											('0','Fondachello','98040','ME'),
											('0','Fonderia di Lovere','','BG'),
											('0','Fondi','04022','LT'),
											('0','Fondo in Val di Non','38013','TN'),
											('0','Fondotoce','','VB'),
											('0','Fondra','24010','BG'),
											('0','Fonni','08023','NU'),
											('0','Fontainemore','11020','AO'),
											('0','Fontana','43010','PR'),
											('0','Fontana','80070','NA'),
											('0','Fontana di Montella','83040','AV'),
											('0','Fontana Liri','03035','FR'),
											('0','Fontana Liri Superiore','03030','FR'),
											('0','Fontana Pradosa','29015','PC'),
											('0','Fontanafredda','33074','PN'),
											('0','Fontanafredda','81035','CE'),
											('0','Fontanaluccia','41040','MO'),
											('0','Fontanaradina','81030','CE'),
											('0','Fontanarosa','83040','AV'),
											('0','Fontanarossa','16020','GE'),
											('0','Fontanarossa Aereoporto','95121','CT'),
											('0','Fontane','12080','CN'),
											('0','Fontanefredde','39040','BZ'),
											('0','Fontanelice','40025','BO'),
											('0','Fontanella','24056','BG'),
											('0','Fontanella Grazioli','46040','MN'),
											('0','Fontanellato','43012','PR'),
											('0','Fontanelle','64030','TE'),
											('0','Fontanelle','81057','CE'),
											('0','Fontanelle','43010','PR'),
											('0','Fontanelle','36062','VI'),
											('0','Fontanelle','31043','TV'),
											('0','Fontanelle','12012','CN'),
											('0','Fontanelle','65131','PE'),
											('0','Fontanelle Casasanta','91100','TP'),
											('0','Fontaneto d\'Agogna','28010','NO'),
											('0','Fontanetto Po','13040','VC'),
											('0','Fontanigorda','16023','GE'),
											('0','Fontanile','14044','AT'),
											('0','Fontanini','43010','PR'),
											('0','Fontaniva','35014','PD'),
											('0','Fonte','84050','SA'),
											('0','Fonte','31010','TV'),
											('0','Fonte Alto','31010','TV'),
											('0','Fonte di Brescia','62025','MC'),
											('0','Fonte di Papa','00016','RM'),
											('0','Fonteblanda','58010','GR'),
											('0','Fontebuona','50036','FI'),
											('0','Fontecchio','67020','AQ'),
											('0','Fontechiari','03030','FR'),
											('0','Fontegreca','81014','CE'),
											('0','Fonteno','24060','BG'),
											('0','Fontenovella','83023','AV'),
											('0','Fonterosa','71030','FG'),
											('0','Fonterutoli','53010','SI'),
											('0','Fontespina','62012','MC'),
											('0','Fontevivo','43010','PR'),
											('0','Fonti Romane della Fratta','','FC'),
											('0','Fontia','54030','MS'),
											('0','Fontignano','06070','PG'),
											('0','Fonzaso','32030','BL'),
											('0','Foppolo','24010','BG'),
											('0','Forano Sabino','02044','RI'),
											('0','Forca di Valle','64040','TE'),
											('0','Force','63045','AP'),
											('0','Forcella','64030','TE'),
											('0','Forcelle','67010','AQ'),
											('0','Forchia','82011','BN'),
											('0','Forchia di Cervino','81023','CE'),
											('0','Forcola','23010','SO'),
											('0','Forcoli','56036','PI'),
											('0','Fordongianus','09083','OR'),
											('0','Forenza','85023','PZ'),
											('0','Foresta','88837','KR'),
											('0','Foresta di Burgos','07010','SS'),
											('0','Foresto','10053','TO'),
											('0','Foresto Sparso','24060','BG'),
											('0','Forgaria nel Friuli','33030','UD'),
											('0','Foria','84050','SA'),
											('0','Forino','83020','AV'),
											('0','Forio','80075','NA'),
											('0','Forl','47100','FC'),
											('0','Forl del Sannio','86084','IS'),
											('0','Forlimpopoli','47034','FC'),
											('0','Formazza','28863','VB'),
											('0','Forme','67050','AQ'),
											('0','Formegan','32035','BL'),
											('0','Formello','00060','RM'),
											('0','Formia','04023','LT'),
											('0','Formica','41056','MO'),
											('0','Formicola','81040','CE'),
											('0','Formigara','26020','CR'),
											('0','Formigine','41043','MO'),
											('0','Formigliana','13030','VC'),
											('0','Formignana','44035','FE'),
											('0','Formigosa','46030','MN'),
											('0','Fornace','38040','TN'),
											('0','Fornace Crocicchio','13030','VC'),
											('0','Fornace Zarattini','48010','RA'),
											('0','Fornacelle','80066','NA'),
											('0','Fornacette','56012','PI'),
											('0','Fornaci','17100','SV'),
											('0','Fornaci','25131','BS'),
											('0','Fornaci di Barga','55052','LU'),
											('0','Fornazzo','95010','CT'),
											('0','Fornelli','84050','SA'),
											('0','Fornelli','86070','IS'),
											('0','Fornero','28897','VB'),
											('0','Forni Avoltri','33020','UD'),
											('0','Forni di Sopra','33024','UD'),
											('0','Forni di Sotto','33020','UD'),
											('0','Forno','54034','MS'),
											('0','Forno Alpi Graie','10070','TO'),
											('0','Forno Canavese','10084','TO'),
											('0','Forno d\'Allione','25040','BS'),
											('0','Forno di Fiemme','38030','TN'),
											('0','Forno di Omegna','28892','VB'),
											('0','Forno di Zoldo','32012','BL'),
											('0','Forno d\'Ono','25078','BS'),
											('0','Fornole','05020','TR'),
											('0','Fornoli','55026','LU'),
											('0','Fornolosa','10080','TO'),
											('0','Fornovo di Taro','43045','PR'),
											('0','Fornovo San Giovanni','24040','BG'),
											('0','Fornovolasco','55020','LU'),
											('0','Foro Appio','04010','LT'),
											('0','Forte dei Marmi','55042','LU'),
											('0','Forte Village','09010','CA'),
											('0','Fortezza','39045','BZ'),
											('0','Fortogna','32010','BL'),
											('0','Fortunago','27040','PV'),
											('0','Forza d\'Agr','98030','ME'),
											('0','Fosciandora','55020','LU'),
											('0','Fosdinovo','54035','MS'),
											('0','Fosdondo','42015','RE'),
											('0','Fossa','67020','AQ'),
											('0','Fossa di Concordia','41033','MO'),
											('0','Fossacesia','66022','CH'),
											('0','Fossacesia Marina','66020','CH'),
											('0','Fossalon','34070','GO'),
											('0','Fossalta','44030','FE'),
											('0','Fossalta di Piave','30020','VE'),
											('0','Fossalta di Portogruaro','30025','VE'),
											('0','Fossalta di Trebaseleghe','35010','PD'),
											('0','Fossalto','86020','CB'),
											('0','Fossalunga','31050','TV'),
											('0','Fossano','12045','CN'),
											('0','Fossarmato','27010','PV'),
											('0','Fossato (Prov. di Prato)','51020','PT'),
											('0','Fossato di Vico','06022','PG'),
											('0','Fossato di Vico Stazione','06022','PG'),
											('0','Fossato Ionico','89060','RC'),
											('0','Fossato Serralta','88050','CZ'),
											('0','Fosse','37020','VR'),
											('0','Fosse','87027','CS'),
											('0','Foss','30030','VE'),
											('0','Fossola','54033','MS'),
											('0','Fossoli','41012','MO'),
											('0','Fossombrone','61034','PU'),
											('0','Fossone','54030','MS'),
											('0','Foza','36010','VI'),
											('0','Frabosa Soprana','12082','CN'),
											('0','Frabosa Sottana','12083','CN'),
											('0','Fraccano','06010','PG'),
											('0','Fraciscio','23021','SO'),
											('0','Fraconalto','15060','AL'),
											('0','Fragagnano','74022','TA'),
											('0','Fragneto L\'Abate','82020','BN'),
											('0','Fragneto Monforte','82020','BN'),
											('0','Fraigas','07014','SS'),
											('0','Fraine','66050','CH'),
											('0','Fralculacciu','08020','NU'),
											('0','Framura','19014','SP'),
											('0','Francavilla Al Mare','66023','CH'),
											('0','Francavilla Al Mare Rione Foro','66023','CH'),
											('0','Francavilla Angitola','89815','VV'),
											('0','Francavilla Bisio','15060','AL'),
											('0','Francavilla d\'Ete','63010','AP'),
											('0','Francavilla di Sicilia','98034','ME'),
											('0','Francavilla Fontana','72021','BR'),
											('0','Francavilla Marittima','87072','CS'),
											('0','Francavilla Sul Sinni','85034','PZ'),
											('0','Francenigo','31018','TV'),
											('0','Franchini','15040','AL'),
											('0','Francica','89851','VV'),
											('0','Francofonte','96015','SR'),
											('0','Francolino','44036','FE'),
											('0','Francolise','81050','CE'),
											('0','Franculacciu','08020','NU'),
											('0','Frangart','39010','BZ'),
											('0','Frangarto','39010','BZ'),
											('0','Franzensfeste','39045','BZ'),
											('0','Fraore','43010','PR'),
											('0','Frascaro','15010','AL'),
											('0','Frascarolo','27030','PV'),
											('0','Frascati','00044','RM'),
											('0','Frascineto','87010','CS'),
											('0','Frassen','32020','BL'),
											('0','Frassignoni','51020','PT'),
											('0','Frassilongo','38050','TN'),
											('0','Frassine','58020','GR'),
											('0','Frassinelle Polesine','45030','RO'),
											('0','Frassinello Monferrato','15035','AL'),
											('0','Frassineti','41026','MO'),
											('0','Frassineto','52040','AR'),
											('0','Frassineto Po','15040','AL'),
											('0','Frassinetto','10080','TO'),
											('0','Frassino','12020','CN'),
											('0','Frassino Mantovano','46038','MN'),
											('0','Frassinoro','41044','MO'),
											('0','Frasso Sabino','02030','RI'),
											('0','Frasso Telesino','82030','BN'),
											('0','Fratta','34076','GO'),
											('0','Fratta Polesine','45025','RO'),
											('0','Fratta Terme','47030','FC'),
											('0','Fratta Todina','06054','PG'),
											('0','Frattamaggiore','80027','NA'),
											('0','Frattaminore','80020','NA'),
											('0','Fratte','84135','SA'),
											('0','Fratte','35010','PD'),
											('0','Fratte di Sassofeltrio','61013','PU'),
											('0','Fratterosa','61040','PU'),
											('0','Fratticiola Selvatica','06020','PG'),
											('0','Frattocchie','00040','RM'),
											('0','Frattura di Scanno','67030','AQ'),
											('0','Frazzan','98070','ME'),
											('0','Fregene','00050','RM'),
											('0','Fregona','31010','TV'),
											('0','Freiberg Vinschgau','39020','BZ'),
											('0','Freienfeld','39040','BZ'),
											('0','Fresagrandinaria','66050','CH'),
											('0','Frescada','31022','TV'),
											('0','Fresciano','52030','AR'),
											('0','Fresonara','15064','AL'),
											('0','Freto','41010','MO'),
											('0','Frigento','83040','AV'),
											('0','Frigintini','97010','RG'),
											('0','Frignano','81030','CE'),
											('0','Frigole','73010','LE'),
											('0','Frinco','14030','AT'),
											('0','Frisa','66030','CH'),
											('0','Frisanco','33080','PN'),
											('0','Frondarola','64040','TE'),
											('0','Front','10070','TO'),
											('0','Frontale','62021','MC'),
											('0','Fronti','88040','CZ'),
											('0','Frontino','61021','PU'),
											('0','Frontone','61040','PU'),
											('0','Frosini','53010','SI'),
											('0','Frosinone','03100','FR'),
											('0','Frosinone Stazione','03100','FR'),
											('0','Frosolone','86095','IS'),
											('0','Frossasco','10060','TO'),
											('0','Frugarolo','15065','AL'),
											('0','Frusci','85030','PZ'),
											('0','Fubine','15043','AL'),
											('0','Fucecchio','50054','FI'),
											('0','Fucine di Ossana','38026','TN'),
											('0','Fugazzolo','43030','PR'),
											('0','Fuipiano Imagna','24030','BG'),
											('0','Fulgatore','91010','TP'),
											('0','Fumane','37022','VR'),
											('0','Fumone','03010','FR'),
											('0','Funes','39040','BZ'),
											('0','Funo','40050','BO'),
											('0','Funo Centergross','40050','BO'),
											('0','Fuorni','84131','SA'),
											('0','Furbara Cerenova','00050','RM'),
											('0','Furci','66050','CH'),
											('0','Furci Siculo','98023','ME'),
											('0','Furlo','61041','PU'),
											('0','Furnari','98054','ME'),
											('0','Furnolo','81057','CE'),
											('0','Furore','84010','SA'),
											('0','Furtei','09040','CA'),
											('0','Fusara','84081','SA'),
											('0','Fusaro','80070','NA'),
											('0','Fuscaldo','87024','CS'),
											('0','Fusignano','48010','RA'),
											('0','Fusine','23010','SO'),
											('0','Fusine in Valromana','33010','UD'),
											('0','Futani','84050','SA'),
											('0','Gabbiana','46010','MN'),
											('0','Gabbiana','54020','MS'),
											('0','Gabbio Con Monte Ossolano','28030','NO'),
											('0','Gabbioneta Binanuova','26030','CR'),
											('0','Gabbro','57010','LI'),
											('0','Gabella','88048','CZ'),
											('0','Gabelletta di Cesi','05100','TR'),
											('0','Gabiano','15020','AL'),
											('0','Gabicce Mare','61011','PU'),
											('0','Gabria','34070','GO'),
											('0','Gaby','11020','AO'),
											('0','Gadesco Pieve Delmona','26030','CR'),
											('0','Gadoni','08030','NU'),
											('0','Gaeta','04024','LT'),
											('0','Gaggi','98030','ME'),
											('0','Gaggiano','20083','MI'),
											('0','Gaggio di Piano','41010','MO'),
											('0','Gaggio Montano','40041','BO'),
											('0','Gaglianico','13894','BI'),
											('0','Gagliano Aterno','67020','AQ'),
											('0','Gagliano Castelferrato','94010','EN'),
											('0','Gagliano del Capo','73034','LE'),
											('0','Gagliano di Mugello','50030','FI'),
											('0','Gagliato','88060','CZ'),
											('0','Gagliole','62022','MC'),
											('0','Gaiana','40024','BO'),
											('0','Gaianello','41026','MO'),
											('0','Gaiano','43030','PR'),
											('0','Gaiarine','31018','TV'),
											('0','Gaiato','41026','MO'),
											('0','Gaiba','45030','RO'),
											('0','Gaibana','44040','FE'),
											('0','Gaibanella','44040','FE'),
											('0','Gaibola','40136','BO'),
											('0','Gaifana','06020','PG'),
											('0','Gainazzo','41050','MO'),
											('0','Gaiola','12010','CN'),
											('0','Gaiole in Chianti','53013','SI'),
											('0','Gairo','08040','NU'),
											('0','Gais','39030','BZ'),
											('0','Gala','98050','ME'),
											('0','Galaino','85050','PZ'),
											('0','Galati Mamertino','98070','ME'),
											('0','Galati Marina','98134','ME'),
											('0','Galatina','73013','LE'),
											('0','Galatone','73044','LE'),
											('0','Galatro','89054','RC'),
											('0','Galbiate','23851','LC'),
											('0','Galciana','59012','PO'),
											('0','Galdo Cilento','84050','SA'),
											('0','Galdo degli Alburni','84030','SA'),
											('0','Galdo di Lauria','85040','PZ'),
											('0','Galeata','47010','FC'),
											('0','Galgagnano','26832','LO'),
											('0','Gallarate','21013','VA'),
											('0','Galleane','12032','CN'),
											('0','Galleno','50050','FI'),
											('0','Gallese','01035','VT'),
											('0','Gallese Scalo Teverina','01030','VT'),
											('0','Galliate','28066','NO'),
											('0','Galliate Lombardo','21020','VA'),
											('0','Galliavola','27034','PV'),
											('0','Gallicano','55027','LU'),
											('0','Gallicano nel Lazio','00010','RM'),
											('0','Gallicchio','85010','PZ'),
											('0','Gallico','89055','RC'),
											('0','Galliera','40015','BO'),
											('0','Galliera Frazione','40010','BO'),
											('0','Galliera Veneta','35015','PD'),
											('0','Gallignano','26029','CR'),
											('0','Gallignano di Ancona','60020','AN'),
											('0','Gallina','53023','SI'),
											('0','Gallina','89061','RC'),
											('0','Gallinaro','03040','FR'),
											('0','Gallio','36032','VI'),
											('0','Gallipoli','73014','LE'),
											('0','Gallo','44020','FE'),
											('0','Gallo','81035','CE'),
											('0','Gallo Bolognese','40060','BO'),
											('0','Gallo di Grinzane','12060','CN'),
											('0','Gallo di Petriano','61020','PU'),
											('0','Gallo di Tagliacozzo','67060','AQ'),
											('0','Gallo Matese','81010','CE'),
											('0','Gallodoro','98030','ME'),
											('0','Galloro','00040','RM'),
											('0','Galluccio','81044','CE'),
											('0','Galluzzo','50124','FI'),
											('0','Galtelli','08020','NU'),
											('0','Galugnano','73010','LE'),
											('0','Galzignano Terme','35030','PD'),
											('0','Gamalero','15010','AL'),
											('0','Gambara','25020','BS'),
											('0','Gambarana','27030','PV'),
											('0','Gambarare','30030','VE'),
											('0','Gambarie','89050','RC'),
											('0','Gambasca','12030','CN'),
											('0','Gambassi Terme','50050','FI'),
											('0','Gambatesa','86013','CB'),
											('0','Gambellara','48010','RA'),
											('0','Gambellara','36053','VI'),
											('0','Gamberale','66040','CH'),
											('0','Gambettola','47035','FC'),
											('0','Gambol','27025','PV'),
											('0','Gambugliano','36050','VI'),
											('0','Gambulaga','44010','FE'),
											('0','Ganaceto','41010','MO'),
											('0','Ganaghello','29015','PC'),
											('0','Gandellino','24020','BG'),
											('0','Gandino','24024','BG'),
											('0','Gandosso','24060','BG'),
											('0','Gangi','90024','PA'),
											('0','Gannano','75020','MT'),
											('0','Ganzirri','98165','ME'),
											('0','Garadassi','15054','AL'),
											('0','Garaguso','75010','MT'),
											('0','Garbagna','15050','AL'),
											('0','Garbagna Novarese','28070','NO'),
											('0','Garbagnate Milanese','20024','MI'),
											('0','Garbagnate Monastero','23846','LC'),
											('0','Garbana','27033','PV'),
											('0','Garda','37016','VR'),
											('0','Gardolo','38014','TN'),
											('0','Gardone Riviera','25083','BS'),
											('0','Gardone Val Trompia','25063','BS'),
											('0','Garessio Borgo Piave','12075','CN'),
											('0','Garessio Borgo Ponte','12075','CN'),
											('0','Gargagnago','37020','VR'),
											('0','Gargallo','41012','MO'),
											('0','Gargallo','28010','NO'),
											('0','Gargani','80030','NA'),
											('0','Gargazon','39010','BZ'),
											('0','Gargazzone','39010','BZ'),
											('0','Gargnano','25084','BS'),
											('0','Garlasco','27026','PV'),
											('0','Garlate','23852','LC'),
											('0','Garlenda','17033','SV'),
											('0','Garna','32010','BL'),
											('0','Garniga','38060','TN'),
											('0','Garofali','81035','CE'),
											('0','Garofalo','41056','MO'),
											('0','Garrufo','64010','TE'),
											('0','Garzeno','22010','CO'),
											('0','Garzigliana','10060','TO'),
											('0','Gasperina','88060','CZ'),
											('0','Gasponi','89862','VV'),
											('0','Gassano','54020','MS'),
											('0','Gassino Torinese','10090','TO'),
											('0','Gatta','42030','RE'),
											('0','Gattaia','50039','FI'),
											('0','Gattaiola','55050','LU'),
											('0','Gattatico','42043','RE'),
											('0','Gatteo','47030','FC'),
											('0','Gatteo Mare','47043','FC'),
											('0','Gattico','28013','NO'),
											('0','Gattinara','13045','VC'),
											('0','Gattolino','47020','FC'),
											('0','Gattorna','16030','GE'),
											('0','Gaudiano','85024','PZ'),
											('0','Gauna','10010','TO'),
											('0','Gavardo','25085','BS'),
											('0','Gavassa','42010','RE'),
											('0','Gavazzana','15063','AL'),
											('0','Gavello','41030','MO'),
											('0','Gavello','44010','FE'),
											('0','Gavello','45010','RO'),
											('0','Gaverina Terme','24060','BG'),
											('0','Gavi','15066','AL'),
											('0','Gavignano','40050','BO'),
											('0','Gavignano','00030','RM'),
											('0','Gavignano Sabino','02040','RI'),
											('0','Gavinana','51025','PT'),
											('0','Gavirate','21026','VA'),
											('0','Gavoi','08020','NU'),
											('0','Gavonata','15016','AL'),
											('0','Gavorrano','58023','GR'),
											('0','Gazoldo degli Ippoliti','46040','MN'),
											('0','Gazzada','21045','VA'),
											('0','Gazzaniga','24025','BG'),
											('0','Gazzano','42010','RE'),
											('0','Gazzera','30174','VE'),
											('0','Gazzi','98124','ME'),
											('0','Gazzo Padovano','35010','PD'),
											('0','Gazzo Veronese','37060','VR'),
											('0','Gazzola','29010','PC'),
											('0','Gazzolo','37040','VR'),
											('0','Gazzuolo','46010','MN'),
											('0','Gela','93012','CL'),
											('0','Gemini','73050','LE'),
											('0','Gemmano','47855','RN'),
											('0','Gemona del Friuli','33013','UD'),
											('0','Gemona Piovega','','UD'),
											('0','Gemonio','21036','VA'),
											('0','Genazzano','00030','RM'),
											('0','Genga','60040','AN'),
											('0','Genga Stazione','60040','AN'),
											('0','Genivolta','26020','CR'),
											('0','Gennamari','09030','CA'),
											('0','Genola','12040','CN'),
											('0','Genoni','08030','NU'),
											('0','Genova','16100','GE'),
											('0','Genova','16156','GE'),
											('0','Genova','16145','GE'),
											('0','Genova','16146','GE'),
											('0','Genova','16125','GE'),
											('0','Genova','16127','GE'),
											('0','Genova','16134','GE'),
											('0','Genova','16136','GE'),
											('0','Genova','16124','GE'),
											('0','Genova','16131','GE'),
											('0','Genova','16135','GE'),
											('0','Genova','16143','GE'),
											('0','Genova','16142','GE'),
											('0','Genova','16139','GE'),
											('0','Genova','16126','GE'),
											('0','Genova','16132','GE'),
											('0','Genova','16144','GE'),
											('0','Genova','16129','GE'),
											('0','Genova','16128','GE'),
											('0','Genova','16123','GE'),
											('0','Genova','16122','GE'),
											('0','Genova','16121','GE'),
											('0','Genuri','09020','CA'),
											('0','Genzano di Lucania','85013','PZ'),
											('0','Genzano di Roma','00045','RM'),
											('0','Genzone','27014','PV'),
											('0','Gera Lario','22010','CO'),
											('0','Gerace','89040','RC'),
											('0','Geraci Siculo','90010','PA'),
											('0','Gerano','00025','RM'),
											('0','Gerbido di Mortizza','29010','PC'),
											('0','Gerbo','12040','CN'),
											('0','Gerbole','10040','TO'),
											('0','Gerenzago','27010','PV'),
											('0','Gerenzano','21040','VA'),
											('0','Gerfalco','58020','GR'),
											('0','Gergei','08030','NU'),
											('0','Germagnano','10070','TO'),
											('0','Germagno','28887','VB'),
											('0','Germasino','22010','CO'),
											('0','Germignaga','21010','VA'),
											('0','Gerocarne','89831','VV'),
											('0','Gerola Alta','23010','SO'),
											('0','Gerosa','24010','BG'),
											('0','Gerre De\' Caprioli','26040','CR'),
											('0','Gervasutta','33100','UD'),
											('0','Gesico','09040','CA'),
											('0','Gessate','20060','MI'),
											('0','Gesso','98153','ME'),
											('0','Gessopalena','66010','CH'),
											('0','Gesturi','09020','CA'),
											('0','Gesualdo','83040','AV'),
											('0','Gesuiti','87030','CS'),
											('0','Gfrill','39040','BZ'),
											('0','Ghedi','25016','BS'),
											('0','Ghemme','28074','NO'),
											('0','Ghevio','28046','NO'),
											('0','Ghezzano','56010','PI'),
											('0','Ghiare di Berceto','43040','PR'),
											('0','Ghiare di Corniglio','43020','PR'),
											('0','Ghibullo','48010','RA'),
											('0','Ghiffa','28823','VB'),
											('0','Ghilarza','09074','OR'),
											('0','Ghirano','33080','PN'),
											('0','Ghirla','21030','VA'),
											('0','Ghirlanda','58020','GR'),
											('0','Ghisalba','24050','BG'),
											('0','Ghislarengo','13030','VC'),
											('0','Ghivizzano','55053','LU'),
											('0','Ghizzano di Peccioli','56030','PI'),
											('0','Ghorio','89060','RC'),
											('0','Giacciano Con Baruchella','45020','RO'),
											('0','Giaglione','10050','TO'),
											('0','Giaiette','16040','GE'),
											('0','Giais','33080','PN'),
											('0','Giallonardo','82027','BN'),
											('0','Giammoro','98040','ME'),
											('0','Giampilieri','98142','ME'),
											('0','Giampilieri Marina','98141','ME'),
											('0','Gianico','25040','BS'),
											('0','Giannutri','58018','GR'),
											('0','Giano Dell\'Umbria','06030','PG'),
											('0','Giano Vetusto','81042','CE'),
											('0','Giardina Gallotti','92010','AG'),
											('0','Giardinello','90040','PA'),
											('0','Giardinetto','15040','AL'),
											('0','Giardini','98035','ME'),
											('0','Giardini Naxos','98030','ME'),
											('0','Giardino','01013','VT'),
											('0','Giarole','15036','AL'),
											('0','Giarratana','97010','RG'),
											('0','Giarre','95014','CT'),
											('0','Giasbana','34070','GO'),
											('0','Giave','07010','SS'),
											('0','Giaveno','10094','TO'),
											('0','Giavera del Montello','31040','TV'),
											('0','Giba','09010','CA'),
											('0','Gibellina','91024','TP'),
											('0','Gibilmanna','90010','PA'),
											('0','Gidilau','08031','NU'),
											('0','Gifflenga','13874','BI'),
											('0','Giffone','89020','RC'),
											('0','Giffoni Sei Casali','84090','SA'),
											('0','Giffoni Valle Piana','84095','SA'),
											('0','Giglio','03020','FR'),
											('0','Giglio Isola','58012','GR'),
											('0','Giglio Porto','58013','GR'),
											('0','Gignese','28836','VB'),
											('0','Gignod','11010','AO'),
											('0','Gildone','86010','CB'),
											('0','Gimigliano','88045','CZ'),
											('0','Gimigliano Inferiore','88040','CZ'),
											('0','Gimillian','11012','AO'),
											('0','Ginestra','85020','PZ'),
											('0','Ginestra degli Schiavoni','82020','BN'),
											('0','Ginestra Fiorentina','50055','FI'),
											('0','Ginestra Sabina','02030','RI'),
											('0','Ginestreto','61100','PU'),
											('0','Ginosa','74013','TA'),
											('0','Ginostra di Lipari','98050','ME'),
											('0','Gioi','84056','SA'),
											('0','Gioia dei Marsi','67055','AQ'),
											('0','Gioia del Colle','70023','BA'),
											('0','Gioia Sannitica','81010','CE'),
											('0','Gioia Tauro','89013','RC'),
											('0','Gioiella','06060','PG'),
											('0','Gioiosa Ionica','89042','RC'),
											('0','Gioiosa Marea','98063','ME'),
											('0','Giove','05024','TR'),
											('0','Giovi','16010','GE'),
											('0','Giovi','84134','SA'),
											('0','Giovi d\'Arezzo','52010','AR'),
											('0','Gioviano','55020','LU'),
											('0','Giovinazzo','70054','BA'),
											('0','Giovo','38030','TN'),
											('0','Giovo Ligure','17042','SV'),
											('0','Giralba','32041','BL'),
											('0','Girasole','08040','NU'),
											('0','Girifalco','88024','CZ'),
											('0','Girlan','39050','BZ'),
											('0','Gironico','22020','CO'),
											('0','Gissi','66052','CH'),
											('0','Giudecca','30133','VE'),
											('0','Giuggianello','73030','LE'),
											('0','Giugliano in Campania','80014','NA'),
											('0','Giugnola','40022','BO'),
											('0','Giuliana','90030','PA'),
											('0','Giulianello','04010','LT'),
											('0','Giuliano','85100','PZ'),
											('0','Giuliano di Lecce','73040','LE'),
											('0','Giuliano di Roma','03020','FR'),
											('0','Giuliano Teatino','66010','CH'),
											('0','Giulianova','64021','TE'),
											('0','Giulianova Spiaggia','64022','TE'),
											('0','Giuliopoli','66040','CH'),
											('0','Giumarra','95040','CT'),
											('0','Giuncano','05030','TR'),
											('0','Giuncarico','58020','GR'),
											('0','Giuncugnano','55030','LU'),
											('0','Giungano','84050','SA'),
											('0','Giurdignano','73020','LE'),
											('0','Giussago','27010','PV'),
											('0','Giussano','20034','MI'),
											('0','Giustenice','17027','SV'),
											('0','Giustino','38086','TN'),
											('0','Giusvalla','17010','SV'),
											('0','Givoletto','10040','TO'),
											('0','Gizzeria','88040','CZ'),
											('0','Gizzeria Lido','88048','CZ'),
											('0','Glair','11029','AO'),
											('0','Glaning','39050','BZ'),
											('0','Gliaca','98060','ME'),
											('0','Glorenza','39024','BZ'),
											('0','Glorie','48020','RA'),
											('0','Glurns','39024','BZ'),
											('0','Gnocca','45018','RO'),
											('0','Gnocchetto','15070','AL'),
											('0','Gobbera','38050','TN'),
											('0','Godega Sant\'Urbano','31010','TV'),
											('0','Godi','29010','PC'),
											('0','Godia','33100','UD'),
											('0','Godiasco','27052','PV'),
											('0','Godo','48010','RA'),
											('0','Godrano','90030','PA'),
											('0','Goito','46044','MN'),
											('0','Golasecca','21010','VA'),
											('0','Goldrain','39020','BZ'),
											('0','Golferenzo','27047','PV'),
											('0','Golfo Aranci','07020','SS'),
											('0','Gomagoi','39020','BZ'),
											('0','Gombito','26020','CR'),
											('0','Gombola','41040','MO'),
											('0','Gonars','33050','UD'),
											('0','Goni','09040','CA'),
											('0','Gonnesa','09010','CA'),
											('0','Gonnoscodina','09090','OR'),
											('0','Gonnosfanadiga','09035','CA'),
											('0','Gonnosn','09090','OR'),
											('0','Gonnostramatza','09093','OR'),
											('0','Gonzaga','46023','MN'),
											('0','Gordona','23020','SO'),
											('0','Gorfigliano','55030','LU'),
											('0','Gorga','00030','RM'),
											('0','Gorga','84050','SA'),
											('0','Gorgazzo','91018','TP'),
											('0','Gorgo Al Monticano','31040','TV'),
											('0','Gorgoglione','75010','MT'),
											('0','Gorgona Isola','57030','LI'),
											('0','Gorgonzola','20064','MI'),
											('0','Goriano Sicoli','67030','AQ'),
											('0','Goriano Valli','67020','AQ'),
											('0','Goricizza e Pozzo','33030','UD'),
											('0','Gorino di Goro','44020','FE'),
											('0','Gorizia','34170','GO'),
											('0','Gorla','20125','MI'),
											('0','Gorla Maggiore','21050','VA'),
											('0','Gorla Minore','21055','VA'),
											('0','Gorlago','24060','BG'),
											('0','Gorle','24020','BG'),
											('0','Gornate Olona','21040','VA'),
											('0','Gorno','24020','BG'),
											('0','Goro','44020','FE'),
											('0','Gorra','17024','SV'),
											('0','Gorreto','16020','GE'),
											('0','Gorzegno','12070','CN'),
											('0','Gorzone','25047','BS'),
											('0','Gosaldo','32020','BL'),
											('0','Gosi Pianvignale','12080','CN'),
											('0','Gossensass','39040','BZ'),
											('0','Gossolengo','29020','PC'),
											('0','Gottasecca','12070','CN'),
											('0','Gottolengo','25023','BS'),
											('0','Governolo','46034','MN'),
											('0','Govone','12040','CN'),
											('0','Gozzano','28024','NO'),
											('0','Gozzolina','46040','MN'),
											('0','Gracciano','53040','SI'),
											('0','Gracciano di Colle Val d\'Elsa','53034','SI'),
											('0','Gradara','61012','PU'),
											('0','Gradisca di Sedegliano','33030','UD'),
											('0','Gradisca d\'Isonzo','34072','GO'),
											('0','Gradizza','44034','FE'),
											('0','Grado','34073','GO'),
											('0','Grado Citt Giardino','34073','GO'),
											('0','Grado Pineta','34073','GO'),
											('0','Gradoli','01010','VT'),
											('0','Graffignana','26813','LO'),
											('0','Graffignano','01020','VT'),
											('0','Graglia','13895','BI'),
											('0','Graglia Bagni','13895','BI'),
											('0','Graglia Santuario','13895','BI'),
											('0','Gragnana','54030','MS'),
											('0','Gragnano','55010','LU'),
											('0','Gragnano','80054','NA'),
											('0','Gragnano Trebbiense','29010','PC'),
											('0','Gragnola','54020','MS'),
											('0','Grammichele','95042','CT'),
											('0','Gramolazzo','55030','LU'),
											('0','Grana','14031','AT'),
											('0','Granaglione','40045','BO'),
											('0','Granaiolo','50057','FI'),
											('0','Granarolo','48019','RA'),
											('0','Granarolo Dell\'Emilia','40057','BO'),
											('0','Grancia','67050','AQ'),
											('0','Grancona','36040','VI'),
											('0','Grand Villa Cravon','11020','AO'),
											('0','Grandate','22070','CO'),
											('0','Grandola Ed Uniti','22010','CO'),
											('0','Granerolo','28883','VB'),
											('0','Granieri','95040','CT'),
											('0','Graniti','98036','ME'),
											('0','Granitola','91020','TP'),
											('0','Granozzo Con Monticello','28060','NO'),
											('0','Grantola','21030','VA'),
											('0','Grantorto','35010','PD'),
											('0','Granze','35040','PD'),
											('0','Granzette','45030','RO'),
											('0','Grassano','75014','MT'),
											('0','Grassina','50015','FI'),
											('0','Grassobbio','24050','BG'),
											('0','Gratacasolo','25055','BS'),
											('0','Gratosoglio','20142','MI'),
											('0','Gratteri','90010','PA'),
											('0','Gratteria','12080','CN'),
											('0','Graun Im Vinschgau','39020','BZ'),
											('0','Grauno','38030','TN'),
											('0','Grava','15040','AL'),
											('0','Gravago','43030','PR'),
											('0','Gravedona','22015','CO'),
											('0','Graveglia','16040','GE'),
											('0','Gravellona Lomellina','27020','PV'),
											('0','Gravellona Toce','28883','VB'),
											('0','Gravere','10050','TO'),
											('0','Gravina di Catania','95030','CT'),
											('0','Gravina in Puglia','70024','BA'),
											('0','Grazie','51030','PT'),
											('0','Grazie','46040','MN'),
											('0','Grazzanise','81046','CE'),
											('0','Grazzano Badoglio','14035','AT'),
											('0','Grazzano Visconti','29020','PC'),
											('0','Greccio','02040','RI'),
											('0','Greci','83030','AV'),
											('0','Greci','87035','CS'),
											('0','Greco','20125','MI'),
											('0','Greggio','13030','VC'),
											('0','Gremiasco','15056','AL'),
											('0','Gressan','11020','AO'),
											('0','Gressoney La Trinit','11020','AO'),
											('0','Gressoney Saint Jean','11025','AO'),
											('0','Greve in Chianti','50022','FI'),
											('0','Grezzago','20056','MI'),
											('0','Grezzana','37023','VR'),
											('0','Griante','22011','CO'),
											('0','Gricignano di Aversa','81030','CE'),
											('0','Grignano','24040','BG'),
											('0','Grignano','34014','TS'),
											('0','Grignano Polesine','45030','RO'),
											('0','Grignasco','28075','NO'),
											('0','Grigno','38055','TN'),
											('0','Grillara','45012','RO'),
											('0','Grilli','58020','GR'),
											('0','Grimacco','33040','UD'),
											('0','Grimaldi','87034','CS'),
											('0','Grimaldi di Ventimiglia','18039','IM'),
											('0','Grinzane Cavour','12060','CN'),
											('0','Grisciano','02011','RI'),
											('0','Grisi','90040','PA'),
											('0','Grisignano di Zocco','36040','VI'),
											('0','Grisolia','87020','CS'),
											('0','Grizzana Morandi','40030','BO'),
											('0','Grognardo','15010','AL'),
											('0','Gromo','24020','BG'),
											('0','Gromola','84050','SA'),
											('0','Grondola','54027','MS'),
											('0','Grondona','15060','AL'),
											('0','Grone','24060','BG'),
											('0','Grontardo','26044','CR'),
											('0','Gropello Cairoli','27027','PV'),
											('0','Groppallo','29020','PC'),
											('0','Gropparello','29025','PC'),
											('0','Groppello d\'Adda','20062','MI'),
											('0','Groppo','41020','MO'),
											('0','Groppoducale','29021','PC'),
											('0','Groppoli','54020','MS'),
											('0','Groppovisdomo','29020','PC'),
											('0','Groscavallo','10070','TO'),
											('0','Grosio','23033','SO'),
											('0','Grosotto','23034','SO'),
											('0','Grosseto','58100','GR'),
											('0','Grosso','10070','TO'),
											('0','Grotta','43040','PR'),
											('0','Grotta Giusti','51015','PT'),
											('0','Grottacalda','94019','EN'),
											('0','Grottaferrata','00046','RM'),
											('0','Grottaglie','74023','TA'),
											('0','Grottaminarda','83035','AV'),
											('0','Grottammare','63013','AP'),
											('0','Grottarossa','00189','RM'),
											('0','Grottazzolina','63024','AP'),
											('0','Grotte','92020','AG'),
											('0','Grotte di Castro','01025','VT'),
											('0','Grotte Santo Stefano','01026','VT'),
											('0','Grotteria','89043','RC'),
											('0','Grotti di Borgorose','02020','RI'),
											('0','Grotti di Cittaducale','02010','RI'),
											('0','Grottole','75010','MT'),
											('0','Grottolella','83010','AV'),
											('0','Gruaro','30020','VE'),
											('0','Grugliasco','10095','TO'),
											('0','Grumello Cremonese','26023','CR'),
											('0','Grumello del Monte','24064','BG'),
											('0','Grumello del Piano','','BG'),
											('0','Grumento Nova','85050','PZ'),
											('0','Grumes','38030','TN'),
											('0','Grumo Appula','70025','BA'),
											('0','Grumo Nevano','80028','NA'),
											('0','Grumolo Delle Abbadesse','36040','VI'),
											('0','Grumolo Pedemonte','36030','VI'),
											('0','Grunuovo di Santi Cosma e Damiano','04020','LT'),
											('0','Gsies','39030','BZ'),
											('0','Guadagnolo','00030','RM'),
											('0','Guagnano','73010','LE'),
											('0','Gualdo Cattaneo','06035','PG'),
											('0','Gualdo di Macerata','62020','MC'),
											('0','Gualdo di Massarosa','55060','LU'),
											('0','Gualdo di Narni','05030','TR'),
											('0','Gualdo Tadino','06023','PG'),
											('0','Gualtieri','42044','RE'),
											('0','Gualtieri Sicamin','98040','ME'),
											('0','Guamaggiore','09040','CA'),
											('0','Guamo','55060','LU'),
											('0','Guanzate','22070','CO'),
											('0','Guarcino','03016','FR'),
											('0','Guarda Ferrarese','44030','FE'),
											('0','Guarda Veneta','45030','RO'),
											('0','Guardabosone','13010','VC'),
											('0','Guardamiglio','26862','LO'),
											('0','Guardavalle','88065','CZ'),
											('0','Guardea','05025','TR'),
											('0','Guardia','95020','CT'),
											('0','Guardia Lombardi','83040','AV'),
											('0','Guardia Perticara','85010','PZ'),
											('0','Guardia Piemontese','87020','CS'),
											('0','Guardia Piemontese Marina','87020','CS'),
											('0','Guardia Piemontese Terme','87020','CS'),
											('0','Guardia Sanframondi','82034','BN'),
											('0','Guardia Vomano','64020','TE'),
											('0','Guardiabruna','66050','CH'),
											('0','Guardiagrele','66016','CH'),
											('0','Guardialfiera','86030','CB'),
											('0','Guardiaregia','86014','CB'),
											('0','Guardistallo','56040','PI'),
											('0','Guarene','12050','CN'),
											('0','Guarrato','91020','TP'),
											('0','Guasila','09040','CA'),
											('0','Guastalla','42016','RE'),
											('0','Guastameroli','66030','CH'),
											('0','Guasticce','57010','LI'),
											('0','Guasto','86090','IS'),
											('0','Guazzino','53048','SI'),
											('0','Guazzora','15050','AL'),
											('0','Gubbio','06024','PG'),
											('0','Gudo Visconti','20088','MI'),
											('0','Gudon','39043','BZ'),
											('0','Gufidaun','39043','BZ'),
											('0','Guglionesi','86034','CB'),
											('0','Guia','31040','TV'),
											('0','Guidaloca','91014','TP'),
											('0','Guidizzolo','46040','MN'),
											('0','Guidomandri','98030','ME'),
											('0','Guidonia','00012','RM'),
											('0','Guiglia','41052','MO'),
											('0','Guilmi','66050','CH'),
											('0','Guinadi','54024','MS'),
											('0','Guizza','35125','PD'),
											('0','Gummer','39050','BZ'),
											('0','Gurro','28825','VB'),
											('0','Gusciola','41045','MO'),
											('0','Guspini','09036','CA'),
											('0','Gussago','25064','BS'),
											('0','Gussola','26040','CR'),
											('0','Hafling','39010','BZ'),
											('0','Holen','39040','BZ'),
											('0','Hone','11020','AO'),
											('0','Iamiano','34070','GO'),
											('0','Iavr Vigo Rendena','38080','TN'),
											('0','Iddiano','41026','MO'),
											('0','Idro','25074','BS'),
											('0','Iesa','53015','SI'),
											('0','Ievoli','88040','CZ'),
											('0','Igea Marina','47813','RN'),
											('0','Iggio','43047','PR'),
											('0','Iglesias','09016','CA'),
											('0','Igliano','12060','CN'),
											('0','Igne','32010','BL'),
											('0','Il Castagno Val d\'Elsa','50050','FI'),
											('0','Ilbono','08040','NU'),
											('0','Ilci','06050','PG'),
											('0','Illasi','37031','VR'),
											('0','Illorai','07010','SS'),
											('0','Imbersago','23898','LC'),
											('0','Imer','38050','TN'),
											('0','Imola','40026','BO'),
											('0','Imperia','18100','IM'),
											('0','Impruneta','50023','FI'),
											('0','Inarzo','21020','VA'),
											('0','Incisa Scapaccino','14045','AT'),
											('0','Incisa Val d\'Arno','50064','FI'),
											('0','Incoronata','86096','IS'),
											('0','Incoronata di Vasto','66053','CH'),
											('0','Incudine','25040','BS'),
											('0','Indiprete','86090','IS'),
											('0','Induno Olona','21056','VA'),
											('0','Ingria','10080','TO'),
											('0','Ingurtosu','09030','CA'),
											('0','Innichen','39038','BZ'),
											('0','Intavolata','87020','CS'),
											('0','Intermesoli','64040','TE'),
											('0','Interporto Bentivoglio','40010','BO'),
											('0','Intimiano','22070','CO'),
											('0','Intra','','VB'),
											('0','Intragna','28816','VB'),
											('0','Introbio','23815','LC'),
											('0','Introd','11010','AO'),
											('0','Introdacqua','67030','AQ'),
											('0','Introzzo','23835','LC'),
											('0','Inverigo','22044','CO'),
											('0','Inverno e Monteleone','27010','PV'),
											('0','Inverso Pinasca','10060','TO'),
											('0','Inveruno','20010','MI'),
											('0','Invillino','33029','UD'),
											('0','Invorio','28045','NO'),
											('0','Inzago','20065','MI'),
											('0','Ioanella','64010','TE'),
											('0','Ioffredo','83012','AV'),
											('0','Ioggi','87010','CS'),
											('0','Iola di Montese','41055','MO'),
											('0','Iolo','59014','PO'),
											('0','Ionadi','89851','VV'),
											('0','Ipplis','33040','UD'),
											('0','Irgoli','08020','NU'),
											('0','Irma','25061','BS'),
											('0','Irsina','75022','MT'),
											('0','Is Murdegus','08048','NU'),
											('0','Isasca','12020','CN'),
											('0','Isca Marina','88060','CZ'),
											('0','Isca Sullo Jonio','88060','CZ'),
											('0','Ischia','63013','AP'),
											('0','Ischia','80077','NA'),
											('0','Ischia di Castro','01010','VT'),
											('0','Ischia Ponte','80077','NA'),
											('0','Ischia Porto','80077','NA'),
											('0','Ischia San Michele','80077','NA'),
											('0','Ischia Trentina','38050','TN'),
											('0','Ischitella','71010','FG'),
											('0','Iselle','28868','VB'),
											('0','Iseo','25049','BS'),
											('0','Isera','38060','TN'),
											('0','Isernia','86170','IS'),
											('0','Isili','08033','NU'),
											('0','Isnello','90010','PA'),
											('0','Isola','55050','LU'),
											('0','Isola','19126','SP'),
											('0','Isola','23020','SO'),
											('0','Isola Bella','28838','VB'),
											('0','Isola d\'Asti','14057','AT'),
											('0','Isola del Cantone','16017','GE'),
											('0','Isola del Gran Sasso','64045','TE'),
											('0','Isola del Liri e Superiore','03036','FR'),
											('0','Isola del Piano','61030','PU'),
											('0','Isola della Scala','37063','VR'),
											('0','Isola Delle Femmine','90040','PA'),
											('0','Isola di Bene Vagienna','12040','CN'),
											('0','Isola di Capo Rizzuto','88841','KR'),
											('0','Isola di Caprera','07020','SS'),
											('0','Isola di Fano','61034','PU'),
											('0','Isola di Fondra','24010','BG'),
											('0','Isola di Ortonovo','19034','SP'),
											('0','Isola di Palanzano','43020','PR'),
											('0','Isola Dovarese','26031','CR'),
											('0','Isola Farnese','00123','RM'),
											('0','Isola Fossara','06020','PG'),
											('0','Isola Maggiore','06060','PG'),
											('0','Isola Morosini','34075','GO'),
											('0','Isola Palmaria','19025','SP'),
											('0','Isola Rizza','37050','VR'),
											('0','Isola Sacra','00054','RM'),
											('0','Isola San Giulio','28016','NO'),
											('0','Isola Sant\'Antonio','15050','AL'),
											('0','Isola Vicentina','36033','VI'),
											('0','Isolabella','10046','TO'),
											('0','Isolabona','18035','IM'),
											('0','Isolato','23020','SO'),
											('0','Isole Tremiti','71040','FG'),
											('0','Isolella','13011','VC'),
											('0','Isoletta','03020','FR'),
											('0','Isolona','16040','GE'),
											('0','Isolotto','50142','FI'),
											('0','Isorella','25010','BS'),
											('0','Isoverde','16010','GE'),
											('0','Ispani','84050','SA'),
											('0','Ispica','97014','RG'),
											('0','Ispra','21027','VA'),
											('0','Ispra Centro Euratom','21027','VA'),
											('0','Issiglio','10080','TO'),
											('0','Issime','11020','AO'),
											('0','Isso','24040','BG'),
											('0','Issogne','11020','AO'),
											('0','Istia d\'Ombrone','58040','GR'),
											('0','Istrago','33097','PN'),
											('0','Istrana','31036','TV'),
											('0','Itala','98025','ME'),
											('0','Itieli','05035','TR'),
											('0','Itri','04020','LT'),
											('0','Ittireddu','07010','SS'),
											('0','Ittiri','07044','SS'),
											('0','Ivano Fracena','38059','TN'),
											('0','Ivica','45010','RO'),
											('0','Ivrea','10015','TO'),
											('0','Izano','26010','CR'),
											('0','Izzalini','06050','PG'),
											('0','Jacurso','88020','CZ'),
											('0','Jalmicco','33057','UD'),
											('0','Japigia','70126','BA'),
											('0','Jaufental','39040','BZ'),
											('0','Jelsi','86015','CB'),
											('0','Jenesien','39050','BZ'),
											('0','Jenne','00020','RM'),
											('0','Jerago Con Orago','21040','VA'),
											('0','Jerzu','08044','NU'),
											('0','Jesi','60035','AN'),
											('0','Jesolo','30016','VE'),
											('0','Joannis','33041','UD'),
											('0','Jolanda di Savoia','44037','FE'),
											('0','Joppolo','89863','VV'),
											('0','Joppolo Giancaxio','92010','AG'),
											('0','Jovencan','11020','AO'),
											('0','Jungi','97018','RG'),
											('0','Kaltenbrunn','39040','BZ'),
											('0','Kaltern A.D.Weinstrasse','39052','BZ'),
											('0','Kamma','91010','TP'),
											('0','Kardaun','39053','BZ'),
											('0','Karersee','39056','BZ'),
											('0','Karneid','39050','BZ'),
											('0','Kastelbell Tschars','39020','BZ'),
											('0','Kastelruth','39040','BZ'),
											('0','Katharinaberg','39020','BZ'),
											('0','Kiens','39030','BZ'),
											('0','Klausen','39043','BZ'),
											('0','Klobenstein','39054','BZ'),
											('0','Kolfuschg','39033','BZ'),
											('0','Kuens','39010','BZ'),
											('0','Kurfar','39033','BZ'),
											('0','Kurtatsch A.D.Weinstrasse','39040','BZ'),
											('0','Kurtinig A.D.Weinstrasse','39040','BZ'),
											('0','La Botte','01013','VT'),
											('0','La Briglia','59028','PO'),
											('0','La Caletta','08020','NU'),
											('0','La California','57020','LI'),
											('0','La Carnia','33010','UD'),
											('0','La Cassa','10040','TO'),
											('0','La Corte','07040','SS'),
											('0','La Costa di Laives','39050','BZ'),
											('0','La Fiora','04010','LT'),
											('0','La Foce','19134','SP'),
											('0','La Forma','03010','FR'),
											('0','La Giustiniana','00135','RM'),
											('0','La Landrigga','07040','SS'),
											('0','La Lima','51020','PT'),
											('0','La Loggia','10040','TO'),
											('0','La Maddalena','07024','SS'),
											('0','La Madonnina','95030','CT'),
											('0','La Magdeleine','11020','AO'),
											('0','La Manna','83030','AV'),
											('0','La Martella','75100','MT'),
											('0','La Morra','12064','CN'),
											('0','La Moschella','71040','FG'),
											('0','La Murgetta','70024','BA'),
											('0','La Pila','57030','LI'),
											('0','La Querce','59100','PO'),
											('0','La Quercia','01030','VT'),
											('0','La Rotta','56025','PI'),
											('0','La Runcina','08020','NU'),
											('0','La Rustica','00155','RM'),
											('0','La Salle','11015','AO'),
											('0','La Salute di Livenza','30020','VE'),
											('0','La Santona','41024','MO'),
											('0','La Saxe','11013','AO'),
											('0','La Scala','56028','PI'),
											('0','La Secca','32010','BL'),
											('0','La Serra','19030','SP'),
											('0','La Serra','56020','PI'),
											('0','La Spezia','19100','SP'),
											('0','La Storta','00123','RM'),
											('0','La Thuile','11016','AO'),
											('0','La Torre','50054','FI'),
											('0','La Traversa','08020','NU'),
											('0','La Valle','39030','BZ'),
											('0','La Valle Agordina','32020','BL'),
											('0','La Verna','52010','AR'),
											('0','La Villa','39030','BZ'),
											('0','Laas','39023','BZ'),
											('0','Laatsch','39020','BZ'),
											('0','Labaro','00188','RM'),
											('0','Labico','00030','RM'),
											('0','Labro','02010','RI'),
											('0','Lacchiarella','20084','MI'),
											('0','Laccio','16020','GE'),
											('0','Lacco Ameno','80076','NA'),
											('0','Lacedonia','83046','AV'),
											('0','Laceno','83043','AV'),
											('0','Laces','39021','BZ'),
											('0','Laconi','08034','NU'),
											('0','Ladispoli','00055','RM'),
											('0','Laerru','07030','SS'),
											('0','Laganadi','89050','RC'),
											('0','Lagaro','40030','BO'),
											('0','Laghetti di Egna','39040','BZ'),
											('0','Laghetto di Castel Gandolfo','00040','RM'),
											('0','Laghetto di Montecompatri','00040','RM'),
											('0','Laghi','36010','VI'),
											('0','Laglio','22010','CO'),
											('0','Lagnasco','12030','CN'),
											('0','Lago','31020','TV'),
											('0','Lago','41045','MO'),
											('0','Lago','87035','CS'),
											('0','Lago Averno','80078','NA'),
											('0','Lago Boracifera','58020','GR'),
											('0','Lago di Vico','01037','VT'),
											('0','Lago Patria','80014','NA'),
											('0','Lagonegro','85042','PZ'),
											('0','Lagopesole','85020','PZ'),
											('0','Lagosanto','44023','FE'),
											('0','Lagrimone','43020','PR'),
											('0','Lagundo','39022','BZ'),
											('0','Laiano','82019','BN'),
											('0','Laigueglia','17053','SV'),
											('0','Lainate','20020','MI'),
											('0','Laino','22020','CO'),
											('0','Laino Borgo','87014','CS'),
											('0','Laino Castello','87015','CS'),
											('0','Laion','39040','BZ'),
											('0','Laipacco','33100','UD'),
											('0','Laise','87020','CS'),
											('0','Laives','39055','BZ'),
											('0','Lajatico','56030','PI'),
											('0','Lajen','39040','BZ'),
											('0','Lallio','24040','BG'),
											('0','L\'Alzoni','08020','NU'),
											('0','Lama','74020','TA'),
											('0','Lama','06013','PG'),
											('0','Lama dei Peligni','66010','CH'),
											('0','Lama di Setta','40037','BO'),
											('0','Lama Mocogno','41023','MO'),
											('0','Lama Polesine','45010','RO'),
											('0','Lamadacqua','70010','BA'),
											('0','Lambrate','20134','MI'),
											('0','Lambrinia','27010','PV'),
											('0','Lambrugo','22045','CO'),
											('0','Lamezia Terme','88046','CZ'),
											('0','Lamia','84098','SA'),
											('0','Lammari','55013','LU'),
											('0','Lamole','50022','FI'),
											('0','Lamoli','61040','PU'),
											('0','Lamon','32033','BL'),
											('0','Lamosano','32010','BL'),
											('0','Lampazzone','89866','VV'),
											('0','Lampedusa','92010','AG'),
											('0','Lamporecchio','51035','PT'),
											('0','Lamporo','13046','VC'),
											('0','Lana A.D. Etsch','39011','BZ'),
											('0','Lana d\'Adige','39011','BZ'),
											('0','Lancenigo','31020','TV'),
											('0','Lanciano','66034','CH'),
											('0','Lancusi','84080','SA'),
											('0','Landiona','28064','NO'),
											('0','Landriano','27015','PV'),
											('0','Langhirano','43013','PR'),
											('0','Langosco','27030','PV'),
											('0','Lanusei','08045','NU'),
											('0','Lanuvio','00040','RM'),
											('0','Lanzada','23020','SO'),
											('0','Lanzara','84080','SA'),
											('0','Lanz','36050','VI'),
											('0','Lanzo di Martina Franca','74010','TA'),
											('0','Lanzo d\'Intelvi','22024','CO'),
											('0','Lanzo Torinese','10074','TO'),
											('0','Lapedona','63026','AP'),
											('0','Lapio','83030','AV'),
											('0','Lappano','87050','CS'),
											('0','Lappato','55010','LU'),
											('0','L\'Aquila','67100','AQ'),
											('0','Larciano','51036','PT'),
											('0','Lardaro','38087','TN'),
											('0','Larderello','56044','PI'),
											('0','Larderia','98129','ME'),
											('0','Lardirago','27016','PV'),
											('0','Lari','56035','PI'),
											('0','Lariano','00040','RM'),
											('0','Larino','86035','CB'),
											('0','Larizzate','13030','VC'),
											('0','Las Plassas','09020','CA'),
											('0','Lasa','39023','BZ'),
											('0','Lascari','90010','PA'),
											('0','Lascari Scalo','90010','PA'),
											('0','Lases','38040','TN'),
											('0','Lasino','38076','TN'),
											('0','Lasnigo','22030','CO'),
											('0','Laste di Rocca Pietore','32020','BL'),
											('0','Lastebasse','36040','VI'),
											('0','Lastra a Signa','50055','FI'),
											('0','Latera','01010','VT'),
											('0','Laterina','52020','AR'),
											('0','Laterina Stazione','52020','AR'),
											('0','Laterza','74014','TA'),
											('0','Latiano','72022','BR'),
											('0','Latignano','56021','PI'),
											('0','Latina','04100','LT'),
											('0','Latina Aeroporto','04013','LT'),
											('0','Latina di Baia','81010','CE'),
											('0','Latina Scalo','04013','LT'),
											('0','Latisana','33053','UD'),
											('0','Latronico','85043','PZ'),
											('0','Latsch','39021','BZ'),
											('0','Lattarico','87010','CS'),
											('0','Latte','18039','IM'),
											('0','Latzfons','39043','BZ'),
											('0','Lauco','33029','UD'),
											('0','Laudes','39020','BZ'),
											('0','Laureana Cilento','84050','SA'),
											('0','Laureana di Borrello','89023','RC'),
											('0','Lauregno','39040','BZ'),
											('0','Laurein','39040','BZ'),
											('0','Laurenzana','85014','PZ'),
											('0','Lauria Inferiore','85044','PZ'),
											('0','Lauria Superiore','85044','PZ'),
											('0','Lauriano','10020','TO'),
											('0','Laurignano','87040','CS'),
											('0','Laurino','84057','SA'),
											('0','Laurito','84050','SA'),
											('0','Lauro','83023','AV'),
											('0','Lauro di Sessa Aurunca','81030','CE'),
											('0','Lauropoli','87010','CS'),
											('0','Lausdomini','80030','NA'),
											('0','Lavagna','16033','GE'),
											('0','Lavagno','37030','VR'),
											('0','Lavagnola','17100','SV'),
											('0','Lavaiano','56030','PI'),
											('0','Lavariano','33050','UD'),
											('0','Lavarone','38046','TN'),
											('0','Lavarone Cappella','38040','TN'),
											('0','Lavello','85024','PZ'),
											('0','Lavena Ponte Tresa','21037','VA'),
											('0','Laveno Mombello','21014','VA'),
											('0','Lavenone','25074','BS'),
											('0','Laverda','36040','VI'),
											('0','Lavezzola','48021','RA'),
											('0','Laviano','84020','SA'),
											('0','Lavina','95025','CT'),
											('0','Lavinaio','95020','CT'),
											('0','Lavinio Lido di Enea','00040','RM'),
											('0','Lavino di Mezzo','40011','BO'),
											('0','Lavis','38015','TN'),
											('0','Lavone di Pezzaze','25060','BS'),
											('0','Lavorate','84080','SA'),
											('0','Lazfons','39043','BZ'),
											('0','Lazise','37017','VR'),
											('0','Lazzaretto','09126','CA'),
											('0','Lazzaro','89062','RC'),
											('0','Lazzate','20020','MI'),
											('0','Lazzeretto','50050','FI'),
											('0','Le Badie','56040','PI'),
											('0','Le Bagnese San Giusto','50018','FI'),
											('0','Le Castella','04010','LT'),
											('0','Le Croci','50041','FI'),
											('0','Le Ferriere','04010','LT'),
											('0','Le Forna','04020','LT'),
											('0','Le Grazie Varignano','19022','SP'),
											('0','Le Moline','12080','CN'),
											('0','Le Moline','29020','PC'),
											('0','Le Mosse','01020','VT'),
											('0','Le Prese','23030','SO'),
											('0','Le Regine','51020','PT'),
											('0','Le Ville','52034','AR'),
											('0','Leca','17031','SV'),
											('0','Lecce','73100','LE'),
											('0','Lecce Nei Marsi','67050','AQ'),
											('0','Lecchi','53010','SI'),
											('0','Leccio','50067','FI'),
											('0','Lecco','23900','LC'),
											('0','Leffe','24026','BG'),
											('0','Leggiuno','21038','VA'),
											('0','Legino','17100','SV'),
											('0','Legnago','37045','VR'),
											('0','Legnano','20025','MI'),
											('0','Legnaro','35020','PD'),
											('0','Legoli','56030','PI'),
											('0','Lei','08010','NU'),
											('0','Leifers','39055','BZ'),
											('0','Lein','10040','TO'),
											('0','Leivi','16040','GE'),
											('0','Lemie','10070','TO'),
											('0','Lemma','12020','CN'),
											('0','Lemna','22020','CO'),
											('0','Lendinara','45026','RO'),
											('0','Lengstein Am Ritten','39050','BZ'),
											('0','Leni','98050','ME'),
											('0','Lenna','24010','BG'),
											('0','Lenno','22016','CO'),
											('0','Leno','25024','BS'),
											('0','Lenola','04025','LT'),
											('0','Lenta','13035','VC'),
											('0','Lentate Sul Seveso','20030','MI'),
											('0','Lentella','66050','CH'),
											('0','Lentiai','32020','BL'),
											('0','Lentigione','42040','RE'),
											('0','Lentini','96016','SR'),
											('0','Lentiscosa','84050','SA'),
											('0','Leofara','64010','TE'),
											('0','Leofreni','02020','RI'),
											('0','Leognano','64040','TE'),
											('0','Leonacco','33019','UD'),
											('0','Leonessa','02016','RI'),
											('0','Leonessa di Melfi','85020','PZ'),
											('0','Leonforte','94013','EN'),
											('0','Leopardi','80040','NA'),
											('0','Leporano','74020','TA'),
											('0','Lequile','73010','LE'),
											('0','Lequio Berria','12050','CN'),
											('0','Lequio Tanaro','12060','CN'),
											('0','Lercara Friddi','90025','PA'),
											('0','Lerchi','06010','PG'),
											('0','Lerici','19032','SP'),
											('0','Lerino','36040','VI'),
											('0','Lerma','15070','AL'),
											('0','Lesa','28040','NO'),
											('0','Lesegno','12076','CN'),
											('0','Lesignana','41010','MO'),
											('0','Lesignano De\' Bagni','43037','PR'),
											('0','Lesignano Palmia','43030','PR'),
											('0','Lesina','71010','FG'),
											('0','Lesmo','20050','MI'),
											('0','Lessolo','10010','TO'),
											('0','Lessona','13853','BI'),
											('0','Lestans','33090','PN'),
											('0','Lestizza','33050','UD'),
											('0','Letino','81010','CE'),
											('0','Letojanni','98037','ME'),
											('0','Lettere','80050','NA'),
											('0','Lettomanoppello','65020','PE'),
											('0','Lettopalena','66010','CH'),
											('0','Leumann','10096','TO'),
											('0','Lev di Montecchio Precalcino','36030','VI'),
											('0','Levada','31047','TV'),
											('0','Levada','35017','PD'),
											('0','Levaldigi','12040','CN'),
											('0','Levane','52023','AR'),
											('0','Levanto','19015','SP'),
											('0','Levanzo','91010','TP'),
											('0','Levate','24040','BG'),
											('0','Leverano','73045','LE'),
											('0','Leverogne','11011','AO'),
											('0','Levice','12070','CN'),
											('0','Levico Terme','38056','TN'),
											('0','Levizzano','42010','RE'),
											('0','Levizzano Rangone','41014','MO'),
											('0','Levo','28838','VB'),
											('0','Levone','10070','TO'),
											('0','Lezzeno','22025','CO'),
											('0','Li Mori','08020','NU'),
											('0','Li Punti','07040','SS'),
											('0','Li Teggi','08020','NU'),
											('0','Libbiano','56045','PI'),
											('0','Liberi','81040','CE'),
											('0','Libertinia','95040','CT'),
											('0','Librizzi','98064','ME'),
											('0','Licata','92027','AG'),
											('0','Licciana Nardi','54016','MS'),
											('0','Licenza','00026','RM'),
											('0','Lichtenberg','39020','BZ'),
											('0','Licignano di Napoli','80015','NA'),
											('0','Licodia Eubea','95040','CT'),
											('0','Licola','80078','NA'),
											('0','Licusati','84050','SA'),
											('0','Lido Conchiglie','73017','LE'),
											('0','Lido degli Estensi','44024','FE'),
											('0','Lido di Adriano','48020','RA'),
											('0','Lido di Camaiore','55043','LU'),
											('0','Lido di Classe','48020','RA'),
											('0','Lido di Fermo','63010','AP'),
											('0','Lido di Jesolo','30017','VE'),
											('0','Lido di Ostia Levante','00122','RM'),
											('0','Lido di Ostia Ponente','00121','RM'),
											('0','Lido di Savio','48020','RA'),
											('0','Lido di Squillace','88069','CZ'),
											('0','Lido di Tarquinia','01010','VT'),
											('0','Lido di Venezia','30126','VE'),
											('0','Lido Silvana','74026','TA'),
											('0','Lido Spina','44024','FE'),
											('0','Lierna','23827','LC'),
											('0','Liettoli','30010','VE'),
											('0','Lignana','13100','VC'),
											('0','Lignano Pineta','33054','UD'),
											('0','Lignano Sabbiadoro','33054','UD'),
											('0','Lignod','11020','AO'),
											('0','Ligonchio','42039','RE'),
											('0','Ligorzano','41028','MO'),
											('0','Ligosullo','33020','UD'),
											('0','Ligurno','21050','VA'),
											('0','Lillianes','11020','AO'),
											('0','Limana','32020','BL'),
											('0','Limatola','82030','BN'),
											('0','Limbadi','89844','VV'),
											('0','Limbiate','20051','MI'),
											('0','Limena','35010','PD'),
											('0','Limestre Pistoiese','51022','PT'),
											('0','Limidi','41010','MO'),
											('0','Limido Comasco','22070','CO'),
											('0','Limina','98030','ME'),
											('0','Limite Sull\'Arno','50050','FI'),
											('0','Limiti di Greccio','02045','RI'),
											('0','Limito','20090','MI'),
											('0','Limone','19136','SP'),
											('0','Limone Piemonte','12015','CN'),
											('0','Limone Sul Garda','25010','BS'),
											('0','Limonta','23865','LC'),
											('0','Limosano','86022','CB'),
											('0','Limpidi','89832','VV'),
											('0','Limpostu','08020','NU'),
											('0','Linaro','47020','FC'),
											('0','Linarolo','27010','PV'),
											('0','Linate Aeroporto','20090','MI'),
											('0','Linate Paese','20068','MI'),
											('0','Linera','95020','CT'),
											('0','Lingua','98050','ME'),
											('0','Linguaglossa','95015','CT'),
											('0','Lingueglietta','18017','IM'),
											('0','Linosa','92010','AG'),
											('0','Linpiddu','08020','NU'),
											('0','Lioni','83047','AV'),
											('0','Lipari','98055','ME'),
											('0','Lipomo','22030','CO'),
											('0','Lippiano','06010','PG'),
											('0','Lirio','27040','PV'),
											('0','Lirone','23020','SO'),
											('0','Liscate','20060','MI'),
											('0','Liscia','66050','CH'),
											('0','Lisciano','63100','AP'),
											('0','Lisciano Niccone','06060','PG'),
											('0','Lisiera','36050','VI'),
											('0','Lisignago','38030','TN'),
											('0','Lisio','12070','CN'),
											('0','Lissone','20035','MI'),
											('0','Litta Parodi','15040','AL'),
											('0','Liuzzo Orto','98159','ME'),
											('0','Livemmo','25070','BS'),
											('0','Livergnano','40060','BO'),
											('0','Liveri','80030','NA'),
											('0','Livigno','23030','SO'),
											('0','Livinallongo del Col di Lana','32020','BL'),
											('0','Livo','38020','TN'),
											('0','Livo','22010','CO'),
											('0','Livorno','57100','LI'),
											('0','Livorno Ferraris','13046','VC'),
											('0','Livraga','26814','LO'),
											('0','Lixius','08030','NU'),
											('0','Lizzanella','38068','TN'),
											('0','Lizzanello','73023','LE'),
											('0','Lizzano','47023','FC'),
											('0','Lizzano','74020','TA'),
											('0','Lizzano in Belvedere','40042','BO'),
											('0','Lizzano Pistoiese','51020','PT'),
											('0','Lizzola','24020','BG'),
											('0','Loano','17025','SV'),
											('0','Loazzolo','14051','AT'),
											('0','Lobbi','15040','AL'),
											('0','Locadi','98020','ME'),
											('0','Locana','10080','TO'),
											('0','Locara','37040','VR'),
											('0','Locate Triulzi','20085','MI'),
											('0','Locate Varesino','22070','CO'),
											('0','Locatello','24030','BG'),
											('0','Locati','90020','PA'),
											('0','Loceri','08040','NU'),
											('0','Loconia','70050','BA'),
											('0','Locorotondo','70010','BA'),
											('0','Locri','89044','RC'),
											('0','Loculi','08020','NU'),
											('0','Lod','08020','NU'),
											('0','Lodi','26900','LO'),
											('0','Lodi Vecchio','26855','LO'),
											('0','Lodine','08020','NU'),
											('0','Lodrino','25060','BS'),
											('0','Lodrone','38080','TN'),
											('0','Lograto','25030','BS'),
											('0','Loiano','40050','BO'),
											('0','Loiri','07020','SS'),
											('0','Lollove','08100','NU'),
											('0','Lomagna','23871','LC'),
											('0','Lomaso','38070','TN'),
											('0','Lomazzo','22074','CO'),
											('0','Lombardore','10040','TO'),
											('0','Lombriasco','10040','TO'),
											('0','Lomello','27034','PV'),
											('0','Lomnago','21020','VA'),
											('0','Lona','38040','TN'),
											('0','Lonate Ceppino','21050','VA'),
											('0','Lonate Pozzolo','21015','VA'),
											('0','Lonato','25017','BS'),
											('0','Loncon','30020','VE'),
											('0','Londa','50060','FI'),
											('0','Lone','84011','SA'),
											('0','Longa','36060','VI'),
											('0','Longano','86090','IS'),
											('0','Longara','36100','VI'),
											('0','Longare','36023','VI'),
											('0','Longarone','32013','BL'),
											('0','Longastrino','44014','FE'),
											('0','Longega','39030','BZ'),
											('0','Longhena','25030','BS'),
											('0','Longi','98070','ME'),
											('0','Longiano','47020','FC'),
											('0','Longiar','39030','BZ'),
											('0','Longobardi','87030','CS'),
											('0','Longobardi','89811','VV'),
											('0','Longobardi Marina','87030','CS'),
											('0','Longobucco','87066','CS'),
											('0','Longone Al Segrino','22030','CO'),
											('0','Longone Sabino','02020','RI'),
											('0','Longuelo','24129','BG'),
											('0','Lonigo','36045','VI'),
											('0','Lonzano','34070','GO'),
											('0','Loppeglia','55060','LU'),
											('0','Lora','22100','CO'),
											('0','Loranz','10010','TO'),
											('0','Loreggia','35010','PD'),
											('0','Loreglia','28893','VB'),
											('0','Lorenzago di Cadore','32040','BL'),
											('0','Lorenzana','56043','PI'),
											('0','Loreo','45017','RO'),
											('0','Loreto','60025','AN'),
											('0','Loreto','24128','BG'),
											('0','Loreto Aprutino','65014','PE'),
											('0','Loreto Stazione','60025','AN'),
											('0','Loria','31037','TV'),
											('0','Lorica','87050','CS'),
											('0','Loro Ciuffenna','52024','AR'),
											('0','Loro Piceno','62020','MC'),
											('0','Lorsica','16045','GE'),
											('0','Loseto','70020','BA'),
											('0','Losine','25050','BS'),
											('0','Lotta','41021','MO'),
											('0','Lottulo','12020','CN'),
											('0','Lotturai','08020','NU'),
											('0','Lotzorai','08040','NU'),
											('0','Lovadina','31027','TV'),
											('0','Lovara','36070','VI'),
											('0','Lovere','24065','BG'),
											('0','Lovero Valtellino','23030','SO'),
											('0','Lovoleto','40057','BO'),
											('0','Lozio','25053','BS'),
											('0','Lozza','21040','VA'),
											('0','Lozzo Atestino','35034','PD'),
											('0','Lozzo di Cadore','32040','BL'),
											('0','Lozzolo','13045','VC'),
											('0','Lu','15040','AL'),
											('0','Lu Bagnu','07030','SS'),
											('0','Lu Cuponeddi','08020','NU'),
											('0','Lu Fraili','08020','NU'),
											('0','Lu Lioni','08020','NU'),
											('0','Lu Ricciu','08020','NU'),
											('0','Lu Sitagliacciu','08020','NU'),
											('0','Lu Tintimbaru','08020','NU'),
											('0','Lubriano','01020','VT'),
											('0','Lubrichi','89010','RC'),
											('0','Lucardo','50025','FI'),
											('0','Lucarelli','53017','SI'),
											('0','Lucca','55100','LU'),
											('0','Lucca Sicula','92010','AG'),
											('0','Lucchio','55020','LU'),
											('0','Lucera','71036','FG'),
											('0','Lucernate','20017','MI'),
											('0','Luciana','56043','PI'),
											('0','Lucignano','52046','AR'),
											('0','Lucignano d\'Arbia','53010','SI'),
											('0','Lucinasco','18027','IM'),
											('0','Lucinico','34070','GO'),
											('0','Lucino','22070','CO'),
											('0','Lucito','86030','CB'),
											('0','Luco dei Marsi','67056','AQ'),
											('0','Luco di Mugello','50030','FI'),
											('0','Lucolena','50020','FI'),
											('0','Lucoli','67045','AQ'),
											('0','Lucrezia','61030','PU'),
											('0','Lucrino','80078','NA'),
											('0','Lucugnano','73030','LE'),
											('0','Luddui','08020','NU'),
											('0','Ludriano','25030','BS'),
											('0','Lugagnano','37060','VR'),
											('0','Lugagnano Val d\'Arda','29018','PC'),
											('0','Lughezzano','37030','VR'),
											('0','Lughignano','31032','TV'),
											('0','Lugnacco','10080','TO'),
											('0','Lugnano Citt di Castello','06010','PG'),
											('0','Lugnano in Teverina','05020','TR'),
											('0','Lugo','48022','RA'),
											('0','Lugo di Grezzana','37020','VR'),
											('0','Lugo di Vicenza','36030','VI'),
											('0','Lugugnana','30020','VE'),
											('0','Luicciana','59025','PO'),
											('0','Luino','21016','VA'),
											('0','Luisago','22070','CO'),
											('0','Lula','08020','NU'),
											('0','Lumarzo','16024','GE'),
											('0','Lumellogno','28060','NO'),
											('0','Lumezzane','25065','BS'),
											('0','Lumezzane Pieve','25066','BS'),
											('0','Lumezzane Sant\'Apollonio','25067','BS'),
											('0','Lunamatrona','09022','CA'),
											('0','Lunano','61026','PU'),
											('0','Lunata','55010','LU'),
											('0','Lundo','38070','TN'),
											('0','Lungavilla','27053','PV'),
											('0','Lunghezza','00010','RM'),
											('0','Lungro','87010','CS'),
											('0','Luni','19034','SP'),
											('0','Luogosano','83040','AV'),
											('0','Luogosanto','07020','SS'),
											('0','Lupara','86030','CB'),
											('0','Lupazzano','43020','PR'),
											('0','Lurago d\'Erba','22040','CO'),
											('0','Lurago Marinone','22070','CO'),
											('0','Lurano','24050','BG'),
											('0','Luras','07025','SS'),
											('0','Lurate Caccivio','22075','CO'),
											('0','Lurisia','12088','CN'),
											('0','Lusciano','81030','CE'),
											('0','Lusen','39040','BZ'),
											('0','Luserna','10060','TO'),
											('0','Luserna','38040','TN'),
											('0','Luserna San Giovanni','10062','TO'),
											('0','Lusernetta','10060','TO'),
											('0','Lusevera','33010','UD'),
											('0','Lusia','45020','RO'),
											('0','Lusiana','36046','VI'),
											('0','Lusigli','10080','TO'),
											('0','Luson','39040','BZ'),
											('0','Lussello','15020','AL'),
											('0','Lustignano','56040','PI'),
											('0','Lustra','84050','SA'),
											('0','Lusurasco','29010','PC'),
											('0','Lutago','39030','BZ'),
											('0','Lutirano','50034','FI'),
											('0','Luttach','39030','BZ'),
											('0','Luttuni','08020','NU'),
											('0','Lutturai','08020','NU'),
											('0','Luvinate','21020','VA'),
											('0','Luzzana','24069','BG'),
											('0','Luzzano','82010','BN'),
											('0','Luzzara','42045','RE'),
											('0','Luzzi','87040','CS'),
											('0','Macari','91010','TP'),
											('0','Maccacari','37060','VR'),
											('0','Maccagno','21010','VA'),
											('0','Maccarese','00057','RM'),
											('0','Maccaretolo','40018','BO'),
											('0','Maccastorna','26843','LO'),
											('0','Macchia','71030','FG'),
											('0','Macchia','84090','SA'),
											('0','Macchia Albanese','87060','CS'),
											('0','Macchia di Giarre','95010','CT'),
											('0','Macchia d\'Isernia','86070','IS'),
											('0','Macchia Valfortore','86040','CB'),
											('0','Macchia Vomano','64040','TE'),
											('0','Macchiagodena','86096','IS'),
											('0','Macchiareddu','09032','CA'),
											('0','Macchie','05022','TR'),
											('0','Macchie','06060','PG'),
											('0','Macciadosa','07040','SS'),
											('0','Macellai','12060','CN'),
											('0','Macello','10060','TO'),
											('0','Macerata','62100','MC'),
											('0','Macerata Campania','81047','CE'),
											('0','Macerata Feltria','61023','PU'),
											('0','Macerone','47024','FC'),
											('0','Macherio','20050','MI'),
											('0','Maciano','61016','PU'),
											('0','Maclodio','25030','BS'),
											('0','Macognano','41045','MO'),
											('0','Macomer','08015','NU'),
											('0','Macra','12020','CN'),
											('0','Macugnaga','28876','VB'),
											('0','Maddalene','12040','CN'),
											('0','Maddaloni','81024','CE'),
											('0','Maderno','25088','BS'),
											('0','Madesimo','23024','SO'),
											('0','Madignano','26020','CR'),
											('0','Madone','24040','BG'),
											('0','Madonna Boschi','44028','FE'),
											('0','Madonna degli Angeli','','RA'),
											('0','Madonna dei Fornelli','40048','BO'),
											('0','Madonna del Carmine','66030','CH'),
											('0','Madonna del Monte','62100','MC'),
											('0','Madonna del Piano','03020','FR'),
											('0','Madonna del Pilone','12030','CN'),
											('0','Madonna del Sasso','28894','VB'),
											('0','Madonna della Neve','03100','FR'),
											('0','Madonna della Pace','00020','RM'),
											('0','Madonna della Scala','10023','TO'),
											('0','Madonna della Stella','06030','PG'),
											('0','Madonna Dell\'Albero','48100','RA'),
											('0','Madonna Dell\'Arco','80043','NA'),
											('0','Madonna Delle Grazie','12010','CN'),
											('0','Madonna Delle Lacrime','95030','CT'),
											('0','Madonna Dell\'Olmo','12020','CN'),
											('0','Madonna di Buia','33030','UD'),
											('0','Madonna di Campiglio','38084','TN'),
											('0','Madonna di Pietravolta','41044','MO'),
											('0','Madonna di Pugliano','61014','PU'),
											('0','Madonna di Tirano','23030','SO'),
											('0','Madonnuccia','52030','AR'),
											('0','Madrano','38050','TN'),
											('0','Madruzzo','38076','TN'),
											('0','Maenza','04010','LT'),
											('0','Maerne','30030','VE'),
											('0','Mafalda','86030','CB'),
											('0','Magasa','25080','BS'),
											('0','Magazzeno','41056','MO'),
											('0','Magazzini','57037','LI'),
											('0','Magenta','20013','MI'),
											('0','Maggiano','55050','LU'),
											('0','Maggio','23814','LC'),
											('0','Maggiora','28014','NO'),
											('0','Magherno','27010','PV'),
											('0','Magione','06063','PG'),
											('0','Magisano','88050','CZ'),
											('0','Magli','87050','CS'),
											('0','Magliana Trullo','00148','RM'),
											('0','Magliano','55030','LU'),
											('0','Magliano','73040','LE'),
											('0','Magliano Alfieri','12050','CN'),
											('0','Magliano Alpi Soprano','12060','CN'),
											('0','Magliano Alpi Sottano','12060','CN'),
											('0','Magliano De\' Marsi','67062','AQ'),
											('0','Magliano di Tenna','63025','AP'),
											('0','Magliano in Toscana','58051','GR'),
											('0','Magliano Nuovo','84050','SA'),
											('0','Magliano Para','47014','FC'),
											('0','Magliano Romano','00060','RM'),
											('0','Magliano Sabina','02046','RI'),
											('0','Magliano Vetere','84050','SA'),
											('0','Maglie','73024','LE'),
											('0','Maglio di Sopra','36078','VI'),
											('0','Magliolo','17020','SV'),
											('0','Maglione','10030','TO'),
											('0','Magnacavallo','46020','MN'),
											('0','Magnago','20020','MI'),
											('0','Magnano','13887','BI'),
											('0','Magnano','85043','PZ'),
											('0','Magnano in Riviera','33010','UD'),
											('0','Magnasco','16048','GE'),
											('0','Magno','25063','BS'),
											('0','Magognino','28837','VB'),
											('0','Magomadas','08010','NU'),
											('0','Magr di Schio','36015','VI'),
											('0','Magr sulla Strada del Vino','39040','BZ'),
											('0','Magreglio','22030','CO'),
											('0','Magreta','41010','MO'),
											('0','Magugnano','01026','VT'),
											('0','Maiano','06049','PG'),
											('0','Maida','88025','CZ'),
											('0','Maier','87020','CS'),
											('0','Maierato','89843','VV'),
											('0','Maiero','44010','FE'),
											('0','Maiolati Spontini','60030','AN'),
											('0','Maiolo','61010','PU'),
											('0','Maione','87040','CS'),
											('0','Maiorano di Monte','81040','CE'),
											('0','Maiorca','08020','NU'),
											('0','Maiori','84010','SA'),
											('0','Mairago','26825','LO'),
											('0','Mairano','25030','BS'),
											('0','Maissana','19010','SP'),
											('0','Majano','33030','UD'),
											('0','Malafrasca','53030','SI'),
											('0','Malagnino','26030','CR'),
											('0','Malagrotta','00057','RM'),
											('0','Malalbergo','40051','BO'),
											('0','Malamocco','30126','VE'),
											('0','Malamor','08020','NU'),
											('0','Malanghero','10070','TO'),
											('0','Malavicina','46040','MN'),
											('0','Malborghetto','33010','UD'),
											('0','Malcantone','46028','MN'),
											('0','Malcesine','37018','VR'),
											('0','Malcontenta','30030','VE'),
											('0','Mal','38027','TN'),
											('0','Malegno','25053','BS'),
											('0','Maleo','26847','LO'),
											('0','Malesco','28854','VB'),
											('0','Maletto','95035','CT'),
											('0','Malfa','98050','ME'),
											('0','Malgesso','21020','VA'),
											('0','Malgolo','38010','TN'),
											('0','Malgrate','23864','LC'),
											('0','Maliseti','59100','PO'),
											('0','Malito','87030','CS'),
											('0','Mallare','17045','SV'),
											('0','Malles','39024','BZ'),
											('0','Malmantile','50050','FI'),
											('0','Malnate','21046','VA'),
											('0','Malnisio','33086','PN'),
											('0','Malo','36034','VI'),
											('0','Mal','98070','ME'),
											('0','Malonno','25040','BS'),
											('0','Malosco','38013','TN'),
											('0','Malpaga','24050','BG'),
											('0','Malpasso','00128','RM'),
											('0','Malpensa Aeroporto','21010','VA'),
											('0','Malpensata','24126','BG'),
											('0','Mals','39024','BZ'),
											('0','Maltignano','63040','AP'),
											('0','Maltignano di Cascia','06040','PG'),
											('0','Malva','52020','AR'),
											('0','Malvagna','98030','ME'),
											('0','Malvicino','15015','AL'),
											('0','Malvito','87010','CS'),
											('0','Mambrotta','37036','VR'),
											('0','Mamiano','43030','PR'),
											('0','Mammiano','51020','PT'),
											('0','Mammola','89045','RC'),
											('0','Mamoiada','08024','NU'),
											('0','Mamone','08020','NU'),
											('0','Manarola','19010','SP'),
											('0','Manasuddas','08100','NU'),
											('0','Mancasale','42010','RE'),
											('0','Manciano','52040','AR'),
											('0','Manciano','58014','GR'),
											('0','Mandanici','98020','ME'),
											('0','Mandaradoni','89844','VV'),
											('0','Mandas','09040','CA'),
											('0','Mandatoriccio','87060','CS'),
											('0','Mandela','00020','RM'),
											('0','Mandello del Lario','23826','LC'),
											('0','Mandello Vitta','28060','NO'),
											('0','Mandia di Ascea','84050','SA'),
											('0','Mandolossa di Brescia','25132','BS'),
											('0','Mandras','08020','NU'),
											('0','Mandria','35142','PD'),
											('0','Mandriola','09070','OR'),
											('0','Mandrogne','15040','AL'),
											('0','Manduria','74024','TA'),
											('0','Manera','22074','CO'),
											('0','Manerba del Garda','25080','BS'),
											('0','Manerbio','25025','BS'),
											('0','Manesseno','16010','GE'),
											('0','Manfredonia','71043','FG'),
											('0','Mangano','95020','CT'),
											('0','Mango','12056','CN'),
											('0','Mangone','87050','CS'),
											('0','Maniace di Bronte','95030','CT'),
											('0','Maniago','33085','PN'),
											('0','Manocalzati','83030','AV'),
											('0','Manoppello','65024','PE'),
											('0','Manoppello Stazione','65025','PE'),
											('0','Mansu','31040','TV'),
											('0','Manta','12030','CN'),
											('0','Mantello','23016','SO'),
											('0','Mantignana','06075','PG'),
											('0','Mantignano','50142','FI'),
											('0','Mantova','46100','MN'),
											('0','Manzano','38060','TN'),
											('0','Manzano','33044','UD'),
											('0','Manzi','84082','SA'),
											('0','Manziana','00066','RM'),
											('0','Manzolino','41013','MO'),
											('0','Mapello','24030','BG'),
											('0','Mappano','10070','TO'),
											('0','Mara','07010','SS'),
											('0','Maracalagonis','09040','CA'),
											('0','Marana di Montereale','67010','AQ'),
											('0','Marane','67039','AQ'),
											('0','Maranello','41053','MO'),
											('0','Marano','43020','PR'),
											('0','Marano dei Marsi','67060','AQ'),
											('0','Marano di Napoli','80016','NA'),
											('0','Marano di Valpolicella','37020','VR'),
											('0','Marano Equo','00020','RM'),
											('0','Marano Lagunare','33050','UD'),
											('0','Marano Marchesato','87040','CS'),
											('0','Marano Principato','87040','CS'),
											('0','Marano Sul Panaro','41054','MO'),
											('0','Marano Ticino','28040','NO'),
											('0','Marano Veneziano','30030','VE'),
											('0','Marano Vicentino','36035','VI'),
											('0','Maranola','04020','LT'),
											('0','Maranzana','14040','AT'),
											('0','Maratea','85046','PZ'),
											('0','Maratea Porto','85046','PZ'),
											('0','Marausa','91020','TP'),
											('0','Marausa Loco Grande','91020','TP'),
											('0','Marcallo Con Casone','20010','MI'),
											('0','Marcaria','46010','MN'),
											('0','Marcedusa','88050','CZ'),
											('0','Marcellano','06030','PG'),
											('0','Marcelli','60026','AN'),
											('0','Marcellina','00010','RM'),
											('0','Marcellina','87020','CS'),
											('0','Marcellinara','88044','CZ'),
											('0','Marcellise','37036','VR'),
											('0','Marcena','38020','TN'),
											('0','Marcetelli','02020','RI'),
											('0','Marcheno','25060','BS'),
											('0','Marchesa','80040','NA'),
											('0','Marchesino','37060','VR'),
											('0','Marchirolo','21030','VA'),
											('0','Marcialla','50020','FI'),
											('0','Marciana','57030','LI'),
											('0','Marciana','56021','PI'),
											('0','Marciana Marina','57033','LI'),
											('0','Marcianise','81025','CE'),
											('0','Marciano della Chiana','52047','AR'),
											('0','Marcianofreddo','81012','CE'),
											('0','Marciaso','54030','MS'),
											('0','Marcigliana','00138','RM'),
											('0','Marcignago','27020','PV'),
											('0','Marcignana','50050','FI'),
											('0','Marco','38060','TN'),
											('0','Marcon','30020','VE'),
											('0','Marconia','75020','MT'),
											('0','Marcorengo','10020','TO'),
											('0','Marcottini','34070','GO'),
											('0','Mardimago','45030','RO'),
											('0','Marebbe','39030','BZ'),
											('0','Mareit','39040','BZ'),
											('0','Marene','12030','CN'),
											('0','Marengo','46045','MN'),
											('0','Mareno di Piave','31010','TV'),
											('0','Marentino','10020','TO'),
											('0','Maresca','51026','PT'),
											('0','Maresso','23873','LC'),
											('0','Mareta','39040','BZ'),
											('0','Mareto','29023','PC'),
											('0','Marettimo','91010','TP'),
											('0','Maretto','14018','AT'),
											('0','Margarita','12040','CN'),
											('0','Marghera','30175','VE'),
											('0','Margherita di Savoia','71044','FG'),
											('0','Margine Coperta','51010','PT'),
											('0','Marginone','55010','LU'),
											('0','Margno','23832','LC'),
											('0','Margone','38070','TN'),
											('0','Margreid A.D.Weinstrasse','39040','BZ'),
											('0','Mariana Mantovana','46010','MN'),
											('0','Marianella','80145','NA'),
											('0','Mariano','43047','PR'),
											('0','Mariano Comense','22066','CO'),
											('0','Mariano del Friuli','34070','GO'),
											('0','Marianopoli','93010','CL'),
											('0','Mariglianella','80030','NA'),
											('0','Marigliano','80034','NA'),
											('0','Marina d\'Ardore','89037','RC'),
											('0','Marina di Ascea','84058','SA'),
											('0','Marina di Belvedere Marittimo','87020','CS'),
											('0','Marina di Camerota','84059','SA'),
											('0','Marina di Campo','57034','LI'),
											('0','Marina di Caronia','98070','ME'),
											('0','Marina di Carrara','54036','MS'),
											('0','Marina di Castagneto','57024','LI'),
											('0','Marina di Castellaneta','74010','TA'),
											('0','Marina di Caulonia','89040','RC'),
											('0','Marina di Davoli','88060','CZ'),
											('0','Marina di Fiumefreddo Bruzio','87030','CS'),
											('0','Marina di Fuscaldo','87020','CS'),
											('0','Marina di Ginosa','74025','TA'),
											('0','Marina di Gioia Tauro','89010','RC'),
											('0','Marina di Gioiosa Jonica','89046','RC'),
											('0','Marina di Grosseto','58046','GR'),
											('0','Marina di Guardavalle','88065','CZ'),
											('0','Marina di Leuca','73030','LE'),
											('0','Marina di Massa','54037','MS'),
											('0','Marina di Melilli','96010','SR'),
											('0','Marina di Minturno','04020','LT'),
											('0','Marina di Modica','97010','RG'),
											('0','Marina di Montemarciano','60016','AN'),
											('0','Marina di Nicotera','89844','VV'),
											('0','Marina di Nocera Terinese','88047','CZ'),
											('0','Marina di Palizzi','89038','RC'),
											('0','Marina di Patti','98060','ME'),
											('0','Marina di Pietrasanta','55044','LU'),
											('0','Marina di Pisa','56013','PI'),
											('0','Marina di Pisciotta','84050','SA'),
											('0','Marina di Ragusa','97010','RG'),
											('0','Marina di Ravenna','48023','RA'),
											('0','Marina di San Lorenzo','89060','RC'),
											('0','Marina di San Vito','66035','CH'),
											('0','Marina di Sant\'Andrea Jonio','88060','CZ'),
											('0','Marina di Savelletri','72010','BR'),
											('0','Marina di Strongoli','88815','KR'),
											('0','Marina di Tortora','87020','CS'),
											('0','Marina di Vietri','84010','SA'),
											('0','Marina Grande di Capri','80070','NA'),
											('0','Marina Julia','34074','GO'),
											('0','Marina Palmense','63017','AP'),
											('0','Marina Romea','48010','RA'),
											('0','Marinasco','19134','SP'),
											('0','Marinella','19030','SP'),
											('0','Marinella','89011','RC'),
											('0','Marinella di Selinunte','91022','TP'),
											('0','Marineo','90035','PA'),
											('0','Marini','84013','SA'),
											('0','Marino','00047','RM'),
											('0','Marino del Tronto','63100','AP'),
											('0','Mariotto','70034','BA'),
											('0','Marittima','73030','LE'),
											('0','Marlengo','39020','BZ'),
											('0','Marlia','55014','LU'),
											('0','Marliana','51010','PT'),
											('0','Marling','39020','BZ'),
											('0','Marmentino','25060','BS'),
											('0','Marmirolo','42029','RE'),
											('0','Marmirolo','46045','MN'),
											('0','Marmora','12020','CN'),
											('0','Marmore','05030','TR'),
											('0','Marmorito','14020','AT'),
											('0','Marmorta','40062','BO'),
											('0','Marnate','21050','VA'),
											('0','Marocco','31021','TV'),
											('0','Marola','19132','SP'),
											('0','Marola','42030','RE'),
											('0','Maron','33070','PN'),
											('0','Marone','25054','BS'),
											('0','Maropati','89020','RC'),
											('0','Marostica','36063','VI'),
											('0','Marotta','61035','PU'),
											('0','Marozzo','44020','FE'),
											('0','Marradi','50034','FI'),
											('0','Marrara','44040','FE'),
											('0','Marroneto','58037','GR'),
											('0','Marrubiu','09094','OR'),
											('0','Marruci','67010','AQ'),
											('0','Marsaglia','12060','CN'),
											('0','Marsaglia','29020','PC'),
											('0','Marsala','91025','TP'),
											('0','Marsango','35010','PD'),
											('0','Marsciano','06055','PG'),
											('0','Marsico Nuovo','85052','PZ'),
											('0','Marsicovetere','85050','PZ'),
											('0','Marsiliana','58010','GR'),
											('0','Marsure','33080','PN'),
											('0','Marta','01010','VT'),
											('0','Martano','73025','LE'),
											('0','Martell','39020','BZ'),
											('0','Martellago','30030','VE'),
											('0','Martello','39020','BZ'),
											('0','Marter','38050','TN'),
											('0','Marti','56020','PI'),
											('0','Martignacco','33035','UD'),
											('0','Martignana di Po','26040','CR'),
											('0','Martignano','73020','LE'),
											('0','Martignano','38040','TN'),
											('0','Martina Franca','74015','TA'),
											('0','Martinengo','24057','BG'),
											('0','Martiniana Po','12030','CN'),
											('0','Martinsicuro','64014','TE'),
											('0','Martirano','88040','CZ'),
											('0','Martirano Lombardo','88040','CZ'),
											('0','Martis','07030','SS'),
											('0','Martone','89040','RC'),
											('0','Martorano','47020','FC'),
											('0','Marudo','26866','LO'),
											('0','Maruggio','74020','TA'),
											('0','Marzabotto','40043','BO'),
											('0','Marzaglia','41010','MO'),
											('0','Marzamemi','96010','SR'),
											('0','Marzanello','81058','CE'),
											('0','Marzano','27010','PV'),
											('0','Marzano Appio','81035','CE'),
											('0','Marzano di Nola','83020','AV'),
											('0','Marzeno','48010','RA'),
											('0','Marzi','87050','CS'),
											('0','Marzio','21030','VA'),
											('0','Marzocca di Senigallia','60017','AN'),
											('0','Marzolara','43030','PR'),
											('0','Mas','32025','BL'),
											('0','Masainas','09010','CA'),
											('0','Masano','24043','BG'),
											('0','Masanti','43050','PR'),
											('0','Masate','20060','MI'),
											('0','Mascali','95016','CT'),
											('0','Mascalucia','95030','CT'),
											('0','Maschito','85020','PZ'),
											('0','Masciago Primo','21030','VA'),
											('0','Mascioni','67010','AQ'),
											('0','Masella','89064','RC'),
											('0','Maser','31010','TV'),
											('0','Masera','28855','VB'),
											('0','Maser di Padova','35020','PD'),
											('0','Maserada Sul Piave','31052','TV'),
											('0','Maserno','41055','MO'),
											('0','Masi','35040','PD'),
											('0','Masi di Cavalese','38033','TN'),
											('0','Masi San Giacomo','44020','FE'),
											('0','Masi Torello','44020','FE'),
											('0','Masiano','51030','PT'),
											('0','Masino','10010','TO'),
											('0','Masio','15024','AL'),
											('0','Maslianico','22026','CO'),
											('0','Masnago','21100','VA'),
											('0','Mason Vicentino','36064','VI'),
											('0','Masone','16010','GE'),
											('0','Masone','42029','RE'),
											('0','Massa','54100','MS'),
											('0','Massa','82030','BN'),
											('0','Massa','85046','PZ'),
											('0','Massa d\'Albe','67050','AQ'),
											('0','Massa della Lucania','84050','SA'),
											('0','Massa di Somma','80040','NA'),
											('0','Massa e Cozzile','51010','PT'),
											('0','Massa Fermana','63020','AP'),
											('0','Massa Finalese','41035','MO'),
											('0','Massa Fiscaglia','44025','FE'),
											('0','Massa Lombarda','48024','RA'),
											('0','Massa Lubrense','80061','NA'),
											('0','Massa Macinaia','55060','LU'),
											('0','Massa Marittima','58024','GR'),
											('0','Massa Martana','06056','PG'),
											('0','Massa Pisana','55057','LU'),
											('0','Massa San Giorgio','98156','ME'),
											('0','Massa San Giovanni','98157','ME'),
											('0','Massa Santa Lucia','98157','ME'),
											('0','Massafra','74016','TA'),
											('0','Massalengo','26815','LO'),
											('0','Massama','09070','OR'),
											('0','Massanzago','35010','PD'),
											('0','Massaquano','80060','NA'),
											('0','Massarella','50050','FI'),
											('0','Massarosa','55054','LU'),
											('0','Massazza','13873','BI'),
											('0','Massello','10060','TO'),
											('0','Massenzatica','44020','FE'),
											('0','Massenzatico','42010','RE'),
											('0','Masserano','13866','BI'),
											('0','Massicelle','84050','SA'),
											('0','Massignano','63010','AP'),
											('0','Massimeno','38086','TN'),
											('0','Massimino (Prov.Di Savona)','12071','CN'),
											('0','Massino Visconti','28040','NO'),
											('0','Massiola','28895','VB'),
											('0','Mastromarco','51035','PT'),
											('0','Masullas','09090','OR'),
											('0','Matarocco','91020','TP'),
											('0','Matassino','50063','FI'),
											('0','Matelica','62024','MC'),
											('0','Matera','75100','MT'),
											('0','Materdomini','83040','AV'),
											('0','Materdomini di Nocera','84015','SA'),
											('0','Mathi','10075','TO'),
											('0','Matierno','84135','SA'),
											('0','Matinella','84050','SA'),
											('0','Matino','73046','LE'),
											('0','Matonti','84050','SA'),
											('0','Matraia','55010','LU'),
											('0','Matrice','86030','CB'),
											('0','Matsch','39020','BZ'),
											('0','Mattarana','19020','SP'),
											('0','Mattarello','38060','TN'),
											('0','Mattie','10050','TO'),
											('0','Mattinata','71030','FG'),
											('0','Mattine','71013','FG'),
											('0','Mattinella','83040','AV'),
											('0','Mazara del Vallo','91026','TP'),
											('0','Mazia','39020','BZ'),
											('0','Mazzano','25080','BS'),
											('0','Mazzano Romano','00060','RM'),
											('0','Mazzarino','93013','CL'),
											('0','Mazzar','98030','ME'),
											('0','Mazzarr Sant\'Andrea','98056','ME'),
											('0','Mazzarrone','95040','CT'),
											('0','Mazz','10035','TO'),
											('0','Mazzin','38030','TN'),
											('0','Mazzo di Valtellina','23030','SO'),
											('0','Mazzo Milanese','20017','MI'),
											('0','Mazzoleni','24030','BG'),
											('0','Mazzolla','56048','PI'),
											('0','Mazzorno Destro','45019','RO'),
											('0','Meana di Susa','10050','TO'),
											('0','Meana Sardo','08030','NU'),
											('0','Meano','32030','BL'),
											('0','Meano','38040','TN'),
											('0','Meco','16020','GE'),
											('0','Meda','20036','MI'),
											('0','Mede','27035','PV'),
											('0','Medea','34076','GO'),
											('0','Medesano','43014','PR'),
											('0','Mediano','43020','PR'),
											('0','Medicina','40059','BO'),
											('0','Mediglia','20060','MI'),
											('0','Mediis','33020','UD'),
											('0','Medolago','24030','BG'),
											('0','Medole','46046','MN'),
											('0','Medolla','41036','MO'),
											('0','Meduna di Livenza','31040','TV'),
											('0','Meduno','33092','PN'),
											('0','Megliadino San Fidenzio','35040','PD'),
											('0','Megliadino San Vitale','35040','PD'),
											('0','Meina','28046','NO'),
											('0','Mel','32026','BL'),
											('0','Melano Bastia','60040','AN'),
											('0','Melara','45037','RO'),
											('0','Melara','19136','SP'),
											('0','Melazzo','15010','AL'),
											('0','Meldola','47014','FC'),
											('0','Mele','16010','GE'),
											('0','Meledo','36040','VI'),
											('0','Melegnano','20077','MI'),
											('0','Meleins','39040','BZ'),
											('0','Melendugno','73026','LE'),
											('0','Meles','39040','BZ'),
											('0','Meleti','26843','LO'),
											('0','Meleto','52020','AR'),
											('0','Meletole','42024','RE'),
											('0','Melezzole','05020','TR'),
											('0','Melfi','85025','PZ'),
											('0','Melicucc','89020','RC'),
											('0','Melicucc di Dinami','89832','VV'),
											('0','Melicucco','89020','RC'),
											('0','Melilli','96010','SR'),
											('0','Melissa','88817','KR'),
											('0','Melissano','73040','LE'),
											('0','Melito di Napoli','80017','NA'),
											('0','Melito di Porto Salvo','89063','RC'),
											('0','Melito Irpino','83030','AV'),
											('0','Melizzano','82030','BN'),
											('0','Mellana','12012','CN'),
											('0','Melle','12020','CN'),
											('0','Mello','23010','SO'),
											('0','Melpignano','73020','LE'),
											('0','Mels','33030','UD'),
											('0','Meltina','39010','BZ'),
											('0','Melzo','20066','MI'),
											('0','Men Vallestrema','37040','VR'),
											('0','Menaggio','22017','CO'),
											('0','Menarola','23022','SO'),
											('0','Menconico','27050','PV'),
											('0','Mendatica','18025','IM'),
											('0','Mendicino','87040','CS'),
											('0','Menfi','92013','AG'),
											('0','Mentana','00013','RM'),
											('0','Mentoulles','10060','TO'),
											('0','Meolo','30020','VE'),
											('0','Meran','39012','BZ'),
											('0','Meran Sinich','39010','BZ'),
											('0','Merana','15010','AL'),
											('0','Merano','39012','BZ'),
											('0','Merate','23807','LC'),
											('0','Mercallo','21020','VA'),
											('0','Mercatale','61028','PU'),
											('0','Mercatale','40064','BO'),
											('0','Mercatale di Cortona','52040','AR'),
											('0','Mercatale Val di Pesa','50020','FI'),
											('0','Mercatale Valdarno','52020','AR'),
											('0','Mercatale Vernio','59023','PO'),
											('0','Mercatello','06050','PG'),
											('0','Mercatello di Salerno','84131','SA'),
											('0','Mercatello Sul Metauro','61040','PU'),
											('0','Mercatino Conca','61013','PU'),
											('0','Mercato Cilento','84060','SA'),
											('0','Mercato San Severino','84085','SA'),
											('0','Mercato Saraceno','47025','FC'),
											('0','Mercenasco','10010','TO'),
											('0','Mercogliano','83013','AV'),
											('0','Mercurago','28041','NO'),
											('0','Merella','15060','AL'),
											('0','Mereto di Tomba','33036','UD'),
											('0','Mergnano','62032','MC'),
											('0','Mergo','60030','AN'),
											('0','Mergozzo','28802','VB'),
											('0','Mer','98040','ME'),
											('0','Merici','89044','RC'),
											('0','Merine','73020','LE'),
											('0','Merizzo','54028','MS'),
											('0','Merlara','35040','PD'),
											('0','Merlino','26833','LO'),
											('0','Mernicco','34070','GO'),
											('0','Merone','22046','CO'),
											('0','Mesagne','72023','BR'),
											('0','Mese','23020','SO'),
											('0','Mesenzana','21030','VA'),
											('0','Mesero','20010','MI'),
											('0','Mesola','44026','FE'),
											('0','Mesoraca','88838','KR'),
											('0','Messercola','81023','CE'),
											('0','Messignadi','89010','RC'),
											('0','Messigno','80045','NA'),
											('0','Messina','98100','ME'),
											('0','Messina','98123','ME'),
											('0','Messina','98160','ME'),
											('0','Messina','98150','ME'),
											('0','Messina','98130','ME'),
											('0','Messina','98122','ME'),
											('0','Messina','98121','ME'),
											('0','Messina','98140','ME'),
											('0','Mestre','30175','VE'),
											('0','Mestriago','38020','TN'),
											('0','Mestrino','35035','PD'),
											('0','Meta','67050','AQ'),
											('0','Meta','80062','NA'),
											('0','Metanopoli','20097','MI'),
											('0','Metaponto','75010','MT'),
											('0','Metaponto Lido','75010','MT'),
											('0','Meugliano','10080','TO'),
											('0','Mezzago','20050','MI'),
											('0','Mezzana','56010','PI'),
											('0','Mezzana','59100','PO'),
											('0','Mezzana','85030','PZ'),
											('0','Mezzana Bigli','27030','PV'),
											('0','Mezzana Corti','27051','PV'),
											('0','Mezzana in Val di Sole','38020','TN'),
											('0','Mezzana Mortigliengo','13831','BI'),
											('0','Mezzana Rabattone','27030','PV'),
											('0','Mezzane di Sotto','37030','VR'),
											('0','Mezzanego','16046','GE'),
											('0','Mezzani','43055','PR'),
											('0','Mezzanino','27040','PV'),
											('0','Mezzano','48010','RA'),
											('0','Mezzano','81100','CE'),
											('0','Mezzano Chitantolo','29010','PC'),
											('0','Mezzano di Primiero','38050','TN'),
											('0','Mezzano Inferiore','43054','PR'),
											('0','Mezzano Rondani','43050','PR'),
											('0','Mezzano Scotti','29020','PC'),
											('0','Mezzano Superiore','43055','PR'),
											('0','Mezzaselva di Roana','36010','VI'),
											('0','Mezzegra','22010','CO'),
											('0','Mezzenile','10070','TO'),
											('0','Mezzocammino','00127','RM'),
											('0','Mezzocorona','38016','TN'),
											('0','Mezzogoro','44020','FE'),
											('0','Mezzojuso','90030','PA'),
											('0','Mezzolago','38060','TN'),
											('0','Mezzolara','40054','BO'),
											('0','Mezzoldo','24010','BG'),
											('0','Mezzolombardo','38017','TN'),
											('0','Mezzomerico','28040','NO'),
											('0','Mezzomonte','38064','TN'),
											('0','Miagliano','13816','BI'),
											('0','Miane','31050','TV'),
											('0','Miano','64040','TE'),
											('0','Miano','80131','NA'),
											('0','Miasino','28010','NO'),
											('0','Miazzina','28817','VB'),
											('0','Micciano','56045','PI'),
											('0','Miceno','41026','MO'),
											('0','Micigliano','02010','RI'),
											('0','Miggiano','73035','LE'),
											('0','Migheli','08047','NU'),
											('0','Migliandolo','14037','AT'),
											('0','Miglianico di Chieti','66010','CH'),
											('0','Migliano','06050','PG'),
											('0','Migliano','83023','AV'),
											('0','Migliarina','19125','SP'),
											('0','Migliarina','41012','MO'),
											('0','Migliarino','44027','FE'),
											('0','Migliarino','56019','PI'),
											('0','Migliaro','44020','FE'),
											('0','Miglierina','88040','CZ'),
											('0','Miglionico','75010','MT'),
											('0','Migliuso','88040','CZ'),
											('0','Mignanego','16018','GE'),
											('0','Mignano Monte Lungo','81049','CE'),
											('0','Milanino','20095','MI'),
											('0','Milano','20100','MI'),
											('0','Milano','20158','MI'),
											('0','Milano','20146','MI'),
											('0','Milano','20129','MI'),
											('0','Milano','20147','MI'),
											('0','Milano','20126','MI'),
											('0','Milano','20154','MI'),
											('0','Milano','20156','MI'),
											('0','Milano','20149','MI'),
											('0','Milano','20159','MI'),
											('0','Milano','20123','MI'),
											('0','Milano','20124','MI'),
											('0','Milano','20144','MI'),
											('0','Milano','20155','MI'),
											('0','Milano','20137','MI'),
											('0','Milano','20141','MI'),
											('0','Milano','20133','MI'),
											('0','Milano','20121','MI'),
											('0','Milano','20122','MI'),
											('0','Milano','20128','MI'),
											('0','Milano','20131','MI'),
											('0','Milano','20132','MI'),
											('0','Milano','20145','MI'),
											('0','Milano','20148','MI'),
											('0','Milano','20136','MI'),
											('0','Milano','20135','MI'),
											('0','Milazzo','98057','ME'),
											('0','Milea','89050','RC'),
											('0','Milena','93010','CL'),
											('0','Mileto','89852','VV'),
											('0','Mili Marina','98131','ME'),
											('0','Mili San Marco','98132','ME'),
											('0','Mili Superiore','98133','ME'),
											('0','Milici','98050','ME'),
											('0','Milis','09070','OR'),
											('0','Miliscola','80070','NA'),
											('0','Militello in Val di Catania','95043','CT'),
											('0','Militello Rosmarino','98070','ME'),
											('0','Millesimo','17017','SV'),
											('0','Milo','95010','CT'),
											('0','Milzano','25020','BS'),
											('0','Mineo','95044','CT'),
											('0','Minerbe','37046','VR'),
											('0','Minerbio','40061','BO'),
											('0','Minervino di Lecce','73027','LE'),
											('0','Minervino Murge','70055','BA'),
											('0','Minoprio','22070','CO'),
											('0','Minori','84010','SA'),
											('0','Minozzo','42030','RE'),
											('0','Minturno','04026','LT'),
											('0','Minucciano','55034','LU'),
											('0','Mioglia','17040','SV'),
											('0','Mira','30034','VE'),
											('0','Mira Porte','30034','VE'),
											('0','Mirabella Eclano','83036','AV'),
											('0','Mirabella Imbaccari','95040','CT'),
											('0','Mirabello','44043','FE'),
											('0','Mirabello di Cant','22060','CO'),
											('0','Mirabello di Pavia','27010','PV'),
											('0','Mirabello Monferrato','15040','AL'),
											('0','Mirabello Sannitico','86010','CB'),
											('0','Miracoli','66020','CH'),
											('0','Miradolo Terme','27010','PV'),
											('0','Miraldo','85030','PZ'),
											('0','Miramare di Rimini','47831','RN'),
											('0','Miranda','05100','TR'),
											('0','Miranda','86170','IS'),
											('0','Mirandola','41037','MO'),
											('0','Mirano','30035','VE'),
											('0','Mirteto','54100','MS'),
											('0','Mirto','87060','CS'),
											('0','Mirto','98070','ME'),
											('0','Misano Adriatico','47843','RN'),
											('0','Misano Gera d\'Adda','24040','BG'),
											('0','Misano Monte','47843','RN'),
											('0','Misciano','83020','AV'),
											('0','Miseglia','54033','MS'),
											('0','Misileo','50035','FI'),
											('0','Misilmeri','90036','PA'),
											('0','Misinto','20020','MI'),
											('0','Misitano','98030','ME'),
											('0','Missaglia','23873','LC'),
											('0','Missanello','85010','PZ'),
											('0','Missano','41059','MO'),
											('0','Misserio','98020','ME'),
											('0','Misterbianco','95045','CT'),
											('0','Mistretta','98073','ME'),
											('0','Misurina','32040','BL'),
											('0','Mitogio','95010','CT'),
											('0','Mizzole','37030','VR'),
											('0','Moasca','14050','AT'),
											('0','Mocaiana Stazione','06020','PG'),
											('0','Moccone','87052','CS'),
											('0','Mocenigo','38020','TN'),
											('0','Mocogno','41023','MO'),
											('0','Moconesi','16047','GE'),
											('0','Modena','41100','MO'),
											('0','Modica','97015','RG'),
											('0','Modica Alta','97010','RG'),
											('0','Modigliana','47015','FC'),
											('0','Modolo','08019','NU'),
											('0','Modugno','70026','BA'),
											('0','Moena','38035','TN'),
											('0','Moerna','25080','BS'),
											('0','Moggio','23817','LC'),
											('0','Moggio Udinese','33015','UD'),
											('0','Moggiona di Poppi','52010','AR'),
											('0','Moglia','46024','MN'),
											('0','Moglia di Sermide','46020','MN'),
											('0','Mogliano Marche','62010','MC'),
											('0','Mogliano Veneto','31021','TV'),
											('0','Moglio','17021','SV'),
											('0','Mogorella','09080','OR'),
											('0','Mogoro','09095','OR'),
											('0','Moiano','82010','BN'),
											('0','Moiano','80060','NA'),
											('0','Moiano','06060','PG'),
											('0','Moie','60030','AN'),
											('0','Moimacco','33040','UD'),
											('0','Moio Alcantara','98030','ME'),
											('0','Moio De\' Calvi','24010','BG'),
											('0','Moio della Civitella','84060','SA'),
											('0','Moiola','12010','CN'),
											('0','Moira','98078','ME'),
											('0','Moirano','15011','AL'),
											('0','Mola di Bari','70042','BA'),
											('0','Moladi','89841','VV'),
											('0','Molare','15074','AL'),
											('0','Molassana','16138','GE'),
											('0','Molazzana','55020','LU'),
											('0','Moletolo','43100','PR'),
											('0','Molfetta','70056','BA'),
											('0','Molicciara','19033','SP'),
											('0','Molin Nuovo','52030','AR'),
											('0','Molina Aterno','67020','AQ'),
											('0','Molina di Fiemme','38030','TN'),
											('0','Molina di Ledro','38060','TN'),
											('0','Molina di Quosa','56010','PI'),
											('0','Molina di Vietri Sul Mare','84010','SA'),
											('0','Molinaccio','06020','PG'),
											('0','Molinara','82020','BN'),
											('0','Moline di Banale','38078','TN'),
											('0','Molinella','40062','BO'),
											('0','Molinello','54020','MS'),
											('0','Molinetto','25080','BS'),
											('0','Molini di Triora','18010','IM'),
											('0','Molino dei Torti','15050','AL'),
											('0','Molino del Pallone','40045','BO'),
											('0','Molino del Piano','50060','FI'),
											('0','Molino Dell\'Anzola','43050','PR'),
											('0','Molino di Altissimo','36070','VI'),
											('0','Molino di Bascio','61016','PU'),
											('0','Molise','86020','CB'),
											('0','Moliterno','85050','PZ'),
											('0','Mollaro','38010','TN'),
											('0','Mollia','13020','VC'),
											('0','Molochio','89010','RC'),
											('0','Mologno','55050','LU'),
											('0','Molten','39010','BZ'),
											('0','Molteno','23847','LC'),
											('0','Moltrasio','22010','CO'),
											('0','Molvena','36060','VI'),
											('0','Molveno','38018','TN'),
											('0','Mombaldone','14050','AT'),
											('0','Mombarcaro','12070','CN'),
											('0','Mombaroccio','61024','PU'),
											('0','Mombarone','14020','AT'),
											('0','Mombaruzzo','14046','AT'),
											('0','Mombasiglio','12070','CN'),
											('0','Mombello','20051','MI'),
											('0','Mombello','21014','VA'),
											('0','Mombello di Torino','10020','TO'),
											('0','Mombello Monferrato','15020','AL'),
											('0','Mombercelli','14047','AT'),
											('0','Mombretto','20060','MI'),
											('0','Momigno','51030','PT'),
											('0','Momo','28015','NO'),
											('0','Mompantero','10059','TO'),
											('0','Mompeo','02040','RI'),
											('0','Momperone','15050','AL'),
											('0','Mompiano','25133','BS'),
											('0','Monacilioni','86040','CB'),
											('0','Monale','14013','AT'),
											('0','Monasterace','89040','RC'),
											('0','Monasterace Marina','89040','RC'),
											('0','Monastero','61021','PU'),
											('0','Monastero Bormida','14058','AT'),
											('0','Monastero di Lanzo','10070','TO'),
											('0','Monastero di Vasco','12080','CN'),
											('0','Monasterolo','24060','BG'),
											('0','Monasterolo Casotto','12080','CN'),
											('0','Monasterolo di Savigliano','12030','CN'),
											('0','Monasterolo Torinese','10070','TO'),
											('0','Monastier','31050','TV'),
											('0','Monastir','09023','CA'),
											('0','Moncalieri','10024','TO'),
											('0','Moncalvo','14036','AT'),
											('0','Moncenisio','10050','TO'),
											('0','Moncerrato','41048','MO'),
											('0','Moncestino','15020','AL'),
											('0','Monchiero','12060','CN'),
											('0','Monchio Delle Corti','43010','PR'),
											('0','Monchio nel Frignano','41040','MO'),
											('0','Moncigoli','54010','MS'),
											('0','Moncioni','52020','AR'),
											('0','Monclassico','38020','TN'),
											('0','Moncrivello','13040','VC'),
											('0','Moncucco Torinese','14024','AT'),
											('0','Mondadizza','23035','SO'),
											('0','Mondaino','47836','RN'),
											('0','Mondavio','61040','PU'),
											('0','Mondello','90151','PA'),
											('0','Mondolfo','61037','PU'),
											('0','Mondonio San Domenico Savio','14022','AT'),
											('0','Mondov','12084','CN'),
											('0','Mondragone','81034','CE'),
											('0','Mondrone','10070','TO'),
											('0','Moneglia','16030','GE'),
											('0','Monesiglio','12077','CN'),
											('0','Monestirolo','44040','FE'),
											('0','Moneta','07020','SS'),
											('0','Monfalcone','34074','GO'),
											('0','Monfallito','14034','AT'),
											('0','Monfestino','41028','MO'),
											('0','Monforte d\'Alba','12065','CN'),
											('0','Monforte San Giorgio','98041','ME'),
											('0','Monfumo','31010','TV'),
											('0','Mongardino','14040','AT'),
											('0','Monghidoro','40063','BO'),
											('0','Mongiana','89823','VV'),
											('0','Mongiardino','15070','AL'),
											('0','Mongiardino Ligure','15060','AL'),
											('0','Mongiove','98060','ME'),
											('0','Mongiuffi Madonna della Catena','98030','ME'),
											('0','Mongiuffi Melia','98030','ME'),
											('0','Mongnod','11020','AO'),
											('0','Mongrando','13888','BI'),
											('0','Mongrassano','87040','CS'),
											('0','Mongrassano Stazione','87010','CS'),
											('0','Monguelfo','39035','BZ'),
											('0','Monguzzo','22040','CO'),
											('0','Moniego di Noale','30033','VE'),
											('0','Moniga del Garda','25080','BS'),
											('0','Monigo','31100','TV'),
											('0','Monleale','15059','AL'),
											('0','Monleone','16044','GE'),
											('0','Monno','25040','BS'),
											('0','Monopoli','70043','BA'),
											('0','Monreale','90046','PA'),
											('0','Monrupino','34016','TS'),
											('0','Monsampietro Morico','63029','AP'),
											('0','Monsampolo del Tronto','63030','AP'),
											('0','Monsano','60030','AN'),
											('0','Monselice','35043','PD'),
											('0','Monserrato','09042','CA'),
											('0','Monsola','12020','CN'),
											('0','Monsoreto','89833','VV'),
											('0','Monsummano Terme','51015','PT'),
											('0','Mont','12046','CN'),
											('0','Mont','35138','PD'),
											('0','Montabone','14040','AT'),
											('0','Montacuto','15050','AL'),
											('0','Montafia','14014','AT'),
											('0','Montagano','86023','CB'),
											('0','Montagna','39040','BZ'),
											('0','Montagna in Valtellina','23020','SO'),
											('0','Montagnaga','38040','TN'),
											('0','Montagnana','41028','MO'),
											('0','Montagnana','35044','PD'),
											('0','Montagnana Pistoiese','51030','PT'),
											('0','Montagnana Val di Pesa','50025','FI'),
											('0','Montagnano Alberoro','52040','AR'),
											('0','Montagnareale','98060','ME'),
											('0','Montagne','38070','TN'),
											('0','Montaguto','83030','AV'),
											('0','Montaione','50050','FI'),
											('0','Montalbano','50135','FI'),
											('0','Montalbano','47822','RN'),
											('0','Montalbano','44046','FE'),
											('0','Montalbano di Fasano','72016','BR'),
											('0','Montalbano Elicona','98065','ME'),
											('0','Montalbano Jonico','75023','MT'),
											('0','Montalcinello','53010','SI'),
											('0','Montalcino','53024','SI'),
											('0','Montaldeo','15060','AL'),
											('0','Montaldo Bormida','15010','AL'),
											('0','Montaldo di Mondov','12080','CN'),
											('0','Montaldo Roero','12040','CN'),
											('0','Montaldo Scarampi','14048','AT'),
											('0','Montaldo Torinese','10020','TO'),
											('0','Montale','19015','SP'),
											('0','Montale','51037','PT'),
											('0','Montale Rangone','41050','MO'),
											('0','Montalenghe','10090','TO'),
											('0','Montalero','15020','AL'),
											('0','Montallegro','92010','AG'),
											('0','Montallese','53040','SI'),
											('0','Montalto','41059','MO'),
											('0','Montalto','42030','RE'),
											('0','Montalto di Castro','01014','VT'),
											('0','Montalto Dora','10016','TO'),
											('0','Montalto Ligure','18010','IM'),
											('0','Montalto Marche','63034','AP'),
											('0','Montalto Pavese','27040','PV'),
											('0','Montalto Uffugo','87046','CS'),
											('0','Montalto Uffugo Scalo','87040','CS'),
											('0','Montan','39040','BZ'),
											('0','Montanara','46010','MN'),
											('0','Montanare di Cortona','52040','AR'),
											('0','Montanaro','10017','TO'),
											('0','Montanaro','81050','CE'),
											('0','Montanaso Lombardo','26836','LO'),
											('0','Montaner','31010','TV'),
											('0','Montanera','12040','CN'),
											('0','Montano Antilia','84060','SA'),
											('0','Montano Comasco','22070','CO'),
											('0','Montano Lucino','22070','CO'),
											('0','Montaperto','83030','AV'),
											('0','Montaperto','92010','AG'),
											('0','Montappone','63020','AP'),
											('0','Montaquila','86070','IS'),
											('0','Montasola','02040','RI'),
											('0','Montauro','88060','CZ'),
											('0','Montauro Stazione','88060','CZ'),
											('0','Montazzoli','66030','CH'),
											('0','Monte','15040','AL'),
											('0','Monte Amiata','53020','SI'),
											('0','Monte Antico','58030','GR'),
											('0','Monte Antico Scalo','58030','GR'),
											('0','Monte Argentario','58019','GR'),
											('0','Monte Castello','47025','FC'),
											('0','Monte Castello Vibio','06057','PG'),
											('0','Monte Cavallo','62036','MC'),
											('0','Monte Cerignone','61010','PU'),
											('0','Monte Cicerale','84060','SA'),
											('0','Monte Colombo','47854','RN'),
											('0','Monte Cremasco','26010','CR'),
											('0','Monte di Malo','36030','VI'),
											('0','Monte di Mezzo','38050','TN'),
											('0','Monte di Procida','80070','NA'),
											('0','Monte Donato','40141','BO'),
											('0','Monte Faito','80060','NA'),
											('0','Monte Giberto','63020','AP'),
											('0','Monte Guidi','47018','FC'),
											('0','Monte Isola','25050','BS'),
											('0','Monte Longu','08020','NU'),
											('0','Monte Magr','36015','VI'),
											('0','Monte Marenzo','23804','LC'),
											('0','Monte Olimpino','22100','CO'),
											('0','Monte Oliveto','87055','CS'),
											('0','Monte Oliveto Maggiore','53020','SI'),
											('0','Monte Oriolo','50023','FI'),
											('0','Monte Ortobene','08100','NU'),
											('0','Monte Petriolo','06070','PG'),
											('0','Monte Petrosu','08020','NU'),
											('0','Monte Porzio','61040','PU'),
											('0','Monte Porzio Catone','00040','RM'),
											('0','Monte Rinaldo','63020','AP'),
											('0','Monte Roberto','60030','AN'),
											('0','Monte Romano','01010','VT'),
											('0','Monte San Biagio','04020','LT'),
											('0','Monte San Giacomo','84030','SA'),
											('0','Monte San Giovanni Campano','03025','FR'),
											('0','Monte San Giovanni in Sabina','02040','RI'),
											('0','Monte San Giusto','62015','MC'),
											('0','Monte San Martino','62020','MC'),
											('0','Monte San Pietrangeli','63010','AP'),
											('0','Monte San Pietro','39040','BZ'),
											('0','Monte San Pietro','40050','BO'),
											('0','Monte San Quirico','55100','LU'),
											('0','Monte San Savino','52048','AR'),
											('0','Monte San Vigilio','39010','BZ'),
											('0','Monte San Vito','60037','AN'),
											('0','Monte Santa Caterina','39020','BZ'),
											('0','Monte Santa Maria','02030','RI'),
											('0','Monte Santa Maria Tiberina','06010','PG'),
											('0','Monte Sant\'Angelo','71037','FG'),
											('0','Monte Sante Marie','53041','SI'),
											('0','Monte Terminillo','02017','RI'),
											('0','Monte Urano','63015','AP'),
											('0','Monte Vidon Combatte','63027','AP'),
											('0','Monte Vidon Corrado','63020','AP'),
											('0','Monteacuto Delle Alpi','40042','BO'),
											('0','Montealbano','41059','MO'),
											('0','Montebamboli','58024','GR'),
											('0','Montebaranzone','41040','MO'),
											('0','Montebello','55041','LU'),
											('0','Montebello','06126','PG'),
											('0','Montebello della Battaglia','27054','PV'),
											('0','Montebello di Bertona','65010','PE'),
											('0','Montebello Jonico','89064','RC'),
											('0','Montebello Sul Sangro','66040','CH'),
											('0','Montebello Vicentino','36054','VI'),
											('0','Montebelluna','31044','TV'),
											('0','Montebonello','41026','MO'),
											('0','Montebruno','16025','GE'),
											('0','Montebuono','02040','RI'),
											('0','Montebuono','58010','GR'),
											('0','Montecalvo in Foglia','61020','PU'),
											('0','Montecalvo Irpino','83037','AV'),
											('0','Montecalvo Versiggia','27047','PV'),
											('0','Montecalvoli','56020','PI'),
											('0','Montecampano','05020','TR'),
											('0','Montecarelli','50030','FI'),
											('0','Montecarlo','55015','LU'),
											('0','Montecarotto','60036','AN'),
											('0','Montecassiano','62010','MC'),
											('0','Montecassino Abbazia','03043','FR'),
											('0','Montecastelli Pisano','56040','PI'),
											('0','Montecastelli Umbro','06010','PG'),
											('0','Montecastello','15040','AL'),
											('0','Montecastello','56025','PI'),
											('0','Montecastrilli','05026','TR'),
											('0','Montecatini Terme e Tettuccio','51016','PT'),
											('0','Montecatini Val di Cecina','56040','PI'),
											('0','Montecatini Val di Nievole','51010','PT'),
											('0','Montecavolo','42020','RE'),
											('0','Montecchia di Crosara','37030','VR'),
											('0','Montecchio','05020','TR'),
											('0','Montecchio','61020','PU'),
											('0','Montecchio Emilia','42027','RE'),
											('0','Montecchio Maggiore','36075','VI'),
											('0','Montecchio Precalcino','36030','VI'),
											('0','Montecelio','00014','RM'),
											('0','Montecenere','41023','MO'),
											('0','Montecerboli','56044','PI'),
											('0','Montechiaro','80066','NA'),
											('0','Montechiaro','39020','BZ'),
											('0','Montechiaro d\'Acqui','15010','AL'),
											('0','Montechiaro d\'Asti','14025','AT'),
											('0','Montechiaro Denice','15010','AL'),
											('0','Montechiarugolo','43022','PR'),
											('0','Monteciccardo','61024','PU'),
											('0','Montecilfone','86032','CB'),
											('0','Montecompatri','00040','RM'),
											('0','Montecopiolo','61014','PU'),
											('0','Montecorice','84060','SA'),
											('0','Montecorneo','06126','PG'),
											('0','Montecorone','41050','MO'),
											('0','Montecorvino','84090','SA'),
											('0','Montecorvino Rovella','84096','SA'),
											('0','Montecosaro','62010','MC'),
											('0','Montecosaro Stazione','62010','MC'),
											('0','Montecrestese','28864','VB'),
											('0','Montecreto','41025','MO'),
											('0','Montecucco','25083','BS'),
											('0','Montecuccolo','41026','MO'),
											('0','Montedecoro','81023','CE'),
											('0','Montedinove','63034','AP'),
											('0','Montedivalli','54010','MS'),
											('0','Montedoro','93010','CL'),
											('0','Monteduro','42035','RE'),
											('0','Montefalcione','83030','AV'),
											('0','Montefalco','06036','PG'),
											('0','Montefalcone Appennino','63028','AP'),
											('0','Montefalcone di Val Fortore','82025','BN'),
											('0','Montefalcone nel Sannio','86033','CB'),
											('0','Montefano','62010','MC'),
											('0','Montefegatesi','55050','LU'),
											('0','Montefelcino','61030','PU'),
											('0','Monteferrante','66040','CH'),
											('0','Montefiascone','01027','VT'),
											('0','Montefino','64030','TE'),
											('0','Montefiore Conca','47834','RN'),
											('0','Montefiore Dell\'Aso','63010','AP'),
											('0','Montefiorino','41045','MO'),
											('0','Montefiridolfi','50020','FI'),
											('0','Monteflavio','00010','RM'),
											('0','Montefollonico','53040','SI'),
											('0','Monteforte Cilento','84060','SA'),
											('0','Monteforte d\'Alpone','37032','VR'),
											('0','Monteforte Irpino','83024','AV'),
											('0','Montefortino','60011','AN'),
											('0','Montefortino','63044','AP'),
											('0','Montefoscoli','56036','PI'),
											('0','Montefranco','05030','TR'),
											('0','Montefranco in Venosta','39020','BZ'),
											('0','Montefredane','83030','AV'),
											('0','Montefusco','83030','AV'),
											('0','Montegabbione','05010','TR'),
											('0','Montegalda','36047','VI'),
											('0','Montegaldella','36047','VI'),
											('0','Montegallo','63040','AP'),
											('0','Montegelli','47030','FC'),
											('0','Montegemoli','56045','PI'),
											('0','Montegibbio','41049','MO'),
											('0','Montegioco','15050','AL'),
											('0','Montegiordano','87070','CS'),
											('0','Montegiordano Marina','87070','CS'),
											('0','Montegiorgio','63025','AP'),
											('0','Montegiovi','58030','GR'),
											('0','Montegonzi','52020','AR'),
											('0','Montegranaro','63014','AP'),
											('0','Montegranaro','61100','PU'),
											('0','Montegridolfo','47837','RN'),
											('0','Montegrimano','61010','PU'),
											('0','Montegrino Valtravaglia','21010','VA'),
											('0','Montegrosso','70031','BA'),
											('0','Montegrosso d\'Asti','14048','AT'),
											('0','Montegrosso d\'Asti Stazione','14048','AT'),
											('0','Montegrosso di Cinaglio','14010','AT'),
											('0','Montegrosso Pian Latte','18023','IM'),
											('0','Montegrotto Terme','35036','PD'),
											('0','Montegualtieri','64037','TE'),
											('0','Monteguidi','53031','SI'),
											('0','Monteguiduccio','61030','PU'),
											('0','Monteiasi','74020','TA'),
											('0','Montelabbate','61025','PU'),
											('0','Montelanico','00030','RM'),
											('0','Montelapiano','66040','CH'),
											('0','Montelaterone','58030','GR'),
											('0','Monteleone di Fermo','63029','AP'),
											('0','Monteleone di Puglia','71020','FG'),
											('0','Monteleone di Spoleto','06045','PG'),
											('0','Monteleone d\'Orvieto','05017','TR'),
											('0','Monteleone Rocca Doria','07010','SS'),
											('0','Monteleone Sabino','02033','RI'),
											('0','Montelepre','90040','PA'),
											('0','Montelibretti','00010','RM'),
											('0','Montelicciano','61013','PU'),
											('0','Montella','83048','AV'),
											('0','Montello','24060','BG'),
											('0','Montelongo','86040','CB'),
											('0','Montelparo','63020','AP'),
											('0','Montelupo Albese','12050','CN'),
											('0','Montelupo Fiorentino','50056','FI'),
											('0','Montelupone','62010','MC'),
											('0','Montemaggio','61010','PU'),
											('0','Montemaggiore Al Metauro','61030','PU'),
											('0','Montemaggiore Belsito','90020','PA'),
											('0','Montemagno','56011','PI'),
											('0','Montemagno','14030','AT'),
											('0','Montemagno','55040','LU'),
											('0','Montemagno di Quarrata','51030','PT'),
											('0','Montemale di Cuneo','12025','CN'),
											('0','Montemarano','83040','AV'),
											('0','Montemarcello','19030','SP'),
											('0','Montemarciano','60018','AN'),
											('0','Montemartano','06049','PG'),
											('0','Montemarzino','15050','AL'),
											('0','Montemarzo d\'Asti','14030','AT'),
											('0','Montemassi','58020','GR'),
											('0','Montemerano','58050','GR'),
											('0','Montemerlo','35030','PD'),
											('0','Montemesola','74020','TA'),
											('0','Montemezzo','22010','CO'),
											('0','Montemignaio','52010','AR'),
											('0','Montemiletto','83038','AV'),
											('0','Montemilone','85020','PZ'),
											('0','Montemitro','86030','CB'),
											('0','Montemonaco','63048','AP'),
											('0','Montemurlo','59013','PO'),
											('0','Montemurro','85053','PZ'),
											('0','Montenars','33010','UD'),
											('0','Montenero','57128','LI'),
											('0','Montenero','58040','GR'),
											('0','Montenero di Bisaccia','86036','CB'),
											('0','Montenero di Todi','06050','PG'),
											('0','Montenero Sabino','02040','RI'),
											('0','Montenero Val Cocchiara','86080','IS'),
											('0','Montenerodomo','66010','CH'),
											('0','Monteodorisio','66050','CH'),
											('0','Monteombraro','41050','MO'),
											('0','Monteorsello','41052','MO'),
											('0','Monteortone','35030','PD'),
											('0','Monteortore','41059','MO'),
											('0','Montepagano','64020','TE'),
											('0','Montepaone','88060','CZ'),
											('0','Montepaone Lido','88060','CZ'),
											('0','Monteparano','74020','TA'),
											('0','Montepescali','58030','GR'),
											('0','Montepescali Stazione','58035','GR'),
											('0','Montepetra','47025','FC'),
											('0','Montepiano','59026','PO'),
											('0','Monteponi','09010','CA'),
											('0','Monteprandone','63033','AP'),
											('0','Montepulciano','53045','SI'),
											('0','Montepulciano Stazione','53040','SI'),
											('0','Monterado','60010','AN'),
											('0','Monterappoli','50053','FI'),
											('0','Monterchi','52035','AR'),
											('0','Montereale','67015','AQ'),
											('0','Montereale Valcellina','33086','PN'),
											('0','Montereggio di Mulazzo','54020','MS'),
											('0','Monterenzio','40050','BO'),
											('0','Monteriggioni','53035','SI'),
											('0','Monterocchetta','82010','BN'),
											('0','Monteroduni','86075','IS'),
											('0','Monterolo','61045','PU'),
											('0','Monteromano','48010','RA'),
											('0','Monterone','52038','AR'),
											('0','Monterone','80075','NA'),
											('0','Monteroni d\'Arbia','53014','SI'),
											('0','Monteroni di Lecce','73047','LE'),
											('0','Monterosi','01030','VT'),
											('0','Monterosso','60045','AN'),
											('0','Monterosso Al Mare','19016','SP'),
											('0','Monterosso Almo','97010','RG'),
											('0','Monterosso Calabro','89819','VV'),
											('0','Monterosso Etneo','95020','CT'),
											('0','Monterosso Grana','12020','CN'),
											('0','Monterosso Stazione','60046','AN'),
											('0','Monterotondo','00015','RM'),
											('0','Monterotondo','25050','BS'),
											('0','Monterotondo Marittimo','58025','GR'),
											('0','Monterotondo Stazione','00016','RM'),
											('0','Monterubbiano','63026','AP'),
											('0','Monterubiaglio','05010','TR'),
											('0','Monterusciello','80078','NA'),
											('0','Montesabinese','67061','AQ'),
											('0','Montesano Salentino','73030','LE'),
											('0','Montesano sulla Marcellana','84033','SA'),
											('0','Montesano sulla Marcellana Stazione','84030','SA'),
											('0','Montesanto','44010','FE'),
											('0','Montesarchio','82016','BN'),
											('0','Montesardo','73030','LE'),
											('0','Montescaglioso','75024','MT'),
											('0','Montescano','27040','PV'),
											('0','Montescheno','28843','VB'),
											('0','Montescudaio','56040','PI'),
											('0','Montescudo','47854','RN'),
											('0','Montese','41055','MO'),
											('0','Montesegale','27052','PV'),
											('0','Montesicuro','60020','AN'),
											('0','Montesilvano','65015','PE'),
											('0','Montesilvano Spiaggia','65016','PE'),
											('0','Montesinaro','13812','BI'),
											('0','Montesolaro','22060','CO'),
											('0','Montesoro','89814','VV'),
											('0','Montespecchio','41055','MO'),
											('0','Montespertoli','50025','FI'),
											('0','Montespluga','23020','SO'),
											('0','Monteu da Po','10020','TO'),
											('0','Monteu Roero','12040','CN'),
											('0','Montevaccino','38040','TN'),
											('0','Montevago','92010','AG'),
											('0','Montevarchi','52025','AR'),
											('0','Montevecchia','23874','LC'),
											('0','Montevecchio','09030','CA'),
											('0','Monteveglio','40050','BO'),
											('0','Monteverde','83049','AV'),
											('0','Monteverde di Boiano','86021','CB'),
											('0','Monteverdi Marittimo','56040','PI'),
											('0','Montevettolini','51010','PT'),
											('0','Monteviale','36050','VI'),
											('0','Montevirginio','00060','RM'),
											('0','Montevitozzo','58010','GR'),
											('0','Montezemolo','12070','CN'),
											('0','Monti','07020','SS'),
											('0','Monti','53010','SI'),
											('0','Monti di Licciana','54017','MS'),
											('0','Montiano','58052','GR'),
											('0','Montiano','47020','FC'),
											('0','Monticchiello','53020','SI'),
											('0','Monticchio','04013','LT'),
											('0','Monticchio','67020','AQ'),
											('0','Monticchio','85020','PZ'),
											('0','Monticchio Bagni','85020','PZ'),
											('0','Monticchio di Massa Lubrense','80060','NA'),
											('0','Monticelli','84085','SA'),
											('0','Monticelli','03040','FR'),
											('0','Monticelli','44020','FE'),
											('0','Monticelli','63030','AP'),
											('0','Monticelli Brusati','25040','BS'),
											('0','Monticelli d\'Ongina','29010','PC'),
											('0','Monticelli Pavese','27010','PV'),
											('0','Monticelli Terme di Montechiarugolo','43023','PR'),
											('0','Monticello','06050','PG'),
											('0','Monticello','23876','LC'),
											('0','Monticello Conte Otto','36010','VI'),
											('0','Monticello d\'Alba','12066','CN'),
											('0','Monticello Dell\'Amiata','58047','GR'),
											('0','Montichiari','25018','BS'),
											('0','Monticiano','53015','SI'),
											('0','Montieri','58026','GR'),
											('0','Montiglio','14026','AT'),
											('0','Montignano','60010','AN'),
											('0','Montignoso','54038','MS'),
											('0','Montione','56023','PI'),
											('0','Montioni','57028','LI'),
											('0','Montirone','25010','BS'),
											('0','Montisi','53020','SI'),
											('0','Montisola','02045','RI'),
											('0','Montjovet','11020','AO'),
											('0','Montocchio','85100','PZ'),
											('0','Montodine','26010','CR'),
											('0','Montoggio','16026','GE'),
											('0','Montone','06014','PG'),
											('0','Montone','64020','TE'),
											('0','Montopoli di Sabina','02034','RI'),
											('0','Montopoli in Val d\'Arno','56020','PI'),
											('0','Montorfano','22030','CO'),
											('0','Montorgiali','58050','GR'),
											('0','Montorio','58010','GR'),
											('0','Montorio Al Vomano','64046','TE'),
											('0','Montorio Nei Frentani','86040','CB'),
											('0','Montorio Romano','00010','RM'),
											('0','Montorio Veronese','37033','VR'),
											('0','Montoro','05027','TR'),
											('0','Montoro Inferiore','83025','AV'),
											('0','Montoro Superiore','83026','AV'),
											('0','Montorsaio','58040','GR'),
											('0','Montorso','41026','MO'),
											('0','Montorso Vicentino','36050','VI'),
											('0','Montottone','63020','AP'),
											('0','Montresta','08010','NU'),
											('0','Mont Beccaria','27040','PV'),
											('0','Montuolo','55050','LU'),
											('0','Monvalle','21020','VA'),
											('0','Monza','20052','MI'),
											('0','Monzambano','46040','MN'),
											('0','Monzone','41026','MO'),
											('0','Monzone','54025','MS'),
											('0','Monzuno','40036','BO'),
											('0','Moos in Passeier','39013','BZ'),
											('0','Moraduccio di Valsalva','40022','BO'),
											('0','Moranego','16020','GE'),
											('0','Morano','06023','PG'),
											('0','Morano','41048','MO'),
											('0','Morano Calabro','87016','CS'),
											('0','Morano Po','15025','AL'),
											('0','Moransengo','14023','AT'),
											('0','Moraro','34070','GO'),
											('0','Morazzone','21040','VA'),
											('0','Morbegno','23017','SO'),
											('0','Morbello','15010','AL'),
											('0','Morca','13019','VC'),
											('0','Morciano di Leuca','73040','LE'),
											('0','Morciano di Romagna','47833','RN'),
											('0','Morcone','82026','BN'),
											('0','Mordano','40027','BO'),
											('0','Moregnano','63027','AP'),
											('0','Morena','00040','RM'),
											('0','Morengo','24050','BG'),
											('0','Mores','07013','SS'),
											('0','Moresco','63026','AP'),
											('0','Moretta','12033','CN'),
											('0','Morfasso','29020','PC'),
											('0','Morgano','31050','TV'),
											('0','Morgex','11017','AO'),
											('0','Morgnano','06040','PG'),
											('0','Morgongiori','09090','OR'),
											('0','Mori','38065','TN'),
											('0','Mori Ferrovia','38060','TN'),
											('0','Moriago della Battaglia','31010','TV'),
											('0','Moricone','00010','RM'),
											('0','Morigerati','84030','SA'),
											('0','Morigino','73024','LE'),
											('0','Morimondo','20081','MI'),
											('0','Morino','67050','AQ'),
											('0','Moriondo Torinese','10020','TO'),
											('0','Morlupo','00067','RM'),
											('0','Mormanno','87026','CS'),
											('0','Mormorola','43050','PR'),
											('0','Mornago','21020','VA'),
											('0','Mornese','15075','AL'),
											('0','Mornico Al Serio','24050','BG'),
											('0','Mornico Losana','27040','PV'),
											('0','Morolo','03017','FR'),
											('0','Moron','11027','AO'),
											('0','Morozzo','12040','CN'),
											('0','Morra','06010','PG'),
											('0','Morra De Sanctis','83040','AV'),
											('0','Morrano','05010','TR'),
											('0','Morre','05020','TR'),
											('0','Morro','62032','MC'),
											('0','Morro d\'Alba','60030','AN'),
											('0','Morro d\'Oro','64020','TE'),
											('0','Morro Reatino','02010','RI'),
											('0','Morrona','56030','PI'),
											('0','Morrone del Sannio','86040','CB'),
											('0','Morroni','83032','AV'),
											('0','Morrovalle','62010','MC'),
											('0','Morrovalle Stazione','62010','MC'),
											('0','Morsano Al Tagliamento','33075','PN'),
											('0','Morsasco','15010','AL'),
											('0','Mortara','27036','PV'),
											('0','Mortegliano','33050','UD'),
											('0','Morter','39020','BZ'),
											('0','Morter','39020','BZ'),
											('0','Morterone','23811','LC'),
											('0','Mortise','35129','PD'),
											('0','Mortizza','29010','PC'),
											('0','Mortizzuolo','41037','MO'),
											('0','Moruzzo','33030','UD'),
											('0','Moscazzano','26010','CR'),
											('0','Moschetta di Locri','89040','RC'),
											('0','Moschiano','83020','AV'),
											('0','Mosciano Sant\'Angelo','64023','TE'),
											('0','Moscufo','65010','PE'),
											('0','Mosio','46010','MN'),
											('0','Mosnigo','31010','TV'),
											('0','Moso in Passiria','39013','BZ'),
											('0','Mossa','34070','GO'),
											('0','Mossano','36024','VI'),
											('0','Mossini','23100','SO'),
											('0','Mosso Santa Maria','13822','BI'),
											('0','Mossorofa','89060','RC'),
											('0','Motta Baluffi','26045','CR'),
											('0','Motta Camastra','98030','ME'),
											('0','Motta d\'Affermo','98070','ME'),
											('0','Motta De\' Conti','13010','VC'),
											('0','Motta di Costigliole','14050','AT'),
											('0','Motta di Livenza','31045','TV'),
											('0','Motta Filocastro','89844','VV'),
											('0','Motta Montecorvino','71030','FG'),
											('0','Motta San Damiano','27010','PV'),
											('0','Motta San Giovanni','89065','RC'),
											('0','Motta Santa Lucia','88040','CZ'),
											('0','Motta Sant\'Anastasia','95040','CT'),
											('0','Motta sulla Secchia','41032','MO'),
											('0','Motta Visconti','20086','MI'),
											('0','Mottafollone','87010','CS'),
											('0','Mottalciata','13874','BI'),
											('0','Mottarone','28836','VB'),
											('0','Motteggiana','46020','MN'),
											('0','Motticella','89030','RC'),
											('0','Mottola','74017','TA'),
											('0','Mozzagrogna','66030','CH'),
											('0','Mozzanica','24050','BG'),
											('0','Mozzano','63040','AP'),
											('0','Mozzano','43020','PR'),
											('0','Mozzate','22076','CO'),
											('0','Mozzecane','37060','VR'),
											('0','Mozzo','24030','BG'),
											('0','Muccia','62034','MC'),
											('0','Mucignano','06010','PG'),
											('0','Mucinasso','29100','PC'),
											('0','Muffa','40056','BO'),
											('0','Mugarone','15042','AL'),
											('0','Muggia','34015','TS'),
											('0','Muggiano','19139','SP'),
											('0','Muggi','20053','MI'),
											('0','Mugnai','32030','BL'),
											('0','Mugnano','01020','VT'),
											('0','Mugnano','06076','PG'),
											('0','Mugnano del Cardinale','83027','AV'),
											('0','Mugnano di Napoli','80018','NA'),
											('0','Muhlbach','39037','BZ'),
											('0','Muhlwald','39030','BZ'),
											('0','Mulargia','08015','NU'),
											('0','Mulazzano','26837','LO'),
											('0','Mulazzano','43010','PR'),
											('0','Mulazzo','54026','MS'),
											('0','Mulino','41056','MO'),
											('0','Multedo','16155','GE'),
											('0','Mungivacca','70126','BA'),
											('0','Mura','25070','BS'),
											('0','Muraglia','61100','PU'),
											('0','Muraglione','61049','PU'),
											('0','Murano','30141','VE'),
											('0','Muravera','09043','CA'),
											('0','Murazzano','12060','CN'),
											('0','Murazzo','12040','CN'),
											('0','Murci','58050','GR'),
											('0','Murello','12030','CN'),
											('0','Murgia','70023','BA'),
											('0','Muriaglio','10080','TO'),
											('0','Murialdo','17013','SV'),
											('0','Muris di Ragogna','33030','UD'),
											('0','Muriscuv','08020','NU'),
											('0','Murisengo','15020','AL'),
											('0','Murlo','53016','SI'),
											('0','Muro Leccese','73036','LE'),
											('0','Muro Lucano','85054','PZ'),
											('0','Muros','07030','SS'),
											('0','Musano di Trevignano','31040','TV'),
											('0','Muscoline','25080','BS'),
											('0','Musei','09010','CA'),
											('0','Musellaro','65020','PE'),
											('0','Musestre','31050','TV'),
											('0','Musiara Inferiore','43028','PR'),
											('0','Musigliano','56023','PI'),
											('0','Musignano','01011','VT'),
											('0','Musile di Piave','30024','VE'),
											('0','Musocco','20151','MI'),
											('0','Musso','22010','CO'),
											('0','Mussolente','36065','VI'),
											('0','Mussomeli','93014','CL'),
											('0','Mussotto','12051','CN'),
											('0','Mutigliano','55100','LU'),
											('0','Mutignano','64038','TE'),
											('0','Muvruneddi','08020','NU'),
											('0','Muzzana del Turgnano','33055','UD'),
											('0','Muzzano','13895','BI'),
											('0','Nago','38060','TN'),
											('0','Nalles','39010','BZ'),
											('0','Nals','39010','BZ'),
											('0','Nanno','38010','TN'),
											('0','Nanto','36024','VI'),
											('0','Nao','89851','VV'),
											('0','Napola','91010','TP'),
											('0','Napoli','80100','NA'),
											('0','Napoli','80138','NA'),
											('0','Napoli','80133','NA'),
											('0','Napoli','80132','NA'),
											('0','Napoli','80123','NA'),
											('0','Napoli','80122','NA'),
											('0','Napoli','80121','NA'),
											('0','Napoli','80143','NA'),
											('0','Napoli','80142','NA'),
											('0','Napoli','80141','NA'),
											('0','Napoli','80139','NA'),
											('0','Napoli','80137','NA'),
											('0','Napoli','80136','NA'),
											('0','Napoli','80134','NA'),
											('0','Napoli','80135','NA'),
											('0','Napoli','80128','NA'),
											('0','Napoli','80129','NA'),
											('0','Narbolia','09070','OR'),
											('0','Narcao','09010','CA'),
											('0','Nard','73048','LE'),
											('0','Nardodipace','89824','VV'),
											('0','Narnali','59100','PO'),
											('0','Narni','05035','TR'),
											('0','Narni Stazione','05036','TR'),
											('0','Naro','92028','AG'),
											('0','Narzole','12068','CN'),
											('0','Nasca','21010','VA'),
											('0','Nasidi','98064','ME'),
											('0','Nasino','17030','SV'),
											('0','Naso','98074','ME'),
											('0','Natile','89030','RC'),
											('0','Naturno','39025','BZ'),
											('0','Naturns','39025','BZ'),
											('0','Natz Schabs','39040','BZ'),
											('0','Navacchio','56023','PI'),
											('0','Navazzo','25084','BS'),
											('0','Nave','25075','BS'),
											('0','Nave','33074','PN'),
											('0','Nave San Felice','38015','TN'),
											('0','Nave San Rocco','38010','TN'),
											('0','Navelli','67020','AQ'),
											('0','Naz Sciaves','39040','BZ'),
											('0','Nazzano','00060','RM'),
											('0','Ne','16040','GE'),
											('0','Nebbiano','60040','AN'),
											('0','Nebbiuno','28010','NO'),
											('0','Nebida','09010','CA'),
											('0','Negarine','37020','VR'),
											('0','Negrar','37024','VR'),
											('0','Negrisia','31047','TV'),
											('0','Neirone','16040','GE'),
											('0','Neive','12052','CN'),
											('0','Nembro','24027','BG'),
											('0','Nemi','00040','RM'),
											('0','Nemoli','85040','PZ'),
											('0','Neoneli','09080','OR'),
											('0','Nepezzano','64020','TE'),
											('0','Nepi','01036','VT'),
											('0','Nera Montoro','05027','TR'),
											('0','Nereto','64015','TE'),
											('0','Nerola','00017','RM'),
											('0','Nervesa della Battaglia','31040','TV'),
											('0','Nervi','16167','GE'),
											('0','Nerviano','20014','MI'),
											('0','Nese','24022','BG'),
											('0','Nesima Inferiore','95122','CT'),
											('0','Nesima Superiore','95122','CT'),
											('0','Nespoledo','33050','UD'),
											('0','Nespoli','47010','FC'),
											('0','Nespolo','02020','RI'),
											('0','Nesso','22020','CO'),
											('0','Netro','13896','BI'),
											('0','Nettuno','00048','RM'),
											('0','Neumarkt','39044','BZ'),
											('0','Neviano','73040','LE'),
											('0','Neviano De\' Rossi','43050','PR'),
											('0','Neviano degli Arduini','43024','PR'),
											('0','Neviglie','12050','CN'),
											('0','Niardo','25050','BS'),
											('0','Nibbia','28060','NO'),
											('0','Nibbiaia','57010','LI'),
											('0','Nibbiano','29010','PC'),
											('0','Nibbiola','28070','NO'),
											('0','Nibionno','23895','LC'),
											('0','Nicastro','','CZ'),
											('0','Niccioleta','58020','GR'),
											('0','Niccone','06010','PG'),
											('0','Nichelino','10042','TO'),
											('0','Nicola','19034','SP'),
											('0','Nicolosi','95030','CT'),
											('0','Nicorvo','27020','PV'),
											('0','Nicosia','94014','EN'),
											('0','Nicotera','89844','VV'),
											('0','Nidastore','60040','AN'),
											('0','Niederdorf','39039','BZ'),
											('0','Niederrasen','39030','BZ'),
											('0','Niella Belbo','12050','CN'),
											('0','Niella Tanaro','12060','CN'),
											('0','Nievole','51010','PT'),
											('0','Nigoline','25040','BS'),
											('0','Niguarda','20162','MI'),
											('0','Nimis','33045','UD'),
											('0','Niscemi','93015','CL'),
											('0','Nissoria','94010','EN'),
											('0','Niviano','41026','MO'),
											('0','Niviano Castello','29029','PC'),
											('0','Nizza di Sicilia','98026','ME'),
											('0','Nizza Monferrato','14049','AT'),
											('0','Noale','30033','VE'),
											('0','Noasca','10080','TO'),
											('0','Nocara','87070','CS'),
											('0','Nocchi','55063','LU'),
											('0','Nocciano','65010','PE'),
											('0','Nocelleto','81030','CE'),
											('0','Nocera Inferiore','84014','SA'),
											('0','Nocera Superiore','84015','SA'),
											('0','Nocera Terinese','88047','CZ'),
											('0','Nocera Umbra','06025','PG'),
											('0','Noceto','43015','PR'),
											('0','Noci','70015','BA'),
											('0','Nociazzi Inferiore','90020','PA'),
											('0','Nociglia','73020','LE'),
											('0','Nodica','56019','PI'),
											('0','Noepoli','85035','PZ'),
											('0','Nogara','37054','VR'),
											('0','Nogaredo','38060','TN'),
											('0','Nogarole Rocca','37060','VR'),
											('0','Nogarole Vicentino','36070','VI'),
											('0','Noha','73010','LE'),
											('0','Noicattaro','70016','BA'),
											('0','Nola','80035','NA'),
											('0','Nole','10076','TO'),
											('0','Noli','17026','SV'),
											('0','Nomaglio','10010','TO'),
											('0','Nomi','38060','TN'),
											('0','Nonantola','41015','MO'),
											('0','None','10060','TO'),
											('0','Nonio','28891','VB'),
											('0','Noragugume','08010','NU'),
											('0','Norbello','09070','OR'),
											('0','Norcen','32034','BL'),
											('0','Norcia','06046','PG'),
											('0','Norma','04010','LT'),
											('0','Nosate','20020','MI'),
											('0','Nosellari','38040','TN'),
											('0','Notaresco','64024','TE'),
											('0','Notaresco Stazione','64020','TE'),
											('0','Noto','96017','SR'),
											('0','Nova Levante','39056','BZ'),
											('0','Nova Milanese','20054','MI'),
											('0','Nova Ponente','39050','BZ'),
											('0','Nova Siri','75020','MT'),
											('0','Nova Siri Stazione','75020','MT'),
											('0','Novafeltria','61015','PU'),
											('0','Novalba','88060','CZ'),
											('0','Novale','36078','VI'),
											('0','Novaledo','38050','TN'),
											('0','Novalesa','10050','TO'),
											('0','Novara','28100','NO'),
											('0','Novara di Sicilia','98058','ME'),
											('0','Novate Mezzola','23025','SO'),
											('0','Novate Milanese','20026','MI'),
											('0','Nove','36055','VI'),
											('0','Nove','31010','TV'),
											('0','Novedrate','22060','CO'),
											('0','Novellara','42017','RE'),
											('0','Novello','12060','CN'),
											('0','Noventa di Piave','30020','VE'),
											('0','Noventa Padovana','35027','PD'),
											('0','Noventa Vicentina','36025','VI'),
											('0','Novi di Modena','41016','MO'),
											('0','Novi Ligure','15067','AL'),
											('0','Novi Velia','84060','SA'),
											('0','Noviglio','20082','MI'),
											('0','Novilara','61020','PU'),
											('0','Novoli','50127','FI'),
											('0','Novoli','73051','LE'),
											('0','Nozza','25078','BS'),
											('0','Nozzano','55050','LU'),
											('0','Nubia','91027','TP'),
											('0','Nucetto','12070','CN'),
											('0','Nuchis','07020','SS'),
											('0','Nuditta','08020','NU'),
											('0','Nughedu di San Nicol','07010','SS'),
											('0','Nughedu Santa Vittoria','09080','OR'),
											('0','Nugola','57010','LI'),
											('0','Nule','07010','SS'),
											('0','Nulvi','07032','SS'),
											('0','Numana','60026','AN'),
											('0','Numana Lido','60026','AN'),
											('0','Nunziata','95010','CT'),
											('0','Nuoro','08100','NU'),
											('0','Nuova Cliternia','86040','CB'),
											('0','Nuova Olonio','23020','SO'),
											('0','Nurachi','09070','OR'),
											('0','Nuragheddu','08020','NU'),
											('0','Nuragus','08030','NU'),
											('0','Nurallao','08030','NU'),
											('0','Nuraminis','09024','CA'),
											('0','Nuraxinieddu','09070','OR'),
											('0','Nureci','09080','OR'),
											('0','Nurri','08035','NU'),
											('0','Nus','11020','AO'),
											('0','Nusco','83051','AV'),
											('0','Nusenna','53010','SI'),
											('0','Nuvolato','46020','MN'),
											('0','Nuvolento','25080','BS'),
											('0','Nuvolera','25080','BS'),
											('0','Nuxis','09010','CA'),
											('0','Oberbozen','39059','BZ'),
											('0','Oberin','39050','BZ'),
											('0','Occhieppo Inferiore','13897','BI'),
											('0','Occhieppo Superiore','13898','BI'),
											('0','Occhiobello','45030','RO'),
											('0','Occimiano','15040','AL'),
											('0','Ocre','67040','AQ'),
											('0','Odalengo Grande','15020','AL'),
											('0','Odalengo Piccolo','15020','AL'),
											('0','Oderzo','31046','TV'),
											('0','Odolo','25076','BS'),
											('0','Ofena','67025','AQ'),
											('0','Offagna','60020','AN'),
											('0','Offanengo','26010','CR'),
											('0','Offida','63035','AP'),
											('0','Offlaga','25020','BS'),
											('0','Oggebbio','28824','VB'),
											('0','Oggiona Con Santo Stefano','21040','VA'),
											('0','Oggiono','23848','LC'),
											('0','Oglianico','10080','TO'),
											('0','Ogliara','84135','SA'),
											('0','Ogliastro Cilento','84061','SA'),
											('0','Ogliastro Marina','84060','SA'),
											('0','Ognina','95126','CT'),
											('0','Ognio','16030','GE'),
											('0','Olang','39030','BZ'),
											('0','Olba','17048','SV'),
											('0','Olbia','07026','SS'),
											('0','Olcenengo','13047','VC'),
											('0','Olda','24010','BG'),
											('0','Oldenico','13030','VC'),
											('0','Oleggio','28047','NO'),
											('0','Oleggio Castello','28040','NO'),
											('0','Olengo','28100','NO'),
											('0','Olevano di Lomellina','27020','PV'),
											('0','Olevano Romano','00035','RM'),
											('0','Olevano Sul Tusciano','84062','SA'),
											('0','Olgiate Comasco','22077','CO'),
											('0','Olgiate Molgora','23887','LC'),
											('0','Olgiate Olona','21057','VA'),
											('0','Olginate','23854','LC'),
											('0','Oliena','08025','NU'),
											('0','Olina','41026','MO'),
											('0','Oliosi','37014','VR'),
											('0','Oliva Gessi','27050','PV'),
											('0','Olivadi','88067','CZ'),
											('0','Olivarella','98040','ME'),
											('0','Oliveri','98060','ME'),
											('0','Oliveto Citra','84020','SA'),
											('0','Oliveto Lario','23865','LC'),
											('0','Oliveto Lucano','75010','MT'),
											('0','Olivetta San Michele','18030','IM'),
											('0','Olivola','15030','AL'),
											('0','Ollastra Simaxis','09084','OR'),
											('0','Olle','38051','TN'),
											('0','Ollolai','08020','NU'),
											('0','Ollomont','11010','AO'),
											('0','Olmedo','07040','SS'),
											('0','Olmeneta','26010','CR'),
											('0','Olmi','39040','BZ'),
											('0','Olmi','51038','PT'),
											('0','Olmi','66050','CH'),
											('0','Olmi di Treviso','31050','TV'),
											('0','Olmo','52040','AR'),
											('0','Olmo','36051','VI'),
											('0','Olmo Al Brembo','24010','BG'),
											('0','Olmo di Castagnole Lanze','14054','AT'),
											('0','Olmo di Martellago','30030','VE'),
											('0','Olmo Gentile','14050','AT'),
											('0','Oltre Il Colle','24013','BG'),
											('0','Oltresarca','38062','TN'),
											('0','Oltressenda Alta','24020','BG'),
											('0','Oltrona Al Lago','21026','VA'),
											('0','Oltrona San Mamette','22070','CO'),
											('0','Olzai','08020','NU'),
											('0','Omate','20041','MI'),
											('0','Ombriano','26013','CR'),
											('0','Ome','25050','BS'),
											('0','Omegna','28887','VB'),
											('0','Omignano','84060','SA'),
											('0','Omignano Stazione','84060','SA'),
											('0','Onani','08020','NU'),
											('0','Onano','01010','VT'),
											('0','Onara','35010','PD'),
											('0','Oncino','12030','CN'),
											('0','Oneglia','18100','IM'),
											('0','Oneta','24020','BG'),
											('0','Onferno','47855','RN'),
											('0','Onifai','08020','NU'),
											('0','Oniferi','08020','NU'),
											('0','Onigo','31050','TV'),
											('0','Onna','67020','AQ'),
											('0','Onno','23865','LC'),
											('0','Ono San Pietro','25040','BS'),
											('0','Onore','24020','BG'),
											('0','Onzo','17037','SV'),
											('0','Opera','20090','MI'),
											('0','Opi','67030','AQ'),
											('0','Oppeano','37050','VR'),
											('0','Oppido Lucano','85015','PZ'),
											('0','Oppido Mamertina','89014','RC'),
											('0','Ora','39040','BZ'),
											('0','Orani','08026','NU'),
											('0','Oratino','86010','CB'),
											('0','Orbassano','10043','TO'),
											('0','Orbetello','58015','GR'),
											('0','Orbetello Stazione','58016','GR'),
											('0','Orbignano','50059','FI'),
											('0','Orbignano','51035','PT'),
											('0','Orchi','81044','CE'),
											('0','Orciano di Pesaro','61038','PU'),
											('0','Orciano Pisano','56040','PI'),
											('0','Orciatico','56030','PI'),
											('0','Orco Feglino','17024','SV'),
											('0','Ordona','71040','FG'),
											('0','Oreno','','MI'),
											('0','Orentano','56020','PI'),
											('0','Orero','16015','GE'),
											('0','Orero','16040','GE'),
											('0','Orezzoli','29026','PC'),
											('0','Orfengo','28060','NO'),
											('0','Orgiano','36040','VI'),
											('0','Orgosolo','08027','NU'),
											('0','Oria','72024','BR'),
											('0','Oriago','30030','VE'),
											('0','Oricola','67063','AQ'),
											('0','Origgio','21040','VA'),
											('0','Orino','21030','VA'),
											('0','Orio Al Serio','24050','BG'),
											('0','Orio Canavese','10010','TO'),
											('0','Orio Litta','26863','LO'),
											('0','Oriola','47020','FC'),
											('0','Oriolo','87073','CS'),
											('0','Oriolo Romano','01010','VT'),
											('0','Oris','39020','BZ'),
											('0','Oristano','09170','OR'),
											('0','Ormea','12078','CN'),
											('0','Ormelle','31010','TV'),
											('0','Ornago','20060','MI'),
											('0','Ornano Grande','64040','TE'),
											('0','Ornavasso','28877','VB'),
											('0','Orneta','83030','AV'),
											('0','Ornica','24010','BG'),
											('0','Oropa','13813','BI'),
											('0','Orosei','08028','NU'),
											('0','Orotelli','08020','NU'),
											('0','Orria','84060','SA'),
											('0','Orroli','08030','NU'),
											('0','Orsago','31010','TV'),
											('0','Orsano e Cammoro','06030','PG'),
											('0','Orsara Bormida','15010','AL'),
											('0','Orsara di Puglia','71027','FG'),
											('0','Orsenigo','22030','CO'),
											('0','Orsigna','51020','PT'),
											('0','Orsogna','66036','CH'),
											('0','Orsomarso','87020','CS'),
											('0','Orta di Atella','81030','CE'),
											('0','Orta Nova','71045','FG'),
											('0','Orta Novarese','','NO'),
											('0','Orta San Giulio','28016','NO'),
											('0','Ortacesus','09040','CA'),
											('0','Orte','01028','VT'),
											('0','Orte Stazione','01029','VT'),
											('0','Ortelle','73030','LE'),
											('0','Ortezzano','63020','AP'),
											('0','Orti','15100','AL'),
											('0','Orti','89060','RC'),
											('0','Ortignano','52010','AR'),
											('0','Ortisei','39046','BZ'),
											('0','Ortodonico','84060','SA'),
											('0','Ortolano','67010','AQ'),
											('0','Ortona','66026','CH'),
											('0','Ortona dei Marsi','67050','AQ'),
											('0','Ortona Foro','66027','CH'),
											('0','Ortona Porto','66028','CH'),
											('0','Ortonovo','19034','SP'),
											('0','Ortovero','17037','SV'),
											('0','Ortucchio','67050','AQ'),
											('0','Ortueri','08036','NU'),
											('0','Orune','08020','NU'),
											('0','Orvieto','05018','TR'),
											('0','Orvieto Stazione','05019','TR'),
											('0','Orvinio','02035','RI'),
											('0','Orzinuovi','25034','BS'),
											('0','Orzivecchi','25030','BS'),
											('0','Osasco','10060','TO'),
											('0','Osasio','10040','TO'),
											('0','Oschiri','07027','SS'),
											('0','Osidda','08020','NU'),
											('0','Osiglia','17010','SV'),
											('0','Osilo','07033','SS'),
											('0','Osimo','60027','AN'),
											('0','Osimo Stazione','60028','AN'),
											('0','Osini','08040','NU'),
											('0','Osio Sopra','24040','BG'),
											('0','Osio Sotto','24046','BG'),
											('0','Oslavia','34070','GO'),
											('0','Osmannoro','50019','FI'),
											('0','Osmate Lentate','21018','VA'),
											('0','Osnago','23875','LC'),
											('0','Osoppo','33010','UD'),
											('0','Ospedaletti','18014','IM'),
											('0','Ospedaletto','38050','TN'),
											('0','Ospedaletto','05010','TR'),
											('0','Ospedaletto d\'Alpinolo','83014','AV'),
											('0','Ospedaletto di Gemona','33013','UD'),
											('0','Ospedaletto di Rimini','47852','RN'),
											('0','Ospedaletto Euganeo','35045','PD'),
											('0','Ospedaletto Lodigiano','26864','LO'),
											('0','Ospedalicchio di Bastia Umbra','06080','PG'),
											('0','Ospital Monacale','44010','FE'),
											('0','Ospitale','44012','FE'),
											('0','Ospitale di Cadore','32010','BL'),
											('0','Ospitale nel Frignano','41021','MO'),
											('0','Ospitaletto','41054','MO'),
											('0','Ospitaletto','20032','MI'),
											('0','Ospitaletto','25035','BS'),
											('0','Ospitaletto Mantovano','46010','MN'),
											('0','Ospizio','42100','RE'),
											('0','Ossago','26816','LO'),
											('0','Ossana','38026','TN'),
											('0','Ossi','07045','SS'),
											('0','Ossimo Inferiore','25050','BS'),
											('0','Ossimo Superiore','25050','BS'),
											('0','Ossona','20010','MI'),
											('0','Ossuccio','22010','CO'),
											('0','Ostana','12030','CN'),
											('0','Oste','59013','PO'),
											('0','Ostellato','44020','FE'),
											('0','Osteria della Fontana','03012','FR'),
											('0','Osteria Grande','40060','BO'),
											('0','Osteria Nuova','50012','FI'),
											('0','Osteria Nuova','02030','RI'),
											('0','Ostia Antica','00119','RM'),
											('0','Ostia di Borgo Val di Taro','43040','PR'),
											('0','Ostiano','26032','CR'),
											('0','Ostiglia','46035','MN'),
											('0','Ostigliano','84060','SA'),
											('0','Ostra','60010','AN'),
											('0','Ostra Vetere','60010','AN'),
											('0','Ostuni','72017','BR'),
											('0','Osulai','08040','NU'),
											('0','Otranto','73028','LE'),
											('0','Otricoli','05030','TR'),
											('0','Ottana','08020','NU'),
											('0','Ottati','84020','SA'),
											('0','Ottaviano','80044','NA'),
											('0','Ottiglio','15038','AL'),
											('0','Ottiolu','08020','NU'),
											('0','Ottobiano','27030','PV'),
											('0','Ottone','29026','PC'),
											('0','Oulx','10056','TO'),
											('0','Ovada','15076','AL'),
											('0','Ovaro','33025','UD'),
											('0','Oved','08020','NU'),
											('0','Oviglio','15026','AL'),
											('0','Ovindoli','67046','AQ'),
											('0','Ovodda','08020','NU'),
											('0','Oyace','11010','AO'),
											('0','Ozegna','10080','TO'),
											('0','Ozieri','07014','SS'),
											('0','Ozzano Dell\'Emilia','40064','BO'),
											('0','Ozzano Monferrato','15039','AL'),
											('0','Ozzano Taro','43046','PR'),
											('0','Ozzero','20080','MI'),
											('0','Pabillonis','09030','CA'),
											('0','Pace','02020','RI'),
											('0','Pace','98167','ME'),
											('0','Pace del Mela','98042','ME'),
											('0','Paceco','91027','TP'),
											('0','Pacengo','37010','VR'),
											('0','Pacentro','67030','AQ'),
											('0','Pachino','96018','SR'),
											('0','Paciano','06060','PG'),
											('0','Paciug','33040','UD'),
											('0','Padenghe Sul Garda','25080','BS'),
											('0','Padergnone','38070','TN'),
											('0','Paderna','15050','AL'),
											('0','Padernello','25022','BS'),
											('0','Padernello','31038','TV'),
											('0','Paderno','32030','BL'),
											('0','Paderno','40136','BO'),
											('0','Paderno d\'Adda','23877','LC'),
											('0','Paderno del Grappa','31017','TV'),
											('0','Paderno Dugnano','20037','MI'),
											('0','Paderno Franciacorta','25050','BS'),
											('0','Paderno Ponchielli','26024','CR'),
											('0','Padivarma','19020','SP'),
											('0','Padola','32040','BL'),
											('0','Padova','35100','PD'),
											('0','Padria','07015','SS'),
											('0','Padru','07020','SS'),
											('0','Padula','64040','TE'),
											('0','Padula','84034','SA'),
											('0','Padula Scalo','84030','SA'),
											('0','Padule','06020','PG'),
											('0','Paduli','82020','BN'),
											('0','Padulle','40010','BO'),
											('0','Paesana','12034','CN'),
											('0','Paese','31038','TV'),
											('0','Paestum','84063','SA'),
											('0','Pagani','84016','SA'),
											('0','Paganica','67016','AQ'),
											('0','Paganico','58048','GR'),
											('0','Paganico Sabino','02020','RI'),
											('0','Pagazzano','24040','BG'),
											('0','Paggese','63041','AP'),
											('0','Pagliara','82010','BN'),
											('0','Pagliara','83040','AV'),
											('0','Pagliara','98020','ME'),
											('0','Pagliara dei Marsi','67050','AQ'),
											('0','Pagliare','67018','AQ'),
											('0','Pagliare','63036','AP'),
											('0','Pagliarelle','88837','KR'),
											('0','Pagliaroli','64040','TE'),
											('0','Paglieta','66020','CH'),
											('0','Pagnacco','33010','UD'),
											('0','Pagno','12030','CN'),
											('0','Pagnona','23833','LC'),
											('0','Pago del Vallo di Lauro','83020','AV'),
											('0','Pago Veiano','82020','BN'),
											('0','Paina','20030','MI'),
											('0','Paisco','25051','BS'),
											('0','Paitone','25080','BS'),
											('0','Paladina','24030','BG'),
											('0','Palagano','41046','MO'),
											('0','Palagianello','74018','TA'),
											('0','Palagiano','74019','TA'),
											('0','Palagnana','55060','LU'),
											('0','Palagonia','95046','CT'),
											('0','Palaia','56036','PI'),
											('0','Palanzano','43025','PR'),
											('0','Palata','86037','CB'),
											('0','Palata Pepoli','40010','BO'),
											('0','Palau','07020','SS'),
											('0','Palazzago','24030','BG'),
											('0','Palazzisi','83030','AV'),
											('0','Palazzo Adriano','90030','PA'),
											('0','Palazzo Canavese','10010','TO'),
											('0','Palazzo d\'Arcevia','60010','AN'),
											('0','Palazzo d\'Assisi','06080','PG'),
											('0','Palazzo del Pero','52030','AR'),
											('0','Palazzo Pignano','26020','CR'),
											('0','Palazzo San Gervasio','85026','PZ'),
											('0','Palazzolo','37010','VR'),
											('0','Palazzolo Acreide','96010','SR'),
											('0','Palazzolo Dello Stella','33056','UD'),
											('0','Palazzolo Milanese','20030','MI'),
											('0','Palazzolo Sull\'Oglio','25036','BS'),
											('0','Palazzolo Vercellese','13040','VC'),
											('0','Palazzone','53040','SI'),
											('0','Palazzuolo','52048','AR'),
											('0','Palazzuolo Sul Senio','50035','FI'),
											('0','Pale','06030','PG'),
											('0','Palena','66017','CH'),
											('0','Palermiti','88050','CZ'),
											('0','Palermo','90100','PA'),
											('0','Palermo','90144','PA'),
											('0','Palermo','90127','PA'),
											('0','Palermo','90129','PA'),
											('0','Palermo','90133','PA'),
											('0','Palermo','90134','PA'),
											('0','Palermo','90135','PA'),
											('0','Palermo','90147','PA'),
											('0','Palermo','90139','PA'),
											('0','Palermo','90149','PA'),
											('0','Palermo','90141','PA'),
											('0','Palermo','90142','PA'),
											('0','Palermo','90143','PA'),
											('0','Palermo','90145','PA'),
											('0','Palermo','90123','PA'),
											('0','Palermo','90124','PA'),
											('0','Palermo','90125','PA'),
											('0','Palermo','90138','PA'),
											('0','Palermo','90128','PA'),
											('0','Palermo','90132','PA'),
											('0','Palermo','90136','PA'),
											('0','Palermo','90137','PA'),
											('0','Palermo','90126','PA'),
											('0','Palese','70057','BA'),
											('0','Palestrina','00036','RM'),
											('0','Palestro','27030','PV'),
											('0','Paliano','03018','FR'),
											('0','Palidano','46020','MN'),
											('0','Palinuro','84064','SA'),
											('0','Palizzi','89030','RC'),
											('0','Pallagorio','88818','KR'),
											('0','Pallanza','','VB'),
											('0','Pallanzeno','28884','VB'),
											('0','Pallare','17043','SV'),
											('0','Pallerone','54020','MS'),
											('0','Palleroso','55032','LU'),
											('0','Palma Campania','80036','NA'),
											('0','Palma di Montechiaro','92020','AG'),
											('0','Palmadula','07040','SS'),
											('0','Palmanova','33057','UD'),
											('0','Palmariggi','73020','LE'),
											('0','Palmaro di Pr','16157','GE'),
											('0','Palmas Arborea','09090','OR'),
											('0','Palmi','89015','RC'),
											('0','Palmiano','63049','AP'),
											('0','Palmoli','66050','CH'),
											('0','Palmori','71030','FG'),
											('0','Palo','17046','SV'),
											('0','Palo','00055','RM'),
											('0','Palo del Colle','70027','BA'),
											('0','Palombaio','70036','BA'),
											('0','Palombara Sabina','00018','RM'),
											('0','Palombaro','66010','CH'),
											('0','Palombina','60020','AN'),
											('0','Palomonte','84020','SA'),
											('0','Palosco','24050','BG'),
											('0','Pal','37050','VR'),
											('0','Pal del Fersina','38050','TN'),
											('0','Paludi','87060','CS'),
											('0','Paluello','30039','VE'),
											('0','Paluzza','33026','UD'),
											('0','Pamparato','12087','CN'),
											('0','Panaia','89864','VV'),
											('0','Panarea','98050','ME'),
											('0','Pancalieri','10060','TO'),
											('0','Pancarana','27050','PV'),
											('0','Panchi','38030','TN'),
											('0','Pancole','58050','GR'),
											('0','Pandino','26025','CR'),
											('0','Pandola','84085','SA'),
											('0','Panettieri','87050','CS'),
											('0','Paneveggio','38037','TN'),
											('0','Panicaglia','50030','FI'),
											('0','Panicale','06064','PG'),
											('0','Panicarola','06060','PG'),
											('0','Pannaconi','89816','VV'),
											('0','Pannarano','82017','BN'),
											('0','Panni','71020','FG'),
											('0','Pannone','','TN'),
											('0','Pantalla','06050','PG'),
											('0','Pantano','42033','RE'),
											('0','Pantano','61100','PU'),
											('0','Pantano','85010','PZ'),
											('0','Pantano','06070','PG'),
											('0','Pantano di Grano','00057','RM'),
											('0','Pantano di Teggiano','84030','SA'),
											('0','Pantelleria','91017','TP'),
											('0','Pantelleria Aeroporto','91010','TP'),
											('0','Pantigliate','20090','MI'),
											('0','Pantuliano','81050','CE'),
											('0','Panza','80070','NA'),
											('0','Panzano','41011','MO'),
											('0','Panzano','50020','FI'),
											('0','Paola','87027','CS'),
											('0','Paola Marina','87027','CS'),
											('0','Paola Santuario','87027','CS'),
											('0','Paolantonio','64016','TE'),
											('0','Paolini','91020','TP'),
											('0','Paolisi','82011','BN'),
											('0','Papanice','88843','KR'),
											('0','Papasidero','87020','CS'),
											('0','Paperino','59100','PO'),
											('0','Papiano','06050','PG'),
											('0','Papiano','52017','AR'),
											('0','Papigno','05037','TR'),
											('0','Papozze','45010','RO'),
											('0','Para','47014','FC'),
											('0','Parabiago','20015','MI'),
											('0','Parabita','73052','LE'),
											('0','Paradigna','43100','PR'),
											('0','Paraggi','16038','GE'),
											('0','Paratico','25030','BS'),
											('0','Paravati','89852','VV'),
											('0','Parazzuolo','16040','GE'),
											('0','Parcines','39020','BZ'),
											('0','Parco Delle Acacie','80020','NA'),
											('0','Pardesca','89032','RC'),
											('0','Pardu Nou','09070','OR'),
											('0','Par','22020','CO'),
											('0','Parella','10010','TO'),
											('0','Parenti','87040','CS'),
											('0','Parete','81030','CE'),
											('0','Pareto','15010','AL'),
											('0','Parghelia','89861','VV'),
											('0','Pari','58040','GR'),
											('0','Parisi','70022','BA'),
											('0','Parlasco','23837','LC'),
											('0','Parlesca','06080','PG'),
											('0','Parma','43100','PR'),
											('0','Parodi Ligure','15060','AL'),
											('0','Parola','43030','PR'),
											('0','Paroldo','12070','CN'),
											('0','Parolise','83050','AV'),
											('0','Parona','27020','PV'),
											('0','Parona di Valpolicella','37025','VR'),
											('0','Parrana San Giusto','57010','LI'),
											('0','Parrana San Martino','57010','LI'),
											('0','Parrano','05010','TR'),
											('0','Parre Ponte Selva','24020','BG'),
											('0','Partanna','91028','TP'),
											('0','Partanna Mondello','90151','PA'),
											('0','Partina','52010','AR'),
											('0','Partinico','90047','PA'),
											('0','Partino','56036','PI'),
											('0','Partschins','39020','BZ'),
											('0','Paruzzaro','28040','NO'),
											('0','Parzanica','24060','BG'),
											('0','Pascarola','80023','NA'),
											('0','Pascellata','64010','TE'),
											('0','Pascelupo','06020','PG'),
											('0','Pascomonti','12084','CN'),
											('0','Pascoso','55060','LU'),
											('0','Pasian di Prato','33037','UD'),
											('0','Pasiano di Pordenone','33087','PN'),
											('0','Paspardo','25050','BS'),
											('0','Passaggio di Bettona','06080','PG'),
											('0','Passalacqua','15057','AL'),
											('0','Passarella','30020','VE'),
											('0','Passatempo','60020','AN'),
											('0','Passatore','12020','CN'),
											('0','Passerano','14020','AT'),
											('0','Passetto','45011','RO'),
											('0','Passiano','84010','SA'),
											('0','Passignano Sul Trasimeno','06065','PG'),
											('0','Passirano','25050','BS'),
											('0','Passo Corese','02036','RI'),
											('0','Passo Costalunga','38030','TN'),
											('0','Passo dei Pecorai','50020','FI'),
											('0','Passo del Bocco','16040','GE'),
											('0','Passo del Tonale','38020','TN'),
											('0','Passo di Mirabella','83030','AV'),
											('0','Passo di Ripe','60010','AN'),
											('0','Passo di Treia','62010','MC'),
											('0','Passo Oscuro','00050','RM'),
											('0','Passo Penice','29020','PC'),
											('0','Passo Rolle','38037','TN'),
											('0','Passo San Ginesio','62026','MC'),
											('0','Passo Stelvio','23032','SO'),
											('0','Passogatto','48028','RA'),
											('0','Passopisciaro','95030','CT'),
											('0','Pastena','03020','FR'),
											('0','Pastena di Salerno','84128','SA'),
											('0','Pastene','82100','BN'),
											('0','Pasteria','95010','CT'),
											('0','Pastina','56040','PI'),
											('0','Pastine di Pontecorvo','03037','FR'),
											('0','Pastorano','81050','CE'),
											('0','Pastorello','43010','PR'),
											('0','Pastrengo','37010','VR'),
											('0','Pasturana','15060','AL'),
											('0','Pasturo','23818','LC'),
											('0','Paterno','67050','AQ'),
											('0','Patern','95047','CT'),
											('0','Paterno Calabro','87040','CS'),
											('0','Paterno di Ancona','60020','AN'),
											('0','Paterno di Lucania','85050','PZ'),
											('0','Paternopoli','83052','AV'),
											('0','Patinedda','08020','NU'),
											('0','Patrica','03010','FR'),
											('0','Patrignone','63034','AP'),
											('0','Pattada','07016','SS'),
											('0','Pattano','84060','SA'),
											('0','Patti','98066','ME'),
											('0','Pat','73053','LE'),
											('0','Pau','09090','OR'),
											('0','Paularo','33027','UD'),
											('0','Pauli Arbarei','09020','CA'),
											('0','Paulilatino','09070','OR'),
											('0','Paullo','20067','MI'),
											('0','Paullo di Casina','42020','RE'),
											('0','Paupisi','82030','BN'),
											('0','Pavana Pistoiese','51020','PT'),
											('0','Pavarolo','10020','TO'),
											('0','Pavia','27100','PV'),
											('0','Pavia di Udine','33050','UD'),
											('0','Pavicolo','39010','BZ'),
											('0','Pavignano','13842','BI'),
											('0','Pavignone','41038','MO'),
											('0','Pavona','00040','RM'),
											('0','Pavona Stazione','00040','RM'),
											('0','Pavone Canavese','10018','TO'),
											('0','Pavone d\'Alessandria','15040','AL'),
											('0','Pavone del Mella','25020','BS'),
											('0','Pavullo nel Frignano','41026','MO'),
											('0','Pawigl','39010','BZ'),
											('0','Pazzano','41028','MO'),
											('0','Pazzano','89040','RC'),
											('0','Peccioli','56037','PI'),
											('0','Pecco','10080','TO'),
											('0','Pecetto di Valenza','15040','AL'),
											('0','Pecetto Torinese','10020','TO'),
											('0','Pecorara','29010','PC'),
											('0','Pecorile','42020','RE'),
											('0','Pecorini a Mare','98050','ME'),
											('0','Pecorone','85044','PZ'),
											('0','Pedace','87050','CS'),
											('0','Pedagaggi','96010','SR'),
											('0','Pedali di Viggianello','85040','PZ'),
											('0','Pedalino','97010','RG'),
											('0','Pedara','95030','CT'),
											('0','Pedaso','63016','AP'),
											('0','Pedavena','32034','BL'),
											('0','Pedeguarda','31050','TV'),
											('0','Pedemonte','28883','VB'),
											('0','Pedemonte','36040','VI'),
											('0','Pedemonte','37020','VR'),
											('0','Pedergnaga-Oriano','25020','BS'),
											('0','Pederoa','39030','BZ'),
											('0','Pederobba','31040','TV'),
											('0','Pedescala','36040','VI'),
											('0','Pedesina','23010','SO'),
											('0','Pedivigliano','87050','CS'),
											('0','Pedona','55040','LU'),
											('0','Pedra e Cupa','08020','NU'),
											('0','Pedraces','39036','BZ'),
											('0','Pedrengo','24066','BG'),
											('0','Pedriano','20098','MI'),
											('0','Pegazzano','19123','SP'),
											('0','Peghera','24010','BG'),
											('0','Pegli','16155','GE'),
											('0','Peglio','61049','PU'),
											('0','Peglio','22010','CO'),
											('0','Pegognaga','46020','MN'),
											('0','Pegola','40051','BO'),
											('0','Pei','29020','PC'),
											('0','Peia','24020','BG'),
											('0','Pejo','38020','TN'),
											('0','Pelago','50060','FI'),
											('0','Pella','28010','NO'),
											('0','Pellaloco','46048','MN'),
											('0','Pellare','84060','SA'),
											('0','Pellaro','89066','RC'),
											('0','Pellegrina','37060','VR'),
											('0','Pellegrina','89010','RC'),
											('0','Pellegrino','98040','ME'),
											('0','Pellegrino Parmense','43047','PR'),
											('0','Pellestrina','30010','VE'),
											('0','Pellezzano','84080','SA'),
											('0','Pellio Intelvi','22020','CO'),
											('0','Pellizzano','38020','TN'),
											('0','Pelos','32040','BL'),
											('0','Pelugo','38088','TN'),
											('0','Penango','14030','AT'),
											('0','Penna in Teverina','05028','TR'),
											('0','Penna San Giovanni','62020','MC'),
											('0','Penna Sant\'Andrea','64039','TE'),
											('0','Pennabilli','61016','PU'),
											('0','Pennadomo','66040','CH'),
											('0','Pennapiedimonte','66010','CH'),
											('0','Penne','65017','PE'),
											('0','Penta','84080','SA'),
											('0','Pentedattilo','89060','RC'),
											('0','Pentone','88050','CZ'),
											('0','Penzale','44042','FE'),
											('0','Pera di Fassa','38030','TN'),
											('0','Perano','66040','CH'),
											('0','Perarolo','35010','PD'),
											('0','Perarolo di Cadore','32010','BL'),
											('0','Perca','39030','BZ'),
											('0','Percha','39030','BZ'),
											('0','Percile','00020','RM'),
											('0','Percoto','33050','UD'),
											('0','Perdasdefogu','08046','NU'),
											('0','Perdaxius','09010','CA'),
											('0','Perdifumo','84060','SA'),
											('0','Peregallo','20050','MI'),
											('0','Perego','23888','LC'),
											('0','Pereta','58050','GR'),
											('0','Pereto','67064','AQ'),
											('0','Peretola','50145','FI'),
											('0','Perfugas','07034','SS'),
											('0','Pergine Valdarno','52020','AR'),
											('0','Pergine Valsugana','38057','TN'),
											('0','Pergola','61045','PU'),
											('0','Pergola','85050','PZ'),
											('0','Pergusa','94010','EN'),
											('0','Peri','37020','VR'),
											('0','Periasc','11020','AO'),
											('0','Perignano','56030','PI'),
											('0','Perinaldo','18032','IM'),
											('0','Perino','29020','PC'),
											('0','Perito','84060','SA'),
											('0','Perledo','23828','LC'),
											('0','Perletto','12074','CN'),
											('0','Perlo','12070','CN'),
											('0','Perloz','11020','AO'),
											('0','Pernate','28067','NO'),
											('0','Perno','12060','CN'),
											('0','Pernocari','89841','VV'),
											('0','Pernumia','35020','PD'),
											('0','Pero','17019','SV'),
											('0','Pero','20016','MI'),
											('0','Pero dei Santi','67050','AQ'),
											('0','Perosa Argentina','10063','TO'),
											('0','Perosa Canavese','10010','TO'),
											('0','Peroulaz','11020','AO'),
											('0','Perrazze','84020','SA'),
											('0','Perrero','10060','TO'),
											('0','Perrillo','82100','BN'),
											('0','Persano','84023','SA'),
											('0','Persico Dosimo','26043','CR'),
											('0','Pertegada','33050','UD'),
											('0','Pertengo','13030','VC'),
											('0','Perteole','33040','UD'),
											('0','Pertica Alta','25070','BS'),
											('0','Pertica Bassa','25078','BS'),
											('0','Perticani','06034','PG'),
											('0','Perticano','60040','AN'),
											('0','Perticara','61017','PU'),
											('0','Perticaro','88823','KR'),
											('0','Perticato','22066','CO'),
											('0','Pertosa','84030','SA'),
											('0','Pertusio','10080','TO'),
											('0','Perugia','06100','PG'),
											('0','Perugia','06125','PG'),
											('0','Perugia','06122','PG'),
											('0','Perugia','06121','PG'),
											('0','Perugia','06123','PG'),
											('0','Perugia Stazione','06124','PG'),
											('0','Perzacco','37059','VR'),
											('0','Pesariis','33020','UD'),
											('0','Pesaro','61100','PU'),
											('0','Pescaglia','55064','LU'),
											('0','Pescantina','37026','VR'),
											('0','Pescara','65100','PE'),
											('0','Pescara Colli','65125','PE'),
											('0','Pescara del Tronto','63043','AP'),
											('0','Pescarolo','26033','CR'),
											('0','Pescasseroli','67032','AQ'),
											('0','Pescate','23855','LC'),
											('0','Pesche','86090','IS'),
											('0','Peschici','71010','FG'),
											('0','Peschiera Borromeo','20068','MI'),
											('0','Peschiera del Garda','37019','VR'),
											('0','Peschiera Maraglio','25050','BS'),
											('0','Peschieta','02020','RI'),
											('0','Pescia','51017','PT'),
											('0','Pescia Romana','01010','VT'),
											('0','Pescina','67057','AQ'),
											('0','Pesco Sannita','82020','BN'),
											('0','Pescocanale di Capistrello','67050','AQ'),
											('0','Pescocostanzo','67033','AQ'),
											('0','Pescolanciano','86097','IS'),
											('0','Pesconuovo','65020','PE'),
											('0','Pescopagano','85020','PZ'),
											('0','Pescopennataro','86080','IS'),
											('0','Pescorocchiano','02024','RI'),
											('0','Pescosansonesco','65020','PE'),
											('0','Pescosolido','03030','FR'),
											('0','Peseggia','30030','VE'),
											('0','Pesina','37010','VR'),
											('0','Pessano Con Bornago','20060','MI'),
											('0','Pessina Cremonese','26030','CR'),
											('0','Pessinetto','10070','TO'),
											('0','Pessione','10020','TO'),
											('0','Pessola','43040','PR'),
											('0','Pestarena','28878','VB'),
											('0','Petacciato','86038','CB'),
											('0','Petesberg','39040','BZ'),
											('0','Petilia Policastro','88837','KR'),
											('0','Petina','84020','SA'),
											('0','Petosino','24010','BG'),
											('0','Petralia Soprana','90026','PA'),
											('0','Petralia Sottana','90027','PA'),
											('0','Petrazzi','50051','FI'),
											('0','Petrella Liri','67060','AQ'),
											('0','Petrella Salto','02025','RI'),
											('0','Petrella Tifernina','86024','CB'),
											('0','Petrelle','06010','PG'),
											('0','Petriano','61020','PU'),
											('0','Petricci','58050','GR'),
											('0','Petrignano d\'Assisi','06086','PG'),
											('0','Petrignano del Lago','06060','PG'),
											('0','Petriolo','62014','MC'),
											('0','Petritoli','63027','AP'),
											('0','Petrizia','88070','CZ'),
											('0','Petrizzi','88060','CZ'),
											('0','Petroia','06010','PG'),
											('0','Petroio','53020','SI'),
											('0','Petron','88050','CZ'),
											('0','Petrosino','91020','TP'),
											('0','Petrulli','71010','FG'),
											('0','Petrullo','81042','CE'),
											('0','Petruro','83020','AV'),
											('0','Petruro Irpino','83010','AV'),
											('0','Pettenasco','28028','NO'),
											('0','Pettinengo','13843','BI'),
											('0','Pettineo','98070','ME'),
											('0','Pettoranello del Molise','86090','IS'),
											('0','Pettorano Sul Gizio','67034','AQ'),
											('0','Pettorazza','45010','RO'),
											('0','Peveragno','12016','CN'),
											('0','Pezzana','13010','VC'),
											('0','Pezzaze','25060','BS'),
											('0','Pezze di Greco','72010','BR'),
											('0','Pezzo di Villa San Giovanni','89010','RC'),
											('0','Pezzolo','98138','ME'),
											('0','Pezzolo Valle Uzzone','12070','CN'),
											('0','Pfalzen','39030','BZ'),
											('0','Pfatten','39051','BZ'),
											('0','Pfelders','39010','BZ'),
											('0','Pfitsch','39040','BZ'),
											('0','Piacenza','29100','PC'),
											('0','Piacenza d\'Adige','35040','PD'),
											('0','Piadena','26034','CR'),
											('0','Piagge','61030','PU'),
											('0','Piagge di Ascoli Piceno','63100','AP'),
											('0','Piaggia','18025','IM'),
											('0','Piaggine','84065','SA'),
											('0','Piaggione','55050','LU'),
											('0','Piampaludo','17048','SV'),
											('0','Pian Camuno','25050','BS'),
											('0','Pian dei Ratti','16040','GE'),
											('0','Pian di Borno','25052','BS'),
											('0','Pian di Casale','40046','BO'),
											('0','Pian di Pieca','62026','MC'),
											('0','Pian di San Martino','06050','PG'),
											('0','Pian di Sco','52026','AR'),
											('0','Piana','36078','VI'),
											('0','Piana Battolla','19020','SP'),
											('0','Piana Crixia','17058','SV'),
											('0','Piana degli Albanesi','90037','PA'),
											('0','Piana di Capo d\'Orlando','98070','ME'),
											('0','Piana di Cerchiara','87070','CS'),
											('0','Piana di Monte Verna','81013','CE'),
											('0','Pianaccio','40042','BO'),
											('0','Pianazzo','23020','SO'),
											('0','Piancaldoli','50030','FI'),
											('0','Piancarani','64010','TE'),
											('0','Piancastagnaio','53025','SI'),
											('0','Pianceri','13867','BI'),
											('0','Pianche','12010','CN'),
											('0','Piancogno','25052','BS'),
											('0','Piandelagotti','41047','MO'),
											('0','Piandicastello','61020','PU'),
											('0','Piandifieno','16040','GE'),
											('0','Piandimeleto','61026','PU'),
											('0','Piane Crati','87050','CS'),
											('0','Piane d\'Archi','66044','CH'),
											('0','Piane di Falerone','63020','AP'),
											('0','Piane di Montegiorgio','63025','AP'),
											('0','Pianella','53010','SI'),
											('0','Pianella','65019','PE'),
											('0','Pianello','61040','PU'),
											('0','Pianello','06080','PG'),
											('0','Pianello del Lario','22010','CO'),
											('0','Pianello di Ostra','60010','AN'),
											('0','Pianello di Petralia Sottana','90020','PA'),
											('0','Pianello Val Tidone','29010','PC'),
											('0','Pianello Vallesina','60030','AN'),
											('0','Pianengo','26010','CR'),
											('0','Pianezza','10044','TO'),
											('0','Pianezze','31049','TV'),
											('0','Pianezze','13821','BI'),
											('0','Pianezze San Lorenzo','36060','VI'),
											('0','Pianfei','12080','CN'),
											('0','Piangipane','48020','RA'),
											('0','Piani di Borghetto','18012','IM'),
											('0','Pianico','24060','BG'),
											('0','Pianiga','30030','VE'),
											('0','Piano d\'Api','95020','CT'),
											('0','Piano d\'Arci','95030','CT'),
											('0','Piano d\'Arta','33022','UD'),
											('0','Piano degli Ontani','51020','PT'),
											('0','Piano dei Peri','85049','PZ'),
											('0','Piano del Conte','85020','PZ'),
											('0','Piano del Voglio','40048','BO'),
											('0','Piano di Coreglia','55028','LU'),
											('0','Piano di Mommio','55040','LU'),
											('0','Piano di Setta','40030','BO'),
											('0','Piano di Sorrento','80063','NA'),
											('0','Piano d\'Orria','84060','SA'),
											('0','Piano d\'Orta','65020','PE'),
											('0','Piano Lago','87050','CS'),
											('0','Piano Porlezza','22010','CO'),
											('0','Piano Regolatore','83044','AV'),
											('0','Piano San Nicola','85020','PZ'),
											('0','Piano Tavola','95045','CT'),
											('0','Piano Vetrale','84060','SA'),
											('0','Pianoconte','98050','ME'),
											('0','Pianopoli','88040','CZ'),
											('0','Pianoro','40065','BO'),
											('0','Pianoro Vecchio','40060','BO'),
											('0','Pianorso','41023','MO'),
											('0','Pianosa Isola','57035','LI'),
											('0','Pianosinatico','51020','PT'),
											('0','Piansano','01010','VT'),
											('0','Pianta','47100','FC'),
											('0','Piantamelon','45011','RO'),
											('0','Piantedo','23010','SO'),
											('0','Piantonia','43040','PR'),
											('0','Pianura','80126','NA'),
											('0','Pianura','86078','IS'),
											('0','Pianventena','47842','RN'),
											('0','Pianzano','31010','TV'),
											('0','Piario','24020','BG'),
											('0','Piasco','12026','CN'),
											('0','Piastre','51020','PT'),
											('0','Piateda','23020','SO'),
											('0','Piatto','13844','BI'),
											('0','Piavola','47020','FC'),
											('0','Piavon','31046','TV'),
											('0','Piazza','51020','PT'),
											('0','Piazza Al Serchio','55035','LU'),
											('0','Piazza Armerina','94015','EN'),
											('0','Piazza Brembana','24014','BG'),
											('0','Piazza del Galdo','84080','SA'),
											('0','Piazza di Pandola','83020','AV'),
											('0','Piazzano di Atessa','66040','CH'),
											('0','Piazzatorre','24010','BG'),
											('0','Piazze','53040','SI'),
											('0','Piazzola Sul Brenta','35016','PD'),
											('0','Piazzolla','80037','NA'),
											('0','Piazzolo','24010','BG'),
											('0','Picanello','95127','CT'),
											('0','Picarelli','83010','AV'),
											('0','Picciame','02019','RI'),
											('0','Piccianello','65010','PE'),
											('0','Picciano','65010','PE'),
											('0','Piccilli','81044','CE'),
											('0','Piccione','06080','PG'),
											('0','Picciorana','55010','LU'),
											('0','Piccolino','39030','BZ'),
											('0','Picenze','67020','AQ'),
											('0','Picerno','85055','PZ'),
											('0','Picinisco','03040','FR'),
											('0','Pico','03020','FR'),
											('0','Picone','70124','BA'),
											('0','Pi di Moggio','02010','RI'),
											('0','Pi di Via','43030','PR'),
											('0','Piea','14020','AT'),
											('0','Piedelpoggio','02010','RI'),
											('0','Piedicavallo','13812','BI'),
											('0','Piedicolle','06050','PG'),
											('0','Piediluco','05038','TR'),
											('0','Piedimonte d\'Alife','','CE'),
											('0','Piedimonte del Calvario','34070','GO'),
											('0','Piedimonte di Sessa Aurunca','81030','CE'),
											('0','Piedimonte d\'Ischia','80070','NA'),
											('0','Piedimonte Etneo','95017','CT'),
											('0','Piedimonte Matese','81016','CE'),
											('0','Piedimonte San Germano','03030','FR'),
											('0','Piedimulera','28885','VB'),
											('0','Piedipaterno Sul Nera','06040','PG'),
											('0','Piediripa','62010','MC'),
											('0','Piedivalle','06040','PG'),
											('0','Piegaio','55060','LU'),
											('0','Piegaro','06066','PG'),
											('0','Pielungo','33090','PN'),
											('0','Pienza','53026','SI'),
											('0','Piepasso','15020','AL'),
											('0','Pieranica','26017','CR'),
											('0','Pierantonio','06015','PG'),
											('0','Pieris','34075','GO'),
											('0','Pietole','46030','MN'),
											('0','Pietra De\' Giorgi','27040','PV'),
											('0','Pietra Ligure','17027','SV'),
											('0','Pietra Marazzi','15040','AL'),
											('0','Pietrabbondante','86085','IS'),
											('0','Pietrabruna','18010','IM'),
											('0','Pietrabuona','51010','PT'),
											('0','Pietracamela','64047','TE'),
											('0','Pietracatella','86040','CB'),
											('0','Pietracupa','86020','CB'),
											('0','Pietracuta','61010','PU'),
											('0','Pietradefusi','83030','AV'),
											('0','Pietraferrazzana','66040','CH'),
											('0','Pietrafitta','03040','FR'),
											('0','Pietrafitta','06060','PG'),
											('0','Pietrafitta','87050','CS'),
											('0','Pietragalla','85016','PZ'),
											('0','Pietragavina','27050','PV'),
											('0','Pietralacroce','60129','AN'),
											('0','Pietralta','64010','TE'),
											('0','Pietralunga','06026','PG'),
											('0','Pietramala','50030','FI'),
											('0','Pietramelara','81051','CE'),
											('0','Pietramontecorvino','71038','FG'),
											('0','Pietramurata','38070','TN'),
											('0','Pietranico','65020','PE'),
											('0','Pietransieri','67030','AQ'),
											('0','Pietrapaola','87060','CS'),
											('0','Pietrapaola Stazione','87060','CS'),
											('0','Pietrapennata','89030','RC'),
											('0','Pietrapertosa','85010','PZ'),
											('0','Pietraperzia','94016','EN'),
											('0','Pietraporzio','12010','CN'),
											('0','Pietraroja','82030','BN'),
											('0','Pietrarubbia','61023','PU'),
											('0','Pietrasanta','55045','LU'),
											('0','Pietrasecca','67065','AQ'),
											('0','Pietrastornina','83015','AV'),
											('0','Pietravairano','81040','CE'),
											('0','Pietraviva','52020','AR'),
											('0','Pietrelcina','82020','BN'),
											('0','Pieve','42016','RE'),
											('0','Pieve','55041','LU'),
											('0','Pieve a Elici','55054','LU'),
											('0','Pieve a Nievole','51018','PT'),
											('0','Pieve a Presciano','52020','AR'),
											('0','Pieve a Ripoli','50126','FI'),
											('0','Pieve Al Bagnoro','52040','AR'),
											('0','Pieve Al Toppo','52041','AR'),
											('0','Pieve Albignola','27030','PV'),
											('0','Pieve Caina','06050','PG'),
											('0','Pieve d\'Alpago','32010','BL'),
											('0','Pieve del Cairo','27037','PV'),
											('0','Pieve di Bono','38085','TN'),
											('0','Pieve di Cadore','32044','BL'),
											('0','Pieve di Cagna','61029','PU'),
											('0','Pieve di Cento','40066','BO'),
											('0','Pieve di Compito','55065','LU'),
											('0','Pieve di Compresseto','06020','PG'),
											('0','Pieve di Controne','55022','LU'),
											('0','Pieve di Coriano','46020','MN'),
											('0','Pieve di Curtarolo','35010','PD'),
											('0','Pieve di Cusignano','43030','PR'),
											('0','Pieve di Ledro','38060','TN'),
											('0','Pieve di Rivoschio','47020','FC'),
											('0','Pieve di Sinalunga','53048','SI'),
											('0','Pieve di Soligo','31053','TV'),
											('0','Pieve di Teco','18026','IM'),
											('0','Pieve di Trebbio','41050','MO'),
											('0','Pieve di Zignago','19020','SP'),
											('0','Pieve d\'Olmi','26040','CR'),
											('0','Pieve Emanuele','20090','MI'),
											('0','Pieve Fanonica','06030','PG'),
											('0','Pieve Fissiraga','26854','LO'),
											('0','Pieve Fosciana','55036','LU'),
											('0','Pieve Ligure','16030','GE'),
											('0','Pieve Modolena','42100','RE'),
											('0','Pieve Porto Morone','27017','PV'),
											('0','Pieve Salutare','47011','FC'),
											('0','Pieve San Giacomo','26035','CR'),
											('0','Pieve San Lorenzo','55030','LU'),
											('0','Pieve San Paolo','55012','LU'),
											('0','Pieve San Vincenzo','42030','RE'),
											('0','Pieve Santa Luce','56040','PI'),
											('0','Pieve Santo Stefano','52036','AR'),
											('0','Pieve Tesino','38050','TN'),
											('0','Pieve Torina','62036','MC'),
											('0','Pieve Vergonte','28886','VB'),
											('0','Pievebelvicino','36036','VI'),
											('0','Pievebovigliana','62035','MC'),
											('0','Pieveottoville','43010','PR'),
											('0','Pievepelago','41027','MO'),
											('0','Pievescola','53031','SI'),
											('0','Pievesestina','47020','FC'),
											('0','Piglio','03010','FR'),
											('0','Pigna','18037','IM'),
											('0','Pignano','56048','PI'),
											('0','Pignataro Interamna','03040','FR'),
											('0','Pignataro Maggiore','81052','CE'),
											('0','Pigneto','41048','MO'),
											('0','Pignola','85010','PZ'),
											('0','Pignone','19020','SP'),
											('0','Pigra','22020','CO'),
											('0','Pikolein','39030','BZ'),
											('0','Pila','13020','VC'),
											('0','Pila','06070','PG'),
											('0','Pila Sul Gromolo','16039','GE'),
											('0','Pilastri','44010','FE'),
											('0','Pilastro','35042','PD'),
											('0','Pilastro','43010','PR'),
											('0','Pile','67100','AQ'),
											('0','Pilzone','25049','BS'),
											('0','Pimentel','09020','CA'),
											('0','Piminoro','89010','RC'),
											('0','Pimonte','80050','NA'),
											('0','Pinarella','48015','RA'),
											('0','Pinarolo Po','27040','PV'),
											('0','Pinasca','10060','TO'),
											('0','Pincara','45020','RO'),
											('0','Pinerolo','10064','TO'),
											('0','Pineta di Arenzano','16011','GE'),
											('0','Pineta di Laives','39050','BZ'),
											('0','Pineta di Pescara','65129','PE'),
											('0','Pineta di Sortenna Vallesana','23035','SO'),
											('0','Pineto','64025','TE'),
											('0','Pino d\'Asti','14022','AT'),
											('0','Pino Lago Maggiore','21010','VA'),
											('0','Pino Torinese','10025','TO'),
											('0','Pinocchio','60127','AN'),
											('0','Pinzano Al Tagliamento','33094','PN'),
											('0','Pinzolo','38086','TN'),
											('0','Piobbico','61046','PU'),
											('0','Piobesi d\'Alba','12040','CN'),
											('0','Piobesi Torinese','10040','TO'),
											('0','Piode','13020','VC'),
											('0','Pioltello','20096','MI'),
											('0','Piombino','57025','LI'),
											('0','Piombino Dese','35017','PD'),
											('0','Pionca','35010','PD'),
											('0','Pione','43030','PR'),
											('0','Pioppe di Salvaro','40038','BO'),
											('0','Pioppi','84060','SA'),
											('0','Pioppo','90040','PA'),
											('0','Pioraco','62025','MC'),
											('0','Piossasco','10045','TO'),
											('0','Piov Massaia','14026','AT'),
											('0','Piovani','12040','CN'),
											('0','Piove di Sacco','35028','PD'),
											('0','Piovene Rocchette','36013','VI'),
											('0','Piovera','15040','AL'),
											('0','Piovezzano','37010','VR'),
											('0','Piozzano','29010','PC'),
											('0','Piozzo','12060','CN'),
											('0','Pira Maseda','08020','NU'),
											('0','Piragineti','87068','CS'),
											('0','Piraino','98060','ME'),
											('0','Piratello','40026','BO'),
											('0','Pirazzolu','07021','SS'),
											('0','Pirri','09134','CA'),
											('0','Pisa','56100','PI'),
											('0','Pisano Etneo','95020','CT'),
											('0','Pisano Novarese','28010','NO'),
											('0','Piscina','10060','TO'),
											('0','Piscinas','09010','CA'),
											('0','Piscinola','80145','NA'),
											('0','Pisciotta','84066','SA'),
											('0','Piscopio','89900','VV'),
											('0','Pisignano','73020','LE'),
											('0','Pisignano','48010','RA'),
											('0','Pisogne','25055','BS'),
											('0','Pisoniano','00020','RM'),
											('0','Pissatola','45027','RO'),
											('0','Pisterzo','04010','LT'),
											('0','Pisticci','75015','MT'),
											('0','Pisticci Scalo','75015','MT'),
											('0','Pistoia','51100','PT'),
											('0','Pistolesa','13822','BI'),
											('0','Pistrino','06010','PG'),
											('0','Piteccio','51030','PT'),
											('0','Piteglio','51020','PT'),
											('0','Pitelli','19137','SP'),
											('0','Piticchio','60010','AN'),
											('0','Pitigliano','58017','GR'),
											('0','Piubega','46040','MN'),
											('0','Piuma','34070','GO'),
											('0','Piumarola','03030','FR'),
											('0','Piumazzo','41010','MO'),
											('0','Piuro','23020','SO'),
											('0','Piverone','10010','TO'),
											('0','Pizzale','27050','PV'),
											('0','Pizzighettone','26026','CR'),
											('0','Pizzo','89812','VV'),
											('0','Pizzo Marina','89812','VV'),
											('0','Pizzoferrato','66040','CH'),
											('0','Pizzoletta','37060','VR'),
											('0','Pizzoli','67017','AQ'),
											('0','Pizzone','86071','IS'),
											('0','Pizzoni','89834','VV'),
											('0','Placanica','89040','RC'),
											('0','Plaesano','89050','RC'),
											('0','Plan Felinaz','11020','AO'),
											('0','Plan in Passiria','39010','BZ'),
											('0','Planaval','11010','AO'),
											('0','Planeil','39020','BZ'),
											('0','Planol','39020','BZ'),
											('0','Plasencis','33030','UD'),
											('0','Plataci','87070','CS'),
											('0','Platania','88040','CZ'),
											('0','Plat','89039','RC'),
											('0','Plaus','39025','BZ'),
											('0','Plesio','22010','CO'),
											('0','Ploaghe','07017','SS'),
											('0','Plodio','17043','SV'),
											('0','Pocapaglia','12060','CN'),
											('0','Pocenia','33050','UD'),
											('0','Podargoni','89060','RC'),
											('0','Podenzana','54010','MS'),
											('0','Podenzano','29027','PC'),
											('0','Poderi di Montemerano','58050','GR'),
											('0','Poderia','84060','SA'),
											('0','Podresca','33040','UD'),
											('0','Poetto','09126','CA'),
											('0','Poffabro','33080','PN'),
											('0','Pofi','03026','FR'),
											('0','Pogerola di Amalfi','84010','SA'),
											('0','Poggetello di Tagliacozzo','67060','AQ'),
											('0','Poggiardo','73037','LE'),
											('0','Poggibonsi','53036','SI'),
											('0','Poggio','18038','IM'),
											('0','Poggio','57030','LI'),
											('0','Poggio a Caiano','59016','PO'),
											('0','Poggio Alla Malva','59015','PO'),
											('0','Poggio Aquilone','05010','TR'),
											('0','Poggio Berni','47824','RN'),
											('0','Poggio Bustone','02018','RI'),
											('0','Poggio Cancelli','67010','AQ'),
											('0','Poggio Capanne','58050','GR'),
											('0','Poggio Catino','02040','RI'),
											('0','Poggio Cinolfo','67060','AQ'),
											('0','Poggio d\'Asti','14038','AT'),
											('0','Poggio Delle Rose','64030','TE'),
											('0','Poggio di Ancona','60020','AN'),
											('0','Poggio di Bretta','63100','AP'),
											('0','Poggio di Otricoli','05032','TR'),
											('0','Poggio di Roio','67040','AQ'),
											('0','Poggio Ferro','58050','GR'),
											('0','Poggio Fidoni','02040','RI'),
											('0','Poggio Filippo','67060','AQ'),
											('0','Poggio Franco','70124','BA'),
											('0','Poggio Garfagnana','55037','LU'),
											('0','Poggio Imperiale','50125','FI'),
											('0','Poggio Imperiale','71010','FG'),
											('0','Poggio Mirteto','02047','RI'),
											('0','Poggio Mirteto Stazione','02040','RI'),
											('0','Poggio Moiano','02037','RI'),
											('0','Poggio Morello','64020','TE'),
											('0','Poggio Murella','58050','GR'),
											('0','Poggio Nativo','02030','RI'),
											('0','Poggio Perugino','02040','RI'),
											('0','Poggio Picenze','67026','AQ'),
											('0','Poggio Renatico','44028','FE'),
											('0','Poggio Rusco','46025','MN'),
											('0','Poggio San Francesco','90040','PA'),
											('0','Poggio San Lorenzo','02030','RI'),
											('0','Poggio San Marcello','60030','AN'),
											('0','Poggio San Vicino','62021','MC'),
											('0','Poggio San Vittorino','64020','TE'),
											('0','Poggio Sannita','86086','IS'),
											('0','Poggio Terzarmata','34078','GO'),
											('0','Poggio Tulliano','00046','RM'),
											('0','Poggio Umbricchio','64040','TE'),
											('0','Poggiodomo','06040','PG'),
											('0','Poggiofiorito','66030','CH'),
											('0','Poggiomarino','80040','NA'),
											('0','Poggioreale del Carso','','TS'),
											('0','Poggioreale Sicilia','91020','TP'),
											('0','Poggiorsini','70020','BA'),
											('0','Poggiovalle di Borgorose','02020','RI'),
											('0','Poggiridenti','23020','SO'),
											('0','Pogli','17037','SV'),
											('0','Pogliano Milanese','20010','MI'),
											('0','Pogliola','12080','CN'),
											('0','Pognana Lario','22020','CO'),
											('0','Pognano','24040','BG'),
											('0','Pogno','28076','NO'),
											('0','Poiana Maggiore','36026','VI'),
											('0','Poianella','36050','VI'),
											('0','Poiano di Valpantena','37030','VR'),
											('0','Poirino','10046','TO'),
											('0','Polaveno','25060','BS'),
											('0','Polazzo','34070','GO'),
											('0','Polcanto','50032','FI'),
											('0','Polcenigo','33070','PN'),
											('0','Polegge','36100','VI'),
											('0','Polenta','47032','FC'),
											('0','Polesella','45038','RO'),
											('0','Polesine','46020','MN'),
											('0','Polesine Parmense','43010','PR'),
											('0','Poli','00010','RM'),
											('0','Polia','89813','VV'),
											('0','Policastrello','87010','CS'),
											('0','Policastro Bussentino','84067','SA'),
											('0','Policoro','75025','MT'),
											('0','Polignano a Mare','70044','BA'),
											('0','Polinago','41040','MO'),
											('0','Polino','05030','TR'),
											('0','Polistena','89024','RC'),
											('0','Polizzello','93010','CL'),
											('0','Polizzi Generosa','90028','PA'),
											('0','Polla','84035','SA'),
											('0','Pollastra','15040','AL'),
											('0','Pollein','11020','AO'),
											('0','Pollella','87030','CS'),
											('0','Pollena Trocchia','80040','NA'),
											('0','Pollenza','62010','MC'),
											('0','Pollenzo','12060','CN'),
											('0','Pollica','84068','SA'),
											('0','Pollina','90010','PA'),
											('0','Pollone','13814','BI'),
											('0','Pollutri','66020','CH'),
											('0','Polonghera','12030','CN'),
											('0','Polpenazze','25080','BS'),
											('0','Polpet','32010','BL'),
											('0','Polveraia','58050','GR'),
											('0','Polverara','35020','PD'),
											('0','Polverigi','60020','AN'),
											('0','Polverina','62037','MC'),
											('0','Polverosa','58010','GR'),
											('0','Polvica','80035','NA'),
											('0','Pomaia','56040','PI'),
											('0','Pomarance','56045','PI'),
											('0','Pomaretto','10063','TO'),
											('0','Pomarico','75016','MT'),
											('0','Pomaro Monferrato','15040','AL'),
											('0','Pomarolo','38060','TN'),
											('0','Pombia','28050','NO'),
											('0','Pometo','27040','PV'),
											('0','Pomezia','00040','RM'),
											('0','Pomigliano d\'Arco','80038','NA'),
											('0','Pomino','50060','FI'),
											('0','Pomonte','57030','LI'),
											('0','Pomonte','58050','GR'),
											('0','Pompeano','41028','MO'),
											('0','Pompei','80045','NA'),
											('0','Pompei Scavi','80045','NA'),
											('0','Pompeiana','18015','IM'),
											('0','Pompiano','25030','BS'),
											('0','Pomponesco','46030','MN'),
											('0','Pomposa','44020','FE'),
											('0','Pompu','09095','OR'),
											('0','Poncarale','25020','BS'),
											('0','Ponchiera','23100','SO'),
											('0','Ponderano','13875','BI'),
											('0','Ponna','22020','CO'),
											('0','Ponsacco','56038','PI'),
											('0','Ponso','35040','PD'),
											('0','Pont Canavese','10085','TO'),
											('0','Pont Saint Martin','11026','AO'),
											('0','Pontagna','25050','BS'),
											('0','Pontasserchio','56010','PI'),
											('0','Pontassieve','50065','FI'),
											('0','Pontboset','11020','AO'),
											('0','Ponte','82030','BN'),
											('0','Ponte a Bozzone','53010','SI'),
											('0','Ponte a Cappiano','50050','FI'),
											('0','Ponte a Egola','56024','PI'),
											('0','Ponte a Elsa','50057','FI'),
											('0','Ponte a Ema','50126','FI'),
											('0','Ponte a Moriano','55029','LU'),
											('0','Ponte a Poppi','52013','AR'),
											('0','Ponte a Serraglio','55021','LU'),
											('0','Ponte a Signa','50055','FI'),
											('0','Ponte a Tressa','53014','SI'),
											('0','Ponte Al Bozzone','53030','SI'),
											('0','Ponte All\'Abate','51010','PT'),
											('0','Ponte All\'Ania','55055','LU'),
											('0','Ponte Barizzo','84060','SA'),
											('0','Ponte Buggianese','51019','PT'),
											('0','Ponte Caffaro','25070','BS'),
											('0','Ponte Chiasso','22100','CO'),
											('0','Ponte d\'Arbia','53010','SI'),
											('0','Ponte d\'Arli','63041','AP'),
											('0','Ponte d\'Assi','06020','PG'),
											('0','Ponte del Giglio','55060','LU'),
											('0','Ponte della Persica','80050','NA'),
											('0','Ponte della Pietra','06128','PG'),
											('0','Ponte della Priula','31010','TV'),
											('0','Ponte della Venturina','40045','BO'),
											('0','Ponte Delle Arche','38077','TN'),
											('0','Ponte Dell\'Olio','29028','PC'),
											('0','Ponte di Barbarano','36021','VI'),
											('0','Ponte di Brenta','35129','PD'),
											('0','Ponte di Falmenta','28825','VB'),
											('0','Ponte di Legno','25056','BS'),
											('0','Ponte di Nava','12070','CN'),
											('0','Ponte di Piave','31047','TV'),
											('0','Ponte di Savignone','16010','GE'),
											('0','Ponte di Verzuno','40032','BO'),
											('0','Ponte Felcino','06077','PG'),
											('0','Ponte Galeria','00050','RM'),
											('0','Ponte Galvano','44021','FE'),
											('0','Ponte Gardena','39040','BZ'),
											('0','Ponte Giurino','24030','BG'),
											('0','Ponte Guelpa','13836','BI'),
											('0','Ponte in Foglia','61020','PU'),
											('0','Ponte in Valtellina','23026','SO'),
											('0','Ponte Lambro','22037','CO'),
											('0','Ponte Messa','61016','PU'),
											('0','Ponte Molino Baffoni','61015','PU'),
											('0','Ponte nelle Alpi','32014','BL'),
											('0','Ponte Nizza','27050','PV'),
											('0','Ponte Nossa','24028','BG'),
											('0','Ponte Nuovo','20013','MI'),
											('0','Ponte Organasco','29020','PC'),
											('0','Ponte Pattoli','06085','PG'),
											('0','Ponte Rio di Monterado','60010','AN'),
											('0','Ponte Ronca','40069','BO'),
											('0','Ponte San Giovanni','06087','PG'),
											('0','Ponte San Marco','25011','BS'),
											('0','Ponte San Nicol','35020','PD'),
											('0','Ponte San Pietro','24036','BG'),
											('0','Ponte San Pietro','55056','LU'),
											('0','Ponte Selva','24020','BG'),
											('0','Ponte Storto','00060','RM'),
											('0','Ponte sulla Moletta','00040','RM'),
											('0','Ponte Taro','43010','PR'),
											('0','Ponte Trebbia','16025','GE'),
											('0','Ponte Tresa','21037','VA'),
											('0','Ponte Valleceppi','06078','PG'),
											('0','Ponte Zanano','25068','BS'),
											('0','Pontebba','33016','UD'),
											('0','Pontecagnano','84098','SA'),
											('0','Pontecchio Marconi','40044','BO'),
											('0','Pontecchio Polesine','45030','RO'),
											('0','Ponteceno','43050','PR'),
											('0','Pontechianale','12020','CN'),
											('0','Pontecorvo','03037','FR'),
											('0','Pontecurone','15055','AL'),
											('0','Pontecuti','06059','PG'),
											('0','Pontedassio','18027','IM'),
											('0','Pontedecimo','16164','GE'),
											('0','Pontedera','56025','PI'),
											('0','Ponteginori','56040','PI'),
											('0','Pontegradella','44030','FE'),
											('0','Pontegrande','88100','CZ'),
											('0','Pontelagoscuro','44038','FE'),
											('0','Pontelandolfo','82027','BN'),
											('0','Pontelangorino','44020','FE'),
											('0','Pontelatone','81040','CE'),
											('0','Pontelongo','35029','PD'),
											('0','Pontelucano','00010','RM'),
											('0','Pontelungo','51030','PT'),
											('0','Pontemerlano','46030','MN'),
											('0','Pontenova','39050','BZ'),
											('0','Pontenuovo','06053','PG'),
											('0','Pontenure','29010','PC'),
											('0','Pontepetri','51020','PT'),
											('0','Ponteranica','24010','BG'),
											('0','Pontericcioli','61044','PU'),
											('0','Ponteromito','83050','AV'),
											('0','Pontestazzemese','55040','LU'),
											('0','Pontestrambo','43050','PR'),
											('0','Pontestura','15027','AL'),
											('0','Pontetetto','55057','LU'),
											('0','Pontevico','25026','BS'),
											('0','Pontey','11024','AO'),
											('0','Ponti','15010','AL'),
											('0','Ponti Sul Mincio','46040','MN'),
											('0','Ponticelli','02030','RI'),
											('0','Ponticelli','40026','BO'),
											('0','Ponticelli','80147','NA'),
											('0','Ponticelli Citt della Pieve','06060','PG'),
											('0','Ponticino','52020','AR'),
											('0','Pontida','24030','BG'),
											('0','Pontinia','04014','LT'),
											('0','Pontinvrea','17042','SV'),
											('0','Pontirolo Nuovo','24040','BG'),
											('0','Pontito','51010','PT'),
											('0','Pontoglio','25037','BS'),
											('0','Pontolo','43043','PR'),
											('0','Pontremoli','54027','MS'),
											('0','Ponza','04027','LT'),
											('0','Ponzano','64010','TE'),
											('0','Ponzano','31050','TV'),
											('0','Ponzano di Fermo','63020','AP'),
											('0','Ponzano Magra','19035','SP'),
											('0','Ponzano Monferrato','15020','AL'),
											('0','Ponzano Romano','00060','RM'),
											('0','Ponz Bovecchio','19020','SP'),
											('0','Ponzone','13832','BI'),
											('0','Ponzone','15010','AL'),
											('0','Popiglio','51020','PT'),
											('0','Popoli','65026','PE'),
											('0','Popolo','15030','AL'),
											('0','Poppi','52014','AR'),
											('0','Populonia','57020','LI'),
											('0','Porano','05010','TR'),
											('0','Porcari','55016','LU'),
											('0','Porcellengo','31040','TV'),
											('0','Porchia','63030','AP'),
											('0','Porchiano del Monte','05020','TR'),
											('0','Porcia','33080','PN'),
											('0','Porciano','51035','PT'),
											('0','Porciano','03015','FR'),
											('0','Porcigatone','43043','PR'),
											('0','Porciorasco','19028','SP'),
											('0','Pordenone','33170','PN'),
											('0','Porelli di Bagnara','89010','RC'),
											('0','Porlezza','22018','CO'),
											('0','Pornassio','18024','IM'),
											('0','Pornello','05010','TR'),
											('0','Porossan','11100','AO'),
											('0','Porotto','44044','FE'),
											('0','Porpetto','33050','UD'),
											('0','Porporano','43030','PR'),
											('0','Porrena','52010','AR'),
											('0','Porretta Terme','40046','BO'),
											('0','Porrino','03025','FR'),
											('0','Portacomaro','14037','AT'),
											('0','Portacomaro Stazione','14038','AT'),
											('0','Portalbera','27040','PV'),
											('0','Portanova','15070','AL'),
											('0','Portaria','05020','TR'),
											('0','Porte','10060','TO'),
											('0','Portegrandi','30020','VE'),
											('0','Porticello','90010','PA'),
											('0','Portichetto','22070','CO'),
											('0','Portici','80055','NA'),
											('0','Portico di Caserta','81050','CE'),
											('0','Portico di Romagna','47010','FC'),
											('0','Portigliola','89040','RC'),
											('0','Portile','41010','MO'),
											('0','Portiolo','46020','MN'),
											('0','Porto','06060','PG'),
											('0','Porto Azzurro','57036','LI'),
											('0','Porto Ceresio','21050','VA'),
											('0','Porto Cervo','07020','SS'),
											('0','Porto Cesareo','73010','LE'),
											('0','Porto Corsini','48010','RA'),
											('0','Porto d\'Ascoli','63037','AP'),
											('0','Porto di Mezzo','50055','FI'),
											('0','Porto Empedocle','92014','AG'),
											('0','Porto Ercole','58018','GR'),
											('0','Porto Frailis','08041','NU'),
											('0','Porto Fuori','48020','RA'),
											('0','Porto Garibaldi','44029','FE'),
											('0','Porto Mantovano','46047','MN'),
											('0','Porto Maurizio','18100','IM'),
											('0','Porto Potenza Picena','62016','MC'),
											('0','Porto Recanati','62017','MC'),
											('0','Porto Rotondo','07020','SS'),
											('0','Porto Salvo','89811','VV'),
											('0','Porto Salvo','98051','ME'),
											('0','Porto San Giorgio','63017','AP'),
											('0','Porto Santa Margherita','30021','VE'),
											('0','Porto Sant\'Elpidio','63018','AP'),
											('0','Porto Santo Stefano','58019','GR'),
											('0','Porto Tolle','45018','RO'),
											('0','Porto Torres','07046','SS'),
											('0','Porto Valtravaglia','21010','VA'),
											('0','Porto Viro','45014','RO'),
											('0','Portobuffol','31040','TV'),
											('0','Portocannone','86045','CB'),
											('0','Portoferraio','57037','LI'),
											('0','Portofino','16034','GE'),
											('0','Portogruaro','30026','VE'),
											('0','Portomaggiore','44015','FE'),
											('0','Portonovo','40059','BO'),
											('0','Portonovo','60020','AN'),
											('0','Portopalo','96010','SR'),
											('0','Portoscuso','09010','CA'),
											('0','Portovecchio','57025','LI'),
											('0','Portovenere','19025','SP'),
											('0','Portula','13833','BI'),
											('0','Porzano','25024','BS'),
											('0','Posada','08020','NU'),
											('0','Posina','36010','VI'),
											('0','Positano','84017','SA'),
											('0','Possagno','31054','TV'),
											('0','Possidente','85020','PZ'),
											('0','Posta','02019','RI'),
											('0','Posta Fibreno','03030','FR'),
											('0','Postal','39014','BZ'),
											('0','Postalesio','23010','SO'),
											('0','Posticciola','02020','RI'),
											('0','Postiglione','84026','SA'),
											('0','Postioma','31040','TV'),
											('0','Postua','13010','VC'),
											('0','Potassa','58020','GR'),
											('0','Potenza','85100','PZ'),
											('0','Potenza Picena','62018','MC'),
											('0','Potenzoni','89817','VV'),
											('0','Pove del Grappa','36020','VI'),
											('0','Povegliano','31050','TV'),
											('0','Povegliano Veronese','37064','VR'),
											('0','Poviglio','42028','RE'),
											('0','Povo','38050','TN'),
											('0','Povolaro','36031','VI'),
											('0','Povoletto','33040','UD'),
											('0','Pozza di Acquasanta','63041','AP'),
											('0','Pozza di Fassa','38036','TN'),
											('0','Pozzaglia Sabino','02030','RI'),
											('0','Pozzaglio','26010','CR'),
											('0','Pozzale','32040','BL'),
											('0','Pozzallo','97016','RG'),
											('0','Pozzengo','15020','AL'),
											('0','Pozzi San Michele Tagliamento','30020','VE'),
											('0','Pozzilli','86077','IS'),
											('0','Pozzillo','95020','CT'),
											('0','Pozzo Alto','61020','PU'),
											('0','Pozzo Camacici','37057','VR'),
											('0','Pozzo d\'Adda','20060','MI'),
											('0','Pozzo della Chiana','52040','AR'),
											('0','Pozzo di Gotto','98050','ME'),
											('0','Pozzo di Gualdo Cattaneo','06030','PG'),
											('0','Pozzo Guacito','72010','BR'),
											('0','Pozzo Sant\'Evasio','15033','AL'),
											('0','Pozzol Groppo','15050','AL'),
											('0','Pozzolengo','25010','BS'),
											('0','Pozzoleone','36050','VI'),
											('0','Pozzolo','46040','MN'),
											('0','Pozzolo Formigaro','15068','AL'),
											('0','Pozzomaggiore','07018','SS'),
											('0','Pozzonovo','35020','PD'),
											('0','Pozzuoli','80078','NA'),
											('0','Pozzuolo','06067','PG'),
											('0','Pozzuolo del Friuli','33050','UD'),
											('0','Pozzuolo Martesana','20060','MI'),
											('0','Pr','16157','GE'),
											('0','Pr Catinat','10060','TO'),
											('0','Pr di Roburent','12080','CN'),
											('0','Pracando','55010','LU'),
											('0','Pracchia','51027','PT'),
											('0','Pracorno','38020','TN'),
											('0','Prad','39026','BZ'),
											('0','Prada','48020','RA'),
											('0','Pradalunga','24020','BG'),
											('0','Pradamano','33040','UD'),
											('0','Prade','38050','TN'),
											('0','Pradipozzo','30020','VE'),
											('0','Pradleves','12027','CN'),
											('0','Pragatto','40056','BO'),
											('0','Pragelato','10060','TO'),
											('0','Prags','39030','BZ'),
											('0','Praia a Mare','87028','CS'),
											('0','Praiano','84010','SA'),
											('0','Pralboino','25020','BS'),
											('0','Prali','10060','TO'),
											('0','Pralormo','10040','TO'),
											('0','Pralungo','13899','BI'),
											('0','Pramaggiore','30020','VE'),
											('0','Pramollo','10065','TO'),
											('0','Prarolo','13100','VC'),
											('0','Prarostino','10060','TO'),
											('0','Prasco','15010','AL'),
											('0','Prascorsano','10080','TO'),
											('0','Praso','38080','TN'),
											('0','Prasomaso','23020','SO'),
											('0','Prata','58020','GR'),
											('0','Prata Camportaccio','23020','SO'),
											('0','Prata d\'Ansidonia','67020','AQ'),
											('0','Prata di Pordenone','33080','PN'),
											('0','Prata Principato Ultra','83030','AV'),
											('0','Prata Sannita','81010','CE'),
											('0','Prataccio','51020','PT'),
											('0','Pratantico','52020','AR'),
											('0','Pratella','81010','CE'),
											('0','Prati','19020','SP'),
											('0','Pratica di Mare','00040','RM'),
											('0','Pratiglione','10080','TO'),
											('0','Prato','59100','PO'),
											('0','Prato All\'Isarco','39050','BZ'),
											('0','Prato Allo Stelvio','39026','BZ'),
											('0','Prato Carnico','33020','UD'),
											('0','Prato Comune','84030','SA'),
											('0','Prato Perillo','84030','SA'),
											('0','Prato Ranieri','58022','GR'),
											('0','Prato Sesia','28077','NO'),
											('0','Prato Sopralacroce','16040','GE'),
											('0','Pratola Peligna','67035','AQ'),
											('0','Pratola Serra','83039','AV'),
											('0','Pratolino','50036','FI'),
											('0','Pratolungo','28028','NO'),
											('0','Pratolungo','58010','GR'),
											('0','Pratomorone','14016','AT'),
											('0','Pratora Sarrottino','88040','CZ'),
											('0','Pratovecchio','52015','AR'),
											('0','Pratrivero','13832','BI'),
											('0','Pravisdomini','33076','PN'),
											('0','Pray Biellese','13867','BI'),
											('0','Prazzo','12028','CN'),
											('0','Prea di Roccaforte','12080','CN'),
											('0','Precenicco','33050','UD'),
											('0','Preci','06047','PG'),
											('0','Precotto','20125','MI'),
											('0','Predappio','47016','FC'),
											('0','Predappio Alta','47010','FC'),
											('0','Predazzo','38037','TN'),
											('0','Predoi','39030','BZ'),
											('0','Predore','24060','BG'),
											('0','Predosa','15077','AL'),
											('0','Preganziol','31022','TV'),
											('0','Pregasina','38060','TN'),
											('0','Preggio','06060','PG'),
											('0','Pregiato','84010','SA'),
											('0','Preglia','28865','VB'),
											('0','Pregnana Milanese','20010','MI'),
											('0','Prel','18100','IM'),
											('0','Prelerna','43040','PR'),
											('0','Premana','23834','LC'),
											('0','Premariacco','33040','UD'),
											('0','Premeno','28818','VB'),
											('0','Premia','28866','VB'),
											('0','Premilcuore','47010','FC'),
											('0','Premolo','24020','BG'),
											('0','Premosello Chiovenda','28803','VB'),
											('0','Preone','33020','UD'),
											('0','Preore','38070','TN'),
											('0','Prepezzano','84090','SA'),
											('0','Prepo','06129','PG'),
											('0','Prepotto','33040','UD'),
											('0','Presa','95010','CT'),
											('0','Pre\'Saint Didier','11010','AO'),
											('0','Preseglie','25070','BS'),
											('0','Preselle Sergardi','58050','GR'),
											('0','Presenzano','81050','CE'),
											('0','Presezzo','24030','BG'),
											('0','Presicce','73054','LE'),
											('0','Presina','35016','PD'),
											('0','Presinaci','89841','VV'),
											('0','Pressana','37040','VR'),
											('0','Prestine','25040','BS'),
											('0','Preta','02012','RI'),
											('0','Pretare','63043','AP'),
											('0','Pretola','06070','PG'),
											('0','Pretoro','66010','CH'),
											('0','Prettau','39030','BZ'),
											('0','Preturo','67010','AQ'),
											('0','Preturo','83025','AV'),
											('0','Prevalle','25080','BS'),
											('0','Prezza','67030','AQ'),
											('0','Prezzo','38085','TN'),
											('0','Priabona','36030','VI'),
											('0','Priacco','10080','TO'),
											('0','Priero','12070','CN'),
											('0','Prignano Cilento','84060','SA'),
											('0','Prignano sulla Secchia','41048','MO'),
											('0','Prima Porta','00188','RM'),
											('0','Primaluna','23819','LC'),
											('0','Prime Case','02032','RI'),
											('0','Primolano','36020','VI'),
											('0','Primolo','23023','SO'),
											('0','Priocca','12040','CN'),
											('0','Priola','12070','CN'),
											('0','Priolo Gargallo','96010','SR'),
											('0','Priosa','16040','GE'),
											('0','Priverno','04015','LT'),
											('0','Prizzi','90038','PA'),
											('0','Procaria','10070','TO'),
											('0','Procchio','57030','LI'),
											('0','Proceno','01020','VT'),
											('0','Procida','80079','NA'),
											('0','Prodo','05010','TR'),
											('0','Promano','06010','PG'),
											('0','Propata','16027','GE'),
											('0','Prosecco','34017','TS'),
											('0','Proserpio','22030','CO'),
											('0','Prossedi','04010','LT'),
											('0','Protonotaro','98050','ME'),
											('0','Prova','37047','VR'),
											('0','Provaglio d\'Iseo','25050','BS'),
											('0','Provaglio Val Sabbia','25070','BS'),
											('0','Provazzano','43024','PR'),
											('0','Proveis','39040','BZ'),
											('0','Proves','39040','BZ'),
											('0','Provesano','33095','PN'),
											('0','Provezze','25050','BS'),
											('0','Provvidenti','86040','CB'),
											('0','Prun','37020','VR'),
											('0','Prunella','89060','RC'),
											('0','Prunetta','51020','PT'),
											('0','Prunetto','12077','CN'),
											('0','Pruno di Stilves','39040','BZ'),
											('0','Puccianiello','81100','CE'),
											('0','Puegnago','25080','BS'),
											('0','Puglianello','82030','BN'),
											('0','Pugliano','81057','CE'),
											('0','Pugliano','84090','SA'),
											('0','Puglietta','84020','SA'),
											('0','Pugliola','19030','SP'),
											('0','Pugnello','36071','VI'),
											('0','Puia','33080','PN'),
											('0','Puianello','42030','RE'),
											('0','Pula','09010','CA'),
											('0','Pulfero','33046','UD'),
											('0','Pulsano','74026','TA'),
											('0','Pumenengo','24050','BG'),
											('0','Punta Ala','58040','GR'),
											('0','Punta Le Castella','88841','KR'),
											('0','Punta Marina','48020','RA'),
											('0','Punta Raisi','90045','PA'),
											('0','Puntalazzo','95010','CT'),
											('0','Puntaldia','08020','NU'),
											('0','Puntone','58020','GR'),
											('0','Puos d\'Alpago','32015','BL'),
											('0','Purello','06020','PG'),
											('0','Purgatorio','03034','FR'),
											('0','Purgessimo','33043','UD'),
											('0','Pusiano','22030','CO'),
											('0','Putifigari','07040','SS'),
											('0','Putignano','','PI'),
											('0','Putignano','70017','BA'),
											('0','Putzu Idu','09070','OR'),
											('0','Quaderni','37060','VR'),
											('0','Quadrelle','83020','AV'),
											('0','Quadrelli','05020','TR'),
											('0','Quadrelli di Fellino','29020','PC'),
											('0','Quadri','66040','CH'),
											('0','Quadrivio di Campagna','84020','SA'),
											('0','Quadroni','00066','RM'),
											('0','Quaglietta','83050','AV'),
											('0','Quagliuzzo','10010','TO'),
											('0','Qualiano','80019','NA'),
											('0','Quara','42010','RE'),
											('0','Quaranti','14040','AT'),
											('0','Quarantoli','41030','MO'),
											('0','Quaras','38047','TN'),
											('0','Quarata','52040','AR'),
											('0','Quaregna','13854','BI'),
											('0','Quargnento','15044','AL'),
											('0','Quarna Sopra','28896','VB'),
											('0','Quarna Sotto','28896','VB'),
											('0','Quarona','13017','VC'),
											('0','Quarrata','51039','PT'),
											('0','Quart','11020','AO'),
											('0','Quartaia','53034','SI'),
											('0','Quartesana','44020','FE'),
											('0','Quarto','80010','NA'),
											('0','Quarto d\'Altino','30020','VE'),
											('0','Quarto d\'Asti','14030','AT'),
											('0','Quarto dei Mille','16148','GE'),
											('0','Quarto di Sarsina','47020','FC'),
											('0','Quarto Inferiore','40057','BO'),
											('0','Quarto Oggiaro','20157','MI'),
											('0','Quartu Sant\'Elena','09045','CA'),
											('0','Quartucciu','09044','CA'),
											('0','Quassolo','10010','TO'),
											('0','Quattordio','15028','AL'),
											('0','Quattro Castella','42020','RE'),
											('0','Quattropani','98050','ME'),
											('0','Quattroventi','81017','CE'),
											('0','Querce','50050','FI'),
											('0','Quercegrossa','53010','SI'),
											('0','Querceta','55046','LU'),
											('0','Querceto','50019','FI'),
											('0','Quercia','54010','MS'),
											('0','Quercianella Sonnino','57015','LI'),
											('0','Querciola','40042','BO'),
											('0','Quercioli','54100','MS'),
											('0','Quero','32030','BL'),
											('0','Quiesa','55050','LU'),
											('0','Quiliano','17047','SV'),
											('0','Quincinetto','10010','TO'),
											('0','Quindici','83020','AV'),
											('0','Quingentole','46020','MN'),
											('0','Quintano','26017','CR'),
											('0','Quinto','50019','FI'),
											('0','Quinto Al Mare','16166','GE'),
											('0','Quinto De Stampi','20089','MI'),
											('0','Quinto di Treviso','31055','TV'),
											('0','Quinto di Valpantena','37034','VR'),
											('0','Quinto Vercellese','13030','VC'),
											('0','Quinto Vicentino','36050','VI'),
											('0','Quintodecimo','63041','AP'),
											('0','Quinzanello','25020','BS'),
											('0','Quinzano','37125','VR'),
											('0','Quinzano d\'Oglio','25027','BS'),
											('0','Quisisana','80050','NA'),
											('0','Quistello','46026','MN'),
											('0','Quittengo','13812','BI'),
											('0','Quota','52014','AR'),
											('0','Rabbi','38020','TN'),
											('0','Racale','73055','LE'),
											('0','Racalmuto','92020','AG'),
											('0','Racchiuso','33040','UD'),
											('0','Racconigi','12035','CN'),
											('0','Raccuja','98067','ME'),
											('0','Racines','39040','BZ'),
											('0','Radda in Chianti','53017','SI'),
											('0','Raddusa','95040','CT'),
											('0','Radein','39040','BZ'),
											('0','Radicofani','53040','SI'),
											('0','Radicondoli','53030','SI'),
											('0','Raffa','25080','BS'),
											('0','Raffadali','92015','AG'),
											('0','Raffaelina','29100','PC'),
											('0','Raffo','90020','PA'),
											('0','Ragalna','95030','CT'),
											('0','Ragattisi','91020','TP'),
											('0','Ragazzola','43010','PR'),
											('0','Raggiolo','52010','AR'),
											('0','Ragogna','33030','UD'),
											('0','Ragoli','38070','TN'),
											('0','Ragusa','97100','RG'),
											('0','Ragusa Ibla','97100','RG'),
											('0','Raiano','67027','AQ'),
											('0','Rain in Taufertal','39030','BZ'),
											('0','Raito','84010','SA'),
											('0','Raldon','37050','VR'),
											('0','Ramacca','95040','CT'),
											('0','Ramazzano','06080','PG'),
											('0','Ramiola','43040','PR'),
											('0','Ramiseto','42030','RE'),
											('0','Ramodipalo','45026','RO'),
											('0','Ramponio Verna','22020','CO'),
											('0','Ramuscello','33079','PN'),
											('0','Ranchio','47020','FC'),
											('0','Rancio Valcuvia','21030','VA'),
											('0','Ranco','21020','VA'),
											('0','Randazzo','95036','CT'),
											('0','Ranica','24020','BG'),
											('0','Ranzanico','24060','BG'),
											('0','Ranzano','43020','PR'),
											('0','Ranzo','18020','IM'),
											('0','Ranzo','38070','TN'),
											('0','Raossi di Vallarsa','38060','TN'),
											('0','Rapagnano','63025','AP'),
											('0','Rapallo','16035','GE'),
											('0','Rapino','66010','CH'),
											('0','Rapolano Terme','53040','SI'),
											('0','Rapolla','85027','PZ'),
											('0','Rapone','85020','PZ'),
											('0','Rasa','21100','VA'),
											('0','Rasiglia','06030','PG'),
											('0','Rassa','13020','VC'),
											('0','Rassina','52016','AR'),
											('0','Rastellino','41013','MO'),
											('0','Rastignano','40067','BO'),
											('0','Rasun di Sotto','39030','BZ'),
											('0','Rasura','23010','SO'),
											('0','Ratschings','39040','BZ'),
											('0','Rauscedo','33095','PN'),
											('0','Ravagnese','89067','RC'),
											('0','Ravalle','44040','FE'),
											('0','Ravanusa','92029','AG'),
											('0','Ravarano','43030','PR'),
											('0','Ravarino','41017','MO'),
											('0','Ravascletto','33020','UD'),
											('0','Ravello','84010','SA'),
											('0','Ravenna','48100','RA'),
											('0','Raveo','33029','UD'),
											('0','Ravi','58020','GR'),
											('0','Ravina','38040','TN'),
											('0','Raviscanina','81017','CE'),
											('0','Ravoledo','23030','SO'),
											('0','Re','28856','VB'),
											('0','Rea','27040','PV'),
											('0','Realmonte','92010','AG'),
											('0','Reana del Roiale','33010','UD'),
											('0','Reane','32041','BL'),
											('0','Reano','10090','TO'),
											('0','Rebbio','22100','CO'),
											('0','Rebeccu','07012','SS'),
											('0','Rebibbia','00156','RM'),
											('0','Recale','81020','CE'),
											('0','Recanati','62019','MC'),
											('0','Recco','16036','GE'),
											('0','Recetto','28060','NO'),
											('0','Recoaro Terme','36076','VI'),
											('0','Recoleta','75020','MT'),
											('0','Recovato','41013','MO'),
											('0','Reda','48020','RA'),
											('0','Redagno','39040','BZ'),
											('0','Redavalle','27050','PV'),
											('0','Redipiano','87050','CS'),
											('0','Redipuglia Sacrario','34070','GO'),
											('0','Redona','24124','BG'),
											('0','Redondesco','46010','MN'),
											('0','Red','41015','MO'),
											('0','Refrancore','14030','AT'),
											('0','Refrontolo','31020','TV'),
											('0','Regalbuto','94017','EN'),
											('0','Regalgioffoli','90020','PA'),
											('0','Reggello','50066','FI'),
											('0','Reggio Calabria','89100','RC'),
											('0','Reggio Emilia','42100','RE'),
											('0','Reggiolo','42046','RE'),
											('0','Regina','87040','CS'),
											('0','Regina Margherita','10097','TO'),
											('0','Regnana','38043','TN'),
											('0','Regnano','42020','RE'),
											('0','Regnano','54010','MS'),
											('0','Reino','82020','BN'),
											('0','Reischach','39031','BZ'),
											('0','Reitano','98070','ME'),
											('0','Remanzacco','33047','UD'),
											('0','Remedello','25010','BS'),
											('0','Remedello Sotto','25010','BS'),
											('0','Renate','20055','MI'),
											('0','Renazzo','44045','FE'),
											('0','Rende','87036','CS'),
											('0','Rendinara','67050','AQ'),
											('0','Renno','41026','MO'),
											('0','Reno','43028','PR'),
											('0','Reno Centese','44040','FE'),
											('0','Reno Finalese','41034','MO'),
											('0','Renon','39054','BZ'),
											('0','Reppia','16040','GE'),
											('0','Rero','44030','FE'),
											('0','Resana','31023','TV'),
											('0','Rescalda','20020','MI'),
											('0','Rescaldina','20027','MI'),
											('0','Reschen','39027','BZ'),
											('0','Resia','33010','UD'),
											('0','Resia All\'Adige','39027','BZ'),
											('0','Resina','','NA'),
											('0','Resiutta','33010','UD'),
											('0','Resuttano','93010','CL'),
											('0','Retegno','26861','LO'),
											('0','Retorbido','27050','PV'),
											('0','Rettorgole','36030','VI'),
											('0','Revello','12036','CN'),
											('0','Revere','46036','MN'),
											('0','Revigliasco d\'Asti','14010','AT'),
											('0','Revigliasco Torinese','10020','TO'),
											('0','Revignano','14010','AT'),
											('0','Revine Lago','31020','TV'),
											('0','Rev','38028','TN'),
											('0','Rezzago','22030','CO'),
											('0','Rezzanello','29010','PC'),
											('0','Rezzano','29020','PC'),
											('0','Rezzato','25086','BS'),
											('0','Rezzo','18026','IM'),
											('0','Rezzoaglio','16048','GE'),
											('0','Rezzonico','22010','CO'),
											('0','Rhemes Notre Dame','11010','AO'),
											('0','Rhemes Saint Georges','11010','AO'),
											('0','Rho','20017','MI'),
											('0','Riace','89040','RC'),
											('0','Riale','40069','BO'),
											('0','Rialto','17020','SV'),
											('0','Riana di Monchio','43010','PR'),
											('0','Riano','00060','RM'),
											('0','Riano','43010','PR'),
											('0','Riardo','81053','CE'),
											('0','Ribera','92016','AG'),
											('0','Ribolla','58027','GR'),
											('0','Ribordone','10080','TO'),
											('0','Ricadi','89866','VV'),
											('0','Ricaldone','15010','AL'),
											('0','Riccardina','40054','BO'),
											('0','Riccia','86016','CB'),
											('0','Riccione','47838','RN'),
											('0','Ricc','43030','PR'),
											('0','Ricc del Golfo','19020','SP'),
											('0','Ricc nel Frignano','41028','MO'),
											('0','Riccovolto','41044','MO'),
											('0','Ricengo','26010','CR'),
											('0','Ricigliano','84020','SA'),
											('0','Riclaretto','10060','TO'),
											('0','Ric','43030','PR'),
											('0','Ric','47010','FC'),
											('0','Ridanna','39040','BZ'),
											('0','Ridnaun','39040','BZ'),
											('0','Ridotti di Balsorano','67050','AQ'),
											('0','Riese Pio X','31039','TV'),
											('0','Riesi','93016','CL'),
											('0','Rieti','02100','RI'),
											('0','Riffian','39010','BZ'),
											('0','Rifiano','39010','BZ'),
											('0','Rifreddo','85010','PZ'),
											('0','Rifreddo di Saluzzo','12030','CN'),
											('0','Rifreddo Mondov','12080','CN'),
											('0','Rifredi','50141','FI'),
											('0','Rifredo','50033','FI'),
											('0','Rigaiolo','53048','SI'),
											('0','Riglione','','PI'),
											('0','Rignano Bolognese','40050','BO'),
											('0','Rignano Flaminio','00068','RM'),
											('0','Rignano Garganico','71010','FG'),
											('0','Rignano Garganico Scalo','71010','FG'),
											('0','Rignano Sull\'Arno','50067','FI'),
											('0','Rigolato','33020','UD'),
											('0','Rigoli','56010','PI'),
											('0','Rigolizia','96010','SR'),
											('0','Rigomagno','53040','SI'),
											('0','Rigoso','43020','PR'),
											('0','Rigutino','52040','AR'),
											('0','Rilievo','91020','TP'),
											('0','Rima San Giuseppe','13026','VC'),
											('0','Rimasco','13026','VC'),
											('0','Rimella','13020','VC'),
											('0','Rimini','47900','RN'),
											('0','Rina','98030','ME'),
											('0','Rinaggiu','08020','NU'),
											('0','Rio di Pusteria','39037','BZ'),
											('0','Rio Marina','57038','LI'),
											('0','Rio Murtas','09010','CA'),
											('0','Rio Nell\'Elba','57039','LI'),
											('0','Rio Saliceto','42010','RE'),
											('0','Rio Salso','61010','PU'),
											('0','Riofreddo','00020','RM'),
											('0','Riola','40047','BO'),
											('0','Riola Sardo','09070','OR'),
											('0','Riolo','41013','MO'),
											('0','Riolo Terme','48025','RA'),
											('0','Riolunato','41020','MO'),
											('0','Riomaggiore','19017','SP'),
											('0','Riomagno','55047','LU'),
											('0','Rionero in Vulture','85028','PZ'),
											('0','Rionero Sannitico','86087','IS'),
											('0','Riosecco','06012','PG'),
											('0','Rioveggio','40040','BO'),
											('0','Ripa','06080','PG'),
											('0','Ripa','55040','LU'),
											('0','Ripa Teatina','66010','CH'),
											('0','Ripaberarda','63030','AP'),
											('0','Ripabianca','06051','PG'),
											('0','Ripabianca Tressanti','82010','BN'),
											('0','Ripabottoni','86040','CB'),
											('0','Ripabottoni Stazione','86040','CB'),
											('0','Ripacandida','85020','PZ'),
											('0','Ripacorbaria','65020','PE'),
											('0','Ripafratta','56010','PI'),
											('0','Ripalimosani','86025','CB'),
											('0','Ripalta','71010','FG'),
											('0','Ripalta Arpina','26010','CR'),
											('0','Ripalta Cremasca','26010','CR'),
											('0','Ripalta Guerina','26010','CR'),
											('0','Ripalvella','05010','TR'),
											('0','Riparbella','56046','PI'),
											('0','Ripatransone','63038','AP'),
											('0','Ripattoni','64020','TE'),
											('0','Ripe','60010','AN'),
											('0','Ripe Civitella del Tronto','64010','TE'),
											('0','Ripe San Ginesio','62020','MC'),
											('0','Ripi','03027','FR'),
											('0','Ripoli','56023','PI'),
											('0','Riposto','95018','CT'),
											('0','Risano','33050','UD'),
											('0','Risaro','00127','RM'),
											('0','Riscone','39031','BZ'),
											('0','Rispescia','58010','GR'),
											('0','Rittana','12010','CN'),
											('0','Ritten','39054','BZ'),
											('0','Riva','46029','MN'),
											('0','Riv','45012','RO'),
											('0','Riva del Garda','38066','TN'),
											('0','Riva del Sole','58043','GR'),
											('0','Riva di Pinerolo','10060','TO'),
											('0','Riva di Solto','24060','BG'),
											('0','Riva di Vallarsa','38060','TN'),
											('0','Riva Faraldi','18016','IM'),
											('0','Riva in Valle','39030','BZ'),
											('0','Riva Ligure','18015','IM'),
											('0','Riva Presso Chieri','10020','TO'),
											('0','Riva Trigoso','16037','GE'),
											('0','Riva Valdobbia','13020','VC'),
											('0','Rivabella','47900','RN'),
											('0','Rivalba','10090','TO'),
											('0','Rivalta','42020','RE'),
											('0','Rivalta','12060','CN'),
											('0','Rivalta Bormida','15010','AL'),
											('0','Rivalta di Torino','10040','TO'),
											('0','Rivalta Scrivia','15050','AL'),
											('0','Rivalta Sul Mincio','46040','MN'),
											('0','Rivalto','56034','PI'),
											('0','Rivamonte Agordino','32020','BL'),
											('0','Rivanazzano','27055','PV'),
											('0','Rivara','41038','MO'),
											('0','Rivara','10080','TO'),
											('0','Rivarolo Canavese','10086','TO'),
											('0','Rivarolo del Re','26036','CR'),
											('0','Rivarolo Ligure','16159','GE'),
											('0','Rivarolo Mantovano','46017','MN'),
											('0','Rivarone','15040','AL'),
											('0','Rivarossa','10040','TO'),
											('0','Rivarotta','33087','PN'),
											('0','Rivazzurra','47900','RN'),
											('0','Rive','13030','VC'),
											('0','Rive d\'Arcano','33030','UD'),
											('0','Rivello','85040','PZ'),
											('0','Rivergaro','29029','PC'),
											('0','Riviera d\'Adda','','BG'),
											('0','Rivignano','33050','UD'),
											('0','Rivisondoli','67036','AQ'),
											('0','Rivodora','10099','TO'),
											('0','Rivodutri','02010','RI'),
											('0','Rivoira','12012','CN'),
											('0','Rivoli','10098','TO'),
											('0','Rivoli Veronese','37010','VR'),
											('0','Rivolta d\'Adda','26027','CR'),
											('0','Rivoltella','25010','BS'),
											('0','Rivolto','33030','UD'),
											('0','Rivotorto','06080','PG'),
											('0','Rizzacorno','66030','CH'),
											('0','Rizziconi','89016','RC'),
											('0','Rizzolo','96010','SR'),
											('0','Ro','44030','FE'),
											('0','Roana','36010','VI'),
											('0','Roaschia','12010','CN'),
											('0','Roascio','12073','CN'),
											('0','Roasio','13060','VC'),
											('0','Roata Chiusani','12044','CN'),
											('0','Roata Rossi','12020','CN'),
											('0','Roatto','14018','AT'),
											('0','Robassomero','10070','TO'),
											('0','Robbiate','23899','LC'),
											('0','Robbio','27038','PV'),
											('0','Robecchetto Con Induno','20020','MI'),
											('0','Robecco d\'Oglio','26010','CR'),
											('0','Robecco Pavese','27042','PV'),
											('0','Robecco Sul Naviglio','20087','MI'),
											('0','Robegano','30030','VE'),
											('0','Robella','14020','AT'),
											('0','Robilante','12017','CN'),
											('0','Roburent','12080','CN'),
											('0','Roca','73026','LE'),
											('0','Rocca Canavese','10070','TO'),
											('0','Rocca Canterano','00020','RM'),
											('0','Rocca Cigli','12060','CN'),
											('0','Rocca Corneta','40047','BO'),
											('0','Rocca d\'Arazzo','14030','AT'),
											('0','Rocca d\'Arce','03030','FR'),
											('0','Rocca d\'Arsi','32030','BL'),
											('0','Rocca De\' Baldi','12047','CN'),
											('0','Rocca De\' Giorgi','27040','PV'),
											('0','Rocca Delle Caminate','47016','FC'),
											('0','Rocca d\'Evandro','81040','CE'),
											('0','Rocca di Botte','67066','AQ'),
											('0','Rocca di Cambio','67047','AQ'),
											('0','Rocca di Capri Leone','98070','ME'),
											('0','Rocca di Cave','00030','RM'),
											('0','Rocca di Mezzo','67048','AQ'),
											('0','Rocca di Neto','88821','KR'),
											('0','Rocca di Papa','00040','RM'),
											('0','Rocca di Roffeno','40034','BO'),
											('0','Rocca Grimalda','15078','AL'),
											('0','Rocca Imperiale','87074','CS'),
											('0','Rocca Imperiale Marina','87074','CS'),
											('0','Rocca Malatina','41050','MO'),
											('0','Rocca Massima','04010','LT'),
											('0','Rocca Monreale','90131','PA'),
											('0','Rocca Pia','67030','AQ'),
											('0','Rocca Pietore','32020','BL'),
											('0','Rocca Preturo','67020','AQ'),
											('0','Rocca Priora','00040','RM'),
											('0','Rocca San Casciano','47017','FC'),
											('0','Rocca San Felice','83050','AV'),
											('0','Rocca San Giovanni','66020','CH'),
											('0','Rocca San Zenone','05100','TR'),
											('0','Rocca Santa Maria','41028','MO'),
											('0','Rocca Santa Maria','64010','TE'),
											('0','Rocca Santo Stefano','00030','RM'),
											('0','Rocca Santo Stefano di Tornimparte','67040','AQ'),
											('0','Rocca Sinibalda','02026','RI'),
											('0','Rocca Susella','27052','PV'),
											('0','Rocca Tunda','09070','OR'),
											('0','Roccabascerana','83016','AV'),
											('0','Roccabernarda','88835','KR'),
											('0','Roccabianca','43010','PR'),
											('0','Roccabruna','12020','CN'),
											('0','Roccacasale','67030','AQ'),
											('0','Roccacerro','67060','AQ'),
											('0','Roccacinquemiglia','67030','AQ'),
											('0','Roccadaspide','84069','SA'),
											('0','Roccafinadamo','65010','PE'),
											('0','Roccafiorita','98030','ME'),
											('0','Roccafluvione','63049','AP'),
											('0','Roccaforte','15060','AL'),
											('0','Roccaforte del Greco','89060','RC'),
											('0','Roccaforte Mondov','12088','CN'),
											('0','Roccaforzata','74020','TA'),
											('0','Roccafranca','25030','BS'),
											('0','Roccagiovine','00020','RM'),
											('0','Roccagloriosa','84060','SA'),
											('0','Roccagorga','04010','LT'),
											('0','Roccalbegna','58053','GR'),
											('0','Roccalumera','98027','ME'),
											('0','Roccalvecce','01020','VT'),
											('0','Roccamandolfi','86092','IS'),
											('0','Roccamena','90040','PA'),
											('0','Roccamonfina','81035','CE'),
											('0','Roccamontepiano','66010','CH'),
											('0','Roccamorice','65020','PE'),
											('0','Roccanolfi','06047','PG'),
											('0','Roccanova','85036','PZ'),
											('0','Roccantica','02040','RI'),
											('0','Roccapalumba','90020','PA'),
											('0','Roccapelago','41027','MO'),
											('0','Roccapiemonte','84086','SA'),
											('0','Roccapietra','13010','VC'),
											('0','Roccapipirozzi','86078','IS'),
											('0','Roccarainola','80030','NA'),
											('0','Roccaranieri','02020','RI'),
											('0','Roccaraso','67037','AQ'),
											('0','Roccaravindola','86070','IS'),
											('0','Roccaravindola Stazione','86070','IS'),
											('0','Roccaromana','81051','CE'),
											('0','Roccascalegna','66040','CH'),
											('0','Roccasecca','03038','FR'),
											('0','Roccasecca dei Volsci','04010','LT'),
											('0','Roccasecca Stazione','03030','FR'),
											('0','Roccasicura','86080','IS'),
											('0','Roccasparvera','12010','CN'),
											('0','Roccaspinalveti','66050','CH'),
											('0','Roccaspromonte','86010','CB'),
											('0','Roccastrada','58036','GR'),
											('0','Roccatagliata','16040','GE'),
											('0','Roccatederighi','58028','GR'),
											('0','Roccavaldina','98040','ME'),
											('0','Roccaverano','14050','AT'),
											('0','Roccavignale','17017','SV'),
											('0','Roccavione','12018','CN'),
											('0','Roccavivara','86020','CB'),
											('0','Roccavivi','67050','AQ'),
											('0','Roccazzo','97010','RG'),
											('0','Roccella Guarnaschelli','90122','PA'),
											('0','Roccella Ionica','89047','RC'),
											('0','Roccella Valdemone','98030','ME'),
											('0','Rocche di Civitella','64010','TE'),
											('0','Rocchenere','98020','ME'),
											('0','Rocchetta','41052','MO'),
											('0','Rocchetta a Volturno','86070','IS'),
											('0','Rocchetta Belbo','12050','CN'),
											('0','Rocchetta Cairo','17014','SV'),
											('0','Rocchetta di Fabriano','60040','AN'),
											('0','Rocchetta di Vara','19020','SP'),
											('0','Rocchetta e Croce','81042','CE'),
											('0','Rocchetta Ligure','15060','AL'),
											('0','Rocchetta Nervina','18035','IM'),
											('0','Rocchetta Palafea','14042','AT'),
											('0','Rocchetta Sandri','41029','MO'),
											('0','Rocchetta Sant\'Antonio','71020','FG'),
											('0','Rocchetta Sant\'Antonio Stazione','71020','FG'),
											('0','Rocchetta Tanaro','14030','AT'),
											('0','Rocciola Sorda','97010','RG'),
											('0','Rodallo','10010','TO'),
											('0','Rodano','20090','MI'),
											('0','Roddi','12060','CN'),
											('0','Roddino','12050','CN'),
											('0','Rodeano Basso','33030','UD'),
											('0','Rodello','12050','CN'),
											('0','Rodeneck','39037','BZ'),
											('0','Rodengo','39037','BZ'),
											('0','Rodengo Saiano','25050','BS'),
											('0','Rodero','22070','CO'),
											('0','Rodi Garganico','71012','FG'),
											('0','Rod Milici','98059','ME'),
											('0','Rodia','98161','ME'),
											('0','Rodigo','46040','MN'),
											('0','Rodio','84060','SA'),
											('0','Ro Volciano','25077','BS'),
											('0','Rofrano','84070','SA'),
											('0','Rogeno','23849','LC'),
											('0','Roges','87030','CS'),
											('0','Roggiano Gravina','87017','CS'),
											('0','Roggione','26026','CR'),
											('0','Roghudi','89060','RC'),
											('0','Rogliano','87054','CS'),
											('0','Rognano','27012','PV'),
											('0','Rogno','24060','BG'),
											('0','Rogolo','23010','SO'),
											('0','Rogoredo','20138','MI'),
											('0','Roiate','00030','RM'),
											('0','Roio del Sangro','66040','CH'),
											('0','Roio Piano','67040','AQ'),
											('0','Roisan','11100','AO'),
											('0','Roletto','10060','TO'),
											('0','Rolo','42047','RE'),
											('0','Roma','00161','RM'),
											('0','Roma','00100','RM'),
											('0','Roma','00187','RM'),
											('0','Roma','00164','RM'),
											('0','Roma','00163','RM'),
											('0','Roma','00165','RM'),
											('0','Roma','00186','RM'),
											('0','Roma','00173','RM'),
											('0','Roma','00142','RM'),
											('0','Roma','00146','RM'),
											('0','Roma','00175','RM'),
											('0','Roma','00174','RM'),
											('0','Roma','00185','RM'),
											('0','Roma','00149','RM'),
											('0','Roma','00191','RM'),
											('0','Roma','00154','RM'),
											('0','Roma','00153','RM'),
											('0','Roma','00152','RM'),
											('0','Roma','00199','RM'),
											('0','Roma','00159','RM'),
											('0','Roma','00151','RM'),
											('0','Roma','00145','RM'),
											('0','Roma','00126','RM'),
											('0','Roma','00179','RM'),
											('0','Roma','00181','RM'),
											('0','Roma','00182','RM'),
											('0','Roma','00183','RM'),
											('0','Roma','00167','RM'),
											('0','Roma','00168','RM'),
											('0','Roma','00136','RM'),
											('0','Roma','00198','RM'),
											('0','Roma','00195','RM'),
											('0','Roma','00158','RM'),
											('0','Roma','00157','RM'),
											('0','Roma','00141','RM'),
											('0','Roma','00139','RM'),
											('0','Roma','00137','RM'),
											('0','Roma','00147','RM'),
											('0','Roma','00193','RM'),
											('0','Roma','00177','RM'),
											('0','Roma','00192','RM'),
											('0','Roma','00162','RM'),
											('0','Roma','00196','RM'),
											('0','Roma','00197','RM'),
											('0','Roma','00129','RM'),
											('0','Roma','00171','RM'),
											('0','Roma','00172','RM'),
											('0','Roma','00176','RM'),
											('0','Roma','00184','RM'),
											('0','Roma','00194','RM'),
											('0','Romagnano','37023','VR'),
											('0','Romagnano','38060','TN'),
											('0','Romagnano Al Monte','84020','SA'),
											('0','Romagnano Sesia','28078','NO'),
											('0','Romagnese','27050','PV'),
											('0','Romallo','38028','TN'),
											('0','Romana','07010','SS'),
											('0','Romanengo','26014','CR'),
											('0','Roman Brianza','22040','CO'),
											('0','Romano Canavese','10090','TO'),
											('0','Romano d\'Ezzelino','36060','VI'),
											('0','Romano di Lombardia','24058','BG'),
											('0','Romanore','46030','MN'),
											('0','Romanoro','41040','MO'),
											('0','Romans di Varmo','33030','UD'),
											('0','Romans d\'Isonzo','34076','GO'),
											('0','Rombiolo','89841','VV'),
											('0','Romeno','38010','TN'),
											('0','Romentino','28068','NO'),
											('0','Rometta','98043','ME'),
											('0','Rometta Apuana','54020','MS'),
											('0','Rometta Marea','98040','ME'),
											('0','Romito Magra','19030','SP'),
											('0','Romola','50020','FI'),
											('0','Ronago','22027','CO'),
											('0','Ronc','37030','VR'),
											('0','Roncade','31056','TV'),
											('0','Roncadelle','31024','TV'),
											('0','Roncadelle','25030','BS'),
											('0','Roncadello','47010','FC'),
											('0','Roncaglia','29010','PC'),
											('0','Roncaglia','35020','PD'),
											('0','Roncaglia','15030','AL'),
											('0','Roncanova','37060','VR'),
											('0','Roncaro','27010','PV'),
											('0','Roncegno','38050','TN'),
											('0','Roncello','20040','MI'),
											('0','Ronchi','12020','CN'),
											('0','Ronchi','54039','MS'),
											('0','Ronchi dei Legionari','34077','GO'),
											('0','Ronchi Valsugana','38051','TN'),
											('0','Ronchis','33050','UD'),
											('0','Ronciglione','01037','VT'),
											('0','Roncitelli','60010','AN'),
											('0','Ronco','47100','FC'),
											('0','Ronco All\'Adige','37055','VR'),
											('0','Ronco Biellese','13845','BI'),
											('0','Ronco Briantino','20050','MI'),
											('0','Ronco Campo Canneto','43010','PR'),
											('0','Ronco Canavese','10080','TO'),
											('0','Ronco Scrivia','16019','GE'),
											('0','Roncobello','24010','BG'),
											('0','Roncocesi','42100','RE'),
											('0','Roncoferraro','46037','MN'),
											('0','Roncofreddo','47020','FC'),
											('0','Roncogno','38057','TN'),
											('0','Roncola','24030','BG'),
											('0','Roncole Verdi','43010','PR'),
											('0','Roncolev','37060','VR'),
											('0','Roncone','38087','TN'),
											('0','Roncoscaglia','41029','MO'),
											('0','Roncrio','40136','BO'),
											('0','Rondanina','16025','GE'),
											('0','Rondinara','42030','RE'),
											('0','Rondissone','10030','TO'),
											('0','Ronsecco','13036','VC'),
											('0','Ronta','47020','FC'),
											('0','Ronta','50030','FI'),
											('0','Rontagnano','47030','FC'),
											('0','Ronzo Chienis','38060','TN'),
											('0','Ronzone','38010','TN'),
											('0','Roppolo','13883','BI'),
											('0','Ror','10060','TO'),
											('0','Roraipiccolo','33080','PN'),
											('0','Rore','12020','CN'),
											('0','Roreto','12060','CN'),
											('0','Roreto Chisone','','TO'),
											('0','Ros','36027','VI'),
											('0','Rosal','89050','RC'),
											('0','Rosano','42020','RE'),
											('0','Rosario Valanidi','89060','RC'),
											('0','Rosarno','89025','RC'),
											('0','Rosas','09010','CA'),
											('0','Rosasco','27030','PV'),
											('0','Rosate','20088','MI'),
											('0','Rosazza','13815','BI'),
											('0','Rosciano','65020','PE'),
											('0','Roscigno','84020','SA'),
											('0','Rosciolo','67060','AQ'),
											('0','Rose','87040','CS'),
											('0','Rosegaferro','37060','VR'),
											('0','Roselle Terme','58040','GR'),
											('0','Roselli','03030','FR'),
											('0','Rosello','66040','CH'),
											('0','Roseto Capo Spulico','87070','CS'),
											('0','Roseto Capo Spulico Stazione','87070','CS'),
											('0','Roseto degli Abruzzi','64026','TE'),
											('0','Roseto Valfortore','71039','FG'),
											('0','Rosia','53010','SI'),
											('0','Rosignano Marittimo','57016','LI'),
											('0','Rosignano Monferrato','15030','AL'),
											('0','Rosignano Solvay','57013','LI'),
											('0','Rosola','41059','MO'),
											('0','Rosolina','45010','RO'),
											('0','Rosolina Mare','45010','RO'),
											('0','Rosolini','96019','SR'),
											('0','Rosone','10080','TO'),
											('0','Rosora','60030','AN'),
											('0','Rossa','13020','VC'),
											('0','Rossana','12020','CN'),
											('0','Rossano','87067','CS'),
											('0','Rossano Stazione','87068','CS'),
											('0','Rossano Veneto','36028','VI'),
											('0','Rossiglione','16010','GE'),
											('0','Rossino','23805','LC'),
											('0','Rosta','10090','TO'),
											('0','Rota d\'Imagna','24037','BG'),
											('0','Rota Greca','87010','CS'),
											('0','Roteglia','42010','RE'),
											('0','Rotella','63030','AP'),
											('0','Rotello','86040','CB'),
											('0','Rotonda','85048','PZ'),
											('0','Rotondella','75026','MT'),
											('0','Rotondi','83017','AV'),
											('0','Rotta Primero','34073','GO'),
											('0','Rottanova di Cavarzere','30010','VE'),
											('0','Rottofreno','29010','PC'),
											('0','Rotzo','36010','VI'),
											('0','Roure','10060','TO'),
											('0','Rovagnate','23888','LC'),
											('0','Rovasenda','13040','VC'),
											('0','Rovate','21040','VA'),
											('0','Rovato','25038','BS'),
											('0','Rovegliana','36076','VI'),
											('0','Rovegno','16028','GE'),
											('0','Roveleto','29010','PC'),
											('0','Roveleto Landi','29029','PC'),
											('0','Rovellasca','22069','CO'),
											('0','Rovello Porro','22070','CO'),
											('0','Roverbasso','31013','TV'),
											('0','Roverbella','46048','MN'),
											('0','Roverchiara','37050','VR'),
											('0','Roverchiaretta','37050','VR'),
											('0','Roverdicr','45100','RO'),
											('0','Rover della Luna','38030','TN'),
											('0','Rovere di Rocca di Mezzo','67040','AQ'),
											('0','Rover Veronese','37028','VR'),
											('0','Roveredo di Gu','37040','VR'),
											('0','Roveredo in Piano','33080','PN'),
											('0','Rovereto','38068','TN'),
											('0','Rovereto Ferrarese','44020','FE'),
											('0','Rovereto sulla Secchia','41030','MO'),
											('0','Roveri','40138','BO'),
											('0','Roverino','18039','IM'),
											('0','Rovescala','27040','PV'),
											('0','Rovetta','24020','BG'),
											('0','Rovezzano','50136','FI'),
											('0','Roviano','00027','RM'),
											('0','Rovigo','45100','RO'),
											('0','Rovito','87050','CS'),
											('0','Rovolo','41040','MO'),
											('0','Rovolon','35030','PD'),
											('0','Rozzampia','36016','VI'),
											('0','Rozzano','20089','MI'),
											('0','Rubano','35030','PD'),
											('0','Rubbianello','63026','AP'),
											('0','Rubbiano','41045','MO'),
											('0','Rubiana','10040','TO'),
											('0','Rubiera','42048','RE'),
											('0','Ruda','33050','UD'),
											('0','Rudiano','25030','BS'),
											('0','Rueglio','10010','TO'),
											('0','Ruffano','73049','LE'),
											('0','Ruffia','12030','CN'),
											('0','Ruffr','38010','TN'),
											('0','Rufina','50068','FI'),
											('0','Ruggiano','73050','LE'),
											('0','Ruina','44030','FE'),
											('0','Ruinas','09085','OR'),
											('0','Ruino','27040','PV'),
											('0','Rumanedda','07040','SS'),
											('0','Rumo','38020','TN'),
											('0','Runaz','11010','AO'),
											('0','Runco','44010','FE'),
											('0','Ruosina','55040','LU'),
											('0','Ruota','55060','LU'),
											('0','Ruoti','85056','PZ'),
											('0','Rupa','34070','GO'),
											('0','Rupecanina','50039','FI'),
											('0','Russi','48026','RA'),
											('0','Rustigazzo','29020','PC'),
											('0','Rustign','31046','TV'),
											('0','Ruta','16030','GE'),
											('0','Rutigliano','70018','BA'),
											('0','Rutino','84070','SA'),
											('0','Ruviano','81010','CE'),
											('0','Ruvo del Monte','85020','PZ'),
											('0','Ruvo di Puglia','70037','BA'),
											('0','Ruzzano','43020','PR'),
											('0','Sa Lumenera','08010','NU'),
											('0','Sa Pala Ruia','08020','NU'),
											('0','Sa Perta Ruia','08020','NU'),
											('0','Sa Pischera','08020','NU'),
											('0','Sabaudia','04016','LT'),
											('0','Sabbia','13020','VC'),
											('0','Sabbio Bergamasco','24044','BG'),
											('0','Sabbio Chiese','25070','BS'),
											('0','Sabbion','37044','VR'),
											('0','Sabbioncello San Pietro','44030','FE'),
											('0','Sabbioncello San Vittore','44030','FE'),
											('0','Sabbioneta','46018','MN'),
											('0','Sabbioni','26013','CR'),
											('0','Sacca Fisola','30133','VE'),
											('0','Sacchetta','46030','MN'),
											('0','Sacco','23010','SO'),
											('0','Sacco','84070','SA'),
											('0','Saccolongo','35030','PD'),
											('0','Sacconago','21052','VA'),
											('0','Sacile','33077','PN'),
											('0','Sacrofano','00060','RM'),
											('0','Sadali','08030','NU'),
											('0','Safforze','32100','BL'),
											('0','Sagama','08010','NU'),
											('0','Sagliano Micca','13816','BI'),
											('0','Sagrado','34078','GO'),
											('0','Sagron Mis','38050','TN'),
											('0','Saguedo','45026','RO'),
											('0','Saiano','47023','FC'),
											('0','Sailetto','46030','MN'),
											('0','Saint Barthelemy','11020','AO'),
											('0','Saint Christophe','11020','AO'),
											('0','Saint Denis','11023','AO'),
											('0','Saint Marcel','11020','AO'),
											('0','Saint Nicolas','11010','AO'),
											('0','Saint Oyen','11014','AO'),
											('0','Saint Pierre','11010','AO'),
											('0','Saint Rhemy En Bosses','11010','AO'),
											('0','Saint Vincent','11027','AO'),
											('0','Sairano','27030','PV'),
											('0','Sala','47040','FC'),
											('0','Sala','05016','TR'),
											('0','Sala','31036','TV'),
											('0','Sala Al Barro','23856','LC'),
											('0','Sala Baganza','43038','PR'),
											('0','Sala Biellese','13884','BI'),
											('0','Sala Bolognese','40010','BO'),
											('0','Sala Comacina','22010','CO'),
											('0','Sala Consilina','84036','SA'),
											('0','Sala di Caserta','81100','CE'),
											('0','Sala Monferrato','15030','AL'),
											('0','Salaiola','58031','GR'),
											('0','Salandra','75017','MT'),
											('0','Salaparuta','91020','TP'),
											('0','Salara','45030','RO'),
											('0','Salasco','13040','VC'),
											('0','Salassa','10080','TO'),
											('0','Salbertrand','10050','TO'),
											('0','Salboro','35124','PD'),
											('0','Salce','32100','BL'),
											('0','Salcedo','36040','VI'),
											('0','Salci','06060','PG'),
											('0','Salcito','86026','CB'),
											('0','Sale','15045','AL'),
											('0','Sale Delle Langhe','12070','CN'),
											('0','Sale Marasino','25057','BS'),
											('0','Sale San Giovanni','12070','CN'),
											('0','Salemi','91018','TP'),
											('0','Salento','84070','SA'),
											('0','Salerano Canavese','10010','TO'),
											('0','Salerano Sul Lambro','26857','LO'),
											('0','Salerno','84100','SA'),
											('0','Saletta','44030','FE'),
											('0','Saletto','35046','PD'),
											('0','Saletto','31030','TV'),
											('0','Saletto di Vigodarzere','35010','PD'),
											('0','Salgareda','31040','TV'),
											('0','Sali Vercellese','13047','VC'),
											('0','Saliano','87040','CS'),
											('0','Salice','98154','ME'),
											('0','Salice Calabro','89050','RC'),
											('0','Salice d\'Ulzio','10050','TO'),
											('0','Salice Salentino','73015','LE'),
											('0','Salice Terme','27056','PV'),
											('0','Saliceto','12079','CN'),
											('0','Saliceto Buzzalino','41011','MO'),
											('0','Saliceto Panaro','41010','MO'),
											('0','Saliceto San Giuliano','41100','MO'),
											('0','Salignano','73040','LE'),
											('0','Salina Grande','91020','TP'),
											('0','Saline di Volterra','56048','PI'),
											('0','Saline Joniche','89060','RC'),
											('0','Salino','33027','UD'),
											('0','Salionze','37067','VR'),
											('0','Salisano','02040','RI'),
											('0','Salitto','84060','SA'),
											('0','Salizzole','37056','VR'),
											('0','Salle','65020','PE'),
											('0','Salmour','12040','CN'),
											('0','Sal','25087','BS'),
											('0','Salone','','RM'),
											('0','Salorno','39040','BZ'),
											('0','Salsomaggiore Terme','43039','PR'),
											('0','Salsominore','29020','PC'),
											('0','Saltara','61030','PU'),
											('0','Saltaus','39010','BZ'),
											('0','Saltino','50060','FI'),
											('0','Saltino sulla Secchia','41040','MO'),
											('0','Salto','41055','MO'),
											('0','Salto Canavese','10010','TO'),
											('0','Salto di Fondi','04020','LT'),
											('0','Saltocchio','55010','LU'),
											('0','Saltrio','21050','VA'),
											('0','Saltusio','39010','BZ'),
											('0','Saludecio','47835','RN'),
											('0','Saluggia','13040','VC'),
											('0','Salurn','39040','BZ'),
											('0','Salussola','13885','BI'),
											('0','Salutio','52010','AR'),
											('0','Saluzzo','12037','CN'),
											('0','Salvarosa','31033','TV'),
											('0','Salvaterra','42010','RE'),
											('0','Salvaterra','45021','RO'),
											('0','Salvatronda','31033','TV'),
											('0','Salve','73050','LE'),
											('0','Salviano','57124','LI'),
											('0','Salvirola','26010','CR'),
											('0','Salvitelle','84020','SA'),
											('0','Salza di Pinerolo','10060','TO'),
											('0','Salza Irpina','83050','AV'),
											('0','Salzano','30030','VE'),
											('0','Samarate','21017','VA'),
											('0','Samassi','09030','CA'),
											('0','Samatzai','09020','CA'),
											('0','Sambatello','89050','RC'),
											('0','Sambiase di Lamezia Terme','88048','CZ'),
											('0','Sambruson','30030','VE'),
											('0','Sambuca di Sicilia','92017','AG'),
											('0','Sambuca Pistoiese','51020','PT'),
											('0','Sambuca Val di Pesa','50020','FI'),
											('0','Sambuceto','66020','CH'),
											('0','Sambucheto','62010','MC'),
											('0','Sambuchi','90010','PA'),
											('0','Sambuci','00020','RM'),
											('0','Sambuco','12010','CN'),
											('0','Sambughetto','28895','VB'),
											('0','Sammichele di Bari','70010','BA'),
											('0','Samminiatello','50056','FI'),
											('0','Sammontana','50056','FI'),
											('0','Samo','89030','RC'),
											('0','Samolaco','','SO'),
											('0','Samone','41050','MO'),
											('0','Samone','38059','TN'),
											('0','Samone','10010','TO'),
											('0','Sampeyre','12020','CN'),
											('0','Sampierdarena','16149','GE'),
											('0','Sampieri','97010','RG'),
											('0','Samugheo','09086','OR'),
											('0','San Baronto','51030','PT'),
											('0','San Bartolo','48100','RA'),
											('0','San Bartolomeo','09126','CA'),
											('0','San Bartolomeo','19138','SP'),
											('0','San Bartolomeo','12010','CN'),
											('0','San Bartolomeo','18038','IM'),
											('0','San Bartolomeo Al Mare','18016','IM'),
											('0','San Bartolomeo in Bosco','44040','FE'),
											('0','San Bartolomeo in Galdo','82028','BN'),
											('0','San Bartolomeo Lanze','14054','AT'),
											('0','San Bartolomeo Val Cavargna','22010','CO'),
											('0','San Basile','87010','CS'),
											('0','San Basilio','09040','CA'),
											('0','San Basilio di Novara di Sicilia','98050','ME'),
											('0','San Basilio Mottola','74010','TA'),
											('0','San Bassano','26020','CR'),
											('0','San Bellino','45020','RO'),
											('0','San Benedetto','09010','CA'),
											('0','San Benedetto','19020','SP'),
											('0','San Benedetto a Settimo','56026','PI'),
											('0','San Benedetto Belbo','12050','CN'),
											('0','San Benedetto dei Marsi','67058','AQ'),
											('0','San Benedetto del Querceto','40050','BO'),
											('0','San Benedetto del Tronto','63039','AP'),
											('0','San Benedetto di Lugana','37010','VR'),
											('0','San Benedetto in Alpe','47010','FC'),
											('0','San Benedetto in Guarano','87040','CS'),
											('0','San Benedetto in Perillis','67020','AQ'),
											('0','San Benedetto Po','46027','MN'),
											('0','San Benedetto Ullano','87040','CS'),
											('0','San Benedetto Val di Sambro','40048','BO'),
											('0','San Benedetto Vecchio','06026','PG'),
											('0','San Benigno','12020','CN'),
											('0','San Benigno Canavese','10080','TO'),
											('0','San Bernardino','28072','NO'),
											('0','San Bernardino','48020','RA'),
											('0','San Bernardino','42017','RE'),
											('0','San Bernardino Verbano','28804','VB'),
											('0','San Bernardo','17044','SV'),
											('0','San Bernardo','88041','CZ'),
											('0','San Bernardo Carmagnola','10020','TO'),
											('0','San Bernardo d\'Ivrea','10090','TO'),
											('0','San Biagio','44016','FE'),
											('0','San Biagio','46030','MN'),
											('0','San Biagio','83020','AV'),
											('0','San Biagio della Cima','18036','IM'),
											('0','San Biagio della Valle','06070','PG'),
											('0','San Biagio di Callalta','31048','TV'),
											('0','San Biagio in Padule','41038','MO'),
											('0','San Biagio Platani','92020','AG'),
											('0','San Biagio Saracinisco','03040','FR'),
											('0','San Biase','87030','CS'),
											('0','San Biase di Campobasso','86020','CB'),
											('0','San Bonifacio','37047','VR'),
											('0','San Bortolo','37030','VR'),
											('0','San Brancato','85037','PZ'),
											('0','San Briccio','37030','VR'),
											('0','San Brizio','06040','PG'),
											('0','San Buono','66050','CH'),
											('0','San Calogero','89842','VV'),
											('0','San Candido','39038','BZ'),
											('0','San Canzian d\'Isonzo','34075','GO'),
											('0','San Carlo','57020','LI'),
											('0','San Carlo','90030','PA'),
											('0','San Carlo','71020','FG'),
											('0','San Carlo','44040','FE'),
											('0','San Carlo','28879','VB'),
											('0','San Carlo','89030','RC'),
											('0','San Carlo Canavese','10070','TO'),
											('0','San Carlo di Cesena','47020','FC'),
											('0','San Carlo di Sessa Aurunca','81030','CE'),
											('0','San Casciano','56026','PI'),
											('0','San Casciano dei Bagni','53040','SI'),
											('0','San Casciano Val di Pesa','50026','FI'),
											('0','San Cassiano','48020','RA'),
											('0','San Cassiano','39030','BZ'),
											('0','San Cassiano','42010','RE'),
											('0','San Cassiano di Controni','55050','LU'),
											('0','San Cassiano di Lecce','73020','LE'),
											('0','San Cassiano Valchiavenna','23020','SO'),
											('0','San Castrese','81030','CE'),
											('0','San Cataldo','93017','CL'),
											('0','San Cataldo','46030','MN'),
											('0','San Cataldo','70123','BA'),
											('0','San Cataldo','73100','LE'),
											('0','San Cataldo di Bella','85021','PZ'),
											('0','San Cesareo','00030','RM'),
											('0','San Cesario di Lecce','73016','LE'),
											('0','San Cesario Sul Panaro','41018','MO'),
											('0','San Chiaffredo','12020','CN'),
											('0','San Chirico Nuovo','85010','PZ'),
											('0','San Chirico Raparo','85030','PZ'),
											('0','San Cipirello','90040','PA'),
											('0','San Cipriano','31056','TV'),
											('0','San Cipriano d\'Aversa','81036','CE'),
											('0','San Cipriano Picentino','84099','SA'),
											('0','San Cipriano Po','27043','PV'),
											('0','San Clemente','47832','RN'),
											('0','San Clemente','81100','CE'),
											('0','San Clemente di Leonessa','02010','RI'),
											('0','San Colombano','25060','BS'),
											('0','San Colombano','55010','LU'),
											('0','San Colombano Al Lambro','20078','MI'),
											('0','San Colombano Belmonte','10080','TO'),
											('0','San Colombano Certenoli','16040','GE'),
											('0','San Colombano di Meldola','47010','FC'),
											('0','San Cono','89816','VV'),
											('0','San Cono','95040','CT'),
											('0','San Corrado di Fuori','96010','SR'),
											('0','San Cosimo','98060','ME'),
											('0','San Cosimo Alla Macchia','72020','BR'),
											('0','San Cosma','35043','PD'),
											('0','San Cosmo Albanese','87060','CS'),
											('0','San Costantino Albanese','85030','PZ'),
											('0','San Costantino Calabro','89851','VV'),
											('0','San Costantino di Briatico','89817','VV'),
											('0','San Costantino di Rivello','85040','PZ'),
											('0','San Costanzo','61039','PU'),
											('0','San Cristoforo','15060','AL'),
											('0','San Cristoforo','61032','PU'),
											('0','San Cristoforo Al Lago','38050','TN'),
											('0','San Dalmazio','56040','PI'),
											('0','San Dalmazio nel Frignano','41028','MO'),
											('0','San Damaso','41010','MO'),
											('0','San Damiano','20050','MI'),
											('0','San Damiano','29019','PC'),
											('0','San Damiano Al Colle','27040','PV'),
											('0','San Damiano d\'Asti','14015','AT'),
											('0','San Damiano Macra','12029','CN'),
											('0','San Dana','73034','LE'),
											('0','San Daniele del Friuli','33038','UD'),
											('0','San Daniele Po','26046','CR'),
											('0','San Defendente','12020','CN'),
											('0','San Demetrio Corone','87069','CS'),
											('0','San Demetrio Nei Vestini','67028','AQ'),
											('0','San Desiderio','14031','AT'),
											('0','San Desiderio','16133','GE'),
											('0','San Didero','10050','TO'),
											('0','San Domenico di Fiesole','50016','FI'),
											('0','San Domino','71040','FG'),
											('0','San Don di Piave','30027','VE'),
											('0','San Donaci','72025','BR'),
											('0','San Donato','60040','AN'),
											('0','San Donato','61019','PU'),
											('0','San Donato di Lecce','73010','LE'),
											('0','San Donato di Mango','12050','CN'),
											('0','San Donato di Ninea','87010','CS'),
											('0','San Donato di Tagliacozzo','67060','AQ'),
											('0','San Donato in Collina','50010','FI'),
											('0','San Donato in Poggio','50020','FI'),
											('0','San Donato Milanese','20097','MI'),
											('0','San Donato Val di Comino','03046','FR'),
											('0','San Donnino','40127','BO'),
											('0','San Donnino di Campi','50010','FI'),
											('0','San Dorligo della Valle','34018','TS'),
											('0','San Fantino','89060','RC'),
											('0','San Fatucchio','06060','PG'),
											('0','San Fedele Intelvi','22028','CO'),
											('0','San Fele','85020','PZ'),
											('0','San Felice','20090','MI'),
											('0','San Felice','51030','PT'),
											('0','San Felice','81050','CE'),
											('0','San Felice a Cancello','81027','CE'),
											('0','San Felice a Ema','50125','FI'),
											('0','San Felice a Pietravairano','81040','CE'),
											('0','San Felice Circeo','04017','LT'),
											('0','San Felice del Benaco','25010','BS'),
											('0','San Felice del Molise','86030','CB'),
											('0','San Felice Sul Panaro','41038','MO'),
											('0','San Felice Val di Non','39010','BZ'),
											('0','San Feliciano','06060','PG'),
											('0','San Ferdinando','89026','RC'),
											('0','San Ferdinando di Puglia','71046','FG'),
											('0','San Fermo','46040','MN'),
											('0','San Fermo','21100','VA'),
											('0','San Fermo della Battaglia','22020','CO'),
											('0','San Fili','87037','CS'),
											('0','San Filippo','87022','CS'),
											('0','San Filippo','98144','ME'),
											('0','San Filippo del Mela','98044','ME'),
											('0','San Filippo di Contigliano','02040','RI'),
											('0','San Fior','31020','TV'),
											('0','San Fiorano','26848','LO'),
											('0','San Floriano','31020','TV'),
											('0','San Floriano','37020','VR'),
											('0','San Floriano del Collio','34070','GO'),
											('0','San Floro','88021','CZ'),
											('0','San Foca','33080','PN'),
											('0','San Foca','73026','LE'),
											('0','San Foc','96010','SR'),
											('0','San Fortunato','47900','RN'),
											('0','San Fortunato della Collina','06070','PG'),
											('0','San Francesco','38050','TN'),
											('0','San Francesco Al Campo','10070','TO'),
											('0','San Francesco d\'Aglientu','','SS'),
											('0','San Francesco Dell\'Arena','70123','BA'),
											('0','San Fratello','98075','ME'),
											('0','San Frediano a Settimo','56026','PI'),
											('0','San Fruttuoso','20052','MI'),
											('0','San Fruttuoso di Camogli','16030','GE'),
											('0','San Gabriele','40052','BO'),
											('0','San Gabriele Dell\'Addolorata','64048','TE'),
											('0','San Gaetano','30021','VE'),
											('0','San Gavino','08020','NU'),
											('0','San Gavino Monreale','09037','CA'),
											('0','San Gemini','05029','TR'),
											('0','San Genesio','39050','BZ'),
											('0','San Genesio Ed Uniti','27010','PV'),
											('0','San Gennarello','80040','NA'),
											('0','San Gennaro','55010','LU'),
											('0','San Gennaro Vesuviano','80040','NA'),
											('0','San Genuario','13040','VC'),
											('0','San Germano','15040','AL'),
											('0','San Germano Chisone','10065','TO'),
											('0','San Germano dei Berici','36040','VI'),
											('0','San Germano Vercellese','13047','VC'),
											('0','San Gervasio Bresciano','25020','BS'),
											('0','San Gervasio d\'Adda','24042','BG'),
											('0','San Giacomo','18038','IM'),
											('0','San Giacomo','94014','EN'),
											('0','San Giacomo d\'Acri','87040','CS'),
											('0','San Giacomo d\'Atri','64030','TE'),
											('0','San Giacomo degli Schiavoni','86030','CB'),
											('0','San Giacomo del Martignone','40011','BO'),
											('0','San Giacomo Delle Segnate','46020','MN'),
											('0','San Giacomo di Boves','12010','CN'),
											('0','San Giacomo di Cerzeto','87040','CS'),
											('0','San Giacomo di Laives','39050','BZ'),
											('0','San Giacomo di Scerni','66020','CH'),
											('0','San Giacomo di Spoleto','06048','PG'),
											('0','San Giacomo di Teglio','23030','SO'),
											('0','San Giacomo di Veglia','31020','TV'),
											('0','San Giacomo Filippo','23020','SO'),
											('0','San Giacomo in Valle Aurina','39030','BZ'),
											('0','San Giacomo Maggiore','41055','MO'),
											('0','San Giacomo Roncole','41037','MO'),
											('0','San Giacomo Vercellese','13030','VC'),
											('0','San Gillio','10040','TO'),
											('0','San Gimignano','53037','SI'),
											('0','San Ginese','55060','LU'),
											('0','San Ginesio','62026','MC'),
											('0','San Giorgio','70040','BA'),
											('0','San Giorgio','94010','EN'),
											('0','San Giorgio','95121','CT'),
											('0','San Giorgio','98060','ME'),
											('0','San Giorgio a Colonica','59100','PO'),
											('0','San Giorgio a Cremano','80046','NA'),
											('0','San Giorgio a Liri','03047','FR'),
											('0','San Giorgio Albanese','87060','CS'),
											('0','San Giorgio Canavese','10090','TO'),
											('0','San Giorgio del Sannio','82018','BN'),
											('0','San Giorgio della Richinvelda','33095','PN'),
											('0','San Giorgio Delle Pertiche','35010','PD'),
											('0','San Giorgio di Cesena','47020','FC'),
											('0','San Giorgio di Crognaleto','64040','TE'),
											('0','San Giorgio di Livenza','30020','VE'),
											('0','San Giorgio di Lomellina','27020','PV'),
											('0','San Giorgio di Mantova','46030','MN'),
											('0','San Giorgio di Nogaro','33058','UD'),
											('0','San Giorgio di Perlena','36030','VI'),
											('0','San Giorgio di Pesaro','61030','PU'),
											('0','San Giorgio di Piano','40016','BO'),
											('0','San Giorgio di Pietragalla','85020','PZ'),
											('0','San Giorgio Extra','89133','RC'),
											('0','San Giorgio in Bosco','35010','PD'),
											('0','San Giorgio in Salici','37060','VR'),
											('0','San Giorgio Jonico','74027','TA'),
											('0','San Giorgio La Molara','82020','BN'),
											('0','San Giorgio Lucano','75027','MT'),
											('0','San Giorgio Monferrato','15020','AL'),
											('0','San Giorgio Morgeto','89017','RC'),
											('0','San Giorgio Piacentino','29019','PC'),
											('0','San Giorgio Scarampi','14059','AT'),
											('0','San Giorgio Su Legnano','20010','MI'),
											('0','San Giorio di Susa','10050','TO'),
											('0','San Giovanni','08020','NU'),
											('0','San Giovanni','67012','AQ'),
											('0','San Giovanni','41033','MO'),
											('0','San Giovanni','07040','SS'),
											('0','San Giovanni','57037','LI'),
											('0','San Giovanni a Piro','84070','SA'),
											('0','San Giovanni a Teduccio','80146','NA'),
											('0','San Giovanni Al Natisone','33048','UD'),
											('0','San Giovanni Alla Vena','56010','PI'),
											('0','San Giovanni Battista','16154','GE'),
											('0','San Giovanni Bianco','24015','BG'),
											('0','San Giovanni Canavese','10010','TO'),
											('0','San Giovanni d\'Albi','88055','CZ'),
											('0','San Giovanni d\'Asso','53020','SI'),
											('0','San Giovanni del Dosso','46020','MN'),
											('0','San Giovanni Delle Contee','58010','GR'),
											('0','San Giovanni di Bellagio','22020','CO'),
											('0','San Giovanni di Casarsa','33072','PN'),
											('0','San Giovanni di Ceppaloni','82010','BN'),
											('0','San Giovanni di Galermo','95040','CT'),
											('0','San Giovanni di Gerace','89040','RC'),
											('0','San Giovanni di Ostellato','44020','FE'),
											('0','San Giovanni di Polcenigo','33070','PN'),
											('0','San Giovanni di Querciola','42020','RE'),
											('0','San Giovanni di San Giorgio del Sannio','82018','BN'),
											('0','San Giovanni di Zambrone','89867','VV'),
											('0','San Giovanni e Paolo','81013','CE'),
											('0','San Giovanni Gemini','92020','AG'),
											('0','San Giovanni Ilarione','37035','VR'),
											('0','San Giovanni in Croce','26037','CR'),
											('0','San Giovanni in Fiore','87055','CS'),
											('0','San Giovanni in Galdo','86010','CB'),
											('0','San Giovanni in Galilea','47030','FC'),
											('0','San Giovanni in Marignano','47842','RN'),
											('0','San Giovanni in Persiceto','40017','BO'),
											('0','San Giovanni in Valle Aurina','39030','BZ'),
											('0','San Giovanni Incarico','03028','FR'),
											('0','San Giovanni La Punta','95037','CT'),
											('0','San Giovanni Li Greci','90012','PA'),
											('0','San Giovanni Lipioni','66050','CH'),
											('0','San Giovanni Lupatoto','37057','VR'),
											('0','San Giovanni Montebello','95010','CT'),
											('0','San Giovanni Paganica','67010','AQ'),
											('0','San Giovanni Profiamma','06030','PG'),
											('0','San Giovanni Reatino','02030','RI'),
											('0','San Giovanni Rotondo','71013','FG'),
											('0','San Giovanni Suergiu','09010','CA'),
											('0','San Giovanni Teatino','66020','CH'),
											('0','San Giovanni Valdarno','52027','AR'),
											('0','San Girolamo','42016','RE'),
											('0','San Girolamo','70123','BA'),
											('0','San Giuliano','81057','CE'),
											('0','San Giuliano a Mare','47900','RN'),
											('0','San Giuliano d\'Arezzo','52040','AR'),
											('0','San Giuliano del Sannio','86010','CB'),
											('0','San Giuliano di Puglia','86040','CB'),
											('0','San Giuliano Milanese','20098','MI'),
											('0','San Giuliano Nuovo','15050','AL'),
											('0','San Giuliano Piacentino','29010','PC'),
											('0','San Giuliano Terme','56017','PI'),
											('0','San Giuliano Trentapiedi','91100','TP'),
											('0','San Giuliano Vecchio','15050','AL'),
											('0','San Giuseppe Alla Rena','95121','CT'),
											('0','San Giuseppe di Cairo','17014','SV'),
											('0','San Giuseppe di Cassola','36067','VI'),
											('0','San Giuseppe di Comacchio','44020','FE'),
											('0','San Giuseppe Jato','90048','PA'),
											('0','San Giuseppe Vesuviano','80047','NA'),
											('0','San Giustino','06016','PG'),
											('0','San Giustino Valdarno','52020','AR'),
											('0','San Giusto Canavese','10090','TO'),
											('0','San Godenzo','50060','FI'),
											('0','San Gregorio','89068','RC'),
											('0','San Gregorio','67020','AQ'),
											('0','San Gregorio da Sassola','00010','RM'),
											('0','San Gregorio di Camin','35020','PD'),
											('0','San Gregorio di Catania','95027','CT'),
											('0','San Gregorio di Veronella','37040','VR'),
											('0','San Gregorio d\'Ippona','89900','VV'),
											('0','San Gregorio Magno','84020','SA'),
											('0','San Gregorio Matese','81010','CE'),
											('0','San Gregorio nelle Alpi','32030','BL'),
											('0','San Guido','57020','LI'),
											('0','San Gusm','53010','SI'),
											('0','San Lazzaro','19038','SP'),
											('0','San Lazzaro Alberoni','29100','PC'),
											('0','San Lazzaro di Agerola','80051','NA'),
											('0','San Lazzaro di Savena','40068','BO'),
											('0','San Lazzaro Parmense','43026','PR'),
											('0','San Lazzaro Saluzzo','12030','CN'),
											('0','San Leo','61018','PU'),
											('0','San Leo Bastia','06010','PG'),
											('0','San Leo di Anghiari','52030','AR'),
											('0','San Leonardello','95010','CT'),
											('0','San Leonardo','09075','OR'),
											('0','San Leonardo','84131','SA'),
											('0','San Leonardo','43100','PR'),
											('0','San Leonardo','66020','CH'),
											('0','San Leonardo del Friuli','33040','UD'),
											('0','San Leonardo di Cutro','88842','KR'),
											('0','San Leonardo di Linarolo','27010','PV'),
											('0','San Leonardo in Passiria','39015','BZ'),
											('0','San Leonardo Valcellina','33086','PN'),
											('0','San Leone','09012','CA'),
											('0','San Leucio','81100','CE'),
											('0','San Leucio del Sannio','82010','BN'),
											('0','San Liberato','05027','TR'),
											('0','San Lorenzello','82030','BN'),
											('0','San Lorenzitto','98066','ME'),
											('0','San Lorenzo','08020','NU'),
											('0','San Lorenzo','89069','RC'),
											('0','San Lorenzo a Merse','53010','SI'),
											('0','San Lorenzo a Pagnatico','56026','PI'),
											('0','San Lorenzo Al Mare','18017','IM'),
											('0','San Lorenzo Alle Corti','56023','PI'),
											('0','San Lorenzo Bellizzi','87070','CS'),
											('0','San Lorenzo Colli','90146','PA'),
											('0','San Lorenzo del Vallo','87040','CS'),
											('0','San Lorenzo della Costa','16030','GE'),
											('0','San Lorenzo di Lugo','48020','RA'),
											('0','San Lorenzo di Moriano','55060','LU'),
											('0','San Lorenzo di Pizzoli','67010','AQ'),
											('0','San Lorenzo di Sant\'Egidio','84010','SA'),
											('0','San Lorenzo di Santi Cosma e Damiano','04020','LT'),
											('0','San Lorenzo di Sebato','39030','BZ'),
											('0','San Lorenzo di Vasto','66050','CH'),
											('0','San Lorenzo in Banale','38078','TN'),
											('0','San Lorenzo in Campo','61047','PU'),
											('0','San Lorenzo in Correggiano','47851','RN'),
											('0','San Lorenzo in Noceto','47010','FC'),
											('0','San Lorenzo Isontino','34070','GO'),
											('0','San Lorenzo Maggiore','82034','BN'),
											('0','San Lorenzo Nuovo','01020','VT'),
											('0','San Lorenzo Peveragno','12010','CN'),
											('0','San Lorenzo Pioppa','41030','MO'),
											('0','San Lorenzo Roero','12040','CN'),
											('0','San Luca','62032','MC'),
											('0','San Luca','89030','RC'),
											('0','San Lucido','87038','CS'),
											('0','San Lugano','39040','BZ'),
											('0','San Lupo','82034','BN'),
											('0','San Macario','21010','VA'),
											('0','San Maderno','70042','BA'),
											('0','San Magno','04020','LT'),
											('0','San Maiano','06010','PG'),
											('0','San Mango Cilento','84070','SA'),
											('0','San Mango d\'Aquino','88040','CZ'),
											('0','San Mango Piemonte','84090','SA'),
											('0','San Mango Sul Calore','83050','AV'),
											('0','San Marcellino','81030','CE'),
											('0','San Marcello','60030','AN'),
											('0','San Marcello Pistoiese','51028','PT'),
											('0','San Marco','70010','BA'),
											('0','San Marco','81057','CE'),
											('0','San Marco','06131','PG'),
											('0','San Marco','84071','SA'),
											('0','San Marco Argentano','87018','CS'),
											('0','San Marco d\'Alunzio','98070','ME'),
											('0','San Marco dei Cavoti','82029','BN'),
											('0','San Marco di Borgomanero','28021','NO'),
											('0','San Marco di Montefalco','06030','PG'),
											('0','San Marco di Teggiano','84030','SA'),
											('0','San Marco Evangelista','81020','CE'),
											('0','San Marco in Lamis','71014','FG'),
											('0','San Marco La Catola','71030','FG'),
											('0','San Marco Roggiano Stazione','87010','CS'),
											('0','San Marco Trotti','81020','CE'),
											('0','San Mariano','06070','PG'),
											('0','San Marino','36020','VI'),
											('0','San Marino','41012','MO'),
											('0','San Martino','41055','MO'),
											('0','San Martino','42015','RE'),
											('0','San Martino','41030','MO'),
											('0','San Martino','15030','AL'),
											('0','San Martino','44046','FE'),
											('0','San Martino Al Cimino','01030','VT'),
											('0','San Martino Al Faggio','63020','AP'),
											('0','San Martino Al Tagliamento','33098','PN'),
											('0','San Martino Alfieri','14010','AT'),
											('0','San Martino Alla Palma','50010','FI'),
											('0','San Martino Badia','39030','BZ'),
											('0','San Martino Buon Albergo','37036','VR'),
											('0','San Martino Canavese','10010','TO'),
											('0','San Martino Carano','41037','MO'),
											('0','San Martino d\'Agri','85030','PZ'),
											('0','San Martino Dall\'Argine','46010','MN'),
											('0','San Martino dei Colli','06076','PG'),
											('0','San Martino dei Mulini','47828','RN'),
											('0','San Martino del Carso','34078','GO'),
											('0','San Martino del Lago','26040','CR'),
											('0','San Martino della Battaglia','25010','BS'),
											('0','San Martino Delle Scale','90040','PA'),
											('0','San Martino di Acquasanta','63040','AP'),
											('0','San Martino di Campagna','33081','PN'),
											('0','San Martino di Castrozza','38058','TN'),
											('0','San Martino di Colle Umberto','31014','TV'),
											('0','San Martino di Durasca','19020','SP'),
											('0','San Martino di Finita','87010','CS'),
											('0','San Martino di Lupari','35018','PD'),
											('0','San Martino di Sessa Aurunca','81030','CE'),
											('0','San Martino di Taurianova','89020','RC'),
											('0','San Martino di Valmozzola','43050','PR'),
											('0','San Martino di Venezze','45030','RO'),
											('0','San Martino d\'Ocre','67040','AQ'),
											('0','San Martino in Argine','40062','BO'),
											('0','San Martino in Beliseto','26022','CR'),
											('0','San Martino in Campo','06079','PG'),
											('0','San Martino in Casies','39030','BZ'),
											('0','San Martino in Colle','06070','PG'),
											('0','San Martino in Converseto','47030','FC'),
											('0','San Martino in Freddana','55060','LU'),
											('0','San Martino in Gattara','48020','RA'),
											('0','San Martino in Passiria','39010','BZ'),
											('0','San Martino in Pedriolo','40024','BO'),
											('0','San Martino in Pensilis','86046','CB'),
											('0','San Martino in Rio','42018','RE'),
											('0','San Martino in Strada','26817','LO'),
											('0','San Martino in Strada','47010','FC'),
											('0','San Martino Montecorvino Rovella','84090','SA'),
											('0','San Martino Sannita','82010','BN'),
											('0','San Martino Secchia','41012','MO'),
											('0','San Martino Siccomario','27028','PV'),
											('0','San Martino Sinzano','43030','PR'),
											('0','San Martino Spadafora','98040','ME'),
											('0','San Martino Spino','41030','MO'),
											('0','San Martino Stella','17010','SV'),
											('0','San Martino Sul Fiora','58050','GR'),
											('0','San Martino sulla Marrucina','66010','CH'),
											('0','San Martino Val Masino','23010','SO'),
											('0','San Martino Vallata','41040','MO'),
											('0','San Martino Valle Caudina','83018','AV'),
											('0','San Marzano di San Giuseppe','74020','TA'),
											('0','San Marzano Oliveto','14050','AT'),
											('0','San Marzano Sul Sarno','84010','SA'),
											('0','San Marzanotto','14050','AT'),
											('0','San Massimo','86027','CB'),
											('0','San Massimo All\'Adige','37139','VR'),
											('0','San Matteo della Decima','40010','BO'),
											('0','San Matteo Delle Chiaviche','46030','MN'),
											('0','San Maurizio','15030','AL'),
											('0','San Maurizio','42029','RE'),
											('0','San Maurizio Al Lambro','20090','MI'),
											('0','San Maurizio Canavese','10077','TO'),
											('0','San Maurizio d\'Opaglio','28017','NO'),
											('0','San Mauro','38042','TN'),
											('0','San Mauro a Signa','50050','FI'),
											('0','San Mauro Castelverde','90010','PA'),
											('0','San Mauro Cilento','84070','SA'),
											('0','San Mauro di Saline','37030','VR'),
											('0','San Mauro Forte','75010','MT'),
											('0','San Mauro in Valle','47023','FC'),
											('0','San Mauro La Bruca','84070','SA'),
											('0','San Mauro Marchesato','88831','KR'),
											('0','San Mauro Mare','47030','FC'),
											('0','San Mauro Pascoli','47030','FC'),
											('0','San Mauro Torinese','10099','TO'),
											('0','San Mazzeo','88048','CZ'),
											('0','San Menaio','71010','FG'),
											('0','San Miceli','87020','CS'),
											('0','San Michele','15040','AL'),
											('0','San Michele','95024','CT'),
											('0','San Michele','88040','CZ'),
											('0','San Michele','60040','AN'),
											('0','San Michele','25083','BS'),
											('0','San Michele','51031','PT'),
											('0','San Michele Al Fiume','61040','PU'),
											('0','San Michele Al Tagliamento','30028','VE'),
											('0','San Michele All\'Adige','38010','TN'),
											('0','San Michele Appiano','39057','BZ'),
											('0','San Michele Cavana','43013','PR'),
											('0','San Michele dei Mucchietti','41049','MO'),
											('0','San Michele del Carso','34078','GO'),
											('0','San Michele di Ganzaria','95040','CT'),
											('0','San Michele di Pagana','16035','GE'),
											('0','San Michele di Piave','31010','TV'),
											('0','San Michele di Pratola Serra','83039','AV'),
											('0','San Michele di Serino','83020','AV'),
											('0','San Michele di Tiorre','43030','PR'),
											('0','San Michele Extra','37132','VR'),
											('0','San Michele in Bosco','46010','MN'),
											('0','San Michele in Monte Laureto','70010','BA'),
											('0','San Michele in Teverina','01020','VT'),
											('0','San Michele Mondov','12080','CN'),
											('0','San Michele Prazzo','12020','CN'),
											('0','San Michele Salentino','72018','BR'),
											('0','San Miniato','56028','PI'),
											('0','San Miniato Basso','56028','PI'),
											('0','San Momm','51020','PT'),
											('0','San Morello','87060','CS'),
											('0','San Nazario','36020','VI'),
											('0','San Nazario','84082','SA'),
											('0','San Nazzaro','82018','BN'),
											('0','San Nazzaro d\'Ongina','29010','PC'),
											('0','San Nazzaro Sesia','28060','NO'),
											('0','San Nazzaro Val Cavargna','22010','CO'),
											('0','San Nicola','66020','CH'),
											('0','San Nicola','71040','FG'),
											('0','San Nicola','89031','RC'),
											('0','San Nicola Arcella','87020','CS'),
											('0','San Nicola Baronia','83050','AV'),
											('0','San Nicola da Crissa','89821','VV'),
											('0','San Nicola Dell\'Alto','88817','KR'),
											('0','San Nicola di Caulonia','89040','RC'),
											('0','San Nicola di Centola','84070','SA'),
											('0','San Nicola di Tornimparte','67040','AQ'),
											('0','San Nicola La Strada','81020','CE'),
											('0','San Nicola Manfredi','82010','BN'),
											('0','San Nicol','44040','FE'),
											('0','San Nicol','95020','CT'),
											('0','San Nicol a Tordino','64020','TE'),
											('0','San Nicol a Trebbia','29010','PC'),
											('0','San Nicol d\'Arcidano','09097','OR'),
											('0','San Nicol di Celle','06050','PG'),
											('0','San Nicol di Comelico','32040','BL'),
											('0','San Nicol di Ricadi','89865','VV'),
											('0','San Nicol di Valfurva','23030','SO'),
											('0','San Nicol Gerrei','09040','CA'),
											('0','San Nicol in Val d\'Ega','39050','BZ'),
											('0','San Nicol L\'Arena','90010','PA'),
											('0','San Nicol Po','46030','MN'),
											('0','San Nicol Ultimo','39010','BZ'),
											('0','San Nullo','95123','CT'),
											('0','San Pancrazio','25036','BS'),
											('0','San Pancrazio','39010','BZ'),
											('0','San Pancrazio','48020','RA'),
											('0','San Pancrazio','50020','FI'),
											('0','San Pancrazio Parmense','43016','PR'),
											('0','San Pancrazio Salentino','72026','BR'),
											('0','San Pantaleo','07020','SS'),
											('0','San Pantaleo','50059','FI'),
											('0','San Pantaleone','89060','RC'),
											('0','San Paolo','74010','TA'),
											('0','San Paolo','70123','BA'),
											('0','San Paolo','25020','BS'),
											('0','San Paolo','39050','BZ'),
											('0','San Paolo Albanese','85030','PZ'),
											('0','San Paolo Bel Sito','80030','NA'),
											('0','San Paolo Cervo','13812','BI'),
											('0','San Paolo d\'Argon','24060','BG'),
											('0','San Paolo di Civitate','71010','FG'),
											('0','San Paolo di Jesi','60038','AN'),
											('0','San Paolo di Noto','96010','SR'),
											('0','San Paolo Solbrito','14010','AT'),
											('0','San Pasquale','07020','SS'),
											('0','San Pasquale','70125','BA'),
											('0','San Patrizio','48020','RA'),
											('0','San Pelagio','34011','TS'),
											('0','San Pelino','67050','AQ'),
											('0','San Pellegrinetto','55020','LU'),
											('0','San Pellegrino','42100','RE'),
											('0','San Pellegrino Al Cassero','51020','PT'),
											('0','San Pellegrino di Gualdo Tadino','06020','PG'),
											('0','San Pellegrino di Norcia','06040','PG'),
											('0','San Pellegrino in Alpe','55030','LU'),
											('0','San Pellegrino Terme','24016','BG'),
											('0','San Pier d\'Isonzo','34070','GO'),
											('0','San Pier Fedele','89020','RC'),
											('0','San Pier Niceto','98045','ME'),
											('0','San Pierino','50054','FI'),
											('0','San Piero','51031','PT'),
											('0','San Piero a Grado','','PI'),
											('0','San Piero a Ponti','50017','FI'),
											('0','San Piero a Sieve','50037','FI'),
											('0','San Piero in Bagno','47026','FC'),
											('0','San Piero in Campo','57030','LI'),
											('0','San Piero Patti','98068','ME'),
											('0','San Pietro','08020','NU'),
											('0','San Pietro a Maida','88025','CZ'),
											('0','San Pietro a Patierno','80144','NA'),
											('0','San Pietro a Vico','55017','LU'),
											('0','San Pietro Al Natisone','33049','UD'),
											('0','San Pietro Al Tanagro','84030','SA'),
											('0','San Pietro All\'Olmo','20010','MI'),
											('0','San Pietro Apostolo','88040','CZ'),
											('0','San Pietro Avellana','86088','IS'),
											('0','San Pietro Belvedere','56033','PI'),
											('0','San Pietro Capofiume','40062','BO'),
											('0','San Pietro Clarenza','95030','CT'),
											('0','San Pietro del Gallo','12020','CN'),
											('0','San Pietro di Barbozza','31040','TV'),
											('0','San Pietro di Berbenno','23010','SO'),
											('0','San Pietro di Cadore','32040','BL'),
											('0','San Pietro di Caltagirone','95040','CT'),
											('0','San Pietro di Carid','89020','RC'),
											('0','San Pietro di Cava','84010','SA'),
											('0','San Pietro di Cavarzere','30010','VE'),
											('0','San Pietro di Feletto','31020','TV'),
											('0','San Pietro di Legnago','37048','VR'),
											('0','San Pietro di Milazzo','98040','ME'),
											('0','San Pietro di Montoro Superiore','83020','AV'),
											('0','San Pietro di Morubio','37050','VR'),
											('0','San Pietro di Scafati','84010','SA'),
											('0','San Pietro di Str','30039','VE'),
											('0','San Pietro in Amantea','87030','CS'),
											('0','San Pietro in Bevagna','74024','TA'),
											('0','San Pietro in Calibano','','PU'),
											('0','San Pietro in Cariano','37029','VR'),
											('0','San Pietro in Casale','40018','BO'),
											('0','San Pietro in Cerro','29010','PC'),
											('0','San Pietro in Elda','41030','MO'),
											('0','San Pietro in Gu','35010','PD'),
											('0','San Pietro in Guarano','87047','CS'),
											('0','San Pietro in Lama','73010','LE'),
											('0','San Pietro in Palazzi','57010','LI'),
											('0','San Pietro in Valle','37060','VR'),
											('0','San Pietro in Valle','86095','IS'),
											('0','San Pietro in Vincoli','48020','RA'),
											('0','San Pietro in Volta','30010','VE'),
											('0','San Pietro Infine','81049','CE'),
											('0','San Pietro Irpino','82010','BN'),
											('0','San Pietro Laion','39040','BZ'),
											('0','San Pietro Lametino','88040','CZ'),
											('0','San Pietro Magisano','88055','CZ'),
											('0','San Pietro Monterosso','12020','CN'),
											('0','San Pietro Mosezzo','28060','NO'),
											('0','San Pietro Mussolino','36070','VI'),
											('0','San Pietro Polesine','45030','RO'),
											('0','San Pietro Samolaco','23027','SO'),
											('0','San Pietro Sovera','22010','CO'),
											('0','San Pietro Val Lemina','10060','TO'),
											('0','San Pietro Vara','19020','SP'),
											('0','San Pietro Vernotico','72027','BR'),
											('0','San Pietro Viminario','35020','PD'),
											('0','San Pio Delle Camere','67020','AQ'),
											('0','San Placido Caloner','98139','ME'),
											('0','San Polo','43056','PR'),
											('0','San Polo','25134','BS'),
											('0','San Polo','29010','PC'),
											('0','San Polo dei Cavalieri','00010','RM'),
											('0','San Polo d\'Enza','42020','RE'),
											('0','San Polo di Piave','31020','TV'),
											('0','San Polo in Chianti','50020','FI'),
											('0','San Polo Matese','86020','CB'),
											('0','San Polo Sabino','02040','RI'),
											('0','San Ponso','10080','TO'),
											('0','San Possidonio','41039','MO'),
											('0','San Potito','67040','AQ'),
											('0','San Potito','48022','RA'),
											('0','San Potito Sannitico','81016','CE'),
											('0','San Potito Ultra','83050','AV'),
											('0','San Prisco','81054','CE'),
											('0','San Procopio','89020','RC'),
											('0','San Prospero','40026','BO'),
											('0','San Prospero','46020','MN'),
											('0','San Prospero Parmense','43027','PR'),
											('0','San Prospero sulla Secchia','41030','MO'),
											('0','San Protaso','29017','PC'),
											('0','San Quirico','36070','VI'),
											('0','San Quirico','58010','GR'),
											('0','San Quirico d\'Albareto','43050','PR'),
											('0','San Quirico di Vernio','59024','PO'),
											('0','San Quirico d\'Orcia','53027','SI'),
											('0','San Quirico in Val Polcevera','16163','GE'),
											('0','San Quirico Trecasali','43010','PR'),
											('0','San Quirico Valleriana','51010','PT'),
											('0','San Quirino','33080','PN'),
											('0','San Raffaele Cimena','10090','TO'),
											('0','San Remo','18038','IM'),
											('0','San Roberto','89050','RC'),
											('0','San Rocco','28867','VB'),
											('0','San Rocco','34015','TS'),
											('0','San Rocco','80016','NA'),
											('0','San Rocco a Pilli','53010','SI'),
											('0','San Rocco Al Porto','26865','LO'),
											('0','San Rocco Bernezzo','12020','CN'),
											('0','San Rocco Castagnaretta','12010','CN'),
											('0','San Rocco della Cherasca','12050','CN'),
											('0','San Rocco di Camogli','16030','GE'),
											('0','San Rocco di Piegara','37028','VR'),
											('0','San Rocco in Turrite','55060','LU'),
											('0','San Rocco Mont','12046','CN'),
											('0','San Romano','56020','PI'),
											('0','San Romano in Garfagnana','55038','LU'),
											('0','San Romedio','38010','TN'),
											('0','San Romolo','18038','IM'),
											('0','San Romualdo','48100','RA'),
											('0','San Ruffillo','40141','BO'),
											('0','San Ruffillo','47013','FC'),
											('0','San Rufo','84030','SA'),
											('0','San Saba','98162','ME'),
											('0','San Salvatore','16040','GE'),
											('0','San Salvatore di Fitalia','98070','ME'),
											('0','San Salvatore di Montecarlo','55010','LU'),
											('0','San Salvatore Monferrato','15046','AL'),
											('0','San Salvatore Telesino','82030','BN'),
											('0','San Salvo','66050','CH'),
											('0','San Salvo Marina','66050','CH'),
											('0','San Savino','63038','AP'),
											('0','San Savino di Monte Colombo','47854','RN'),
											('0','San Sebastiano','67050','AQ'),
											('0','San Sebastiano','38060','TN'),
											('0','San Sebastiano Al Vesuvio','80040','NA'),
											('0','San Sebastiano Curone','15056','AL'),
											('0','San Sebastiano della Comunia','12040','CN'),
											('0','San Sebastiano Po','10020','TO'),
											('0','San Secondo','06010','PG'),
											('0','San Secondo di Pinerolo','10060','TO'),
											('0','San Secondo Parmense','43017','PR'),
											('0','San Severino di Centola','84070','SA'),
											('0','San Severino Lucano','85030','PZ'),
											('0','San Severino Marche','62027','MC'),
											('0','San Severo','71016','FG'),
											('0','San Sigismondo','39030','BZ'),
											('0','San Silvestro','08020','NU'),
											('0','San Silvestro','65132','PE'),
											('0','San Silvestro','13044','VC'),
											('0','San Silvestro','46010','MN'),
											('0','San Silvestro','48018','RA'),
											('0','San Silvestro','64030','TE'),
											('0','San Simone','73017','LE'),
											('0','San Siro','46027','MN'),
											('0','San Sisto','61026','PU'),
											('0','San Sisto','06132','PG'),
											('0','San Sossio Baronia','83050','AV'),
											('0','San Sossio di Serino','83020','AV'),
											('0','San Sostene','88060','CZ'),
											('0','San Sostene Marina','88060','CZ'),
											('0','San Sosti','87010','CS'),
											('0','San Sperate','09026','CA'),
											('0','San Sperato','89133','RC'),
											('0','San Sumino','84070','SA'),
											('0','San Tammaro','81050','CE'),
											('0','San Teodoro','08020','NU'),
											('0','San Teodoro','98030','ME'),
											('0','San Teodoro','95121','CT'),
											('0','San Terenziano','06058','PG'),
											('0','San Terenzo','19036','SP'),
											('0','San Terenzo Monti','54030','MS'),
											('0','San Tomaso','33030','UD'),
											('0','San Tomaso Agordino','32020','BL'),
											('0','San Tomio','36034','VI'),
											('0','San Tommaso','88040','CZ'),
											('0','San Tommaso','65020','PE'),
											('0','San Trovaso','31022','TV'),
											('0','San Valentino','58010','GR'),
											('0','San Valentino della Collina','06050','PG'),
											('0','San Valentino in Abruzzo Citeriore','65020','PE'),
											('0','San Valentino in Campo','39050','BZ'),
											('0','San Valentino Mutta','39020','BZ'),
											('0','San Valentino Torio','84010','SA'),
											('0','San Varano','47100','FC'),
											('0','San Venanzo','05010','TR'),
											('0','San Vendemiano','31020','TV'),
											('0','San Venerio','19135','SP'),
											('0','San Vero Milis','09070','OR'),
											('0','San Vigilio','25062','BS'),
											('0','San Vincenzo','40015','BO'),
											('0','San Vincenzo','57027','LI'),
											('0','San Vincenzo a Torri','50020','FI'),
											('0','San Vincenzo La Costa','87030','CS'),
											('0','San Vincenzo Valle Roveto','67050','AQ'),
											('0','San Vincenzo Vecchio','67050','AQ'),
											('0','San Vitale di Baganza','43038','PR'),
											('0','San Vitaliano','80030','NA'),
											('0','San Vito','09046','CA'),
											('0','San Vito','09040','CA'),
											('0','San Vito','41057','MO'),
											('0','San Vito','47823','RN'),
											('0','San Vito','64010','TE'),
											('0','San Vito Al Tagliamento','33078','PN'),
											('0','San Vito Al Torre','33050','UD'),
											('0','San Vito Chietino','66038','CH'),
											('0','San Vito dei Lombardi','83054','AV'),
											('0','San Vito dei Normanni','72019','BR'),
											('0','San Vito di Altivole','31030','TV'),
											('0','San Vito di Cadore','32046','BL'),
											('0','San Vito di Fagagna','33030','UD'),
											('0','San Vito di Leguzzano','36030','VI'),
											('0','San Vito di Narni','05030','TR'),
											('0','San Vito di Valdobbiadene','31049','TV'),
											('0','San Vito in Monte','05010','TR'),
											('0','San Vito Lo Capo','91010','TP'),
											('0','San Vito Romano','00030','RM'),
											('0','San Vito Sul Cesano','61047','PU'),
											('0','San Vito Sullo Jonio','88067','CZ'),
											('0','San Vito Taranto','74020','TA'),
											('0','San Vittore','12040','CN'),
											('0','San Vittore','37030','VR'),
											('0','San Vittore','47020','FC'),
											('0','San Vittore','62011','MC'),
											('0','San Vittore del Lazio','03040','FR'),
											('0','San Vittore Olona','20028','MI'),
											('0','San Vittorino','00010','RM'),
											('0','San Vittorino Amiterno','67010','AQ'),
											('0','San Zaccaria','48020','RA'),
											('0','San Zeno di Montagna','37010','VR'),
											('0','San Zeno Naviglio','25010','BS'),
											('0','San Zenone Al Lambro','20070','MI'),
											('0','San Zenone degli Ezzelini','31020','TV'),
											('0','San Zenone Po','27010','PV'),
											('0','Sanarica','73030','LE'),
											('0','Sand in Taufers','39032','BZ'),
											('0','Sandigliano','13876','BI'),
											('0','Sandr','37010','VR'),
											('0','Sandrigo','36066','VI'),
											('0','Sanfr','12040','CN'),
											('0','Sanfront','12030','CN'),
											('0','Sangano','10090','TO'),
											('0','Sangiano','21038','VA'),
											('0','Sangineto','87020','CS'),
											('0','Sangineto Lido','87020','CS'),
											('0','Sanguarzo','33040','UD'),
											('0','Sanguinetto','37058','VR'),
											('0','Sanico','15021','AL'),
											('0','Sanluri','09025','CA'),
											('0','Sanluri Stato','09025','CA'),
											('0','Sannazzaro De\' Burgondi','27039','PV'),
											('0','Sannicandro di Bari','70028','BA'),
											('0','Sannicandro Garganico','71015','FG'),
											('0','Sannicola','73017','LE'),
											('0','Sano','38065','TN'),
											('0','Sansepolcro','52037','AR'),
											('0','Santa Aquilina','47900','RN'),
											('0','Santa Barbara','84070','SA'),
											('0','Santa Barbara','98065','ME'),
											('0','Santa Barbara','81100','CE'),
											('0','Santa Barbara','73010','LE'),
											('0','Santa Brigida','38050','TN'),
											('0','Santa Brigida','50060','FI'),
											('0','Santa Brigida','24010','BG'),
											('0','Santa Caterina','19038','SP'),
											('0','Santa Caterina','36046','VI'),
											('0','Santa Caterina','41033','MO'),
											('0','Santa Caterina','58050','GR'),
											('0','Santa Caterina','73050','LE'),
											('0','Santa Caterina','89121','RC'),
											('0','Santa Caterina Albanese','87010','CS'),
											('0','Santa Caterina Dello Jonio','88060','CZ'),
											('0','Santa Caterina Dello Jonio Marina','88060','CZ'),
											('0','Santa Caterina di Cortona','52040','AR'),
											('0','Santa Caterina di Pittinurri','09073','OR'),
											('0','Santa Caterina Valfurva','23030','SO'),
											('0','Santa Caterina Villarmosa','93018','CL'),
											('0','Santa Cecilia di Eboli','84020','SA'),
											('0','Santa Cesarea Terme','73020','LE'),
											('0','Santa Chiara di Nard','','LE'),
											('0','Santa Cristina','39047','BZ'),
											('0','Santa Cristina d\'Aspromonte','89056','RC'),
											('0','Santa Cristina di Borgomanero','28010','NO'),
											('0','Santa Cristina e Bissone','27010','PV'),
											('0','Santa Cristina Gela','90030','PA'),
											('0','Santa Croce Camerina','97017','RG'),
											('0','Santa Croce Cervasca','12010','CN'),
											('0','Santa Croce del Lago','32010','BL'),
											('0','Santa Croce del Sannio','82020','BN'),
											('0','Santa Croce di Cittareale','02010','RI'),
											('0','Santa Croce di Magliano','86047','CB'),
											('0','Santa Croce di Piuro','23020','SO'),
											('0','Santa Croce di Trieste','34010','TS'),
											('0','Santa Croce Sull\'Arno','56029','PI'),
											('0','Santa Domenica Ricadi','89865','VV'),
											('0','Santa Domenica Talao','87020','CS'),
											('0','Santa Domenica Vittoria','98030','ME'),
											('0','Santa Elisabetta','92020','AG'),
											('0','Santa Fiora','58037','GR'),
											('0','Santa Flavia','90017','PA'),
											('0','Santa Francesca','03020','FR'),
											('0','Santa Geltrude in Ultimo','39010','BZ'),
											('0','Santa Giuletta','27046','PV'),
											('0','Santa Giusta','02010','RI'),
											('0','Santa Giusta','09096','OR'),
											('0','Santa Giustina','47821','RN'),
											('0','Santa Giustina','17044','SV'),
											('0','Santa Giustina Bellunese','32035','BL'),
											('0','Santa Giustina in Colle','35010','PD'),
											('0','Santa Giustina Val di Lecca','43030','PR'),
											('0','Santa Iona','67040','AQ'),
											('0','Santa Liberata','58010','GR'),
											('0','Santa Luce','56040','PI'),
											('0','Santa Lucia','','SS'),
											('0','Santa Lucia','00013','RM'),
											('0','Santa Lucia','59100','PO'),
											('0','Santa Lucia','08020','NU'),
											('0','Santa Lucia Battipaglia','84090','SA'),
											('0','Santa Lucia Cilento','84070','SA'),
											('0','Santa Lucia del Mela','98046','ME'),
											('0','Santa Lucia Delle Spianate','48018','RA'),
											('0','Santa Lucia di Budoia','33070','PN'),
											('0','Santa Lucia di Cava','84010','SA'),
											('0','Santa Lucia di Collecorvino','65010','PE'),
											('0','Santa Lucia di Fiamignano','02027','RI'),
											('0','Santa Lucia di Noto','96010','SR'),
											('0','Santa Lucia di Piave','31025','TV'),
											('0','Santa Lucia di Roseto degli Abruzzi','64020','TE'),
											('0','Santa Lucia di Serino','83020','AV'),
											('0','Santa Lucia in Consilvano','63047','AP'),
											('0','Santa Lucia Sopra Contesse','98126','ME'),
											('0','Santa Lucia Uzzanese','51010','PT'),
											('0','Santa Mama','52010','AR'),
											('0','Santa Margherita','38060','TN'),
											('0','Santa Margherita','','VE'),
											('0','Santa Margherita','33030','UD'),
											('0','Santa Margherita','98135','ME'),
											('0','Santa Margherita','12016','CN'),
											('0','Santa Margherita d\'Adige','35040','PD'),
											('0','Santa Margherita di Atri','64030','TE'),
											('0','Santa Margherita di Belice','92018','AG'),
											('0','Santa Margherita Ligure','16038','GE'),
											('0','Santa Margherita Staffora','27050','PV'),
											('0','Santa Maria','08010','NU'),
											('0','Santa Maria a Colonica','59100','PO'),
											('0','Santa Maria a Monte','56020','PI'),
											('0','Santa Maria a Vico','81028','CE'),
											('0','Santa Maria Al Bagno','73050','LE'),
											('0','Santa Maria Apparente','62012','MC'),
											('0','Santa Maria Capua Vetere','81055','CE'),
											('0','Santa Maria Codifiume','44048','FE'),
											('0','Santa Maria Coghinas','07030','SS'),
											('0','Santa Maria degli Ammalati','95020','CT'),
											('0','Santa Maria degli Angeli','06088','PG'),
											('0','Santa Maria del Cedro','87020','CS'),
											('0','Santa Maria del Giudice','55058','LU'),
											('0','Santa Maria del Molise','86096','IS'),
											('0','Santa Maria del Monte','21100','VA'),
											('0','Santa Maria del Piano','47854','RN'),
											('0','Santa Maria del Piano','43030','PR'),
											('0','Santa Maria del Taro','43057','PR'),
											('0','Santa Maria del Tempio','15040','AL'),
											('0','Santa Maria della Croce','26013','CR'),
											('0','Santa Maria della Neve','05032','TR'),
											('0','Santa Maria della Rovere','31100','TV'),
											('0','Santa Maria della Versa','27047','PV'),
											('0','Santa Maria Delle Fabrecce','61100','PU'),
											('0','Santa Maria Delle Grazie','32022','BL'),
											('0','Santa Maria Delle Mole','00040','RM'),
											('0','Santa Maria di Bobbio','29020','PC'),
											('0','Santa Maria di Castellabate','84072','SA'),
											('0','Santa Maria di Catanzaro','88060','CZ'),
											('0','Santa Maria di Galeria','00060','RM'),
											('0','Santa Maria di Labante','40034','BO'),
											('0','Santa Maria di Licodia','95038','CT'),
											('0','Santa Maria di Piave','31010','TV'),
											('0','Santa Maria di Sala','30036','VE'),
											('0','Santa Maria di Zevio','37050','VR'),
											('0','Santa Maria Goretti','95121','CT'),
											('0','Santa Maria Ho','23889','LC'),
											('0','Santa Maria Imbaro','66030','CH'),
											('0','Santa Maria in Fabriago','48020','RA'),
											('0','Santa Maria in Punta','45010','RO'),
											('0','Santa Maria in Selva','62010','MC'),
											('0','Santa Maria in Strada','40011','BO'),
											('0','Santa Maria Infante','04020','LT'),
											('0','Santa Maria La Bruna','80040','NA'),
											('0','Santa Maria La Carit','80050','NA'),
											('0','Santa Maria La Fossa','81050','CE'),
											('0','Santa Maria La Longa','33050','UD'),
											('0','Santa Maria La Palma','07040','SS'),
											('0','Santa Maria La Scala','80047','NA'),
											('0','Santa Maria La Stella','95020','CT'),
											('0','Santa Maria Le Grotte','87040','CS'),
											('0','Santa Maria Maddalena','45030','RO'),
											('0','Santa Maria Maggiore','28857','VB'),
											('0','Santa Maria Navarrese','08040','NU'),
											('0','Santa Maria Nuova','47020','FC'),
											('0','Santa Maria Nuova','60030','AN'),
											('0','Santa Maria Oliveto','86070','IS'),
											('0','Santa Maria Rezzonico','22010','CO'),
											('0','Santa Maria Villiana','40041','BO'),
											('0','Santa Marina','84070','SA'),
											('0','Santa Marina di Milazzo','98050','ME'),
											('0','Santa Marina Salina','98050','ME'),
											('0','Santa Marinella','00058','RM'),
											('0','Santa Ninfa','91029','TP'),
											('0','Santa Palomba','00040','RM'),
											('0','Santa Paolina','83030','AV'),
											('0','Santa Reparata','47015','FC'),
											('0','Santa Restituta','05020','TR'),
											('0','Santa Rufina','02010','RI'),
											('0','Santa Severa','00050','RM'),
											('0','Santa Severina','88832','KR'),
											('0','Santa Sofia','47018','FC'),
											('0','Santa Sofia','08034','NU'),
											('0','Santa Sofia d\'Epiro','87048','CS'),
											('0','Santa Tecla','84090','SA'),
											('0','Santa Tecla di Acireale','95020','CT'),
											('0','Santa Teresa di Gallura','07028','SS'),
											('0','Santa Teresa di Riva','98028','ME'),
											('0','Santa Valburga Ultimo','39016','BZ'),
											('0','Santa Venera','95010','CT'),
											('0','Santa Veneranda','61100','PU'),
											('0','Santa Venerina','95010','CT'),
											('0','Santa Vittoria','07030','SS'),
											('0','Santa Vittoria d\'Alba','12069','CN'),
											('0','Santa Vittoria d\'Alba Cinzano','12069','CN'),
											('0','Santa Vittoria di Gualtieri','42040','RE'),
											('0','Santa Vittoria di Libiola','16030','GE'),
											('0','Santa Vittoria in Matenano','63028','AP'),
											('0','Sant\'Abbondio','22010','CO'),
											('0','Santadi','09010','CA'),
											('0','Sant\'Agabio','28100','NO'),
											('0','Sant\'Agapito','02020','RI'),
											('0','Sant\'Agapito','86070','IS'),
											('0','Sant\'Agapito Scalo','86070','IS'),
											('0','Sant\'Agata','98166','ME'),
											('0','Sant\'Agata Bolognese','40019','BO'),
											('0','Sant\'Agata De\' Goti','82019','BN'),
											('0','Sant\'Agata del Bianco','89030','RC'),
											('0','Sant\'Agata di Esaro','87010','CS'),
											('0','Sant\'Agata di Militello','98076','ME'),
											('0','Sant\'Agata di Puglia','71028','FG'),
											('0','Sant\'Agata Feltria','61019','PU'),
											('0','Sant\'Agata Fossili','15050','AL'),
											('0','Sant\'Agata Irpina','83020','AV'),
											('0','Sant\'Agata Li Battiati','95030','CT'),
											('0','Sant\'Agata Mugello','50030','FI'),
											('0','Sant\'Agata Sui Due Golfi','80064','NA'),
											('0','Sant\'Agata Sul Santerno','48020','RA'),
											('0','Sant\'Agnello','80065','NA'),
											('0','Sant\'Agostino','44047','FE'),
											('0','Sant\'Albano Stura','12040','CN'),
											('0','Sant\'Alberto','48020','RA'),
											('0','Sant\'Albino','53045','SI'),
											('0','Sant\'Alessio Con Vialone','27016','PV'),
											('0','Sant\'Alessio in Aspromonte','89050','RC'),
											('0','Sant\'Alessio Siculo','98030','ME'),
											('0','Sant\'Alfio','95010','CT'),
											('0','Sant\'Amato','50059','FI'),
											('0','Sant\'Ambrogio','90010','PA'),
											('0','Sant\'Ambrogio di Torino','10057','TO'),
											('0','Sant\'Ambrogio di Valpolicella','37010','VR'),
											('0','Sant\'Ambrogio Olona','21100','VA'),
											('0','Sant\'Ambrogio Sul Garigliano','03040','FR'),
											('0','Sant\'Anastasia','80048','NA'),
											('0','Sant\'Anastasio','55035','LU'),
											('0','Sant\'Anatolia','02020','RI'),
											('0','Sant\'Anatolia di Narco','06040','PG'),
											('0','Sant\'Andrea','98040','ME'),
											('0','Sant\'Andrea','85020','PZ'),
											('0','Sant\'Andrea Apostolo','83029','AV'),
											('0','Sant\'Andrea Bonagia','91010','TP'),
											('0','Sant\'Andrea dei Bagni','43048','PR'),
											('0','Sant\'Andrea del Garigliano','03040','FR'),
											('0','Sant\'Andrea del Pizzone','81050','CE'),
											('0','Sant\'Andrea di Campodarsego','35011','PD'),
											('0','Sant\'Andrea di Conza','83053','AV'),
											('0','Sant\'Andrea di Sorbello','52040','AR'),
											('0','Sant\'Andrea di Suasa','61040','PU'),
											('0','Sant\'Andrea Frius','09040','CA'),
											('0','Sant\'Andrea in Casale','47832','RN'),
											('0','Sant\'Andrea in Monte','39040','BZ'),
											('0','Sant\'Andrea Jonio','88060','CZ'),
											('0','Sant\'Andrea Pelago','41027','MO'),
											('0','Sant\'Angelo','80070','NA'),
											('0','Sant\'Angelo a Cancelli','83030','AV'),
											('0','Sant\'Angelo a Cupolo','82010','BN'),
											('0','Sant\'Angelo a Lecore','50010','FI'),
											('0','Sant\'Angelo a Scala','83010','AV'),
											('0','Sant\'Angelo All\'Esca','83050','AV'),
											('0','Sant\'Angelo d\'Alife','81017','CE'),
											('0','Sant\'Angelo dei Lombardi','83054','AV'),
											('0','Sant\'Angelo del Pesco','86080','IS'),
											('0','Sant\'Angelo di Avigliano','85020','PZ'),
											('0','Sant\'Angelo di Brolo','98060','ME'),
											('0','Sant\'Angelo di Celle','06050','PG'),
											('0','Sant\'Angelo di Cetraro','87020','CS'),
											('0','Sant\'Angelo di Mercato San Severino','84080','SA'),
											('0','Sant\'Angelo di Piove di Sacco','35020','PD'),
											('0','Sant\'Angelo di Senigallia','60010','AN'),
											('0','Sant\'Angelo Fasanella','84027','SA'),
											('0','Sant\'Angelo Gerocarne','89831','VV'),
											('0','Sant\'Angelo in Colle','53020','SI'),
											('0','Sant\'Angelo in Formis','81043','CE'),
											('0','Sant\'Angelo in Grotte','86096','IS'),
											('0','Sant\'Angelo in Lizzola','61020','PU'),
											('0','Sant\'Angelo in Mercole','06040','PG'),
											('0','Sant\'Angelo in Pontano','62020','MC'),
											('0','Sant\'Angelo in Theodice','03040','FR'),
											('0','Sant\'Angelo in Vado','61048','PU'),
											('0','Sant\'Angelo in Villa','03020','FR'),
											('0','Sant\'Angelo Le Fratte','85050','PZ'),
											('0','Sant\'Angelo Limosano','86020','CB'),
											('0','Sant\'Angelo Lodigiano','26866','LO'),
											('0','Sant\'Angelo Lomellina','27030','PV'),
											('0','Sant\'Angelo Muxaro','92020','AG'),
											('0','Sant\'Angelo Romano','00010','RM'),
											('0','Sant\'Anna','16035','GE'),
											('0','Sant\'Anna','84091','SA'),
											('0','Sant\'Anna','09094','OR'),
											('0','Sant\'Anna Arresi','09010','CA'),
											('0','Sant\'Anna d\'Alfaedo','37020','VR'),
											('0','Sant\'Anna di Caltabellotta','92010','AG'),
											('0','Sant\'Anna di Chioggia','30010','VE'),
											('0','Sant\'Anna di Seminara','89020','RC'),
											('0','Sant\'Anna di Valdieri','12010','CN'),
											('0','Sant\'Anna Pelago','41027','MO'),
											('0','Sant\'Antimo','80029','NA'),
											('0','Sant\'Antioco','09017','CA'),
											('0','Sant\'Antonino','13040','VC'),
											('0','Sant\'Antonino Convento','98051','ME'),
											('0','Sant\'Antonino di Susa','10050','TO'),
											('0','Sant\'Antonino Ticino','21010','VA'),
											('0','Sant\'Antonio','23030','SO'),
											('0','Sant\'Antonio','29100','PC'),
											('0','Sant\'Antonio','46047','MN'),
											('0','Sant\'Antonio','98050','ME'),
											('0','Sant\'Antonio','18039','IM'),
											('0','Sant\'Antonio Abate','80057','NA'),
											('0','Sant\'Antonio Casalini','85051','PZ'),
											('0','Sant\'Antonio del Pasubio','','VI'),
											('0','Sant\'Antonio di Calangianus','','SS'),
											('0','Sant\'Antonio di Canelli','14053','AT'),
											('0','Sant\'Antonio di Gallura','07030','SS'),
											('0','Sant\'Antonio di Mavignola','38080','TN'),
											('0','Sant\'Antonio di Pontecagnano','84090','SA'),
											('0','Sant\'Antonio di Santadi','09031','CA'),
											('0','Sant\'Antonio in Bosco','34010','TS'),
											('0','Sant\'Antonio in Mercadello','41030','MO'),
											('0','Sant\'Antonio Magliano Alfieri','12050','CN'),
											('0','Sant\'Antonio Morignone','23030','SO'),
											('0','Sant\'Antonio Ruinas','','OR'),
											('0','Sant\'Antonio Tortal','32020','BL'),
											('0','Sant\'Antonio Valli','36030','VI'),
											('0','Sant\'Antuono d\'Ischia','80077','NA'),
											('0','Sant\'Apollinare','03048','FR'),
											('0','Sant\'Apollinare Chietino','66030','CH'),
											('0','Sant\'Apollinare Con Selva','45010','RO'),
											('0','Sant\'Arcangelo','85037','PZ'),
											('0','Sant\'Arcangelo di Magione','06060','PG'),
											('0','Santarcangelo di Romagna','47822','RN'),
											('0','Sant\'Arcangelo Trimonte','82021','BN'),
											('0','Sant\'Arpino','81030','CE'),
											('0','Sant\'Arsenio','84037','SA'),
											('0','Sant\'Atto','64020','TE'),
											('0','Sante Marie','67067','AQ'),
											('0','Sant\'Efisio','08020','NU'),
											('0','Sant\'Egidio','47023','FC'),
											('0','Sant\'Egidio','06080','PG'),
											('0','Sant\'Egidio Alla Vibrata','64016','TE'),
											('0','Sant\'Egidio del Montalbino','84010','SA'),
											('0','Sant\'Elena','35040','PD'),
											('0','Sant\'Elena','30122','VE'),
											('0','Sant\'Elena Irpina','83030','AV'),
											('0','Sant\'Elena Sannita','86095','IS'),
											('0','Sant\'Elia','60040','AN'),
											('0','Sant\'Elia','88050','CZ'),
											('0','Sant\'Elia','90010','PA'),
											('0','Sant\'Elia a Pianisi','86048','CB'),
											('0','Sant\'Elia di Condera','89126','RC'),
											('0','Sant\'Elia Fiumerapido','03049','FR'),
											('0','Sant\'Ellero','50060','FI'),
											('0','Sant\'Elpidio a Mare','63019','AP'),
											('0','Sant\'Elpidio di Pescorocchiano','02028','RI'),
											('0','Sant\'Elpidio Morico','63020','AP'),
											('0','Santena','10026','TO'),
											('0','Sant\'Enea','06070','PG'),
											('0','Sant\'Eraclio','06037','PG'),
											('0','Santeramo in Colle','70029','BA'),
											('0','Sant\'Ermete','47828','RN'),
											('0','Santerno','48020','RA'),
											('0','Sant\'Eufemia','73039','LE'),
											('0','Sant\'Eufemia a Maiella','65020','PE'),
											('0','Sant\'Eufemia d\'Aspromonte','89027','RC'),
											('0','Sant\'Eufemia della Fonte','25135','BS'),
											('0','Sant\'Eufemia di Lamezia Terme','88040','CZ'),
											('0','Sant\'Eusanio del Sangro','66037','CH'),
											('0','Sant\'Eusanio Forconese','67020','AQ'),
											('0','Sant\'Eusebio','16141','GE'),
											('0','Sant\'Eustachio','84080','SA'),
											('0','Santhi','13048','VC'),
											('0','Santi','67010','AQ'),
											('0','Santi Angeli del Montello','31040','TV'),
											('0','Santi Cosma e Damiano','04020','LT'),
											('0','Santi Lorenzo e Flaviano','02012','RI'),
											('0','Sant\'Ilario','57030','LI'),
											('0','Sant\'Ilario','85020','PZ'),
											('0','Sant\'Ilario d\'Enza','42049','RE'),
											('0','Sant\'Ilario di Baganza','43035','PR'),
											('0','Sant\'Ilario Jonico','89040','RC'),
											('0','Sant\'Ilario Ligure','16167','GE'),
											('0','Sant\'Ilario Milanese','20014','MI'),
											('0','Santimento','29010','PC'),
											('0','Sant\'Ippolito','61040','PU'),
											('0','Sant\'Ippolito','02020','RI'),
											('0','Sant\'Ippolito di Cosenza','87040','CS'),
											('0','Santo','98148','ME'),
											('0','Santo Padre Delle Perriere','91020','TP'),
											('0','Santo Spirito','70050','BA'),
											('0','Santo Stefano','04020','LT'),
											('0','Santo Stefano','48020','RA'),
											('0','Santo Stefano Al Mare','18010','IM'),
											('0','Santo Stefano Belbo','12058','CN'),
											('0','Santo Stefano d\'Aspromonte','89057','RC'),
											('0','Santo Stefano d\'Aveto','16049','GE'),
											('0','Santo Stefano del Sole','83050','AV'),
											('0','Santo Stefano di Briga','98137','ME'),
											('0','Santo Stefano di Cadore','32045','BL'),
											('0','Santo Stefano di Camastra','98077','ME'),
											('0','Santo Stefano di Campobasso','86020','CB'),
											('0','Santo Stefano di Magra','19037','SP'),
											('0','Santo Stefano di Rogliano','87056','CS'),
											('0','Santo Stefano di Sante Marie','67060','AQ'),
											('0','Santo Stefano di Sessanio','67020','AQ'),
											('0','Santo Stefano di Torricella Sicura','64010','TE'),
											('0','Santo Stefano di Zimella','37040','VR'),
											('0','Santo Stefano Lodigiano','26849','LO'),
											('0','Santo Stefano Medio','98136','ME'),
											('0','Santo Stefano Quisquina','92020','AG'),
											('0','Santo Stefano Roero','12040','CN'),
											('0','Santo Stefano Ticino','20010','MI'),
											('0','Santo Stino di Livenza','30029','VE'),
											('0','Sant\'Olcese','16010','GE'),
											('0','Sant\'Oliva di Pontecorvo','03030','FR'),
											('0','Santomato','51030','PT'),
											('0','Santomenna','84020','SA'),
											('0','Sant\'Omero','64027','TE'),
											('0','Sant\'Omobono Imagna','24038','BG'),
											('0','Sant\'Onofrio','64017','TE'),
											('0','Sant\'Onofrio','03041','FR'),
											('0','Sant\'Onofrio','89843','VV'),
											('0','Santonuovo','51030','PT'),
											('0','Santopadre','03030','FR'),
											('0','Sant\'Oreste','00060','RM'),
											('0','Santorso','36014','VI'),
											('0','Sant\'Orsola in Passiria','39010','BZ'),
											('0','Sant\'Orsola in Val Fersina','38050','TN'),
											('0','Sant\'Ottilia in Renon','39050','BZ'),
											('0','Santu Lussurgiu','09075','OR'),
											('0','Santuario della Guardia','16010','GE'),
											('0','Santuario di Montevergine','83010','AV'),
											('0','Santuario di Pietracquaria','67050','AQ'),
											('0','Santuario di Polsi','89030','RC'),
											('0','Santuario di Savona','17040','SV'),
											('0','Santuario di Vicoforte','12080','CN'),
											('0','Santuario Tinella','12053','CN'),
											('0','Sant\'Ulderico di Tretto','36030','VI'),
											('0','Sant\'Urbano','36075','VI'),
											('0','Sant\'Urbano','05035','TR'),
											('0','Sant\'Urbano','35040','PD'),
											('0','Sanvito','87100','CS'),
											('0','Sanza','84030','SA'),
											('0','Sanzeno','38010','TN'),
											('0','Saonara','35020','PD'),
											('0','Saone','38070','TN'),
											('0','Saponara','98047','ME'),
											('0','Saponara Marittima','98040','ME'),
											('0','Sappada','32047','BL'),
											('0','Sappanico','60020','AN'),
											('0','Sapri','84073','SA'),
											('0','Saracena','87010','CS'),
											('0','Saracinesco','00020','RM'),
											('0','Saragiolo','53040','SI'),
											('0','Saragnano','84080','SA'),
											('0','Sarcedo','36030','VI'),
											('0','Sarche','38070','TN'),
											('0','S\'Archittu','09073','OR'),
											('0','Sarconi','85050','PZ'),
											('0','Sardagna','38040','TN'),
											('0','Sardara','09030','CA'),
											('0','Sardigliano','15060','AL'),
											('0','Sarego','36040','VI'),
											('0','Sarenargiu','08020','NU'),
											('0','Sarentino','39058','BZ'),
											('0','Sarezzano','15050','AL'),
											('0','Sarezzo','25068','BS'),
											('0','Sarginesco','46010','MN'),
											('0','Sariano','45027','RO'),
											('0','Sarissola','16012','GE'),
											('0','Sarmato','29010','PC'),
											('0','Sarmede','31026','TV'),
											('0','Sarmeola','35030','PD'),
											('0','Sarnano','62028','MC'),
											('0','Sarnico','24067','BG'),
											('0','Sarno','84087','SA'),
											('0','Sarnonico','38011','TN'),
											('0','Sarntal','39058','BZ'),
											('0','Sarone','33070','PN'),
											('0','Saronno','21047','VA'),
											('0','Sarre','11010','AO'),
											('0','S\'Arridellu','08040','NU'),
											('0','Sarro','95019','CT'),
											('0','Sarroch','09018','CA'),
											('0','Sarsina','47027','FC'),
											('0','Sartano','87010','CS'),
											('0','Sarteano','53047','SI'),
											('0','Sartirana Lomellina','27020','PV'),
											('0','Sarule','08020','NU'),
											('0','Sarzana','19038','SP'),
											('0','Sarzanello','19038','SP'),
											('0','Sas Linnas Siccas','08028','NU'),
											('0','Sas Murtas','08020','NU'),
											('0','Sass Pordoi','38032','TN'),
											('0','Sassa','56040','PI'),
											('0','Sassa','67018','AQ'),
											('0','Sassalbo','54010','MS'),
											('0','Sassano','84038','SA'),
											('0','Sassari','07100','SS'),
											('0','Sassatella','41044','MO'),
											('0','Sassello','17046','SV'),
											('0','Sassetta','57020','LI'),
											('0','Sassi','55020','LU'),
											('0','Sassinoro','82026','BN'),
											('0','Sasso','36012','VI'),
											('0','Sasso','60040','AN'),
											('0','Sasso di Castalda','85050','PZ'),
											('0','Sasso di Neviano','43020','PR'),
											('0','Sasso d\'Ombrone','58040','GR'),
											('0','Sasso Guidano','41026','MO'),
											('0','Sasso Marconi','40037','BO'),
											('0','Sasso Morelli','40060','BO'),
											('0','Sasso Morello','41048','MO'),
											('0','Sasso Pisano','56041','PI'),
											('0','Sassocorvaro','61028','PU'),
											('0','Sassofeltrio','61013','PU'),
											('0','Sassoferrato','60041','AN'),
											('0','Sassofortino','58029','GR'),
											('0','Sassoleone','40022','BO'),
											('0','Sassostorno','41024','MO'),
											('0','Sassuolo','41049','MO'),
											('0','Satriano','88060','CZ'),
											('0','Satriano di Lucania','85050','PZ'),
											('0','Saturnana','51030','PT'),
											('0','Saturnia','58050','GR'),
											('0','Sauris','33020','UD'),
											('0','Sauze di Cesana','10054','TO'),
											('0','Sauze d\'Oulx','10050','TO'),
											('0','Sava','74028','TA'),
											('0','Sava','84081','SA'),
											('0','Savarna','48020','RA'),
											('0','Savelletri','72010','BR'),
											('0','Savelli','88825','KR'),
											('0','Savelli di Norcia','06040','PG'),
											('0','Saviano','80039','NA'),
											('0','Savigliano','12038','CN'),
											('0','Savignano di Rigo','47030','FC'),
											('0','Savignano Irpino','83030','AV'),
											('0','Savignano Montetassi','61010','PU'),
											('0','Savignano Stazione','83030','AV'),
											('0','Savignano Sul Panaro','41056','MO'),
											('0','Savignano Sul Rubicone','47039','FC'),
											('0','Savigno','40060','BO'),
											('0','Savignone','16010','GE'),
											('0','Savio','48020','RA'),
											('0','Saviore Dell\'Adamello','25040','BS'),
											('0','Savoca','98038','ME'),
											('0','Savogna','33040','UD'),
											('0','Savogna d\'Isonzo','34070','GO'),
											('0','Savognatica','42033','RE'),
											('0','Savoia di Lucania','85050','PZ'),
											('0','Savona','17100','SV'),
											('0','Savonera','10040','TO'),
											('0','Savoniero','41046','MO'),
											('0','Savorgnano','33078','PN'),
											('0','Savorgnano del Torre','33040','UD'),
											('0','Savuto di Cleto','87030','CS'),
											('0','Sbarre','89133','RC'),
											('0','Scafa','65027','PE'),
											('0','Scafali','06034','PG'),
											('0','Scafati','84018','SA'),
											('0','Scaffa San Sossio','03033','FR'),
											('0','Scagnello','12070','CN'),
											('0','Scai','02010','RI'),
											('0','Scala','84010','SA'),
											('0','Scala','98040','ME'),
											('0','Scala Coeli','87060','CS'),
											('0','Scala Ritiro','98152','ME'),
											('0','Scaldasole','27020','PV'),
											('0','Scalea','87029','CS'),
											('0','Scalenghe','10060','TO'),
											('0','Scalera','85020','PZ'),
											('0','Scaletta Uzzone','12070','CN'),
											('0','Scaletta Zanclea','98029','ME'),
											('0','Scaltenigo','30030','VE'),
											('0','Scalvaia','53015','SI'),
											('0','Scampitella','83050','AV'),
											('0','Scandale','88831','KR'),
											('0','Scandeluzza','14026','AT'),
											('0','Scandiano','42019','RE'),
											('0','Scandicci','50018','FI'),
											('0','Scandolara Ravara','26040','CR'),
											('0','Scandolara Ripa d\'Oglio','26047','CR'),
											('0','Scandriglia','02038','RI'),
											('0','Scannabue','26020','CR'),
											('0','Scanno','67038','AQ'),
											('0','Scano Montiferro','09078','OR'),
											('0','Scansano','58054','GR'),
											('0','Scanzano','75020','MT'),
											('0','Scanzano','80050','NA'),
											('0','Scanzano','67060','AQ'),
											('0','Scanzano','06030','PG'),
											('0','Scanzorosciate','24020','BG'),
											('0','Scapezzano','60010','AN'),
											('0','Scapoli','86070','IS'),
											('0','Scarcelli','87020','CS'),
											('0','Scardovari','45010','RO'),
											('0','Scaria','22020','CO'),
											('0','Scario','84070','SA'),
											('0','Scarlino','58020','GR'),
											('0','Scarlino Stazione','58020','GR'),
											('0','Scarmagno','10010','TO'),
											('0','Scarnafigi','12030','CN'),
											('0','Scarperia','50038','FI'),
											('0','Scauri','04028','LT'),
											('0','Scauri Siculo','91010','TP'),
											('0','Scena','39017','BZ'),
											('0','Scerne di Pineto','64020','TE'),
											('0','Scerni','66020','CH'),
											('0','Scesta','55050','LU'),
											('0','Scheggia','06027','PG'),
											('0','Scheggino','06040','PG'),
											('0','Schianno','21045','VA'),
											('0','Schiava','80030','NA'),
											('0','Schiavi di Abruzzo','66045','CH'),
											('0','Schiavoi','33077','PN'),
											('0','Schiavon','36060','VI'),
											('0','Schiavonea','87060','CS'),
											('0','Schierano','14020','AT'),
											('0','Schieti','61029','PU'),
											('0','Schifanoia','05030','TR'),
											('0','Schifoni','08020','NU'),
											('0','Schignano','22020','CO'),
											('0','Schilpario','24020','BG'),
											('0','Schio','36015','VI'),
											('0','Schivenoglia','46020','MN'),
											('0','Schlanders','39028','BZ'),
											('0','Schluderns','39020','BZ'),
											('0','Schnals','39020','BZ'),
											('0','Schonna','39017','BZ'),
											('0','Schweinsteg','39010','BZ'),
											('0','Sciacca','92019','AG'),
											('0','Sciara','90020','PA'),
											('0','Sciarborasca','16010','GE'),
											('0','Scicli','97018','RG'),
											('0','Sciconi','89817','VV'),
											('0','Scido','89010','RC'),
											('0','Scifelli','03020','FR'),
											('0','Scigliano','87057','CS'),
											('0','Scilla','89058','RC'),
											('0','Scillato','90020','PA'),
											('0','Scillichenti','95020','CT'),
											('0','Sciolze','10090','TO'),
											('0','Scipione','43039','PR'),
											('0','Scisciano','80030','NA'),
											('0','Sclafani Bagni','90020','PA'),
											('0','Scoffera','16020','GE'),
											('0','Scoglitti','97010','RG'),
											('0','Scomigo','31020','TV'),
											('0','Scontrone','67030','AQ'),
											('0','Scopa','13027','VC'),
											('0','Scopello','13028','VC'),
											('0','Scopello','91014','TP'),
											('0','Scopoli','06030','PG'),
											('0','Scoppito','67019','AQ'),
											('0','Scorcetoli','54020','MS'),
											('0','Scordia','95048','CT'),
											('0','Scorrano','64030','TE'),
											('0','Scorrano','73020','LE'),
											('0','Scortichino','44017','FE'),
											('0','Scorz','30037','VE'),
											('0','Scrima','03022','FR'),
											('0','Scri','34070','GO'),
											('0','Scritto','06020','PG'),
											('0','Scrofiano','53040','SI'),
											('0','Scurano','43020','PR'),
											('0','Scurcola Marsicana','67068','AQ'),
											('0','Scurelle','38050','TN'),
											('0','Scurtab','19020','SP'),
											('0','Scurzolengo','14030','AT'),
											('0','Seano','59011','PO'),
											('0','Seborga','18012','IM'),
											('0','Seccheto','57030','LI'),
											('0','Secchiano','61043','PU'),
											('0','Secchiano Marecchia','61015','PU'),
											('0','Secinaro','67029','AQ'),
											('0','Secl','73050','LE'),
											('0','Secondigliano','80144','NA'),
											('0','Secugnago','26826','LO'),
											('0','Sedegliano','33039','UD'),
											('0','Sedico','32036','BL'),
											('0','Sedilo','09076','OR'),
											('0','Sedini','07035','SS'),
											('0','Sedriano','20018','MI'),
											('0','Sedrina','24010','BG'),
											('0','Sefro','62025','MC'),
											('0','Sega dei Lessini','38061','TN'),
											('0','Sega di Cavaion','37010','VR'),
											('0','Segariu','09040','CA'),
											('0','Segezia','71020','FG'),
											('0','Seggiano','20096','MI'),
											('0','Seggiano','58038','GR'),
											('0','Seghe di Velo','36010','VI'),
											('0','Segni','00037','RM'),
											('0','Segonzano','38047','TN'),
											('0','Segrate','20090','MI'),
											('0','Segromigno in Monte','55018','LU'),
											('0','Segromigno in Piano','55010','LU'),
											('0','Segusino','31040','TV'),
											('0','Seiano','80066','NA'),
											('0','Seio','38011','TN'),
											('0','Seis Am Schlern','39040','BZ'),
											('0','Seiser Alm','39040','BZ'),
											('0','Seit Bei Leifers','39050','BZ'),
											('0','Selargius','09047','CA'),
											('0','Selci','06017','PG'),
											('0','Selci Sabino','02040','RI'),
											('0','Selegas','09040','CA'),
											('0','Selifone','08020','NU'),
											('0','Sella di Corno','67010','AQ'),
											('0','Sellano','06030','PG'),
											('0','Sellero','25050','BS'),
											('0','Sellia','88050','CZ'),
											('0','Sellia Marina','88050','CZ'),
											('0','Seluci','85040','PZ'),
											('0','Selva','80034','NA'),
											('0','Selva','58030','GR'),
											('0','Selva dei Molini','39030','BZ'),
											('0','Selva del Bocchetto','43040','PR'),
											('0','Selva del Montello','31040','TV'),
											('0','Selva di Altino','66040','CH'),
											('0','Selva di Cadore','32020','BL'),
											('0','Selva di Fasano','72010','BR'),
											('0','Selva di Grigno','38050','TN'),
											('0','Selva di Progno','37030','VR'),
											('0','Selva di Sora','03039','FR'),
											('0','Selva di Val Gardena','39048','BZ'),
											('0','Selva Malvezzi','40062','BO'),
											('0','Selva nel Frignano','41028','MO'),
											('0','Selvacava','03040','FR'),
											('0','Selvana Bassa','31100','TV'),
											('0','Selvanizza','43020','PR'),
											('0','Selvapiana','47020','FC'),
											('0','Selvatelle','56030','PI'),
											('0','Selvazzano Dentro','35030','PD'),
											('0','Selve Marcone','13811','BI'),
											('0','Selvena','58030','GR'),
											('0','Selvino','24020','BG'),
											('0','Semelano','41059','MO'),
											('0','Semestene','07010','SS'),
											('0','Semiana','27020','PV'),
											('0','Seminara','89028','RC'),
											('0','Semivicoli','66010','CH'),
											('0','Semogo','23030','SO'),
											('0','Semonte','06024','PG'),
											('0','Semonzo','31030','TV'),
											('0','Semproniano','58055','GR'),
											('0','S\'Ena Sa Chitta','08020','NU'),
											('0','Senago','20030','MI'),
											('0','Senale','39010','BZ'),
											('0','Senales','39020','BZ'),
											('0','Seneghe','09070','OR'),
											('0','Senerchia','83050','AV'),
											('0','Seniga','25020','BS'),
											('0','Senigallia','60019','AN'),
											('0','Senis','09080','OR'),
											('0','Senise','85038','PZ'),
											('0','Senna Comasco','22070','CO'),
											('0','Senna Lodigiana','26856','LO'),
											('0','Sennariolo','09078','OR'),
											('0','Sennori','07036','SS'),
											('0','Senorb','09040','CA'),
											('0','Sepicciano','81016','CE'),
											('0','Sepino','86017','CB'),
											('0','Seppiana','28843','VB'),
											('0','Seppio','62025','MC'),
											('0','Sequals','33090','PN'),
											('0','Seravezza','55047','LU'),
											('0','Serbadone','47834','RN'),
											('0','Serbariu','09010','CA'),
											('0','Serdiana','09040','CA'),
											('0','Seregno','20038','MI'),
											('0','Seren del Grappa','32030','BL'),
											('0','Sergnano','26010','CR'),
											('0','Seriate','24068','BG'),
											('0','Serina','24017','BG'),
											('0','Serino','83028','AV'),
											('0','Serle','25080','BS'),
											('0','Sermide','46028','MN'),
											('0','Sermoneta','04013','LT'),
											('0','Sermugnano','01020','VT'),
											('0','Sernaglia della Battaglia','31020','TV'),
											('0','Sernio','23030','SO'),
											('0','Serole','14050','AT'),
											('0','Serpiano','41020','MO'),
											('0','Serra','83030','AV'),
											('0','Serra d\'Aiello','87030','CS'),
											('0','Serra De\' Conti','60030','AN'),
											('0','Serra di Castelcivita','84020','SA'),
											('0','Serra di Pratola Serra','83030','AV'),
											('0','Serra Pamparato','12080','CN'),
											('0','Serra Pedace','87050','CS'),
											('0','Serra Pistoiese','51010','PT'),
											('0','Serra Ricc','16010','GE'),
											('0','Serra San Bruno','89822','VV'),
											('0','Serra San Quirico','60048','AN'),
											('0','Serra San Quirico Stazione','60049','AN'),
											('0','Serra Sant\'Abbondio','61040','PU'),
											('0','Serracapriola','71010','FG'),
											('0','Serrada di Folgaria','38060','TN'),
											('0','Serradarce','84020','SA'),
											('0','Serradica','60040','AN'),
											('0','Serradifalco','93010','CL'),
											('0','Serralunga d\'Alba','12050','CN'),
											('0','Serralunga di Crea','15020','AL'),
											('0','Serramanna','09038','CA'),
											('0','Serramarina','75010','MT'),
											('0','Serramazzoni','41028','MO'),
											('0','Serramezzana','84070','SA'),
											('0','Serramonacesca','65020','PE'),
											('0','Serrano','73020','LE'),
											('0','Serranova di Carovigno','72010','BR'),
											('0','Serrapetrona','62020','MC'),
											('0','Serrara','80070','NA'),
											('0','Serrastretta','88040','CZ'),
											('0','Serrata','89020','RC'),
											('0','Serravalle','19034','SP'),
											('0','Serravalle','44030','FE'),
											('0','Serravalle All\'Adige','38060','TN'),
											('0','Serravalle d\'Asti','14020','AT'),
											('0','Serravalle di Bibbiena','52010','AR'),
											('0','Serravalle di Carda','61042','PU'),
											('0','Serravalle di Chienti','62038','MC'),
											('0','Serravalle di Norcia','06040','PG'),
											('0','Serravalle Langhe','12050','CN'),
											('0','Serravalle Pistoiese','51030','PT'),
											('0','Serravalle Po','46030','MN'),
											('0','Serravalle Scrivia','15069','AL'),
											('0','Serravalle Sesia','13037','VC'),
											('0','Serrazzano','56040','PI'),
											('0','Serrazzone','41021','MO'),
											('0','Serre','84028','SA'),
											('0','Serre di Rapolano','53040','SI'),
											('0','Serrenti','09027','CA'),
											('0','Serri','08030','NU'),
											('0','Serricciolo','54010','MS'),
											('0','Serricella','87040','CS'),
											('0','Serro','98040','ME'),
											('0','Serrone','03010','FR'),
											('0','Serrungarina','61030','PU'),
											('0','Sersale','88054','CZ'),
											('0','Serso','38057','TN'),
											('0','Servigliano','63029','AP'),
											('0','Sessa Aurunca','81037','CE'),
											('0','Sessa Cilento','84074','SA'),
											('0','Sessame','14058','AT'),
											('0','Sessano del Molise','86097','IS'),
											('0','Sessant','14020','AT'),
											('0','Sesso','42020','RE'),
											('0','Sesta Godano','19020','SP'),
											('0','Sestino','52038','AR'),
											('0','Sesto','39030','BZ'),
											('0','Sesto Al Reghena','33079','PN'),
											('0','Sesto Calende','21018','VA'),
											('0','Sesto Campano','86078','IS'),
											('0','Sesto Cremonese','26028','CR'),
											('0','Sesto Ed Uniti','26028','CR'),
											('0','Sesto Fiorentino','50019','FI'),
											('0','Sesto Imolese','40060','BO'),
											('0','Sesto San Giovanni','20099','MI'),
											('0','Sesto Ulteriano','20098','MI'),
											('0','Sestola','41029','MO'),
											('0','Sestri Levante','16039','GE'),
											('0','Sestri Ponente','16154','GE'),
											('0','Sestriere','10058','TO'),
											('0','Sestu','09028','CA'),
											('0','Settala','20090','MI'),
											('0','Settebagni','00138','RM'),
											('0','Settec','36100','VI'),
											('0','Settecamini','00131','RM'),
											('0','Settefrati','03040','FR'),
											('0','Setteville di Guidonia','00010','RM'),
											('0','Settignano','50135','FI'),
											('0','Settima','29020','PC'),
											('0','Settime','14020','AT'),
											('0','Settimello','50041','FI'),
											('0','Settimo Milanese','20019','MI'),
											('0','Settimo Rottaro','10010','TO'),
											('0','Settimo San Pietro','09040','CA'),
											('0','Settimo Torinese','10036','TO'),
											('0','Settimo Vittone','10010','TO'),
											('0','Settingiano','88040','CZ'),
											('0','Setzu','09029','CA'),
											('0','Seui','08037','NU'),
											('0','Seulo','08030','NU'),
											('0','Seveso','20030','MI'),
											('0','Sevignano','38047','TN'),
											('0','Sexten','39030','BZ'),
											('0','Sezzadio','15079','AL'),
											('0','Sezze','04018','LT'),
											('0','Sezze Stazione','04010','LT'),
											('0','Sfaranda','98070','ME'),
											('0','Sferracavallo','05010','TR'),
											('0','Sferracavallo','90148','PA'),
											('0','Sferro','95040','CT'),
											('0','Sforzacosta','62010','MC'),
											('0','Sforzatica','24044','BG'),
											('0','Sfruz','38010','TN'),
											('0','Sgonico','34010','TS'),
											('0','Sgurgola','03010','FR'),
											('0','Siamaggiore','09070','OR'),
											('0','Siamanna Siapiccia','09080','OR'),
											('0','Siano','84088','SA'),
											('0','Siano','88100','CZ'),
											('0','Sibari Stazione','87070','CS'),
											('0','Sicignano degli Alburni','84029','SA'),
											('0','Sicignano degli Alburni Stazione','84020','SA'),
											('0','Sicili','84030','SA'),
											('0','Siculiana','92010','AG'),
											('0','Siddi','09020','CA'),
											('0','Siderno Marina','89048','RC'),
											('0','Siderno Superiore','89040','RC'),
											('0','Sieci','50069','FI'),
											('0','Siena','53100','SI'),
											('0','Sieti','84090','SA'),
											('0','Sigillo','06028','PG'),
											('0','Sigillo di Posta','02010','RI'),
											('0','Sigmundskron','39010','BZ'),
											('0','Signa','50058','FI'),
											('0','Signayes','11100','AO'),
											('0','Silandro','39028','BZ'),
											('0','Silanus','08017','NU'),
											('0','Silea','31057','TV'),
											('0','Sil','09087','OR'),
											('0','Siligo','07040','SS'),
											('0','Silimini','08020','NU'),
											('0','Siliqua','09010','CA'),
											('0','Silius','09040','CA'),
											('0','Silla','40041','BO'),
											('0','Silla','84030','SA'),
											('0','Sillano','55030','LU'),
											('0','Sillavengo','28064','NO'),
											('0','Silvana Mansio','87050','CS'),
											('0','Silvano d\'Orba','15060','AL'),
											('0','Silvano Pietra','27050','PV'),
											('0','Silvi','64028','TE'),
											('0','Silvi Marina','64029','TE'),
											('0','Simala','09090','OR'),
											('0','Simaxis','09088','OR'),
											('0','Simbario','89822','VV'),
											('0','Simeri Crichi','88050','CZ'),
											('0','Sinagra','98069','ME'),
											('0','Sinalunga','53048','SI'),
											('0','Sindia','08018','NU'),
											('0','Sini','09090','OR'),
											('0','Sinio','12050','CN'),
											('0','Siniscola','08029','NU'),
											('0','Sinnai','09048','CA'),
											('0','Sinopoli','89020','RC'),
											('0','Sinopoli Inferiore','89020','RC'),
											('0','Sipicciano','01020','VT'),
											('0','Sipicciano','81044','CE'),
											('0','Siponto','71040','FG'),
											('0','Siracusa','96100','SR'),
											('0','Sirai','09013','CA'),
											('0','Sirignano','83020','AV'),
											('0','Siris','09090','OR'),
											('0','Sirmione','25019','BS'),
											('0','Sirolo','60020','AN'),
											('0','Sirone','23844','LC'),
											('0','Siror','38054','TN'),
											('0','Sirtori','23896','LC'),
											('0','S\'Iscala','08020','NU'),
											('0','Sisini','09040','CA'),
											('0','Sismano','05020','TR'),
											('0','Sissa','43018','PR'),
											('0','Sistiana','34019','TS'),
											('0','Sitizano','89010','RC'),
											('0','Siurgus Donigala','09040','CA'),
											('0','Siusi','39040','BZ'),
											('0','Siviano','25050','BS'),
											('0','Sivizzano','43050','PR'),
											('0','Siziano','27010','PV'),
											('0','Sizzano','28070','NO'),
											('0','Sluderno','39020','BZ'),
											('0','Smarano','38010','TN'),
											('0','Smerillo','63020','AP'),
											('0','Smirra','61043','PU'),
											('0','Soanne','61016','PU'),
											('0','Soave','37038','VR'),
											('0','Soave Mantovano','46040','MN'),
											('0','Soccavo','80126','NA'),
											('0','Soccher','32011','BL'),
											('0','Socchieve','33020','UD'),
											('0','Soccorso','98040','ME'),
											('0','Soci','52010','AR'),
											('0','Sodd','09080','OR'),
											('0','Sogliano Al Rubicone','47030','FC'),
											('0','Sogliano Cavour','73010','LE'),
											('0','Soglio','14020','AT'),
											('0','Soiana','56030','PI'),
											('0','Soiano del Lago','25080','BS'),
											('0','Sois','32100','BL'),
											('0','Solagna','36020','VI'),
											('0','Solanas','09072','OR'),
											('0','Solano Inferiore','89010','RC'),
											('0','Solara','41030','MO'),
											('0','Solarino','96010','SR'),
											('0','Solaro','20020','MI'),
											('0','Solarolo','46040','MN'),
											('0','Solarolo','48027','RA'),
											('0','Solarolo Rainerio','26030','CR'),
											('0','Solarussa','09077','OR'),
											('0','Solbiate Arno','21048','VA'),
											('0','Solbiate Comasco','22070','CO'),
											('0','Solbiate Olona','21058','VA'),
											('0','Solda','39029','BZ'),
											('0','Soldano','18036','IM'),
											('0','Soleminis','09040','CA'),
											('0','Solero','15029','AL'),
											('0','Solesino','35047','PD'),
											('0','Soleto','73010','LE'),
											('0','Solfagnano','06080','PG'),
											('0','Solferino','46040','MN'),
											('0','Solicchiata','95030','CT'),
											('0','Soliera','41019','MO'),
											('0','Soliera Apuana','54018','MS'),
											('0','Solighetto','31053','TV'),
											('0','Solignano','43040','PR'),
											('0','Solignano Nuovo','41014','MO'),
											('0','Soligo','31010','TV'),
											('0','Solimbergo','33090','PN'),
											('0','Solit','08020','NU'),
											('0','Solofra','83029','AV'),
											('0','Sologno','42030','RE'),
											('0','Solomiac','10054','TO'),
											('0','Solonghello','15020','AL'),
											('0','Solopaca','82036','BN'),
											('0','Solto Collina','24060','BG'),
											('0','Solza','24030','BG'),
											('0','Solzago','22038','CO'),
											('0','Somaggia','23028','SO'),
											('0','Somaglia','26867','LO'),
											('0','Somano','12060','CN'),
											('0','Somma Lombardo','21019','VA'),
											('0','Somma Vesuviana','80049','NA'),
											('0','Sommacampagna','37066','VR'),
											('0','Sommacolonia','55051','LU'),
											('0','Sommariva Bosco','12048','CN'),
											('0','Sommariva Perno','12040','CN'),
											('0','Sommati','02012','RI'),
											('0','Sommatino','93019','CL'),
											('0','Sommo','27048','PV'),
											('0','Sona','37060','VR'),
											('0','Soncino','26029','CR'),
											('0','Sondalo','23035','SO'),
											('0','Sondrio','23100','SO'),
											('0','Songavazzo','24020','BG'),
											('0','Sonico','25048','BS'),
											('0','Sonnino','04010','LT'),
											('0','Soprabolzano','39059','BZ'),
											('0','Sopramonte','38070','TN'),
											('0','Soprana','13834','BI'),
											('0','Sora','03039','FR'),
											('0','Soraga','38030','TN'),
											('0','Soragna','43019','PR'),
											('0','Sorano','58010','GR'),
											('0','Soranzen','32030','BL'),
											('0','Sorbano','47027','FC'),
											('0','Sorbara','41030','MO'),
											('0','Sorbo di Montella','83050','AV'),
											('0','Sorbo di Tagliacozzo','67060','AQ'),
											('0','Sorbo San Basile','88050','CZ'),
											('0','Sorbo Serpico','83050','AV'),
											('0','Sorbolo','43058','PR'),
											('0','Sorbolongo','61040','PU'),
											('0','Sordevolo','13817','BI'),
											('0','Sordio','26858','LO'),
											('0','Soresina','26015','CR'),
											('0','Sorg','37060','VR'),
											('0','Sorgane','50126','FI'),
											('0','Sorgenti di Santa Lucia','07012','SS'),
											('0','Sorgnano','54030','MS'),
											('0','Sorgono','08038','NU'),
											('0','Sori','16030','GE'),
											('0','Soria','61100','PU'),
											('0','Sorianello','89831','VV'),
											('0','Soriano Calabro','89831','VV'),
											('0','Soriano nel Cimino','01038','VT'),
											('0','Sorico','22010','CO'),
											('0','Soriso','28010','NO'),
											('0','Sorisole','24010','BG'),
											('0','Sormano','22030','CO'),
											('0','Sorradile','09080','OR'),
											('0','Sorrento','80067','NA'),
											('0','Sorso','07037','SS'),
											('0','Sortino','96010','SR'),
											('0','Sorvaro','84050','SA'),
											('0','Sos Alinos','08028','NU'),
											('0','Sospiro','26048','CR'),
											('0','Sospirolo','32037','BL'),
											('0','Sossai','32024','BL'),
											('0','Sossano','36040','VI'),
											('0','Sostegno','13868','BI'),
											('0','Sotto Il Monte Giovanni Xxiii','24039','BG'),
											('0','Sottocastello','32040','BL'),
											('0','Sottomarina','30019','VE'),
											('0','Sovana','58010','GR'),
											('0','Sovazza','28010','NO'),
											('0','Sover','38048','TN'),
											('0','Soverato','88068','CZ'),
											('0','Soverato Superiore','88068','CZ'),
											('0','Sovere','24060','BG'),
											('0','Soveria Mannelli','88049','CZ'),
											('0','Soveria Simeri','88050','CZ'),
											('0','Soverzene','32010','BL'),
											('0','Sovicille','53018','SI'),
											('0','Sovico','20050','MI'),
											('0','Sovigliana','50053','FI'),
											('0','Sovizzo','36050','VI'),
											('0','Sovramonte','32030','BL'),
											('0','Sozzago','28060','NO'),
											('0','Sozzigalli','41019','MO'),
											('0','Spadafora','98048','ME'),
											('0','Spadola','89822','VV'),
											('0','Spagnola','91020','TP'),
											('0','Sparanise','81056','CE'),
											('0','Sparone','10080','TO'),
											('0','Spart','98163','ME'),
											('0','Spazzate Sassatelli','40060','BO'),
											('0','Specchia','73040','LE'),
											('0','Specchia Gallone','73020','LE'),
											('0','Specchia Tarantina','74010','TA'),
											('0','Specchio','43040','PR'),
											('0','Spello','06038','PG'),
											('0','Spelonga','63043','AP'),
											('0','Spera','38059','TN'),
											('0','Spercenigo','31050','TV'),
											('0','Sperlinga','94010','EN'),
											('0','Sperlonga','04029','LT'),
											('0','Sperone','83020','AV'),
											('0','Sperone di Custonaci','91010','TP'),
											('0','Spert','32010','BL'),
											('0','Spessa','27010','PV'),
											('0','Spezzano','41040','MO'),
											('0','Spezzano Albanese','87019','CS'),
											('0','Spezzano Albanese Stazione','87010','CS'),
											('0','Spezzano Albanese Terme','87010','CS'),
											('0','Spezzano della Sila','87058','CS'),
											('0','Spezzano Piccolo','87050','CS'),
											('0','Spianate','55010','LU'),
											('0','Spiano','64040','TE'),
											('0','Spiano','84085','SA'),
											('0','Spiazzi','37010','VR'),
											('0','Spiazzo Rendena','38088','TN'),
											('0','Spicchio','50053','FI'),
											('0','Spigno Monferrato','15018','AL'),
											('0','Spigno Saturnia','04020','LT'),
											('0','Spilamberto','41057','MO'),
											('0','Spilimbergo','33097','PN'),
											('0','Spilinga','89864','VV'),
											('0','Spin','36060','VI'),
											('0','Spina','06050','PG'),
											('0','Spinadesco','26020','CR'),
											('0','Spinazzola','70058','BA'),
											('0','Spinea','30038','VE'),
											('0','Spineda','26030','CR'),
											('0','Spinete','86020','CB'),
											('0','Spineto Scrivia','15050','AL'),
											('0','Spinetoli','63036','AP'),
											('0','Spinetta','12010','CN'),
											('0','Spinetta Marengo','15047','AL'),
											('0','Spinimbecco','37040','VR'),
											('0','Spino d\'Adda','26016','CR'),
											('0','Spinone Al Lago','24060','BG'),
											('0','Spinoso','85050','PZ'),
											('0','Spirano','24050','BG'),
											('0','Spirito Santo','89128','RC'),
											('0','Spoleto','06049','PG'),
											('0','Spoltore','65010','PE'),
											('0','Spongano','73038','LE'),
											('0','Spormaggiore','38010','TN'),
											('0','Sporminore','38010','TN'),
											('0','Spotorno','17028','SV'),
											('0','Spresiano','31027','TV'),
											('0','Spriana','23020','SO'),
											('0','Squillace','88069','CZ'),
											('0','Squillani','83010','AV'),
											('0','Squille','81010','CE'),
											('0','Squinzano','73018','LE'),
											('0','St.Andra','39040','BZ'),
											('0','St.Christina','39047','BZ'),
											('0','St.Felix','39010','BZ'),
											('0','St.Gertraud in Ulten','39010','BZ'),
											('0','St.Jakob Bei Bozen','39050','BZ'),
											('0','St.Jakob in Ahrntal','39030','BZ'),
											('0','St.Johann in Ahrntal','39030','BZ'),
											('0','St.Kassian','39030','BZ'),
											('0','St.Leonhard in Passeier','39015','BZ'),
											('0','St.Lorenzen','39030','BZ'),
											('0','St.Lugano','39040','BZ'),
											('0','St.Martin Gsies','39030','BZ'),
											('0','St.Martin in Passeier','39010','BZ'),
											('0','St.Martin in Thurn','39030','BZ'),
											('0','St.Nikolaus Ulten','39010','BZ'),
											('0','St.Pankraz','39010','BZ'),
											('0','St.Pauls','39050','BZ'),
											('0','St.Peter Lajen','39040','BZ'),
											('0','St.Sigmund','39030','BZ'),
											('0','St.Ulrich','39046','BZ'),
											('0','St.Valentin A.D. Heide','39020','BZ'),
											('0','St.Vigil Enneberg','39030','BZ'),
											('0','St.Walburg Ulten','39016','BZ'),
											('0','Stabbia','50050','FI'),
											('0','Staben','39020','BZ'),
											('0','Stadolina','25050','BS'),
											('0','Staffarda','12030','CN'),
											('0','Staffoli','56020','PI'),
											('0','Staffolo','60039','AN'),
											('0','Staggia','53038','SI'),
											('0','Staggia Modenese','41030','MO'),
											('0','Staggiano','52030','AR'),
											('0','Staglieno','16137','GE'),
											('0','Stagno','57017','LI'),
											('0','Stagno Lombardo','26049','CR'),
											('0','Staiti','89030','RC'),
											('0','Stalett','88069','CZ'),
											('0','Stallavena','37020','VR'),
											('0','Stange','39040','BZ'),
											('0','Stanghe','39040','BZ'),
											('0','Stanghella','35048','PD'),
											('0','Stanic','70123','BA'),
											('0','Staranzano','34079','GO'),
											('0','Staro','36030','VI'),
											('0','Starze di Summonte','83010','AV'),
											('0','Statigliano','81051','CE'),
											('0','Statte','74010','TA'),
											('0','Staturano','81100','CE'),
											('0','Stava','39020','BZ'),
											('0','Stazzano','15060','AL'),
											('0','Stazzema','55040','LU'),
											('0','Stazzo','95020','CT'),
											('0','Stazzona','22010','CO'),
											('0','Stazzu Bruciatu','08020','NU'),
											('0','Stazzu Mesu','08020','NU'),
											('0','Stefanaconi','89843','VV'),
											('0','Steinegg','39050','BZ'),
											('0','Steinhaus','39030','BZ'),
											('0','Steinmannwald','39050','BZ'),
											('0','Stella','17044','SV'),
											('0','Stella Cilento','84070','SA'),
											('0','Stella di Monsanpolo','63030','AP'),
											('0','Stellanello','17020','SV'),
											('0','Stellata','44010','FE'),
											('0','Stelletanone','89050','RC'),
											('0','Stelvio','39020','BZ'),
											('0','Stenico','38070','TN'),
											('0','Stern','39030','BZ'),
											('0','Sternatia','73010','LE'),
											('0','Sterpete','06034','PG'),
											('0','Sterpito','85020','PZ'),
											('0','Sterzing','39049','BZ'),
											('0','Stevani','15030','AL'),
											('0','Stezzano','24040','BG'),
											('0','Stia','52017','AR'),
											('0','Stiava','55040','LU'),
											('0','Sticciano','58030','GR'),
											('0','Sticciano Stazione','58030','GR'),
											('0','Stienta','45039','RO'),
											('0','Stifone','05027','TR'),
											('0','Stigliano','75018','MT'),
											('0','Stignano','89040','RC'),
											('0','Stilfs','39020','BZ'),
											('0','Stilo','89049','RC'),
											('0','Stimigliano','02048','RI'),
											('0','Stimigliano Stazione','02040','RI'),
											('0','Stintino','07040','SS'),
											('0','Stio','84075','SA'),
											('0','Stipes','02020','RI'),
											('0','Stocchetta','25136','BS'),
											('0','Stolvizza','33010','UD'),
											('0','Stoner','36052','VI'),
											('0','Stornara','71047','FG'),
											('0','Stornarella','71048','FG'),
											('0','Storo','38089','TN'),
											('0','Str','29010','PC'),
											('0','Str','30039','VE'),
											('0','Strada','52018','AR'),
											('0','Strada','62011','MC'),
											('0','Strada in Chianti','50027','FI'),
											('0','Strada San Zeno','47010','FC'),
											('0','Stradella','27049','PV'),
											('0','Strambinello','10010','TO'),
											('0','Strambino','10019','TO'),
											('0','Stramentizzo','38030','TN'),
											('0','Strangolagalli','03020','FR'),
											('0','Strasatti di Marsala','91020','TP'),
											('0','Strassoldo','33050','UD'),
											('0','Straulas','08020','NU'),
											('0','Stravignino','25060','BS'),
											('0','Stravino','38073','TN'),
											('0','Stregna','33040','UD'),
											('0','Strela','43050','PR'),
											('0','Strembo','38080','TN'),
											('0','Stresa','28838','VB'),
											('0','Stretti di Eraclea','30020','VE'),
											('0','Strettura','06040','PG'),
											('0','Strevi','15019','AL'),
											('0','Striano','80040','NA'),
											('0','Stribugliano','58040','GR'),
											('0','Strigno','38059','TN'),
											('0','Stromboli','98050','ME'),
											('0','Strona','13823','BI'),
											('0','Stroncone','05039','TR'),
											('0','Strongoli','88816','KR'),
											('0','Stroppiana','13010','VC'),
											('0','Stroppo','12020','CN'),
											('0','Strove','53035','SI'),
											('0','Strozza','24030','BG'),
											('0','Strud','73020','LE'),
											('0','Strugas','08020','NU'),
											('0','Struppa','16165','GE'),
											('0','Stuffione','41017','MO'),
											('0','Stupinigi','10040','TO'),
											('0','Sturla','16147','GE'),
											('0','Sturno','83055','AV'),
											('0','Su Canale','07020','SS'),
											('0','Su Cologone','08025','NU'),
											('0','Su Cossu','08020','NU'),
											('0','Su Lau','08034','NU'),
											('0','Su Linalvu','08020','NU'),
											('0','Su Pinu','08048','NU'),
											('0','Su Pradu','08020','NU'),
											('0','Su Tillio','08020','NU'),
											('0','Su Troccu','08048','NU'),
											('0','Suardi','27030','PV'),
											('0','Suaredda','08020','NU'),
											('0','Subbiano','52010','AR'),
											('0','Subiaco','00028','RM'),
											('0','Succhivo','80070','NA'),
											('0','Succiso','42030','RE'),
											('0','Succivo','81030','CE'),
											('0','Sueglio','23835','LC'),
											('0','Suelli','09040','CA'),
											('0','Suello','23867','LC'),
											('0','Sugano','05010','TR'),
											('0','Suio Terme','04020','LT'),
											('0','Suisio','24040','BG'),
											('0','Sulbiate','20050','MI'),
											('0','Sulden','39029','BZ'),
											('0','Sulmona','67039','AQ'),
											('0','Sulzano','25058','BS'),
											('0','Sumirago','21040','VA'),
											('0','Summaga','30020','VE'),
											('0','Summonte','83010','AV'),
											('0','Suna','','VB'),
											('0','Suni','08010','NU'),
											('0','Suno','28019','NO'),
											('0','Superga','10132','TO'),
											('0','Supersano','73040','LE'),
											('0','Supino','03019','FR'),
											('0','Surano','73030','LE'),
											('0','Surbo','73010','LE'),
											('0','Surdo','87030','CS'),
											('0','Susa','10059','TO'),
											('0','Susano','41046','MO'),
											('0','Susano','40040','BO'),
											('0','Susegana','31058','TV'),
											('0','Sustinente','46030','MN'),
											('0','Sutera','93010','CL'),
											('0','Sutri','01015','VT'),
											('0','Sutrio','33020','UD'),
											('0','Suvereto','57028','LI'),
											('0','Suvero','19020','SP'),
											('0','Suviana','40030','BO'),
											('0','Suzzara','46029','MN'),
											('0','Tabaccaro','91020','TP'),
											('0','Tabellano','46030','MN'),
											('0','Tabiano','43030','PR'),
											('0','Taccona','20053','MI'),
											('0','Taccone','75022','MT'),
											('0','Taceno','23837','LC'),
											('0','Tadasuni','09080','OR'),
											('0','Taggia','18018','IM'),
											('0','Tagliacozzo','67069','AQ'),
											('0','Tagliata','12045','CN'),
											('0','Taglio di Po','45019','RO'),
											('0','Tagliole','41027','MO'),
											('0','Tagliolo Monferrato','15070','AL'),
											('0','Tai di Cadore','32040','BL'),
											('0','Taibon Agordino','32027','BL'),
											('0','Taiedo','33083','PN'),
											('0','Taino','21020','VA'),
											('0','Taio','38010','TN'),
											('0','Taipana','33040','UD'),
											('0','Taizzano','05030','TR'),
											('0','Talamello','61015','PU'),
											('0','Talamona','23018','SO'),
											('0','Talamone','58010','GR'),
											('0','Talana','08040','NU'),
											('0','Talav','08020','NU'),
											('0','Taleggio','24010','BG'),
											('0','Talignano','43030','PR'),
											('0','Talla','52010','AR'),
											('0','Tallacano','63041','AP'),
											('0','Talmassons','33030','UD'),
											('0','Talsano','74029','TA'),
											('0','Tamai','33070','PN'),
											('0','Tamara','44030','FE'),
											('0','Tamarispa','08020','NU'),
											('0','Tambre d\'Alpago','32010','BL'),
											('0','Tanas','39020','BZ'),
											('0','Tanaunella','08020','NU'),
											('0','Tancau','08040','NU'),
											('0','Taormina','98039','ME'),
											('0','Tapogliano','33040','UD'),
											('0','Taquisara','08040','NU'),
											('0','Tarano','02040','RI'),
											('0','Taranta Peligna','66018','CH'),
											('0','Tarantasca','12020','CN'),
											('0','Taranto','74100','TA'),
											('0','Tarcento','33017','UD'),
											('0','Tarces','39020','BZ'),
											('0','Tardiano','84030','SA'),
											('0','Tarquinia','01016','VT'),
											('0','Tarres','39020','BZ'),
											('0','Tarsch','39020','BZ'),
											('0','Tarsia','87040','CS'),
											('0','Tarsogno','43050','PR'),
											('0','Tartano','23010','SO'),
											('0','Tartsch','39020','BZ'),
											('0','Tarvisio','33018','UD'),
											('0','Tarzo','31020','TV'),
											('0','Tassarolo','15060','AL'),
											('0','Tassullo','38010','TN'),
											('0','Tatti','58040','GR'),
											('0','Taufers Im Munstertal','39020','BZ'),
											('0','Taurano','83020','AV'),
											('0','Taurasi','83030','AV'),
											('0','Taureana','89010','RC'),
											('0','Tauriano','33097','PN'),
											('0','Taurianova','89029','RC'),
											('0','Taurisano','73056','LE'),
											('0','Tavagnacco','33010','UD'),
											('0','Tavagnasco','10010','TO'),
											('0','Tavarnelle Val di Pesa','50028','FI'),
											('0','Tavarnuzze','50029','FI'),
											('0','Tavazzano Con Villavesco','26838','LO'),
											('0','Tavenna','86030','CB'),
											('0','Taverna','88055','CZ'),
											('0','Taverna di Montalto Uffugo','87040','CS'),
											('0','Taverna di Monte Colombo','47854','RN'),
											('0','Taverna di Schiavi di Abruzzo','66040','CH'),
											('0','Tavernanova','80013','NA'),
											('0','Taverne d\'Arbia','53010','SI'),
											('0','Tavernelle','06068','PG'),
											('0','Tavernelle','54010','MS'),
											('0','Tavernelle','61030','PU'),
											('0','Tavernelle Emilia','40010','BO'),
											('0','Tavernelle Vicentina','36077','VI'),
											('0','Tavernerio','22038','CO'),
											('0','Tavernola','71040','FG'),
											('0','Tavernola','22100','CO'),
											('0','Tavernola Bergamasca','24060','BG'),
											('0','Tavernola San Felice','83020','AV'),
											('0','Tavernole Sul Mella','25060','BS'),
											('0','Taviano','73057','LE'),
											('0','Tavigliano','13811','BI'),
											('0','Tavodo','38070','TN'),
											('0','Tavola','59014','PO'),
											('0','Tavoleto','61020','PU'),
											('0','Tavon','38010','TN'),
											('0','Tavullia','61010','PU'),
											('0','Teana','85032','PZ'),
											('0','Teano','81057','CE'),
											('0','Tecchiena','03010','FR'),
											('0','Teggiano','84039','SA'),
											('0','Teglia','16161','GE'),
											('0','Teglio','23036','SO'),
											('0','Teglio Veneto','30025','VE'),
											('0','Tegoleto','52040','AR'),
											('0','Tel','39020','BZ'),
											('0','Telese Terme','82037','BN'),
											('0','Telgate','24060','BG'),
											('0','Tellaro','19030','SP'),
											('0','Telti','07020','SS'),
											('0','Telve di Sopra','38050','TN'),
											('0','Telve di Valsugana','38050','TN'),
											('0','Tempio Pausania','07029','SS'),
											('0','Tem','25050','BS'),
											('0','Tenaglie','05020','TR'),
											('0','Tencarola','35030','PD'),
											('0','Tendola','54030','MS'),
											('0','Tenerano','54020','MS'),
											('0','Tenna','38050','TN'),
											('0','Tenno','38060','TN'),
											('0','Teodone','39031','BZ'),
											('0','Teodorano','47010','FC'),
											('0','Teolo','35037','PD'),
											('0','Teor','33050','UD'),
											('0','Teora','83056','AV'),
											('0','Teramo','64100','TE'),
											('0','Terdobbiate','28070','NO'),
											('0','Tereglio','55020','LU'),
											('0','Terelle','03040','FR'),
											('0','Terenten','39030','BZ'),
											('0','Terento','39030','BZ'),
											('0','Terenzano','33050','UD'),
											('0','Terenzo','43040','PR'),
											('0','Tergu','07030','SS'),
											('0','Terlago','38070','TN'),
											('0','Terlan','39018','BZ'),
											('0','Terlano','39018','BZ'),
											('0','Terlizzi','70038','BA'),
											('0','Terme di Stigliano','00060','RM'),
											('0','Terme Vigliatore','98050','ME'),
											('0','Termeno sulla Strada del Vino','39040','BZ'),
											('0','Termine','32010','BL'),
											('0','Termini','80068','NA'),
											('0','Termini Imerese','90018','PA'),
											('0','Termo','19136','SP'),
											('0','Termoli','86039','CB'),
											('0','Ternate','21020','VA'),
											('0','Ternengo','13844','BI'),
											('0','Terni','05100','TR'),
											('0','Terno d\'Isola','24030','BG'),
											('0','Terontola','52040','AR'),
											('0','Terra del Sole','47010','FC'),
											('0','Terracina','04019','LT'),
											('0','Terradura di Ascea','84070','SA'),
											('0','Terragnolo','38060','TN'),
											('0','Terralba','09098','OR'),
											('0','Terranegra','35127','PD'),
											('0','Terranegra','37040','VR'),
											('0','Terranova','66010','CH'),
											('0','Terranova da Sibari','87010','CS'),
											('0','Terranova d\'Arpaise','82010','BN'),
											('0','Terranova dei Passerini','26827','LO'),
											('0','Terranova di Pollino','85030','PZ'),
											('0','Terranova Monferrato','15030','AL'),
											('0','Terranova Sappo Minulio','89010','RC'),
											('0','Terranuova Bracciolini','52028','AR'),
											('0','Terrapadedda','08020','NU'),
											('0','Terrarossa','54019','MS'),
											('0','Terrasini','90049','PA'),
											('0','Terrassa Padovana','35020','PD'),
											('0','Terrati','87030','CS'),
											('0','Terravecchia','87060','CS'),
											('0','Terrazzano','20017','MI'),
											('0','Terrazzo','37040','VR'),
											('0','Terrenove Bambina','91020','TP'),
											('0','Terres','38010','TN'),
											('0','Terresoli','09010','CA'),
											('0','Terreti','89060','RC'),
											('0','Terricciola','56030','PI'),
											('0','Terrinca','55040','LU'),
											('0','Terrossa','37030','VR'),
											('0','Terruggia','15030','AL'),
											('0','Tertenia','08047','NU'),
											('0','Terzigno','80040','NA'),
											('0','Terzo','15010','AL'),
											('0','Terzo di Aquileia','33050','UD'),
											('0','Terzo di Tolmezzo','33020','UD'),
											('0','Terzo La Pieve','06040','PG'),
											('0','Terzolas','38027','TN'),
											('0','Terzone','02010','RI'),
											('0','Terzorio','18010','IM'),
											('0','Tesero','38038','TN'),
											('0','Tesimo','39010','BZ'),
											('0','Tesoriero','98068','ME'),
											('0','Tessano','87040','CS'),
											('0','Tessello','47020','FC'),
											('0','Tessennano','01010','VT'),
											('0','Tessera','30030','VE'),
											('0','Testa Dell\'Acqua','96010','SR'),
											('0','Testa di Lepre di Sopra','00050','RM'),
											('0','Testaccio d\'Ischia','80070','NA'),
											('0','Testico','17020','SV'),
											('0','Testona','10027','TO'),
											('0','Teti','08030','NU'),
											('0','Teulada','09019','CA'),
											('0','Teverola','81030','CE'),
											('0','Tezze','31028','TV'),
											('0','Tezze','36071','VI'),
											('0','Tezze Sul Brenta','36056','VI'),
											('0','Tezze Val Sugana','38050','TN'),
											('0','Thiene','36016','VI'),
											('0','Thiesi','07047','SS'),
											('0','Tiana','08020','NU'),
											('0','Tiarno di Sopra','38060','TN'),
											('0','Tiarno di Sotto','38060','TN'),
											('0','Ticchione','65020','PE'),
											('0','Ticengo','26020','CR'),
											('0','Ticineto','15040','AL'),
											('0','Tiedoli','43043','PR'),
											('0','Tiers','39050','BZ'),
											('0','Tiezzo','33082','PN'),
											('0','Tiggiano','73030','LE'),
											('0','Tiglieto','16010','GE'),
											('0','Tiglio','55050','LU'),
											('0','Tigliole','14016','AT'),
											('0','Tignale','25080','BS'),
											('0','Timau','33020','UD'),
											('0','Timoline','25050','BS'),
											('0','Timparello di Luzzi','87040','CS'),
											('0','Tina','10030','TO'),
											('0','Tindari','98060','ME'),
											('0','Tinnura','08010','NU'),
											('0','Tiolo','23033','SO'),
											('0','Tione degli Abruzzi','67020','AQ'),
											('0','Tione di Trento','38079','TN'),
											('0','Tirano','23037','SO'),
											('0','Tirano Stazione','23037','SO'),
											('0','Tires','39050','BZ'),
											('0','Tiria','09087','OR'),
											('0','Tiridduli','08020','NU'),
											('0','Tiriolo','88056','CZ'),
											('0','Tirli','58040','GR'),
											('0','Tirol','39019','BZ'),
											('0','Tirolo','39019','BZ'),
											('0','Tirrenia','56018','PI'),
											('0','Tisens','39010','BZ'),
											('0','Tiser','32020','BL'),
											('0','Tissi','07040','SS'),
											('0','Titignano','05010','TR'),
											('0','Tito','85050','PZ'),
											('0','Tito Scalo','85050','PZ'),
											('0','Tivegna','19020','SP'),
											('0','Tivoli','00019','RM'),
											('0','Tizzana','51039','PT'),
											('0','Tizzano Val Parma','43028','PR'),
											('0','Toano','42010','RE'),
											('0','Tobbiana','51030','PT'),
											('0','Tobia','01030','VT'),
											('0','Toblach','39034','BZ'),
											('0','Tocchi','53015','SI'),
											('0','Tocco Casauria','65028','PE'),
											('0','Tocco Caudio','82030','BN'),
											('0','Toceno','28858','VB'),
											('0','Todi','06059','PG'),
											('0','Todiano','06040','PG'),
											('0','Toffia','02039','RI'),
											('0','Toirano','17055','SV'),
											('0','Tol','40040','BO'),
											('0','Tolentino','62029','MC'),
											('0','Tolfa','00059','RM'),
											('0','Toline','25055','BS'),
											('0','Toll','39020','BZ'),
											('0','Tolle','45010','RO'),
											('0','Tollegno','13818','BI'),
											('0','Tollo','66010','CH'),
											('0','Tolmezzo','33028','UD'),
											('0','Tolve','85017','PZ'),
											('0','Tomba di Nerone','00189','RM'),
											('0','Tombazosana','37050','VR'),
											('0','Tombolo','35019','PD'),
											('0','Tommaso Natale','90148','PA'),
											('0','Ton','38010','TN'),
											('0','Tonadico','38054','TN'),
											('0','Tonara','08039','NU'),
											('0','Tonco','14039','AT'),
											('0','Tonengo','14023','AT'),
											('0','Tonengo di Mazz','10030','TO'),
											('0','Tonezza del Cimone','36040','VI'),
											('0','Tonfano','55044','LU'),
											('0','Tonnarella','98050','ME'),
											('0','Tontola','47010','FC'),
											('0','Toppo','33090','PN'),
											('0','Tor De\' Cenci','00128','RM'),
											('0','Tor San Lorenzo','00040','RM'),
											('0','Tor Sapienza','00155','RM'),
											('0','Tor Tre Ponti','04013','LT'),
											('0','Tor Vaianica','00040','RM'),
											('0','Tora','81044','CE'),
											('0','Torano','54033','MS'),
											('0','Torano','02029','RI'),
											('0','Torano Castello','87010','CS'),
											('0','Torano Castello Scalo','87010','CS'),
											('0','Torano Nuovo','64010','TE'),
											('0','Torbole Casaglia','25030','BS'),
											('0','Torbole Sul Garda','38069','TN'),
											('0','Torcegno','38050','TN'),
											('0','Torchiara','84076','SA'),
											('0','Torchiaro','63020','AP'),
											('0','Torchiarolo','72020','BR'),
											('0','Torcino','81010','CE'),
											('0','Tordandrea','06088','PG'),
											('0','Tordinia','64040','TE'),
											('0','Torella dei Lombardi','83057','AV'),
											('0','Torella del Sannio','86028','CB'),
											('0','Torelli di Mercogliano','83010','AV'),
											('0','Torello di Melizzano','82030','BN'),
											('0','Torgiano','06089','PG'),
											('0','Torgnon','11020','AO'),
											('0','Torino','10129','TO'),
											('0','Torino','10131','TO'),
											('0','Torino','10146','TO'),
											('0','Torino','10145','TO'),
											('0','Torino','10142','TO'),
											('0','Torino','10141','TO'),
											('0','Torino','10139','TO'),
											('0','Torino','10122','TO'),
											('0','Torino','10153','TO'),
											('0','Torino','10123','TO'),
											('0','Torino','10128','TO'),
											('0','Torino','10127','TO'),
											('0','Torino','10126','TO'),
											('0','Torino','10125','TO'),
											('0','Torino','10124','TO'),
											('0','Torino','10138','TO'),
											('0','Torino','10149','TO'),
											('0','Torino','10100','TO'),
											('0','Torino','10121','TO'),
											('0','Torino','10155','TO'),
											('0','Torino','10151','TO'),
											('0','Torino','10152','TO'),
											('0','Torino','10134','TO'),
											('0','Torino','10148','TO'),
											('0','Torino','10147','TO'),
											('0','Torino','10144','TO'),
											('0','Torino','10143','TO'),
											('0','Torino','10137','TO'),
											('0','Torino','10136','TO'),
											('0','Torino','10135','TO'),
											('0','Torino','10154','TO'),
											('0','Torino di Sangro','66020','CH'),
											('0','Torino di Sangro Stazione','66020','CH'),
											('0','Toritto','70020','BA'),
											('0','Torlino Vimercati','26017','CR'),
											('0','Torlupara di Mentana','00010','RM'),
											('0','Tornaco','28070','NO'),
											('0','Tornano','47030','FC'),
											('0','Tornareccio','66046','CH'),
											('0','Tornata','26030','CR'),
											('0','Tornavento','21010','VA'),
											('0','Torniella','58030','GR'),
											('0','Tornimparte','67049','AQ'),
											('0','Torno','22020','CO'),
											('0','Tornolo','43059','PR'),
											('0','Toro','86018','CB'),
											('0','Torp','08020','NU'),
											('0','Torraca','84030','SA'),
											('0','Torralba','07048','SS'),
											('0','Torrazza Coste','27050','PV'),
											('0','Torrazza Piemonte','10037','TO'),
											('0','Torrazzo','13884','BI'),
											('0','Torre a Mare','70045','BA'),
											('0','Torre Alfina','01020','VT'),
											('0','Torre Angela','00133','RM'),
											('0','Torre Annunziata','80058','NA'),
											('0','Torre Archirafi','95010','CT'),
											('0','Torre Balfredo','10030','TO'),
											('0','Torre Beretti','27030','PV'),
											('0','Torre Boldone','24020','BG'),
											('0','Torre Bormida','12050','CN'),
											('0','Torre Cajetani','03010','FR'),
											('0','Torre Canavese','10010','TO'),
											('0','Torre Canne','72010','BR'),
											('0','Torre Cerchiara','','CS'),
											('0','Torre Cesarea','','LE'),
											('0','Torre Chianca','73100','LE'),
											('0','Torre d\'Arese','27010','PV'),
											('0','Torre De\' Busi','23806','LC'),
											('0','Torre De\' Negri','27011','PV'),
											('0','Torre De\' Passeri','65029','PE'),
											('0','Torre De\' Picenardi','26038','CR'),
											('0','Torre De\' Ratti','15060','AL'),
											('0','Torre De\' Roveri','24060','BG'),
											('0','Torre degli Alberi','27040','PV'),
											('0','Torre dei Calzolari','06020','PG'),
											('0','Torre dei Nolfi','67030','AQ'),
											('0','Torre del Greco','80059','NA'),
											('0','Torre del Lago Puccini','55048','LU'),
											('0','Torre del Moro','47023','FC'),
											('0','Torre del Padiglione','04011','LT'),
											('0','Torre del Pozzo','09073','OR'),
											('0','Torre Dell\'Orso','73026','LE'),
											('0','Torre di Fine','30020','VE'),
											('0','Torre di Mosto','30020','VE'),
											('0','Torre di Palme','63017','AP'),
											('0','Torre di Ruggiero','88060','CZ'),
											('0','Torre di Santa Maria','23020','SO'),
											('0','Torre d\'Isola','27020','PV'),
											('0','Torre Faro','98164','ME'),
											('0','Torre Gaia','00133','RM'),
											('0','Torre Garofoli','15057','AL'),
											('0','Torre Lapillo','73050','LE'),
											('0','Torre Le Nocelle','83030','AV'),
											('0','Torre Maina','41050','MO'),
											('0','Torre Maura','00169','RM'),
											('0','Torre Melissa','88814','KR'),
											('0','Torre Mondov','12080','CN'),
											('0','Torre Mozza','57020','LI'),
											('0','Torre Normanna','90010','PA'),
											('0','Torre Orsaia','84077','SA'),
											('0','Torre Orsina','05030','TR'),
											('0','Torre Pallavicina','24050','BG'),
											('0','Torre Pedrera','47812','RN'),
											('0','Torre Pellice','10066','TO'),
											('0','Torre Piscitelli','80016','NA'),
											('0','Torre San Giorgio','12030','CN'),
											('0','Torre San Patrizio','63010','AP'),
											('0','Torre Santa Susanna','72028','BR'),
											('0','Torre Spaccata','00169','RM'),
											('0','Torreano di Cividale','33040','UD'),
											('0','Torreano di Martignacco','33035','UD'),
											('0','Torrebelvicino','36036','VI'),
											('0','Torrebruna','66050','CH'),
											('0','Torrecandele','98070','ME'),
											('0','Torrechiara','43010','PR'),
											('0','Torrecuso','82030','BN'),
											('0','Torregaveta','80070','NA'),
											('0','Torreglia','35038','PD'),
											('0','Torregrande','09072','OR'),
											('0','Torregrotta','98040','ME'),
											('0','Torremaggiore','71017','FG'),
											('0','Torremezzo','87030','CS'),
											('0','Torremuzza','98070','ME'),
											('0','Torrenieri','53028','SI'),
											('0','Torrenova','98070','ME'),
											('0','Torrenova','00133','RM'),
											('0','Torrepaduli','73040','LE'),
											('0','Torresina','12070','CN'),
											('0','Torretta','90040','PA'),
											('0','Torrette di Ancona','60020','AN'),
											('0','Torrevecchia','87020','CS'),
											('0','Torrevecchia Pia','27010','PV'),
											('0','Torrevecchia Teatina','66010','CH'),
											('0','Torri','51020','PT'),
											('0','Torri','18039','IM'),
											('0','Torri d\'Arcugnano','36057','VI'),
											('0','Torri del Benaco','37010','VR'),
											('0','Torri di Quartesolo','36040','VI'),
											('0','Torri in Sabina','02049','RI'),
											('0','Torriana','47825','RN'),
											('0','Torrice','03020','FR'),
											('0','Torricella','74020','TA'),
											('0','Torricella del Pizzo','26040','CR'),
											('0','Torricella Peligna','66019','CH'),
											('0','Torricella Sabina','02030','RI'),
											('0','Torricella Sicura','64010','TE'),
											('0','Torricella Verzate','27050','PV'),
											('0','Torricola','00178','RM'),
											('0','Torriglia','16029','GE'),
											('0','Torrile','43030','PR'),
											('0','Torrimpietra','00050','RM'),
											('0','Torrio Sopra e Sotto e Casetta','29020','PC'),
											('0','Torrion Quartara','28100','NO'),
											('0','Torrione di Salerno','84127','SA'),
											('0','Torrioni','83010','AV'),
											('0','Torrita','02010','RI'),
											('0','Torrita di Siena','53049','SI'),
											('0','Torrita Stazione','53040','SI'),
											('0','Torrita Tiberina','00060','RM'),
											('0','Torrone di Sulmona','67030','AQ'),
											('0','Torsa di Pocenia','33050','UD'),
											('0','Tortol','08048','NU'),
											('0','Tortona','15057','AL'),
											('0','Tortora','87020','CS'),
											('0','Tortorella','84030','SA'),
											('0','Tortoreto','64018','TE'),
											('0','Tortoreto Lido','64019','TE'),
											('0','Tortorici','98078','ME'),
											('0','Torviscosa','33050','UD'),
											('0','Torza','19010','SP'),
											('0','Toscanella','40060','BO'),
											('0','Toscolano','25088','BS'),
											('0','Tosi','50060','FI'),
											('0','Tossicia','64049','TE'),
											('0','Tossignano','40021','BO'),
											('0','Totari','81011','CE'),
											('0','Tottea','64040','TE'),
											('0','Tottubella','07040','SS'),
											('0','Tovena','31030','TV'),
											('0','Tovo di Sant\'Agata','23030','SO'),
											('0','Tovo San Giacomo','17020','SV'),
											('0','Trabia','90019','PA'),
											('0','Trabia Miniere','93019','CL'),
											('0','Tradate','21049','VA'),
											('0','Trafoi','39020','BZ'),
											('0','Traghetto','44010','FE'),
											('0','Traidodini','08034','NU'),
											('0','Tramariglio','07040','SS'),
											('0','Tramatza','09070','OR'),
											('0','Trambileno','38068','TN'),
											('0','Tramin A.D.Weinstrasse','39040','BZ'),
											('0','Tramonti','84010','SA'),
											('0','Tramonti di Sopra','33090','PN'),
											('0','Tramonti di Sotto','33090','PN'),
											('0','Tramuschio','41037','MO'),
											('0','Tramutola','85057','PZ'),
											('0','Trana','10090','TO'),
											('0','Trani','70059','BA'),
											('0','Transacqua','38054','TN'),
											('0','Traona','23019','SO'),
											('0','Trapani','91100','TP'),
											('0','Trappa','12070','CN'),
											('0','Trappeto','90040','PA'),
											('0','Trappeto','95030','CT'),
											('0','Trappitello','98030','ME'),
											('0','Trarego Viggiona','28826','VB'),
											('0','Trarivi','47854','RN'),
											('0','Trasacco','67059','AQ'),
											('0','Trasaghis','33010','UD'),
											('0','Trasanni','61029','PU'),
											('0','Trasquera','28868','VB'),
											('0','Trassilico','55020','LU'),
											('0','Tratalias','09010','CA'),
											('0','Trausella','10080','TO'),
											('0','Trava','33029','UD'),
											('0','Travac Siccomario','27020','PV'),
											('0','Travagliato','25039','BS'),
											('0','Travale','58020','GR'),
											('0','Travedona Monate','21028','VA'),
											('0','Traverde','54027','MS'),
											('0','Traversa','50030','FI'),
											('0','Traversara','48020','RA'),
											('0','Traversella','10080','TO'),
											('0','Traversetolo','43029','PR'),
											('0','Traves','10070','TO'),
											('0','Travesio','33090','PN'),
											('0','Travo','29020','PC'),
											('0','Tre Croci','01010','VT'),
											('0','Tre Fontane','16020','GE'),
											('0','Tre Fontane','91021','TP'),
											('0','Trebaseleghe','35010','PD'),
											('0','Trebbio','47824','RN'),
											('0','Trebbo di Reno','40013','BO'),
											('0','Trebisacce','87075','CS'),
											('0','Trecasali','43010','PR'),
											('0','Trecase','80040','NA'),
											('0','Trecastagni','95039','CT'),
											('0','Trecate','28069','NO'),
											('0','Trecchina','85049','PZ'),
											('0','Trecella','20060','MI'),
											('0','Trecenta','45027','RO'),
											('0','Treciminiere','64030','TE'),
											('0','Trecroci','89813','VV'),
											('0','Tredozio','47019','FC'),
											('0','Treggiaia','56025','PI'),
											('0','Tregiovo','38028','TN'),
											('0','Treglia','81040','CE'),
											('0','Treglio','66030','CH'),
											('0','Tregnago','37039','VR'),
											('0','Treia','62010','MC'),
											('0','Treiso','12050','CN'),
											('0','Tremenico','23836','LC'),
											('0','Tremensuoli','04020','LT'),
											('0','Tremestieri','98128','ME'),
											('0','Tremestieri Etneo','95030','CT'),
											('0','Tremezzo','22019','CO'),
											('0','Tremignon','35016','PD'),
											('0','Tremiti Isole','','FG'),
											('0','Tremonti','67060','AQ'),
											('0','Tremosine','25010','BS'),
											('0','Trenno','20153','MI'),
											('0','Trenta','87050','CS'),
											('0','Trentinara','84070','SA'),
											('0','Trentino nel Frignano','41021','MO'),
											('0','Trento','38100','TN'),
											('0','Trentola','81038','CE'),
											('0','Trenzano','25030','BS'),
											('0','Trepalle','23030','SO'),
											('0','Treporti','30010','VE'),
											('0','Treppio','51020','PT'),
											('0','Treppo Carnico','33020','UD'),
											('0','Treppo Grande','33010','UD'),
											('0','Trepunti','95010','CT'),
											('0','Trepuzzi','73019','LE'),
											('0','Trequanda','53020','SI'),
											('0','Tres','38010','TN'),
											('0','Tresana','54012','MS'),
											('0','Tresch Conca','36010','VI'),
											('0','Treschietto','54021','MS'),
											('0','Trescore Balneario','24069','BG'),
											('0','Trescore Cremasco','26017','CR'),
											('0','Tresenda','23030','SO'),
											('0','Tresigallo','44039','FE'),
											('0','Tresilico','89010','RC'),
											('0','Tresivio','23020','SO'),
											('0','Tresnuraghes','09079','OR'),
											('0','Trespiano','50010','FI'),
											('0','Trestina','06018','PG'),
											('0','Tret','38013','TN'),
											('0','Tretto','36030','VI'),
											('0','Trevenzuolo','37060','VR'),
											('0','Trevi','06039','PG'),
											('0','Trevi nel Lazio','03010','FR'),
											('0','Trevico','83058','AV'),
											('0','Treviglio','24047','BG'),
											('0','Trevignano','31040','TV'),
											('0','Trevignano Romano','00069','RM'),
											('0','Treville','15030','AL'),
											('0','Trevinano','01020','VT'),
											('0','Treviolo','24048','BG'),
											('0','Trevisago','21030','VA'),
											('0','Treviso','31100','TV'),
											('0','Treviso Bresciano','25074','BS'),
											('0','Trevozzo','29010','PC'),
											('0','Trezzano Rosa','20060','MI'),
											('0','Trezzano Sul Naviglio','20090','MI'),
											('0','Trezzo Sull\'Adda','20056','MI'),
											('0','Trezzo Tinella','12050','CN'),
											('0','Trezzone','22010','CO'),
											('0','Triana','58050','GR'),
											('0','Triangia','23100','SO'),
											('0','Tribano','35020','PD'),
											('0','Tribiano','20067','MI'),
											('0','Tribogna','16030','GE'),
											('0','Tricalle','66100','CH'),
											('0','Tricarico','75019','MT'),
											('0','Tricase','73039','LE'),
											('0','Tricase Porto','73030','LE'),
											('0','Tricerro','13038','VC'),
											('0','Tricesimo','33019','UD'),
											('0','Trichiana','32028','BL'),
											('0','Triei','08040','NU'),
											('0','Trieste','34100','TS'),
											('0','Triggianello','70046','BA'),
											('0','Triggiano','70019','BA'),
											('0','Trignano nel Frignano','41021','MO'),
											('0','Trigolo','26018','CR'),
											('0','Trinit','84030','SA'),
											('0','Trinit','42020','RE'),
											('0','Trinit','12049','CN'),
											('0','Trinit d\'Agultu','07038','SS'),
											('0','Trinitapoli','71049','FG'),
											('0','Trino Vercellese','13039','VC'),
											('0','Trinquelli','60040','AN'),
											('0','Triora','18010','IM'),
											('0','Triparni','89900','VV'),
											('0','Tripi','98060','ME'),
											('0','Tripoli','46030','MN'),
											('0','Triponzo','06040','PG'),
											('0','Trisobbio','15070','AL'),
											('0','Trissino','36070','VI'),
											('0','Trisungo','63043','AP'),
											('0','Tritanti','89020','RC'),
											('0','Trito','70010','BA'),
											('0','Triuggio','20050','MI'),
											('0','Trivento','86029','CB'),
											('0','Trivero','13835','BI'),
											('0','Trivigliano','03010','FR'),
											('0','Trivignano','30030','VE'),
											('0','Trivignano Udinese','33050','UD'),
											('0','Trivigno','85018','PZ'),
											('0','Trivio di Formia','04020','LT'),
											('0','Trivolzio','27020','PV'),
											('0','Trobaso','','VB'),
											('0','Trodena','39040','BZ'),
											('0','Trodica','62010','MC'),
											('0','Trodio','89015','RC'),
											('0','Trofarello','10028','TO'),
											('0','Troghi','50010','FI'),
											('0','Troia','71029','FG'),
											('0','Troina','94018','EN'),
											('0','Tromello','27020','PV'),
											('0','Trontano','28859','VB'),
											('0','Tronzano Lago Maggiore','21010','VA'),
											('0','Tronzano Vercellese','13049','VC'),
											('0','Tropea','89861','VV'),
											('0','Troviggiano','62011','MC'),
											('0','Trovo','27020','PV'),
											('0','Truccazzano','20060','MI'),
											('0','Trucchi','12040','CN'),
											('0','Trucco','18039','IM'),
											('0','Truden','39040','BZ'),
											('0','Tschengels','39020','BZ'),
											('0','Tscherms','39010','BZ'),
											('0','Tubre','39020','BZ'),
											('0','Tuenno','38019','TN'),
											('0','Tufara','86010','CB'),
											('0','Tufara Valle','83010','AV'),
											('0','Tufariello','84030','SA'),
											('0','Tufillo','66050','CH'),
											('0','Tufino','80030','NA'),
											('0','Tufo','83010','AV'),
											('0','Tufo di Carsoli','67060','AQ'),
											('0','Tufo di Minturno','04020','LT'),
											('0','Tuglie','73058','LE'),
											('0','Tuili','09029','CA'),
											('0','Tula','07010','SS'),
											('0','Tuoro','81100','CE'),
											('0','Tuoro Sul Trasimeno','06069','PG'),
											('0','Turania','02020','RI'),
											('0','Turano','54100','MS'),
											('0','Turano Lodigiano','26828','LO'),
											('0','Turas','08010','NU'),
											('0','Turate','22078','CO'),
											('0','Turbigo','20029','MI'),
											('0','Turi','70010','BA'),
											('0','Turri','09020','CA'),
											('0','Turriaco','34070','GO'),
											('0','Turritecava','55020','LU'),
											('0','Turrivalignani','65020','PE'),
											('0','Tursi','75028','MT'),
											('0','Tusa','98079','ME'),
											('0','Tuscania','01017','VT'),
											('0','Tussio','67020','AQ'),
											('0','Tutino','73039','LE'),
											('0','Tuturano','72020','BR'),
											('0','Ubersetto','41040','MO'),
											('0','Ubiale Clanezzo','24010','BG'),
											('0','Uboldo','21040','VA'),
											('0','Ucria','98060','ME'),
											('0','Udine','33100','UD'),
											('0','Ugento','73059','LE'),
											('0','Uggiano La Chiesa','73020','LE'),
											('0','Uggiano Montefusco','74020','TA'),
											('0','Uggiate Trevano','22029','CO'),
											('0','Ugovizza','33010','UD'),
											('0','Ula Tirso','09080','OR'),
											('0','Ulassai','08040','NU'),
											('0','Ulignano','53030','SI'),
											('0','Ulignano','56048','PI'),
											('0','Uliveto Terme','56010','PI'),
											('0','Ulmi','91010','TP'),
											('0','Ulten','39016','BZ'),
											('0','Ultimo','39016','BZ'),
											('0','Ulzio','','TO'),
											('0','Umbertide','06019','PG'),
											('0','Umbra','71018','FG'),
											('0','Umbriatico','88823','KR'),
											('0','Ummari','91010','TP'),
											('0','Unsere Liebe Frau Im Walde','39010','BZ'),
											('0','Untereggen','39050','BZ'),
											('0','Unterinn','39050','BZ'),
											('0','Uppello','06034','PG'),
											('0','Urago d\'Oglio','25030','BS'),
											('0','Uras','09099','OR'),
											('0','Urbana','35040','PD'),
											('0','Urbania','61049','PU'),
											('0','Urbe','17048','SV'),
											('0','Urbignacco','33030','UD'),
											('0','Urbino','61029','PU'),
											('0','Urbisaglia','62010','MC'),
											('0','Urgnano','24059','BG'),
											('0','Uri','07040','SS'),
											('0','Uria','88050','CZ'),
											('0','Urio','22010','CO'),
											('0','Ursini','89040','RC'),
											('0','Ururi','86049','CB'),
											('0','Urzulei','08040','NU'),
											('0','Uscio','16030','GE'),
											('0','Usella','59022','PO'),
											('0','Usellus','09090','OR'),
											('0','Usigliano','56035','PI'),
											('0','Usini','07049','SS'),
											('0','Usmate','20040','MI'),
											('0','Ussana','09020','CA'),
											('0','Ussaramanna','09020','CA'),
											('0','Ussassai','08040','NU'),
											('0','Usseaux','10060','TO'),
											('0','Usseglio','10070','TO'),
											('0','Ussel','11024','AO'),
											('0','Ussita','62039','MC'),
											('0','Ustica','90010','PA'),
											('0','Uta','09010','CA'),
											('0','Uttenheim','39030','BZ'),
											('0','Uzzano e Castello','51010','PT'),
											('0','Vaccareccia','02020','RI'),
											('0','Vaccarezza','29020','PC'),
											('0','Vaccarile','60010','AN'),
											('0','Vaccarizzo Albanese','87060','CS'),
											('0','Vaccarizzo di Montalto','87040','CS'),
											('0','Vaccheria','12050','CN'),
											('0','Vaccheria','81100','CE'),
											('0','Vaccileddi','07020','SS'),
											('0','Vaccolino','44020','FE'),
											('0','Vaciglio','41010','MO'),
											('0','Vacone','02040','RI'),
											('0','Vacri','66010','CH'),
											('0','Vada','57018','LI'),
											('0','Vadena','39051','BZ'),
											('0','Vado','40040','BO'),
											('0','Vado','55041','LU'),
											('0','Vado Ligure','17047','SV'),
											('0','Vaggio','50066','FI'),
											('0','Vagli Sotto','55030','LU'),
											('0','Vaglia','50030','FI'),
											('0','Vagliagli','53010','SI'),
											('0','Vaglie','81044','CE'),
											('0','Vaglierano','14010','AT'),
											('0','Vaglio','13846','BI'),
											('0','Vaglio','41023','MO'),
											('0','Vaglio Basilicata','85010','PZ'),
											('0','Vaglio Serra','14049','AT'),
											('0','Vago','37050','VR'),
											('0','Vahrn','39040','BZ'),
											('0','Vaiano','59021','PO'),
											('0','Vaiano Cremasco','26010','CR'),
											('0','Vaie','10050','TO'),
											('0','Vailate','26019','CR'),
											('0','Vairano Patenora','81058','CE'),
											('0','Vairano Stazione','81059','CE'),
											('0','Vairo','43025','PR'),
											('0','Vajont di Ponte Giulio','33080','PN'),
											('0','Val d\'Assano','81042','CE'),
											('0','Val della Torre','10040','TO'),
											('0','Val di Nizza','27050','PV'),
											('0','Val di Vizze','39049','BZ'),
											('0','Val Durasca','19020','SP'),
											('0','Val Masino','23010','SO'),
											('0','Val Rezzo','22010','CO'),
											('0','Valas','39010','BZ'),
											('0','Valbona','55030','LU'),
											('0','Valbondione','24020','BG'),
											('0','Valbrembo','24030','BG'),
											('0','Valbrevenna','16010','GE'),
											('0','Valbrona','22039','CO'),
											('0','Valbruna','33010','UD'),
											('0','Valcasotto','12080','CN'),
											('0','Valcava','23806','LC'),
											('0','Valcava','38047','TN'),
											('0','Valcimarra','62020','MC'),
											('0','Valconasso','29010','PC'),
											('0','Valda','38030','TN'),
											('0','Valdagno','36078','VI'),
											('0','Valdaora','39030','BZ'),
											('0','Valdastico','36040','VI'),
											('0','Valdengo','13855','BI'),
											('0','Valderice','91019','TP'),
											('0','Valdibrana','51030','PT'),
											('0','Valdicastello Carducci','55040','LU'),
											('0','Valdidentro','23038','SO'),
											('0','Valdieri','12010','CN'),
											('0','Valdina','98040','ME'),
											('0','Valdisotto','23030','SO'),
											('0','Valditacca','43020','PR'),
											('0','Valdivilla','12058','CN'),
											('0','Valdobbiadene','31049','TV'),
											('0','Valdottavo','55067','LU'),
											('0','Valduga','38060','TN'),
											('0','Valduggia','13018','VC'),
											('0','Valeggio Lomellina','27020','PV'),
											('0','Valeggio Sul Mincio','37067','VR'),
											('0','Valentano','01018','VT'),
											('0','Valenza','15048','AL'),
											('0','Valenza','05100','TR'),
											('0','Valenzani','14030','AT'),
											('0','Valenzano','70010','BA'),
											('0','Valera','20039','MI'),
											('0','Valera Fratta','26859','LO'),
											('0','Valeriano','33094','PN'),
											('0','Valestra','42033','RE'),
											('0','Valfabbrica','06029','PG'),
											('0','Valfenera','14017','AT'),
											('0','Valfloriana','38040','TN'),
											('0','Valfurva','23030','SO'),
											('0','Valganna','21039','VA'),
											('0','Valgatara','37020','VR'),
											('0','Valgera','14100','AT'),
											('0','Valgioie','10094','TO'),
											('0','Valgiovo','39040','BZ'),
											('0','Valgoglio','24020','BG'),
											('0','Valgrana','12020','CN'),
											('0','Valgreghentino','23857','LC'),
											('0','Valgrisenche','11010','AO'),
											('0','Valguarnera','94019','EN'),
											('0','Valiano','53040','SI'),
											('0','Vall','31030','TV'),
											('0','Vallada Agordina','32020','BL'),
											('0','Vallalta','41033','MO'),
											('0','Vall\'Alta','24020','BG'),
											('0','Vallanzengo','13847','BI'),
											('0','Vallarsa','38060','TN'),
											('0','Vallata','83059','AV'),
											('0','Valle','41028','MO'),
											('0','Valle Agricola','81010','CE'),
											('0','Valle Aurina','39030','BZ'),
											('0','Valle Benedetta','57124','LI'),
											('0','Valle Canzano','64020','TE'),
											('0','Valle Castellana','64010','TE'),
											('0','Valle Dell\'Angelo','84070','SA'),
											('0','Valle di Cadore','32040','BL'),
											('0','Valle di Casies','39030','BZ'),
											('0','Valle di Maddaloni','81020','CE'),
											('0','Valle di Murialdo','17013','SV'),
											('0','Valle di Saviore','25050','BS'),
											('0','Valle di Teva','61028','PU'),
											('0','Valle Lomellina','27020','PV'),
											('0','Valle Martella','00030','RM'),
											('0','Valle Mosso','13825','BI'),
											('0','Valle Ponticelli','83010','AV'),
											('0','Valle Salimbene','27010','PV'),
											('0','Valle San Bartolomeo','15040','AL'),
											('0','Valle San Felice','38060','TN'),
											('0','Valle San Floriano','36063','VI'),
											('0','Valle San Giovanni','64040','TE'),
											('0','Valle San Nicolao','13847','BI'),
											('0','Valle Sant\'Anastasio','61013','PU'),
											('0','Valle Sauglio','10020','TO'),
											('0','Valle Talloria','12050','CN'),
											('0','Valleandona','14010','AT'),
											('0','Vallebona','18012','IM'),
											('0','Vallebruca','98070','ME'),
											('0','Vallecchia','55040','LU'),
											('0','Vallecorsa','03020','FR'),
											('0','Vallecrosia','18019','IM'),
											('0','Valledolmo','90029','PA'),
											('0','Valledoria','07039','SS'),
											('0','Vallefiorita','88050','CZ'),
											('0','Valleggia','17047','SV'),
											('0','Vallegioliti','15020','AL'),
											('0','Vallelonga','89821','VV'),
											('0','Valleluce','03040','FR'),
											('0','Vallelunga','81010','CE'),
											('0','Vallelunga Pratameno','93010','CL'),
											('0','Vallemaio','03040','FR'),
											('0','Vallemare','02010','RI'),
											('0','Vallemare di Cepagatti','65010','PE'),
											('0','Vallenoncello','33170','PN'),
											('0','Vallepietra','00020','RM'),
											('0','Vallerano','01030','VT'),
											('0','Vallermosa','09010','CA'),
											('0','Vallerona','58050','GR'),
											('0','Vallerotonda','03040','FR'),
											('0','Vallesaccarda','83050','AV'),
											('0','Vallesana','23035','SO'),
											('0','Vallese','37050','VR'),
											('0','Vallesella','32040','BL'),
											('0','Valletanaro','14100','AT'),
											('0','Valleve','24010','BG'),
											('0','Valli del Pasubio','36030','VI'),
											('0','Valli Moceniche','35040','PD'),
											('0','Valliera','45011','RO'),
											('0','Vallinfreda','00020','RM'),
											('0','Vallio Terme','25080','BS'),
											('0','Vallo della Lucania','84078','SA'),
											('0','Vallo di Caluso','10010','TO'),
											('0','Vallo di Nera','06040','PG'),
											('0','Vallo Torinese','10070','TO'),
											('0','Vallombrosa','50060','FI'),
											('0','Vallonara','36063','VI'),
											('0','Valloriate','12010','CN'),
											('0','Valmacca','15040','AL'),
											('0','Valmadonna','15040','AL'),
											('0','Valmadrera','23868','LC'),
											('0','Valmaggia','13019','VC'),
											('0','Valmala','12020','CN'),
											('0','Valmarana','36077','VI'),
											('0','Valmareno','31051','TV'),
											('0','Valmontone','00038','RM'),
											('0','Valmorbia','38060','TN'),
											('0','Valmorea','22070','CO'),
											('0','Valmozzola','43050','PR'),
											('0','Valmozzola Stazione','43050','PR'),
											('0','Valnegra','24010','BG'),
											('0','Valogno','81037','CE'),
											('0','Valpelline','11010','AO'),
											('0','Valperga','10087','TO'),
											('0','Valpiana','58020','GR'),
											('0','Valpone','12043','CN'),
											('0','Valprato Soana','10080','TO'),
											('0','Valpromaro','55068','LU'),
											('0','Valrovina','36061','VI'),
											('0','Valsavarenche','11010','AO'),
											('0','Valsecca','24030','BG'),
											('0','Valsinni','75029','MT'),
											('0','Valsolda','22010','CO'),
											('0','Valsorda','38049','TN'),
											('0','Valstagna','36020','VI'),
											('0','Valstrona','28897','VB'),
											('0','Valtesse','24123','BG'),
											('0','Valtina','39010','BZ'),
											('0','Valtopina','06030','PG'),
											('0','Valtorta','24010','BG'),
											('0','Valtournenche','11028','AO'),
											('0','Valva','84020','SA'),
											('0','Valvasone','33098','PN'),
											('0','Valverde','27050','PV'),
											('0','Valverde','95028','CT'),
											('0','Valvestino','25080','BS'),
											('0','Valvori','03040','FR'),
											('0','Vandoies','39030','BZ'),
											('0','Vandorno','13900','BI'),
											('0','Vandra','86080','IS'),
											('0','Vaneze di Bondone','38040','TN'),
											('0','Vanga','39050','BZ'),
											('0','Vangadizza','37040','VR'),
											('0','Vanzaghello','20020','MI'),
											('0','Vanzago','20010','MI'),
											('0','Vanze','73029','LE'),
											('0','Vanzone Con San Carlo','28879','VB'),
											('0','Vaprio d\'Adda','20069','MI'),
											('0','Vaprio d\'Agogna','28010','NO'),
											('0','Vara','17048','SV'),
											('0','Varago','31052','TV'),
											('0','Varallo','13019','VC'),
											('0','Varallo Pombia','28040','NO'),
											('0','Varana','41028','MO'),
											('0','Varano','60029','AN'),
											('0','Varano Borghi','21020','VA'),
											('0','Varano De\' Melegari','43040','PR'),
											('0','Varano dei Marchesi','43040','PR'),
											('0','Varapodio','89010','RC'),
											('0','Varazze','17019','SV'),
											('0','Varcaturo','80014','NA'),
											('0','Varco Sabino','02020','RI'),
											('0','Varedo','20039','MI'),
											('0','Varena','38030','TN'),
											('0','Varengo','15020','AL'),
											('0','Varenna','23829','LC'),
											('0','Varese','21100','VA'),
											('0','Varese Ligure','19028','SP'),
											('0','Variglie','14100','AT'),
											('0','Varigotti','17029','SV'),
											('0','Varisella','10070','TO'),
											('0','Varlungo','50136','FI'),
											('0','Varmo','33030','UD'),
											('0','Varna','50050','FI'),
											('0','Varna','39040','BZ'),
											('0','Varone','38060','TN'),
											('0','Varoni','82016','BN'),
											('0','Varsi','43049','PR'),
											('0','Varzi','27057','PV'),
											('0','Varzo','28868','VB'),
											('0','Vas','32030','BL'),
											('0','Vasanello','01030','VT'),
											('0','Vascon','31050','TV'),
											('0','Vasia','18100','IM'),
											('0','Vasio','38013','TN'),
											('0','Vaste','73030','LE'),
											('0','Vasto','66054','CH'),
											('0','Vasto Marina','66055','CH'),
											('0','Vastogirardi','86089','IS'),
											('0','Vaticano','',''),
											('0','Vatolla','84070','SA'),
											('0','Vattaro','38049','TN'),
											('0','Vauda Canavese','10070','TO'),
											('0','Vazia','02010','RI'),
											('0','Vazzano','89834','VV'),
											('0','Vazzola','31028','TV'),
											('0','Vecchiano','56019','PI'),
											('0','Vecchiarello','','CS'),
											('0','Vecchiazzano','47100','FC'),
											('0','Vedano Al Lambro','20057','MI'),
											('0','Vedano Olona','21040','VA'),
											('0','Veddasca','21010','VA'),
											('0','Vedegheto','40060','BO'),
											('0','Vedelago','31050','TV'),
											('0','Vedeseta','24010','BG'),
											('0','Vedrana','40054','BO'),
											('0','Vedronza','33010','UD'),
											('0','Veduggio Con Colzano','20050','MI'),
											('0','Veggia','42010','RE'),
											('0','Veggiano','35030','PD'),
											('0','Veglie','73010','LE'),
											('0','Veglio','13824','BI'),
											('0','Vejano','01010','VT'),
											('0','Velate Milanese','20040','MI'),
											('0','Veleso','22020','CO'),
											('0','Velezzo Lomellina','27020','PV'),
											('0','Vellano','51010','PT'),
											('0','Velletri','00049','RM'),
											('0','Vellezzo Bellini','27010','PV'),
											('0','Velo d\'Astico','36010','VI'),
											('0','Velo Veronese','37030','VR'),
											('0','Velturno','39040','BZ'),
											('0','Velva','16030','GE'),
											('0','Vena','95010','CT'),
											('0','Vena Superiore','89900','VV'),
											('0','Venafro','86079','IS'),
											('0','Venagrande','63040','AP'),
											('0','Venalzio','10050','TO'),
											('0','Venaria','10078','TO'),
											('0','Venarotta','63040','AP'),
											('0','Venas','32040','BL'),
											('0','Venasca','12020','CN'),
											('0','Venaus','10050','TO'),
											('0','Venc','34070','GO'),
											('0','Vendone','17032','SV'),
											('0','Vendrogno','23838','LC'),
											('0','Venegazz','31040','TV'),
											('0','Venegono Inferiore','21040','VA'),
											('0','Venegono Superiore','21040','VA'),
											('0','Venere','67050','AQ'),
											('0','Veneri','51010','PT'),
											('0','Venetico','98040','ME'),
											('0','Venetico Marina','98040','ME'),
											('0','Venezia','30131','VE'),
											('0','Venezia','30121','VE'),
											('0','Venezia','30123','VE'),
											('0','Venezia','30125','VE'),
											('0','Venezia','30100','VE'),
											('0','Venezia','30132','VE'),
											('0','Venezia','30135','VE'),
											('0','Venezia','30171','VE'),
											('0','Venezia','30172','VE'),
											('0','Venezia','30124','VE'),
											('0','Venezia Aeroporto Marco Polo','30030','VE'),
											('0','Venezia Mestre','30170','VE'),
											('0','Veniano','22070','CO'),
											('0','Venosa','85029','PZ'),
											('0','Venticano','83030','AV'),
											('0','Ventimiglia','18039','IM'),
											('0','Ventimiglia di Sicilia','90020','PA'),
											('0','Ventotene','04020','LT'),
											('0','Venturina','57029','LI'),
											('0','Venusio','75100','MT'),
											('0','Venzone','33010','UD'),
											('0','Veppo','19020','SP'),
											('0','Verano','39010','BZ'),
											('0','Verano Brianza','20050','MI'),
											('0','Verbania','28900','VB'),
											('0','Verbicaro','87020','CS'),
											('0','Vercana','22013','CO'),
											('0','Verceia','23020','SO'),
											('0','Vercelli','13100','VC'),
											('0','Verchiano','06030','PG'),
											('0','Vercurago','23808','LC'),
											('0','Verdellino','24049','BG'),
											('0','Verdello','24049','BG'),
											('0','Verderio Inferiore','23879','LC'),
											('0','Verderio Superiore','23878','LC'),
											('0','Verdesina','38080','TN'),
											('0','Verduno','12060','CN'),
											('0','Verezzo','18038','IM'),
											('0','Vergano di Borgomanero','28021','NO'),
											('0','Vergato','40038','BO'),
											('0','Vergemoli','55020','LU'),
											('0','Verghera','21010','VA'),
											('0','Verghereto','47028','FC'),
											('0','Vergiano','47828','RN'),
											('0','Vergiate','21029','VA'),
											('0','Vergnacco','33010','UD'),
											('0','Vergnasco','13882','BI'),
											('0','Verica','41026','MO'),
											('0','Verla','38030','TN'),
											('0','Vermegliano','34077','GO'),
											('0','Vermezzo','20080','MI'),
											('0','Vermicino','00044','RM'),
											('0','Vermiglio','38029','TN'),
											('0','Verna','','AR'),
											('0','Vernante','12019','CN'),
											('0','Vernasca','29010','PC'),
											('0','Vernate','20080','MI'),
											('0','Vernazza','19018','SP'),
											('0','Vernio','59024','PO'),
											('0','Vernole','73029','LE'),
											('0','Verocai','32043','BL'),
											('0','Verolanuova','25028','BS'),
											('0','Verolavecchia','25029','BS'),
											('0','Verolengo','10038','TO'),
											('0','Veroli','03029','FR'),
											('0','Verona','37100','VR'),
											('0','Veronella','37040','VR'),
											('0','Verrand','11010','AO'),
											('0','Verrayes','11020','AO'),
											('0','Verrecchie','67060','AQ'),
											('0','Verres','11029','AO'),
											('0','Verretto','27053','PV'),
											('0','Verrone','13871','BI'),
											('0','Verrua Po','27040','PV'),
											('0','Verrua Savoia','10020','TO'),
											('0','Versa','34076','GO'),
											('0','Versano','81057','CE'),
											('0','Vert','11020','AO'),
											('0','Vertemate Con Minoprio','22070','CO'),
											('0','Vertova','24029','BG'),
											('0','Verucchio','47826','RN'),
											('0','Veruno','28010','NO'),
											('0','Vervio','23030','SO'),
											('0','Verv','38010','TN'),
											('0','Verza','29100','PC'),
											('0','Verzegnis','33020','UD'),
											('0','Verzella','95010','CT'),
											('0','Verzino','88819','KR'),
											('0','Verzuolo','12039','CN'),
											('0','Vesale','41029','MO'),
											('0','Vescovana','35040','PD'),
											('0','Vescovato','26039','CR'),
											('0','Vesime','14059','AT'),
											('0','Vesio','25010','BS'),
											('0','Vespolate','28079','NO'),
											('0','Vessa','47026','FC'),
											('0','Vessalico','18026','IM'),
											('0','Vestea','65010','PE'),
											('0','Vestenanova','37030','VR'),
											('0','Vestign','10030','TO'),
											('0','Vestone','25078','BS'),
											('0','Vestreno','23835','LC'),
											('0','Vetrale','84060','SA'),
											('0','Vetralla','01019','VT'),
											('0','Vetriolo','01020','VT'),
											('0','Vettica Pastena','84011','SA'),
											('0','Vetto','42020','RE'),
											('0','Vetulonia','58040','GR'),
											('0','Veveri','28100','NO'),
											('0','Vezza d\'Alba','12040','CN'),
											('0','Vezza d\'Oglio','25059','BS'),
											('0','Vezzano','38070','TN'),
											('0','Vezzano','43020','PR'),
											('0','Vezzano Ligure','19020','SP'),
											('0','Vezzano Sul Crostolo','42030','RE'),
											('0','Vezzi Portio','17028','SV'),
											('0','Vezzo','28839','VB'),
											('0','Vezzola','42010','RE'),
											('0','Via dei Romani','12030','CN'),
											('0','Via Larga','41015','MO'),
											('0','Via Piana','61029','PU'),
											('0','Viaccia','59100','PO'),
											('0','Viadana','46019','MN'),
											('0','Viadanica','24060','BG'),
											('0','Viagrande','95029','CT'),
											('0','Vialba','20157','MI'),
											('0','Viale','14014','AT'),
											('0','Vialfr','10090','TO'),
											('0','Vianino','43040','PR'),
											('0','Viano','42030','RE'),
											('0','Viarago','38057','TN'),
											('0','Viareggio','55049','LU'),
											('0','Viarigi','14030','AT'),
											('0','Viarolo','43010','PR'),
											('0','Viatosto','14100','AT'),
											('0','Viazzano','43040','PR'),
											('0','Vibo Valentia','89900','VV'),
											('0','Vibo Valentia Marina','89811','VV'),
											('0','Vibonati','84079','SA'),
											('0','Vicalvi','03030','FR'),
											('0','Vicarello','57019','LI'),
											('0','Vicarello','00069','RM'),
											('0','Vicari','90020','PA'),
											('0','Vicchio','50039','FI'),
											('0','Vicenza','36100','VI'),
											('0','Viciomaggio','52040','AR'),
											('0','Vico','87050','CS'),
											('0','Vico Canavese','10080','TO'),
											('0','Vico del Gargano','71018','FG'),
											('0','Vico d\'Elsa','50050','FI'),
											('0','Vico di Palma','80036','NA'),
											('0','Vico Equense','80069','NA'),
											('0','Vico Matrino','01012','VT'),
											('0','Vico nel Lazio','03010','FR'),
											('0','Vicobarone','29010','PC'),
											('0','Vicobellignano','26041','CR'),
											('0','Vicofertile','43040','PR'),
											('0','Vicoforte','12080','CN'),
											('0','Vicoli','65010','PE'),
											('0','Vicolungo','28060','NO'),
											('0','Vicomero','43031','PR'),
											('0','Vicomoscano','26040','CR'),
											('0','Viconago','21031','VA'),
											('0','Viconovo','44020','FE'),
											('0','Vicopisano','56010','PI'),
											('0','Vicovaro','00029','RM'),
											('0','Viddalba','07030','SS'),
											('0','Vidiciatico','40042','BO'),
											('0','Vidigulfo','27018','PV'),
											('0','Vidor','31020','TV'),
											('0','Vidracco','10080','TO'),
											('0','Viepri','06050','PG'),
											('0','Vieste','71019','FG'),
											('0','Vietri di Potenza','85058','PZ'),
											('0','Vietri Sul Mare','84019','SA'),
											('0','Vieyes','11012','AO'),
											('0','Vigalzano','38057','TN'),
											('0','Viganella','28841','VB'),
											('0','Vigan','23897','LC'),
											('0','Vigano San Martino','24060','BG'),
											('0','Vigarano Mainarda','44049','FE'),
											('0','Vigarano Pieve','44018','FE'),
											('0','Vigasio','37068','VR'),
											('0','Vigatto','43010','PR'),
											('0','Vigevano','27029','PV'),
											('0','Viggianello','85040','PZ'),
											('0','Viggiano','85059','PZ'),
											('0','Viggi','21059','VA'),
											('0','Vighizzolo d\'Este','35040','PD'),
											('0','Vighizzolo di Cant','22060','CO'),
											('0','Vigiljoch','39010','BZ'),
											('0','Vigliano','67010','AQ'),
											('0','Vigliano Biellese','13856','BI'),
											('0','Vigliano d\'Asti','14040','AT'),
											('0','Vigliatore','98050','ME'),
											('0','Vigna di Valle','00062','RM'),
											('0','Vignacastrisi','73030','LE'),
											('0','Vignale','84099','SA'),
											('0','Vignale','28070','NO'),
											('0','Vignale Monferrato','15049','AL'),
											('0','Vignale Riotorto','57020','LI'),
											('0','Vignanello','01039','VT'),
											('0','Vignate','20060','MI'),
											('0','Vigne','07014','SS'),
											('0','Vigne di Castrovillari','87010','CS'),
											('0','Vigne di Colle Mattia','00030','RM'),
											('0','Vigne di Narni','05030','TR'),
											('0','Vignola','38057','TN'),
											('0','Vignola','41058','MO'),
											('0','Vignola','54027','MS'),
											('0','Vignola Lu Colbu','07030','SS'),
											('0','Vignole Borbera','15060','AL'),
											('0','Vignolo','12010','CN'),
											('0','Vignone','28819','VB'),
											('0','Vigo Anaunia','38010','TN'),
											('0','Vigo Cavedine','38073','TN'),
											('0','Vigo di Cadore','32040','BL'),
											('0','Vigo di Fassa','38039','TN'),
											('0','Vigo di Ton','38010','TN'),
											('0','Vigo Lomaso','38070','TN'),
											('0','Vigo Rendena','38080','TN'),
											('0','Vigodarzere','35010','PD'),
											('0','Vigoleno','29010','PC'),
											('0','Vigolo','24060','BG'),
											('0','Vigolo Baselga','38070','TN'),
											('0','Vigolo Marchese','29010','PC'),
											('0','Vigolo Vattaro','38049','TN'),
											('0','Vigolzone','29020','PC'),
											('0','Vigone','10067','TO'),
											('0','Vigonovo','33074','PN'),
											('0','Vigonovo','30030','VE'),
											('0','Vigonza','35010','PD'),
											('0','Viguzzolo','15058','AL'),
											('0','Villa a Roggio','55060','LU'),
											('0','Villa Adriana','00010','RM'),
											('0','Villa Agnedo','38059','TN'),
											('0','Villa Badessa','65010','PE'),
											('0','Villa Baggio','51030','PT'),
											('0','Villa Baldassarri','73010','LE'),
											('0','Villa Banale','38070','TN'),
											('0','Villa Bartolomea','37049','VR'),
											('0','Villa Basilica','55019','LU'),
											('0','Villa Bianca','41054','MO'),
											('0','Villa Bigioni','02010','RI'),
											('0','Villa Biscossi','27035','PV'),
											('0','Villa Botteri','15070','AL'),
											('0','Villa Bozza','64030','TE'),
											('0','Villa Caldari','66020','CH'),
											('0','Villa Campanile','56020','PI'),
											('0','Villa Canale','86081','IS'),
											('0','Villa Carcina','25069','BS'),
											('0','Villa Carmine','65016','PE'),
											('0','Villa Castelli','72029','BR'),
											('0','Villa Castelnuovo','10080','TO'),
											('0','Villa Celiera','65010','PE'),
											('0','Villa Cipresso','65010','PE'),
											('0','Villa Col De\' Canali','06020','PG'),
											('0','Villa Collemandina','55030','LU'),
											('0','Villa Convento','73050','LE'),
											('0','Villa Cortese','20020','MI'),
											('0','Villa d\'Adda','24030','BG'),
											('0','Villa d\'Adige','45021','RO'),
											('0','Villa d\'Agri','85050','PZ'),
											('0','Villa d\'Aiano','40034','BO'),
											('0','Villa d\'Alm','24018','BG'),
											('0','Villa del Bosco','13868','BI'),
											('0','Villa del Conte','35010','PD'),
											('0','Villa del Foro','15020','AL'),
											('0','Villa di Briano','81030','CE'),
											('0','Villa di Chiavenna','23029','SO'),
											('0','Villa di Serio','24020','BG'),
											('0','Villa di Teolo','35033','PD'),
											('0','Villa di Tirano','23030','SO'),
											('0','Villa di Tresana','54010','MS'),
											('0','Villa di Villa','32020','BL'),
											('0','Villa d\'Ogna','24020','BG'),
											('0','Villa d\'Orri','09018','CA'),
											('0','Villa Elce','66030','CH'),
											('0','Villa Estense','35040','PD'),
											('0','Villa Faraldi','18016','IM'),
											('0','Villa Fastiggi','61100','PU'),
											('0','Villa Favale','64010','TE'),
											('0','Villa Fontana','40059','BO'),
											('0','Villa Fornaci','20060','MI'),
											('0','Villa Ganzerla','36020','VI'),
											('0','Villa Garibaldi','46037','MN'),
											('0','Villa Guardia','22079','CO'),
											('0','Villa Lagarina','38060','TN'),
											('0','Villa Latina','03040','FR'),
											('0','Villa Lempa','64010','TE'),
											('0','Villa Literno','81039','CE'),
											('0','Villa Littorio','84070','SA'),
											('0','Villa Minozzo','42030','RE'),
											('0','Villa Moscosi','62011','MC'),
											('0','Villa Musone','60025','AN'),
											('0','Villa Oliveti','65010','PE'),
											('0','Villa Opicina','34016','TS'),
											('0','Villa Ottone','39030','BZ'),
											('0','Villa Pasquali','46010','MN'),
											('0','Villa Passo','64010','TE'),
											('0','Villa Paterno','64010','TE'),
											('0','Villa Pedergnano','25030','BS'),
											('0','Villa Petto','64030','TE'),
											('0','Villa Poma','46020','MN'),
											('0','Villa Potenza','62010','MC'),
											('0','Villa Raspa','65010','PE'),
											('0','Villa Raverio','20050','MI'),
											('0','Villa Rendena','38080','TN'),
											('0','Villa Ripa','64040','TE'),
											('0','Villa Romagnoli','66030','CH'),
											('0','Villa Romana','67060','AQ'),
											('0','Villa Rosa di Martinsicuro','64010','TE'),
											('0','Villa Rovere','47010','FC'),
											('0','Villa Saletta','56036','PI'),
											('0','Villa San Faustino','06050','PG'),
											('0','Villa San Filippo','62015','MC'),
											('0','Villa San Giovanni','65010','PE'),
											('0','Villa San Giovanni','89018','RC'),
											('0','Villa San Giovanni in Tuscia','01010','VT'),
											('0','Villa San Giuseppe','63030','AP'),
											('0','Villa San Giuseppe','89050','RC'),
											('0','Villa San Martino','48020','RA'),
											('0','Villa San Martino','61100','PU'),
											('0','Villa San Michele','86083','IS'),
											('0','Villa San Pietro','09010','CA'),
											('0','Villa San Romualdo','64030','TE'),
											('0','Villa San Sebastiano','67060','AQ'),
											('0','Villa San Secondo','14020','AT'),
											('0','Villa San Vincenzo','66030','CH'),
											('0','Villa Santa Croce','81013','CE'),
											('0','Villa Santa Lucia','03030','FR'),
											('0','Villa Santa Lucia degli Abruzzi','67020','AQ'),
											('0','Villa Santa Maria','66047','CH'),
											('0','Villa Sant\'Angelo','67020','AQ'),
											('0','Villa Sant\'Antonio','09080','OR'),
											('0','Villa Santina','33029','UD'),
											('0','Villa Santo Stefano','03020','FR'),
											('0','Villa Saviola','46020','MN'),
											('0','Villa Scontrone','67030','AQ'),
											('0','Villa Serraglio','48024','RA'),
											('0','Villa Torre','62011','MC'),
											('0','Villa Tucci','66010','CH'),
											('0','Villa Verde','09090','OR'),
											('0','Villa Verucchio','47827','RN'),
											('0','Villa Vicentina','33059','UD'),
											('0','Villa Vomano','64020','TE'),
											('0','Villabassa','39039','BZ'),
											('0','Villabate','90039','PA'),
											('0','Villabella','15036','AL'),
											('0','Villaberza','42038','RE'),
											('0','Villabruna','32030','BL'),
											('0','Villachiara','25030','BS'),
											('0','Villacidro','09039','CA'),
											('0','Villadeati','15020','AL'),
											('0','Villadoro','94010','EN'),
											('0','Villadose','45010','RO'),
											('0','Villadossola','28844','VB'),
											('0','Villafalletto','12020','CN'),
											('0','Villafontana','37050','VR'),
											('0','Villafranca','47010','FC'),
											('0','Villafranca d\'Asti','14018','AT'),
											('0','Villafranca di Medolla','41036','MO'),
											('0','Villafranca di Verona','37069','VR'),
											('0','Villafranca in Lunigiana','54028','MS'),
											('0','Villafranca Padovana','35010','PD'),
											('0','Villafranca Piemonte','10068','TO'),
											('0','Villafranca Sicula','92020','AG'),
											('0','Villafranca Tirrena','98049','ME'),
											('0','Villafrati','90030','PA'),
											('0','Villaga','36021','VI'),
											('0','Villaggi','13856','BI'),
											('0','Villaggio Aldisio','98147','ME'),
											('0','Villaggio Annunziata','98168','ME'),
											('0','Villaggio Bucchi','88900','KR'),
											('0','Villaggio Coppola Pinetamare','81030','CE'),
											('0','Villaggio dei Giovi','20051','MI'),
											('0','Villaggio Garbagnate','20020','MI'),
											('0','Villaggio Madonna Delle Grazie','91024','TP'),
											('0','Villaggio Mancuso','88055','CZ'),
											('0','Villaggio Mos','92100','AG'),
											('0','Villaggio Paradiso','98168','ME'),
											('0','Villaggio Racise','88055','CZ'),
											('0','Villaggio San Francesco','95030','CT'),
											('0','Villaggio San Marco','30173','VE'),
											('0','Villaggio Santa Barbara','93010','CL'),
											('0','Villaggio Snia','20030','MI'),
											('0','Villaggio Sondalo','23039','SO'),
											('0','Villaggio Turistico Citt del Mare','90040','PA'),
											('0','Villaggio Turistico di Borca di Cadore','32040','BL'),
											('0','Villagrande','66020','CH'),
											('0','Villagrande Strisaili','08049','NU'),
											('0','Villagrazia','90148','PA'),
											('0','Villagrazia di Carini','90040','PA'),
											('0','Villagreca','09024','CA'),
											('0','Villalago','67030','AQ'),
											('0','Villalba','93010','CL'),
											('0','Villalba','00011','RM'),
											('0','Villalfonsina','66020','CH'),
											('0','Villalta','47040','FC'),
											('0','Villalvernia','15050','AL'),
											('0','Villamagna','56040','PI'),
											('0','Villamagna','66010','CH'),
											('0','Villamaina','83050','AV'),
											('0','Villamar','09020','CA'),
											('0','Villamarzana','45030','RO'),
											('0','Villamassargia','09010','CA'),
											('0','Villamesa','89050','RC'),
											('0','Villamiroglio','15020','AL'),
											('0','Villammare','84070','SA'),
											('0','Villanders','39040','BZ'),
											('0','Villandro','39040','BZ'),
											('0','Villaneto','85030','PZ'),
											('0','Villanova','40055','BO'),
											('0','Villanova','65010','PE'),
											('0','Villanova','47100','FC'),
											('0','Villanova Biellese','13877','BI'),
											('0','Villanova Canavese','10070','TO'),
											('0','Villanova d\'Albenga','17038','SV'),
											('0','Villanova d\'Ardenghi','27030','PV'),
											('0','Villanova d\'Asti','14019','AT'),
											('0','Villanova d\'Asti Stazione','14019','AT'),
											('0','Villanova del Battista','83030','AV'),
											('0','Villanova del Ghebbo','45020','RO'),
											('0','Villanova di Bagnacavallo','48020','RA'),
											('0','Villanova di Camposanpiero','35010','PD'),
											('0','Villanova di Denore','44020','FE'),
											('0','Villanova di Fossalta di Portogruaro','30025','VE'),
											('0','Villanova di Guidonia','00010','RM'),
											('0','Villanova di San Daniele','33030','UD'),
											('0','Villanova Marchesana','45030','RO'),
											('0','Villanova Mondov','12089','CN'),
											('0','Villanova Monferrato','15030','AL'),
											('0','Villanova Monteleone','07019','SS'),
											('0','Villanova San Pancrazio','41010','MO'),
											('0','Villanova Santa Margherita','30020','VE'),
											('0','Villanova Sillaro','26818','LO'),
											('0','Villanova Solaro','12030','CN'),
											('0','Villanova Strisaili','08040','NU'),
											('0','Villanova Sull\'Arda','29010','PC'),
											('0','Villanova Truschedu','09084','OR'),
											('0','Villanovaforru','09020','CA'),
											('0','Villanovafranca','09020','CA'),
											('0','Villanovatulo','08030','NU'),
											('0','Villanovetta','12039','CN'),
											('0','Villanterio','27019','PV'),
											('0','Villanuova Sul Clisi','25089','BS'),
											('0','Villapaiera','32030','BL'),
											('0','Villaperuccio','09010','CA'),
											('0','Villapiana','87076','CS'),
											('0','Villapiana Lido','87070','CS'),
											('0','Villapiana Scalo','87070','CS'),
											('0','Villapiccola','32040','BL'),
											('0','Villapriolo','94010','EN'),
											('0','Villaputzu','09040','CA'),
											('0','Villar Dora','10040','TO'),
											('0','Villar Focchiardo','10050','TO'),
											('0','Villar Pellice','10060','TO'),
											('0','Villar Perosa','10069','TO'),
											('0','Villar Sampeyre','12020','CN'),
											('0','Villar San Costanzo','12020','CN'),
											('0','Villaraspa','36064','VI'),
											('0','Villarbasse','10090','TO'),
											('0','Villarboit','13030','VC'),
											('0','Villareggia','10030','TO'),
											('0','Villaregia','45014','RO'),
											('0','Villaretto Chisone','10060','TO'),
											('0','Villaricca','80010','NA'),
											('0','Villarios','09010','CA'),
											('0','Villaromagnano','15050','AL'),
											('0','Villarosa Sicilia','94010','EN'),
											('0','Villarotta','42010','RE'),
											('0','Villasalto','09040','CA'),
											('0','Villasanta','20058','MI'),
											('0','Villascorciosa','66020','CH'),
											('0','Villasimius','09049','CA'),
											('0','Villasmundo','96010','SR'),
											('0','Villasor','09034','CA'),
											('0','Villaspeciosa','09010','CA'),
											('0','Villastanza','20010','MI'),
											('0','Villastellone','10029','TO'),
											('0','Villastrada','46030','MN'),
											('0','Villastrada Umbra','06060','PG'),
											('0','Villata','13010','VC'),
											('0','Villate','10090','TO'),
											('0','Villatora','35020','PD'),
											('0','Villaurbana','09080','OR'),
											('0','Villavallelonga','67050','AQ'),
											('0','Villaverla','36030','VI'),
											('0','Villavesco','20080','MI'),
											('0','Villazzano','38050','TN'),
											('0','Ville','11020','AO'),
											('0','Ville di Fano','67010','AQ'),
											('0','Ville di Lucoli','67040','AQ'),
											('0','Ville Sur Nus','11020','AO'),
											('0','Villefranche','11020','AO'),
											('0','Villeneuve','11018','AO'),
											('0','Villerose','02020','RI'),
											('0','Villesse','34070','GO'),
											('0','Villetta Barrea','67030','AQ'),
											('0','Villetta Sant\'Antonio','02030','RI'),
											('0','Villette','28856','VB'),
											('0','Villimpenta','46039','MN'),
											('0','Villnoss','39040','BZ'),
											('0','Vill','29020','PC'),
											('0','Villongo','24060','BG'),
											('0','Villorba','31020','TV'),
											('0','Villore','50039','FI'),
											('0','Villotta','33083','PN'),
											('0','Vilminore di Scalve','24020','BG'),
											('0','Vilpian','39010','BZ'),
											('0','Vilpiano','39010','BZ'),
											('0','Vimercate','20059','MI'),
											('0','Vimodrone','20090','MI'),
											('0','Vinadio','12010','CN'),
											('0','Vinca','54020','MS'),
											('0','Vinchiana','55050','LU'),
											('0','Vinchiaturo','86019','CB'),
											('0','Vinchio','14040','AT'),
											('0','Vinci','50059','FI'),
											('0','Vinco','89060','RC'),
											('0','Vindicio di Formia','04020','LT'),
											('0','Vindoli','02016','RI'),
											('0','Vinovo','10048','TO'),
											('0','Vintebbio','13037','VC'),
											('0','Vintl','39030','BZ'),
											('0','Vinzaglio','28060','NO'),
											('0','Viola','12070','CN'),
											('0','Viole di Assisi','06080','PG'),
											('0','Vione','25050','BS'),
											('0','Vipiteno','39049','BZ'),
											('0','Virgilio','46030','MN'),
											('0','Virgoletta','54028','MS'),
											('0','Virle Piemonte','10060','TO'),
											('0','Virle Treponti','25086','BS'),
											('0','Visano','25010','BS'),
											('0','Vische','10030','TO'),
											('0','Visciano','80030','NA'),
											('0','Visciano','81042','CE'),
											('0','Visco','33040','UD'),
											('0','Viserba','47811','RN'),
											('0','Viserbella','47811','RN'),
											('0','Visinale','33087','PN'),
											('0','Visn','31028','TV'),
											('0','Visnadello','31027','TV'),
											('0','Visome','32020','BL'),
											('0','Visone','15010','AL'),
											('0','Visso','62039','MC'),
											('0','Vistarino','27010','PV'),
											('0','Vistrorio','10080','TO'),
											('0','Vita','91010','TP'),
											('0','Viterbo','01100','VT'),
											('0','Viticuso','03040','FR'),
											('0','Vitigliano','73030','LE'),
											('0','Vitigliano','73030','LE'),
											('0','Vitignano','47014','FC'),
											('0','Vitinia','00127','RM'),
											('0','Vito','89060','RC'),
											('0','Vito d\'Asio','33090','PN'),
											('0','Vitolini','50050','FI'),
											('0','Vitorchiano','01030','VT'),
											('0','Vitorchiano Stazione','01030','VT'),
											('0','Vitriola','41045','MO'),
											('0','Vittoria','97019','RG'),
											('0','Vittorio Veneto','31029','TV'),
											('0','Vittorito','67030','AQ'),
											('0','Vittuone','20010','MI'),
											('0','Vitulano','82038','BN'),
											('0','Vitulazio','81041','CE'),
											('0','Vi','10070','TO'),
											('0','Vivaro','33099','PN'),
											('0','Vivaro Romano','00020','RM'),
											('0','Viverone','13886','BI'),
											('0','Vivo d\'Orcia','53020','SI'),
											('0','Vizze','39040','BZ'),
											('0','Vizzero','40045','BO'),
											('0','Vizzini','95049','CT'),
											('0','Vizzola Ticino','21010','VA'),
											('0','Vizzolo Predabissi','20070','MI'),
											('0','Vo','35030','PD'),
											('0','Vo Vecchio','35030','PD'),
											('0','Vobarno','25079','BS'),
											('0','Vobbia','16010','GE'),
											('0','Vocca','13020','VC'),
											('0','Vocogno','28852','VB'),
											('0','Vodo Cadore','32040','BL'),
											('0','Voghera','27058','PV'),
											('0','Voghiera','44019','FE'),
											('0','Vogogna','28805','VB'),
											('0','Volania','44022','FE'),
											('0','Volano','38060','TN'),
											('0','Volargne','37020','VR'),
											('0','Voldomino','21016','VA'),
											('0','Volla','80040','NA'),
											('0','Vologno','42035','RE'),
											('0','Volongo','26030','CR'),
											('0','Volpago del Montello','31040','TV'),
											('0','Volpara','27047','PV'),
											('0','Volpedo','15059','AL'),
											('0','Volpeglino','15050','AL'),
											('0','Volpiano','10088','TO'),
											('0','Vols Am Schlern','39050','BZ'),
											('0','Volser Aicha','39050','BZ'),
											('0','Volta Mantovana','46049','MN'),
											('0','Voltaggio','15060','AL'),
											('0','Voltago Agordino','32020','BL'),
											('0','Voltana','48028','RA'),
											('0','Volterra','56048','PI'),
											('0','Voltido','26034','CR'),
											('0','Voltre','47010','FC'),
											('0','Voltri','16158','GE'),
											('0','Volturara Appula','71030','FG'),
											('0','Volturara Irpina','83050','AV'),
											('0','Volturino','71030','FG'),
											('0','Volvera','10040','TO'),
											('0','Vomero','80127','NA'),
											('0','Voran','39010','BZ'),
											('0','Vorno','55060','LU'),
											('0','Vottignasco','12020','CN'),
											('0','Vulcano','98050','ME'),
											('0','Waidbruck','39040','BZ'),
											('0','Walten','39010','BZ'),
											('0','Wangen','39050','BZ'),
											('0','Welsberg','39035','BZ'),
											('0','Welschnofen','39056','BZ'),
											('0','Wengen','39030','BZ'),
											('0','Wolkenstein in Groden','39048','BZ'),
											('0','Xitta','91020','TP'),
											('0','Zaccanopoli','89867','VV'),
											('0','Zaccheo','64020','TE'),
											('0','Zafferana Etnea','95019','CT'),
											('0','Zafferia','98127','ME'),
											('0','Zagarise','88050','CZ'),
											('0','Zagarolo','00039','RM'),
											('0','Zambana','38010','TN'),
											('0','Zambrone','89868','VV'),
											('0','Zanano','25068','BS'),
											('0','Zanco','15020','AL'),
											('0','Zancona','58031','GR'),
											('0','Zandobbio','24060','BG'),
											('0','Zan','36010','VI'),
											('0','Zangarona di Lamezia Terme','88046','CZ'),
											('0','Zanica','24050','BG'),
											('0','Zappa','98060','ME'),
											('0','Zapponeta','71030','FG'),
											('0','Zattaglia','48010','RA'),
											('0','Zavattarello','27059','PV'),
											('0','Zeccone','27010','PV'),
											('0','Zeddiani','09070','OR'),
											('0','Zelarino','30174','VE'),
											('0','Zelbio','22020','CO'),
											('0','Zelo','45020','RO'),
											('0','Zelo Buon Persico','26839','LO'),
											('0','Zelo Surrigone','20080','MI'),
											('0','Zeme','27030','PV'),
											('0','Zenevredo','27049','PV'),
											('0','Zenson di Piave','31050','TV'),
											('0','Zenzalino','44034','FE'),
											('0','Zepponami','01020','VT'),
											('0','Zerba','29020','PC'),
											('0','Zerbo','27017','PV'),
											('0','Zerbol','27020','PV'),
											('0','Zerfaliu','09070','OR'),
											('0','Zeri','54029','MS'),
											('0','Zerman','31021','TV'),
											('0','Zermeghedo','36050','VI'),
											('0','Zero Branco','31059','TV'),
											('0','Zevio','37059','VR'),
											('0','Zia Lisa','95121','CT'),
											('0','Zianigo','30035','VE'),
											('0','Ziano di Fiemme','38030','TN'),
											('0','Ziano Piacentino','29010','PC'),
											('0','Zibello','43010','PR'),
											('0','Zibido San Giacomo','20080','MI'),
											('0','Zignago','19020','SP'),
											('0','Zimella','37040','VR'),
											('0','Zimone','13887','BI'),
											('0','Zinasco','27030','PV'),
											('0','Zinasco Nuovo','27030','PV'),
											('0','Zinga','88822','KR'),
											('0','Zingone di Trezzano Sul Naviglio','20090','MI'),
											('0','Zingonia','24040','BG'),
											('0','Zinola','17100','SV'),
											('0','Ziracco','33047','UD'),
											('0','Zoagli','16030','GE'),
											('0','Zocca','41059','MO'),
											('0','Zocco','25030','BS'),
											('0','Zoccorino','20050','MI'),
											('0','Zogno','24019','BG'),
											('0','Zola Predosa','40069','BO'),
											('0','Zoldo Alto','32010','BL'),
											('0','Zollino','73010','LE'),
											('0','Zone','25050','BS'),
											('0','Zone','55010','LU'),
											('0','Zopp','31020','TV'),
											('0','Zopp di Cadore','32010','BL'),
											('0','Zoppola','33080','PN'),
											('0','Zorlesco','26829','LO'),
											('0','Zovencedo','36020','VI'),
											('0','Zubiena','13888','BI'),
											('0','Zuccarello','17039','SV'),
											('0','Zuccaro','13018','VC'),
											('0','Zuclo','38079','TN'),
											('0','Zuel','32043','BL'),
											('0','Zugliano','36030','VI'),
											('0','Zuglio','33020','UD'),
											('0','Zumaglia','13848','BI'),
											('0','Zumpano','87040','CS'),
											('0','Zungoli','83030','AV'),
											('0','Zungri','89867','VV'),
											('0','Zuppino','84020','SA'),
											('0','Zurgonadio','89010','RC'),
											('0','Zuri','09080','OR'),
											('0','Zwischenwasser','39030','BZ');

CREATE TABLE pref_stampante_et
 (
  prefID     bigint(20) unsigned primary key auto_increment,
  m_destro   int(16),
  m_alto     int(16),
  r_oriz     int(16),
  m_sinistro int(16),
  m_basso    int(16),
  r_vert     int(16),
  num_r      int(16),
  num_c      int(16),
  barcodeon  int(1),
  bcodesmall int(1),
  bcodealt   int(16),
  campi_vis  int(5),
  data       date,
  ora        time,
  ts         int(16) unsigned
 );

INSERT INTO pref_stampante_et VALUES ('0',10,10,0,10,10,0,10,3,1,0,60,0,CURDATE(),CURTIME(),UNIX_TIMESTAMP());

CREATE TABLE pref_stampante_in
 (
  prefID     bigint(20) unsigned primary key auto_increment,
  m_destro   int(16),
  m_alto     int(16),
  r_oriz     int(16),
  m_sinistro int(16),
  m_basso    int(16),
  r_vert     int(16),
  num_r      int(16),
  num_c      int(16),
  title_cli  char(255),
  title_for  char(255),
  data       date,
  ora        time,
  ts         int(16) unsigned
 );

INSERT INTO pref_stampante_in VALUES ('0',10,10,0,10,10,0,10,3,'Gentile','Spett.le',CURDATE(),CURTIME(),UNIX_TIMESTAMP());

CREATE TABLE pref_varie
 (
  prefID     bigint(20) unsigned primary key auto_increment,
  password   char(255),
  moneta     char(255),
  mysql_path char(255),
  data_path  char(255),
  db_path    char(255),
  back_path  char(255),
  usepreview int(1),
  data       date,
  ora        time,
  ts         int(16) unsigned
 );

INSERT INTO pref_varie VALUES ('0','password','Euro','C:/mysql','C:/mysql/data','C:/mysql/data/edepol','C:/backup','1',CURDATE(),CURTIME(),UNIX_TIMESTAMP());

CREATE TABLE db
 (
  ver    char(255),
  edepol char(255),
  data   date,
  ora    time,
  ts     int(16) unsigned
 );

INSERT INTO db VALUES ('1.0','Edepol!',CURDATE(),CURTIME(),UNIX_TIMESTAMP());